@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -75,8 +75,13 @@
 
 const int FK_MAJOR_VERSION = 2;
 const int FK_MINOR_VERSION = 8;
-const int FK_SUBMINOR_VERSION = 9;
+const int FK_SUBMINOR_VERSION = 10;
 
+#if defined(_CYGWIN_GCC_)
+#include <math.h>
+#include <stdio.h>
+#include <string>
+#else
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -86,9 +91,10 @@ const int FK_SUBMINOR_VERSION = 9;
 #include <iostream>
 #include <string>
 
-#if !defined(WIN32) || defined(_CYGWIN_GCC_) || defined(_MINGW_)
+#if !defined(WIN32) || defined(_MINGW_)
 
 #include <sys/unistd.h>
+#include <sys/types.h>
 #include <sys/time.h>
 
 #else
@@ -98,6 +104,8 @@ const int FK_SUBMINOR_VERSION = 9;
 #define vsnprintf _vsnprintf
 
 #endif	// !WIN32 || _CYGWIN_GCC_
+#endif
+/* #endif */
 
 const int FK_UNDEFINED = -1;
 
@@ -126,6 +134,8 @@ enum fk_ObjectType {
 	FK_LIGHT,			//!<	fk_Light 型
 	FK_BEZCURVE,		//!<	fk_BezCurve 型
 	FK_BSPLCURVE,		//!<	fk_BSplCurve 型
+	FK_BEZSURFACE,		//!<	fk_BezSurface 型
+	FK_BSPLSURFACE,		//!<	fk_BSplSurface 型
 	FK_IMAGE,			//!<	fk_Image 型
 	FK_TEXCOORD,		//!<	fk_TexCoord 型
 	FK_TEXTURE,			//!<	fk_Texture 型
@@ -230,4 +240,9 @@ class fk_BaseObject {
 using namespace std;
 #endif
 
+#ifdef FK_DEF_SIZETYPE
+#include <vector>
+typedef std::vector<int>::size_type	_st;
+#endif
+
 #endif /* !__FK_BASE_HEADER__ */
