@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -132,6 +132,7 @@ class fk_DisplayLink : public fk_BaseObject {
 	fk_Perspective			stereoPers[2];
 	fk_Frustum				stereoFrus[2];
 	fk_Ortho				stereoOrtho[2];
+	bool					stereoOverlayMode;
 
 	std::list<fk_Model *> *	GetModelList(void);
 	std::list<fk_Model *> *	GetLightList(void);
@@ -145,7 +146,7 @@ class fk_DisplayLink : public fk_BaseObject {
 	fk_DisplayLink(void);
 
 	//! デストラクタ
-	~fk_DisplayLink();
+	virtual ~fk_DisplayLink();
 
 	//!	初期化関数
 	/*!
@@ -311,6 +312,39 @@ class fk_DisplayLink : public fk_BaseObject {
 	 *	\sa entryStereoCamera(), setStereoProjection(), getStereoCamera(), getStereoProjection()
 	 */
 	void					clearStereo(void);
+
+	//! 立体視モード時のオーバーレイ描画モード設定関数
+	/*!
+	 *	立体視モード時のオーバーレイ描画モデルに対する動作を設定します。
+	 *	一般的なゲームアプリケーションでは、3DCG をレンダリングした画面上に
+	 *	2D の画像や文字などを情報として表示(いわゆる HUD 表示)しますが、
+	 *	立体視を有効にした場合はそれらの表示にも視差が適用されます。
+	 *	この動作は状況によっては望ましくない場合もあります。
+	 *	この関数によって、オーバーレイ描画を行うモデルに対して視差を適用するか、
+	 *	しないかを選択することができます。
+	 *	HUD 表示はオーバーレイ描画によって実現することが多いため、
+	 *	多くの場合はこの関数による設定で十分制御が可能となるはずです。
+	 *	デフォルトではオーバーレイ描画モデルにも視差を適用する設定(true)になっています。
+	 *
+	 *	\param[in]	mode
+	 *		true だった場合、オーバーレイ描画モデルの視差を有効にします。
+	 *		false だった場合、オーバーレイ描画モデルの視差を無効にします。
+	 *
+	 *	\sa fk_Window::setOGLStereoMode(), getStereoOverlayMode()
+	 */
+	void	setStereoOverlayMode(bool mode);
+
+	//! 立体視モード時のオーバーレイ描画モード取得関数
+	/*!
+	 *	立体視モード時のオーバーレイ描画モデルに対する動作モードを取得します。
+	 *
+	 *	\return
+	 *		true だった場合、オーバーレイ描画モデルの視差が有効になっています。
+	 *		false だった場合、オーバーレイ描画モデルの視差が無効になっています。
+	 *
+	 *	\sa fk_DisplayLink, setOGLStereoOverlayMode()
+	 */
+	bool	getStereoOverlayMode(void);
 	//@)
 
 };
