@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -224,7 +224,7 @@ class fk_Rect {
  *	画像処理のための基本的な機能を保持しています。
  *	画像データは RGBA 形式で保存されます。
  *	各要素は整数値で最小値は 0、最大値は 255 です。
- *	透過色要素は 0 が完全な不透明、255 が完全な透明を表します。
+ *	透過色要素は 0 が完全な透明、255 が完全な不透明を表します。
  *	現バージョンのピクセルサイズの最大値は縦幅横幅共に 65536 までです。
  *
  *	実際の画像サイズと、格納するデータについての関係は
@@ -240,6 +240,7 @@ class fk_Image : public fk_BaseObject {
 
 	fk_Dimension			imageSize, bufSize;
 	std::vector<fk_ImType>	imageBuf;
+	fk_ImType				*bufPointer;
 	fk_TexID				texID;
 	bool					initFlag;
 	// テクスチャの部分更新用情報
@@ -299,7 +300,7 @@ class fk_Image : public fk_BaseObject {
 	fk_Image(int w = 0, int h = 0);
 
 	//! デストラクタ
-	~fk_Image();
+	virtual ~fk_Image();
 
 	//! コピーコンストラクタ
 	fk_Image(const fk_Image &);
