@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -192,7 +192,7 @@ class fk_IndexFaceSet : public fk_ParserData {
 	fk_IndexFaceSet(void);
 
 	//! デストラクタ
-	~fk_IndexFaceSet();
+	virtual ~fk_IndexFaceSet();
 
 
 	//! 形状コピー関数
@@ -223,9 +223,11 @@ class fk_IndexFaceSet : public fk_ParserData {
 	 *	本関数が対応しているのは「IndexedFaceSet」ノードに記述された形状のみです。
 	 *
 	 *	\param[in]	fileName		ファイル名
+	 *
 	 *	\param[in]	materialFlg
 	 *		true の場合、VRMLファイル中で設定されているマテリアル情報を入力します。
 	 *		false の場合は、マテリアル情報を無視します。
+	 *
 	 *	\param[in]	solidFlg
 	 *		true の場合、位相の隣接関係を最適化します。
 	 *		ただし、結果として入力に失敗する場合があります。
@@ -257,11 +259,13 @@ class fk_IndexFaceSet : public fk_ParserData {
 	 *	- 3角形面と4角形面が混在している。
 	 *
 	 *	\param[in]	fileName		ファイル名
+	 *
 	 *	\param[in]	solidFlg
 	 *		true の場合、位相の隣接関係を最適化します。
 	 *		ただし、結果として入力に失敗する場合があります。
 	 *		false の場合は隣接関係を最適化せず、
 	 *		すべての面が独立した状態として形状を構築します。
+	 *
 	 *	\param[in]	tolerance
 	 *		solidFlg で true を指定した場合、
 	 *		頂点同士が同一かどうかを判断するための距離許容誤差を指定します。
@@ -288,6 +292,7 @@ class fk_IndexFaceSet : public fk_ParserData {
 	 *	RDS (Ray Dream Studio) 形式のファイルからデータを入力します。
 	 *
 	 *	\param[in]	fileName		ファイル名
+	 *
 	 *	\param[in]	solidFlg
 	 *		true の場合、位相の隣接関係を最適化します。
 	 *		ただし、結果として入力に失敗する場合があります。
@@ -344,7 +349,7 @@ class fk_IndexFaceSet : public fk_ParserData {
 	 *		本来のデータよりも頂点、稜線、面が若干増加する場合があります。
 	 *		false にした場合は、断裂操作を行わずに通常のデータ通り読み込みます。
 	 *	\param[in]	materialFlg
-	 *		true の場合、VRMLファイル中で設定されているマテリアル情報を入力します。
+	 *		true の場合、MQOファイル中で設定されているマテリアル情報を入力します。
 	 *		false の場合は、マテリアル情報を無視します。
 	 *
 	 *	\return		成功すれば true を、失敗すれば false を返します。
@@ -370,17 +375,21 @@ class fk_IndexFaceSet : public fk_ParserData {
 	 *	この関数では、ファイル名とともにオブジェクト名を指定する必要があります。
 	 *
 	 *	\param[in]	fileName	ファイル名
+	 *
 	 *	\param[in]	objName		オブジェクト名
+	 *
 	 *	\param[in]	materialID
 	 *		MQOデータではマテリアルを複数設定することができ、
 	 *		各ポリゴンに対してどのマテリアルを割り振るかのIDが設定されています。
 	 *		この引数にマテリアルIDを指定すると、そのIDを持つポリゴンのみを読み込みます。
 	 *		materialID に -1 を入力した場合は、すべてのポリゴンを読み込みます。
+	 *
 	 *	\param[in]	solidFlg
 	 *		true の場合、位相の隣接関係を最適化します。
 	 *		ただし、結果として入力に失敗する場合があります。
 	 *		false の場合は隣接関係を最適化せず、
 	 *		すべての面が独立した状態として形状を構築します。
+	 *
 	 *	\param[in]	contFlg
 	 *		テクスチャ断絶の設定を指定します。これは、テクスチャ座標が不連続な箇所に対し、
 	 *		形状の位相を断絶する操作を行うためのものです。
@@ -390,8 +399,9 @@ class fk_IndexFaceSet : public fk_ParserData {
 	 *		ただし、断裂操作を行う際に新たな位相要素を生成するため、
 	 *		本来のデータよりも頂点、稜線、面が若干増加する場合があります。
 	 *		false にした場合は、断裂操作を行わずに通常のデータ通り読み込みます。
+	 *
 	 *	\param[in]	materialFlg
-	 *		true の場合、VRMLファイル中で設定されているマテリアル情報を入力します。
+	 *		true の場合、MQOファイル中で設定されているマテリアル情報を入力します。
 	 *		false の場合は、マテリアル情報を無視します。
 	 *
 	 *	\return		成功すれば true を、失敗すれば false を返します。
@@ -421,12 +431,15 @@ class fk_IndexFaceSet : public fk_ParserData {
 	 *	この関数では、ファイル名とともにオブジェクト名を指定する必要があります。
 	 *
 	 *	\param[in]	buffer		データが格納されているバッファ
+	 *
 	 *	\param[in]	objName		オブジェクト名
+	 *
 	 *	\param[in]	solidFlg
 	 *		true の場合、位相の隣接関係を最適化します。
 	 *		ただし、結果として入力に失敗する場合があります。
 	 *		false の場合は隣接関係を最適化せず、
 	 *		すべての面が独立した状態として形状を構築します。
+	 *
 	 *	\param[in]	contFlg
 	 *		テクスチャ断絶の設定を指定します。これは、テクスチャ座標が不連続な箇所に対し、
 	 *		形状の位相を断絶する操作を行うためのものです。
@@ -436,8 +449,9 @@ class fk_IndexFaceSet : public fk_ParserData {
 	 *		ただし、断裂操作を行う際に新たな位相要素を生成するため、
 	 *		本来のデータよりも頂点、稜線、面が若干増加する場合があります。
 	 *		false にした場合は、断裂操作を行わずに通常のデータ通り読み込みます。
+	 *
 	 *	\param[in]	materialFlg
-	 *		true の場合、VRMLファイル中で設定されているマテリアル情報を入力します。
+	 *		true の場合、MQOデータ中で設定されているマテリアル情報を入力します。
 	 *		false の場合は、マテリアル情報を無視します。
 	 *
 	 *	\return		成功すれば true を、失敗すれば false を返します。
@@ -466,17 +480,21 @@ class fk_IndexFaceSet : public fk_ParserData {
 	 *	この関数では、ファイル名とともにオブジェクト名を指定する必要があります。
 	 *
 	 *	\param[in]	buffer		データが格納されているバッファ
+	 *
 	 *	\param[in]	objName		オブジェクト名
+	 *
 	 *	\param[in]	materialID
 	 *		MQOデータではマテリアルを複数設定することができ、
 	 *		各ポリゴンに対してどのマテリアルを割り振るかのIDが設定されています。
 	 *		この引数にマテリアルIDを指定すると、そのIDを持つポリゴンのみを読み込みます。
 	 *		materialID に -1 を入力した場合は、すべてのポリゴンを読み込みます。
+	 *
 	 *	\param[in]	solidFlg
 	 *		true の場合、位相の隣接関係を最適化します。
 	 *		ただし、結果として入力に失敗する場合があります。
 	 *		false の場合は隣接関係を最適化せず、
 	 *		すべての面が独立した状態として形状を構築します。
+	 *
 	 *	\param[in]	contFlg
 	 *		テクスチャ断絶の設定を指定します。これは、テクスチャ座標が不連続な箇所に対し、
 	 *		形状の位相を断絶する操作を行うためのものです。
@@ -486,8 +504,9 @@ class fk_IndexFaceSet : public fk_ParserData {
 	 *		ただし、断裂操作を行う際に新たな位相要素を生成するため、
 	 *		本来のデータよりも頂点、稜線、面が若干増加する場合があります。
 	 *		false にした場合は、断裂操作を行わずに通常のデータ通り読み込みます。
+	 *
 	 *	\param[in]	materialFlg
-	 *		true の場合、VRMLファイル中で設定されているマテリアル情報を入力します。
+	 *		true の場合、MQOデータ中で設定されているマテリアル情報を入力します。
 	 *		false の場合は、マテリアル情報を無視します。
 	 *
 	 *	\return		成功すれば true を、失敗すれば false を返します。
@@ -514,10 +533,12 @@ class fk_IndexFaceSet : public fk_ParserData {
 	 *	この関数では、ファイル名とともにオブジェクト名を指定する必要があります。
 	 *
 	 *	\param[in]	fileName	ファイル名
+	 *
 	 *	\param[in]	objName		オブジェクト名。
 	 *		D3DX 形式では、オブジェクト名を省略することが許容されています。
 	 *		そのような場合は、この引数に空文字列 ( "" ) を入れてください。
 	 *		この場合、ファイル中で最初に存在するオブジェクトのデータを入力します。
+	 *
 	 *	\param[in]	solidFlg
 	 *		true の場合、位相の隣接関係を最適化します。
 	 *		ただし、結果として入力に失敗する場合があります。
@@ -545,15 +566,18 @@ class fk_IndexFaceSet : public fk_ParserData {
 	 *	この関数では、ファイル名とともにオブジェクト名を指定する必要があります。
 	 *
 	 *	\param[in]	fileName	ファイル名
+	 *
 	 *	\param[in]	objName		オブジェクト名。
 	 *		D3DX 形式では、オブジェクト名を省略することが許容されています。
 	 *		そのような場合は、この引数に空文字列 ( "" ) を入れてください。
 	 *		この場合、ファイル中で最初に存在するオブジェクトのデータを入力します。
+	 *
 	 *	\param[in]	solidFlg
 	 *		true の場合、位相の隣接関係を最適化します。
 	 *		ただし、結果として入力に失敗する場合があります。
 	 *		false の場合は隣接関係を最適化せず、
 	 *		すべての面が独立した状態として形状を構築します。
+	 *
 	 *	\param[in]	materialID
 	 *		D3DXデータではマテリアルを複数設定することができ、
 	 *		各ポリゴンに対してどのマテリアルを割り振るかのIDが設定されています。
@@ -1372,10 +1396,13 @@ class fk_IndexFaceSet : public fk_ParserData {
 
 	bool				MakeMesh(std::vector<fk_Vector> *,
 								 std::vector< std::vector<int> > *,
-								 std::vector<int> * = NULL, bool = true);
+								 std::vector<int> * = NULL,
+								 bool = true);
 
 	fk_D3DXAnimation *	GetAnimation(void);
 
+	void				PosPrint(std::string);
+
 #endif
 
 };
