@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -171,7 +171,7 @@ class fk_MatrixAdmin : public fk_BaseObject {
 	fk_MatrixAdmin(fk_ObjectType = FK_MATRIXADMIN);
 
 	//! デストラクタ
-	~fk_MatrixAdmin();
+	virtual ~fk_MatrixAdmin();
 
 	//! \name 状態参照関数
 	//@(
