@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -121,7 +121,7 @@ class fk_Color : public fk_BaseObject {
 	fk_Color(double r, double g, double b);
 
 	//! デストラクタ
-	~fk_Color() {}
+	virtual ~fk_Color() {}
 
 	//! 比較等号演算子
 	/*!
@@ -312,7 +312,7 @@ class fk_Material : public fk_BaseObject {
 	fk_Material();
 
 	//! デストラクタ
-	~fk_Material() {}
+	virtual ~fk_Material() {}
 
 	//! 比較等号演算子
 	/*!
