@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -258,6 +258,48 @@ class fk_Math {
 									 double *t, fk_Vector *P);
 
 
+	//! 三角形対線分交差判定関数
+	/*!
+	 *	線分 PQ と、三角形 ABC が交差しているかどうかを判定します。
+	 *	この関数では、三角形の境界と線分が接している場合や、
+	 *	線分の端点が三角形面上にあるような場合でも、交差していると判断します。
+	 *	以下の条件を満たす場合は、常に false を返します。
+	 *		- 線分 PQ の両端点が同じ場所にある場合。
+	 *		- 三角形 ABC の 3 点のうち、少なくとも 2 点が同じ場所にある場合。
+	 *		- 三角形 ABC の 3 点が同一直線上にある場合。
+	 *		- 線分 PQ と 三角形 ABC が平行だった場合。
+	 *	.
+	 *	\param[in]	P		有向線分の始点。
+	 *	\param[in]	Q		有向線分の終点。
+	 *	\param[in]	A		三角形の頂点。
+	 *	\param[in]	B		三角形の頂点。
+	 *	\param[in]	C		三角形の頂点。
+	 *	\param[out]	R
+	 *		交差の有無にかかわらず、
+	 *		PQを通る直線とABCを通る平面の交点のパラメータが代入されます。
+	 *		以下の式は、ABC平面上の点 T をパラメータ表現したものです。
+	 *		\f[
+	 *			\mathbf{T} = \mathbf{A} + u (\mathbf{B} - \mathbf{A})
+	 *			+ v (\mathbf{C} - \mathbf{A})
+	 *		\f]
+	 *		また、以下の式は直線 PQ 上の点 L をパラメータ表現したものです。
+	 *		\f[
+	 *			\mathbf{L} = (1 - t)\mathbf{P} + t\mathbf{Q}
+	 *		\f]
+	 *		これらの式のうち、平面パラメータ\f$ u, v \f$ が
+	 *		R の x 成分と y 成分、
+	 *		直線パラメータ \f$ t \f$ が R の z 成分に代入されます。
+	 *		なお、パラメータ出力を必要としない場合は、
+	 *		本引数を省略するか NULL を代入しても構いません。
+	 *
+	 *	\return		交差していれば true を、していなければ false を返します。
+	 */
+	static bool calcCrossLineAndTri(const fk_Vector &P,
+									const fk_Vector &Q,
+									const fk_Vector &A,
+									const fk_Vector &B,
+									const fk_Vector &C,
+									fk_Vector *R = NULL);
 
 	//! 余弦値算出関数
 	/*!
