@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -297,6 +297,104 @@ class fk_OrthoMatrix {
 	 */
 	void			set(int row, int col, double value);
 
+	//! 行ベクトル成分設定関数1
+	/*!
+	 *	行列中の、行番号が row である行ベクトルを vec に設定します。
+	 *	row は最初が 0、最後が 3 となります。この関数の場合、
+	 *	行ベクトルの最後の成分については値は変更しません。
+	 *
+	 * 	以下の2つのコードは、同義となります。
+	 *
+	 *	\code
+	 *	M.setRow(row, vec);
+	 *	\endcode
+	 *
+	 *	\code
+	 *	M[row][0] = vec.x;
+	 *	M[row][1] = vec.y;
+	 *	M[row][2] = vec.z;
+	 *	\endcode
+	 */
+	void			setRow(int row, const fk_Vector &vec);
+
+	//! 行ベクトル成分設定関数2
+	/*!
+	 *	行列中の、行番号が row である行ベクトルを vec に設定します。
+	 *	row は最初が 0、最後が 3 となります。
+	 *
+	 * 	以下の2つのコードは、同義となります。
+	 *
+	 *	\code
+	 *	M.setRow(row, vec);
+	 *	\endcode
+	 *
+	 *	\code
+	 *	M[row][0] = vec.x;
+	 *	M[row][1] = vec.y;
+	 *	M[row][2] = vec.z;
+	 *	M[row][3] = vec.w;
+	 *	\endcode
+	 */
+	void			setRow(int row, const fk_HVector &vec);
+
+	//! 列ベクトル成分設定関数1
+	/*!
+	 *	行列中の、列番号が col である列ベクトルを vec に設定します。
+	 *	col は最初が 0、最後が 3 となります。この関数の場合、
+	 *	列ベクトルの最後の成分については値は変更しません。
+	 *
+	 * 	以下の2つのコードは、同義となります。
+	 *
+	 *	\code
+	 *	M.setCol(col, vec);
+	 *	\endcode
+	 *
+	 *	\code
+	 *	M[0][col] = vec.x;
+	 *	M[1][col] = vec.y;
+	 *	M[2][col] = vec.z;
+	 *	\endcode
+	 */
+	void			setCol(int col, const fk_Vector &vec);
+	
+	//! 列ベクトル成分設定関数2
+	/*!
+	 *	行列中の、列番号が col である列ベクトルを vec に設定します。
+	 *	col は最初が 0、最後が 3 となります。
+	 *
+	 * 	以下の2つのコードは、同義となります。
+	 *
+	 *	\code
+	 *	M.setCol(col, vec);
+	 *	\endcode
+	 *
+	 *	\code
+	 *	M[0][col] = vec.x;
+	 *	M[1][col] = vec.y;
+	 *	M[2][col] = vec.z;
+	 *	M[3][col] = vec.w;
+	 *	\endcode
+	 */
+	void			setCol(int col, const fk_HVector &vec);
+
+	//! 行ベクトル成分取得関数
+	/*!
+	 *	行列中の、行番号が row である行ベクトルを返します。
+	 *	row は最初が 0、最後が 3 となります。
+	 *
+	 *	\return 行ベクトル
+	 */
+	fk_HVector		getRow(int row);
+
+	//! 列ベクトル成分取得関数
+	/*!
+	 *	行列中の、列番号が col である列ベクトルを返します。
+	 *	col は最初が 0、最後が 3 となります。
+	 *
+	 *	\return 列ベクトル
+	 */
+	fk_HVector		getCol(int col);
+
 	//! 逆行列化関数
 	/*!
 	 *	現在設定されている行列に対し、自身を逆行列化します。
