@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -88,6 +88,7 @@ const fk_DrawMode FK_LINEMODE			= 0x0002;
 const fk_DrawMode FK_POLYMODE			= 0x0004;
 const fk_DrawMode FK_BACK_POLYMODE		= (0x0008 | FK_POLYMODE);
 const fk_DrawMode FK_FRONTBACK_POLYMODE	= (0x0010 | FK_POLYMODE);
+const fk_DrawMode FK_TEXTUREMODE		= 0x0020;
 
 #ifndef FK_DOXYGEN_USER_PROCESS
 
@@ -139,6 +140,7 @@ class fk_Model : public fk_MatrixAdmin {
 	fk_Color			*lineColor;
 	fk_Shape			*shape;
 	fk_Model			*parent;
+	fk_TreeData			*treeData;
 	bool				materialFlag;
 	fk_DrawMode			drawMode;
 	fk_MaterialMode		materialMode;
@@ -436,6 +438,7 @@ class fk_Model : public fk_MatrixAdmin {
 	 *	- FK_POLYMODE:				面の表を描画します。
 	 *	- FK_BACK_POLYMODE:			面の裏を描画します。
 	 *	- FK_FRONTBACK_POLYMODE:	面の表と裏を描画します。
+	 *	- FK_TEXTUREMODE:			テクスチャを描画します。
 	 *	.
 	 *	これらの描画モードは、
 	 *	ビット論理和を用いて複数のものを同時に指定することが可能です。
