@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -78,9 +78,9 @@
 //! マテリアルモード型
 typedef unsigned char	fk_MaterialMode;
 
+const fk_MaterialMode	FK_NONE_MODE = 0;		//!< 不描画モード
 const fk_MaterialMode	FK_CHILD_MODE = 1;		//!< 個別設定モード
 const fk_MaterialMode	FK_PARENT_MODE = 2;		//!< モデル設定モード
-const fk_MaterialMode	FK_NONE_MODE = 3;		//!< 不描画モード
 
 //! マテリアルパレットを管理するクラス
 /*!
@@ -103,7 +103,7 @@ class fk_Palette : public fk_BaseObject {
 	fk_Palette(void);
 
 	//! デストラクタ
-	~fk_Palette();
+	virtual ~fk_Palette();
 
 	//! 初期化関数
 	/*!
