@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -134,7 +134,7 @@ class fk_Particle: public fk_BaseObject, public fk_Attribute {
 #ifndef FK_DOXYGEN_USER_PROCESS
 
 	fk_Particle(fk_Point *, int);
-	~fk_Particle();
+	virtual ~fk_Particle();
 
 #endif
 
