@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -109,7 +109,7 @@ class fk_ProjectBase : public fk_BaseObject {
 	fk_ProjectBase(fk_ProjectMode = FK_NONE_PROJ_MODE);
 
 	//! デストラクタ
-	~fk_ProjectBase();
+	virtual ~fk_ProjectBase();
 
 	//! 投影法参照関数
 	/*!
@@ -177,7 +177,7 @@ class fk_Perspective : public fk_ProjectBase {
 				   double far = 6000.0);
 
 	//! デストラクタ
-	~fk_Perspective();
+	virtual ~fk_Perspective();
 
 	//! コピーコンストラクタ
 	fk_Perspective(const fk_Perspective &);
@@ -303,7 +303,7 @@ class fk_Frustum : public fk_ProjectBase {
 			   double far = 6000.0);
 
 	//! デストラクタ
-	~fk_Frustum();
+	virtual ~fk_Frustum();
 
 	//! コピーコンストラクタ
 	fk_Frustum(const fk_Frustum &);
@@ -472,7 +472,7 @@ class fk_Ortho : public fk_ProjectBase {
 			 double near = 0.0, double far = 10000.0);
 
 	//! デストラクタ
-	~fk_Ortho();
+	virtual ~fk_Ortho();
 
 	//! コピーコンストラクタ
 	fk_Ortho(const fk_Ortho &);
