@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -171,6 +171,7 @@ class fk_ShapeViewer : public fk_BaseObject {
 	bool				moveFlag;
 	bool				oldMoveFlag;
 	fk_DrawMode			drawMode;
+	bool				axisFlag;
 
 	// FK Object
 	fk_Model					parentModel;
@@ -408,6 +409,28 @@ class fk_ShapeViewer : public fk_BaseObject {
 	 */
 	fk_DrawMode		getDrawMode(void);
 
+	//! 透過処理設定関数
+	/*!
+	 *	描画の際、透過処理を有効とするかどうかを設定します。
+	 *	機能的には fk_Scene::setBlendStatus() と同様です。
+	 *	詳細は、 fk_Scene::setBlendStatus() のマニュアルを参照して下さい。
+	 *
+	 *	\param[in]	mode	true であれば有効、false であれば無効とします。
+	 *
+	 *	\sa fk_Scene::setBlendStatus(), getBlendStatus()
+	 */
+	void			setBlendStatus(bool mode);
+
+	//! 透過処理参照関数
+	/*!
+	 *	現在の透過処理状態を取得します。
+	 *
+	 *	\return		有効であれば true を、無効であれば false を返します。
+	 *
+	 *	\sa setBlendStatus()
+	 */
+	bool			getBlendStatus(void);
+
 	//! 背景色設定関数1
 	/*!
 	 *	描画領域の背景色を設定します。
@@ -442,6 +465,26 @@ class fk_ShapeViewer : public fk_BaseObject {
 	 */
 	fk_Color		getBGColor(void);
 
+	//! 座標軸描画設定関数
+	/*!
+	 *	座標軸の表示の有無を設定します。
+	 *
+	 *	\param[in]	mode	true であれば描画有効、false であれば無効とします。
+	 *
+	 *	\sa setAxisScale(), getAxisMode()
+	 */
+	void			setAxisMode(bool mode);
+
+	//! 座標軸描画参照関数
+	/*!
+	 *	座標軸の表示状態を取得します。
+	 *
+	 *	\return		描画有効であれば true を、無効であれば false を返します。
+	 *
+	 *	\sa setAxisMode()
+	 */
+	bool			getAxisMode(void);
+
 	//! 座標軸大きさ設定関数
 	/*!
 	 *	座標軸の大きさを設定します。ここでいう大きさとは、
@@ -461,6 +504,8 @@ class fk_ShapeViewer : public fk_BaseObject {
 	 */
 	double	getAxisScale(void);
 
+
+
 	//! 描画領域中心座標参照関数
 	/*!
 	 *	現在の描画領域で中心(注視点)となっている位置の位置ベクトルを返します。
