@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -174,6 +174,8 @@ class fk_Texture: public fk_Shape {
 	fk_TexID			GetTexID(void);
 	void				SetTexID(const fk_TexID);
 
+	static void			ClearTexState(fk_Image *);
+
  protected:
 
 #ifndef FK_DOXYGEN_USER_PROCESS
@@ -189,7 +191,7 @@ class fk_Texture: public fk_Shape {
 #ifndef FK_DOXYGEN_USER_PROCESS
 
 	fk_Texture(fk_Image * = (fk_Image *)NULL);
-	~fk_Texture();
+	virtual ~fk_Texture();
 	virtual void			init(void) = 0;
 
 #endif
@@ -467,7 +469,7 @@ class fk_RectTexture : public fk_Texture {
 	fk_RectTexture(fk_Image *image = (fk_Image *)NULL);
 
 	//! デストラクタ
-	~fk_RectTexture();
+	virtual ~fk_RectTexture();
 
 	//! 初期化関数
 	/*!
@@ -640,7 +642,7 @@ class fk_TriTexture : public fk_Texture {
 	fk_TriTexture(fk_Image *image = (fk_Image *)NULL);
 
 	//! デストラクタ
-	~fk_TriTexture();
+	virtual ~fk_TriTexture();
 
 	//! 初期化関数
 	/*!
@@ -799,7 +801,7 @@ class fk_MeshTexture : public fk_Texture {
 	fk_MeshTexture(fk_Image *image = (fk_Image *)NULL);
 
 	//! デストラクタ
-	~fk_MeshTexture();
+	virtual ~fk_MeshTexture();
 
 	//! 初期化関数
 	/*!
