@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,8 +72,8 @@
 #ifndef __FK_TREE_HEADER__
 #define __FK_TREE_HEADER__
 
-#include <string>
 #include <list>
+#include <string>
 #include <iostream>
 
 class fk_Tree;
@@ -88,7 +88,12 @@ class fk_TreeData;
  *
  *	\sa fk_Tree, fk_TreeData
  */
-class fk_TreeBaseObject {};
+
+class fk_TreeBaseObject {
+ public:
+	fk_TreeBaseObject(void) {};
+	virtual ~fk_TreeBaseObject(void) {};
+};
 
 typedef std::list<fk_TreeData *>	fk_TList;
 
@@ -154,7 +159,7 @@ class fk_TreeData {
 				fk_TreeData *parent);
 
 	//! デストラクタ
-	~fk_TreeData();
+	virtual ~fk_TreeData();
 
 	//! 深さ参照関数
 	/*!
