@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -76,11 +76,12 @@
 #include <FK/Base.h>
 
 class ImdKanjiCodeConverter;
-class ImdKcvEncoder_UCS;
+class ImdKcvEncoder;
 
 //! 日本語文字コードを表す列挙型
 enum fk_StringCode {
 	FK_STR_UTF16,	//!< Unicode (UTF-16)
+	FK_STR_UTF8,	//!< Unicode (UTF-8)
 	FK_STR_JIS,		//!< ISO-2022-JIS (JISコード)
 	FK_STR_SJIS,	//!< Shift-JIS (SJISコード)
 	FK_STR_EUC		//!< EUC
@@ -203,7 +204,7 @@ class fk_UniStr : public fk_BaseObject {
 	fk_UniStr(void);
 
 	//! デストラクタ
-	~fk_UniStr();
+	virtual ~fk_UniStr();
 
 	//! コピーコンストラクタ
 	fk_UniStr(const fk_UniStr &);
@@ -473,7 +474,7 @@ class fk_UniStr : public fk_BaseObject {
  *	そのため、その他の文字コードで記述されている
  *	ソースプログラムやデータファイルを入力する場合は、
  *	文字コードを変換する必要があります。
- *	本クラスでは、std::string に格納されている文字列に対し、
+ *	本クラスでは、 std::string に格納されている文字列に対し、
  *	fk_UniStr 型の文字列に変換する機能を提供します。
  *
  *	実質的には、 fk_UniStr::convert() があるため、
@@ -487,18 +488,60 @@ class fk_UniStr : public fk_BaseObject {
 
 class fk_StrConverter {
  private:
-	ImdKanjiCodeConverter	*jisBase, *sjisBase, *eucBase;
-	ImdKanjiCodeConverter	*utf8_sjisBase, *sjis_utf8Base;
+	ImdKanjiCodeConverter	*jis_utf8_Base;
+	ImdKanjiCodeConverter	*sjis_utf8_Base;
+	ImdKanjiCodeConverter	*euc_utf8_Base;
+	ImdKanjiCodeConverter	*utf16_utf8_Base;
+
+	ImdKanjiCodeConverter	*jis_utf16_Base;
+	ImdKanjiCodeConverter	*sjis_utf16_Base;
+	ImdKanjiCodeConverter	*euc_utf16_Base;
+	ImdKanjiCodeConverter	*utf8_utf16_Base;
+
+	ImdKanjiCodeConverter	*jis_sjis_Base;
+	ImdKanjiCodeConverter	*euc_sjis_Base;
+	ImdKanjiCodeConverter	*utf8_sjis_Base;
+	ImdKanjiCodeConverter	*utf16_sjis_Base;
+
 	char					*buffer;
 	int						bufSize;
 
-	ImdKcvEncoder_UCS *		MakeEncoder(void);
+	ImdKcvEncoder *			MakeEncoder(fk_StringCode);
 	void					RemakeBuffer(ImdKanjiCodeConverter *);
-	void					InitJISBase(void);
-	void					InitSJISBase(void);
-	void					InitEUCBase(void);
-	void					InitUTF82SJISBase(void);
-	void					InitSJIS2UTF8Base(void);
+
+	void					InitJIS_UTF8_Base(void);
+	void					InitSJIS_UTF8_Base(void);
+	void					InitEUC_UTF8_Base(void);
+	void					InitUTF16_UTF8_Base(void);
+
+	void					InitJIS_UTF16_Base(void);
+	void					InitSJIS_UTF16_Base(void);
+	void					InitEUC_UTF16_Base(void);
+	void					InitUTF8_UTF16_Base(void);
+
+	void					InitJIS_SJIS_Base(void);
+	void					InitEUC_SJIS_Base(void);
+	void					InitUTF8_SJIS_Base(void);
+	void					InitUTF16_SJIS_Base(void);
+
+	void					ConvertJIS_UTF8(const std::string &,
+											std::string *);
+	void					ConvertSJIS_UTF8(const std::string &,
+											 std::string *);
+	void					ConvertEUC_UTF8(const std::string &,
+											std::string *);
+	void					ConvertUTF16_UTF8(const std::string &,
+											  std::string *);
+
+	void					ConvertJIS_SJIS(const std::string &,
+											std::string *);
+	void					ConvertEUC_SJIS(const std::string &,
+											std::string *);
+	void					ConvertUTF8_SJIS(const std::string &,
+											 std::string *);
+	void					ConvertUTF16_SJIS(const std::string &,
+											  std::string *);
+
 	void					CommonConvert(ImdKanjiCodeConverter *,
 										  const std::string &, fk_UniStr *);
 
@@ -506,7 +549,7 @@ class fk_StrConverter {
 	//! コンストラクタ
 	fk_StrConverter(void);
 	//! デストラクタ
-	~fk_StrConverter();
+	virtual ~fk_StrConverter();
 
 	//! JISコード変換関数
 	/*!
@@ -536,10 +579,24 @@ class fk_StrConverter {
 	void		convertEUC(const std::string &str, fk_UniStr *uniStr);
 
 #ifndef FK_DOXYGEN_USER_PROCESS
-	void		convertUTF8_SJIS(const std::string &, std::string *);
-	void		convertSJIS_UTF8(const std::string &, std::string *);
+	void		convert_SJIS(const std::string &,
+							 std::string *,
+							 fk_StringCode);
+
+	void		convert_UTF8(const std::string &,
+							 std::string *,
+							 fk_StringCode);
 #endif
 
 };
 
+namespace fk_Code {
+	void	setInputCoding(fk_StringCode);
+
+	char *	utf8(const std::string &);
+	char *	utf8(const std::string &, fk_StringCode);
+	char *	sjis(const std::string &);
+	char *	sjis(const std::string &, fk_StringCode);
+}
+	
 #endif // !__FK_UNICODE_HEADER__
