@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -214,6 +214,7 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 
 	void					SetPickViewPort(int &, int &);
 	bool					IsInsideWindow(void);
+	Fl_Group *				GetInhParentWindow(void);
 	void					GetPickData(bool, fk_PickData *, int, int, int);
 
 	void					draw();	// virtual Function from Fl_Gl_Window class
@@ -238,7 +239,7 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 			  int w = 300, int h = 300, std::string name = "FK Window");
 
 	//! デストラクタ
-	~fk_Window();
+	virtual ~fk_Window();
 
 
 	//! \name シーン制御関数
@@ -246,7 +247,7 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 
 	//! シーン登録関数
 	/*!
-	 *	シーンを本ウィジェットの描画対称として登録します。
+	 *	シーンを本ウィジェットの描画対象として登録します。
 	 *
 	 *	\param[in]	scene		シーンインスタンス
 	 */
@@ -691,6 +692,10 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 	 *	現在の OpenGL 頂点配列処理が有効であるかどうかを参照します。
 	 *	頂点配列についての詳細は setOGLPointerMode() の解説を参照して下さい。
 	 *
+	 *	\note
+	 *		この関数は OpenGL 環境においてのみ有効です。
+	 *		Direct3D 版においては意味のある値を返しません。
+	 *
 	 *	\return
 	 *		頂点配列処理が有効である場合 true を、
 	 *		無効である場合 false を返します。
@@ -699,6 +704,44 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 	 */
 	bool	getOGLPointerMode(void);
 
+	//! OpenGL テクスチャ切り替え低減処理制御関数
+	/*!
+	 *	この関数は、OpenGL 環境におけるテクスチャ描画処理を制御します。
+	 *	リアルタイム 3DCG の描画処理において、使用するテクスチャの切り替え処理が
+	 *	頻発することはパフォーマンスの低下を招きます。そこで FK の内部処理では、
+	 *	同じテクスチャを続けて使用する際に不要な切り替え処理が発生しないようにしています。
+	 *	しかし、実行する環境によっては描画に不具合が生じることもあります。
+	 *	そのような場合、この関数を用いてテクスチャの切り替え処理をその都度行うように、
+	 *	内部処理を切り替えることが可能です。
+	 *	デフォルトでは切り替え低減処理が「有効」となっています。
+	 *
+	 *	\note
+	 *		この関数による設定は、OpenGL 環境においてのみ有効です。
+	 *		Direct3D 版においては設定は意味をなしません。
+	 *
+	 *	\param[in]	mode
+	 *		true の場合、テクスチャ切り替え低減処理を有効とします。
+	 *		false の場合は無効とします。
+	 */
+	void	setOGLTextureBindMode(bool mode);
+
+	//! OpenGL テクスチャ切り替え低減処理参照関数
+	/*!
+	 *	現在の OpenGL テクスチャ切り替え低減理が有効であるかどうかを参照します。
+	 *	該当処理についての詳細は setOGLTextureBindMode() の解説を参照して下さい。
+	 *
+	 *	\note
+	 *		この関数は OpenGL 環境においてのみ有効です。
+	 *		Direct3D 版においては意味のある値を返しません。
+	 *
+	 *	\return
+	 *		テクスチャ切り替え低減処理が有効である場合 true を、
+	 *		無効である場合 false を返します。
+	 *
+	 *	\sa setOGLTextureBindMode()
+	 */
+	bool	getOGLTextureBindMode(void);
+
 	//! テクスチャメモリ解放関数
 	/*!
 	 *	この関数は、現在確保されているテクスチャメモリの解放を行います。
@@ -714,6 +757,25 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 	 */
 	void	clearTextureMemory(void);
 
+	//! テクスチャメモリ使用量取得関数
+	/*!
+	 *	この関数は、現在確保されているテクスチャメモリの使用量を取得します。
+	 *
+	 *	取得できる値は、FK が内部処理によって現時点までにキャッシングを行った
+	 *	テクスチャ画像バッファのトータルサイズです。単位はバイトです。
+	 *	FK では描画効率を優先するため、使用する画像よりも大きなサイズを確保して
+	 *	画像のキャッシングを行っています。また GPU のドライバの設定によっては、
+	 *	実際に GPU 上で占有しているメモリ容量と誤差が生じる場合もあります。
+	 *	アプリケーションが動作するシステムで使用可能な容量を超えてしまうと、
+	 *	正常なテクスチャ描画ができなくなりますので、この関数で使用量を確認し、
+	 *	必要に応じて clearTextureMemory() を使用するのが良いでしょう。
+	 *
+	 *	\return	テクスチャメモリ使用量
+	 *
+	 *	\sa clearTextureMemory()
+	 */
+	unsigned long getUsingTextureMemory(void);
+
 	//! 初期化前処理関数
 	/*!
 	 *	この関数は、グラフィックスシステムの初期化処理において、
@@ -946,21 +1008,21 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 	//! 立体視モード設定関数
 	/*!
 	 *	ウィンドウに対して立体視モードを設定します。
+	 *	デフォルトでは無効になっています。
 	 *
 	 *	\note
-	 *		このシステムにおける立体視画像出力は、OpenGLの標準拡張機能を利用します。
-	 *		Direct3D版では利用できないので注意してください。
-	 *		立体視を利用するには、Quad Bufferをサポートしているグラフィックカードが必須です。
-	 *		本プロジェクトで動作を確認しているのはNVIDIA社のQuadroシリーズのみです。
-	 *		対応していない環境で立体視モードを有効にしようとした場合、
-	 *		その時点でプログラムは強制終了します。
-	 *		現時点ではプログラム的に立体視対応を判別する手段を用意していないので、
-	 *		使用する場合は立体視専用のアプリケーションとして構築してください。
+	 *		このシステムにおける立体視画像出力は、OpenGL の標準拡張機能を利用します。
+	 *		Direct3D 版では利用できないので注意してください。
+	 *		立体視を利用するには、Quad Buffer をサポートしているグラフィックカードが必須です。
+	 *		本プロジェクトで動作を確認しているのは NVIDIA 社の Quadro シリーズのみです。
+	 *		対応していない環境で立体視モードを有効にしようとした場合は、
+	 *		モードを変更せずに関数の処理が終了します。
+	 *		モード切替が成功したかどうかは、後述する関数 getOGLStereoMode()で判定してください。
 	 *
 	 *	\param[in]	mode
-	 *		trueだった場合、立体視モードを有効にします。
-	 *		falseだった場合、立体視モードを無効にします。
-	 *		いずれの動作においても、OpenGLの動作モードの再設定が行われます。
+	 *		true だった場合、立体視モードを有効にします。
+	 *		false だった場合、立体視モードを無効にします。
+	 *		いずれの動作においても、OpenGL の動作モードの再設定が行われます。
 	 *
 	 *	\sa fk_DisplayLink, getOGLStereoMode()
 	 */
@@ -970,22 +1032,19 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 	/*!
 	 *	ウィンドウの現在の立体視モードを取得します。
 	 *
+	 *	\note
+	 *		この関数は OpenGL 環境においてのみ有効です。
+	 *		Direct3D 版においては意味のある値を返しません。
+	 *
 	 *	\return
-	 *		trueだった場合、立体視モードが有効になっています。
-	 *		falseだった場合、立体視モードが無効になっています。
+	 *		true だった場合、立体視モードが有効になっています。
+	 *		false だった場合、立体視モードが無効になっています。
 	 *
 	 *	\sa fk_DisplayLink, setOGLStereoMode()
 	 */
 	bool	getOGLStereoMode(void);
 	//@)
 
-#ifndef FK_DOXYGEN_USER_PROCESS
-
-	void	setOGLTextureBindMode(bool);
-	bool	getOGLTextureBindMode(void);
-
-#endif
-
 };
 
 
