@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -75,7 +75,7 @@
 #include <FL/Fl_Group.H>
 #include <FL/Fl_Check_Button.H>
 #include <FL/Fl_Color_Chooser.H>
-#include <FL/Fl_File_Chooser.H>
+#include <FL/Fl_Native_File_Chooser.H>
 #include <FL/fl_ask.H>
 
 class GUISet {
@@ -192,24 +192,32 @@ GUISet::~GUISet()
 
 string GUISet::getFileName(void)
 {
-	Fl_File_Chooser		*fc;
-	const char			*fCharP;
-	string				fileName;
+	Fl_Native_File_Chooser	*fc;
+	string					fileName;
+	string					cwd;
 
-	fc = new Fl_File_Chooser(".", "*.wrl", Fl_File_Chooser::SINGLE,
-							 "VRML File Select");
-	fc->show();
-	while(fc->visible()) {
-		Fl::wait();
-	}
+	fc = new Fl_Native_File_Chooser();
+	fc->title("VRML File Select");
+	fc->filter("*.wrl");
+	cwd = fk_System::get_cwd();
+	if(cwd.empty() == false) fc->directory(cwd.c_str());
+	fc->type(Fl_Native_File_Chooser::BROWSE_FILE);
 
-	fCharP = fc->value(1);
-	if(fCharP == (const char *)NULL) {
+	switch(fc->show()) {
+	  case -1:
+		fl_alert("%s", fc->errmsg());
 		delete fc;
 		return fileName;
+
+	  case 1:
+		delete fc;
+		return fileName;
+
+	  default:
+		break;
 	}
 
-	fileName = fCharP;
+	fileName = fc->filename();
 	delete fc;
 	return fileName;
 }
@@ -337,11 +345,7 @@ int main(int, char *[])
 	mainWindow.end();
 
 #ifdef _MACOSX_
-
-	char	*path = getenv("PWD");
-	if(path == NULL) exit(1);
-	if(chdir(path) != 0) exit(2);
-
+	fk_System::setcwd();
 #endif
 
 	fk_Material::initDefault();
