@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -70,27 +70,37 @@
  *
  ****************************************************************************/
 #include <FK/FK.h>
-#include <FL/Fl_File_Chooser.H>
+#include <FL/Fl_Native_File_Chooser.H>
 
 string imageFileSelect(void)
 {
-	Fl_File_Chooser	*fc;
-	string			fileName;
-	const char		*fCharP;
+	Fl_Native_File_Chooser	*fc;
+	string					fileName;
+	string					pathName;
 
-	fc = new Fl_File_Chooser(".", "*.bmp", Fl_File_Chooser::SINGLE,
-							 "Image File Select");
-	fc->show();
-	while(fc->visible()) {
-		Fl::wait();
-	}
+	pathName = fk_System::get_cwd();
+	fc = new Fl_Native_File_Chooser();
+	fc->title("Image File Select");
+	fc->filter("*.bmp");
+	if(pathName.empty() == false) fc->directory(pathName.c_str());
+	fc->type(Fl_Native_File_Chooser::BROWSE_FILE);
 
-	fCharP = fc->value(1);
-	if(fCharP == (const char *)NULL) {
+	switch(fc->show()) {
+
+	  case -1:
+		fl_alert("%s", fc->errmsg());
 		delete fc;
 		return fileName;
+
+	  case 1:
+		delete fc;
+		return fileName;
+
+	  default:
+		break;
 	}
-	fileName = fCharP;
+
+	fileName = fc->filename();
 	delete fc;
 	return fileName;
 }
@@ -102,10 +112,6 @@ int main(int, char *[])
 	string			fileName;
 	fk_Material		mat;
 
-#ifdef _MACOSX_
-	fk_System::setcwd();
-#endif
-
 	fileName = imageFileSelect();
 
 	if(tex.readBMP(fileName) == false) {
