@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -69,6 +69,8 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+
+#define FK_DEF_SIZETYPE
 #include <FK/D3DXAnimation.H>
 #include <FK/D3DXData.H>
 #include <FK/D3DXShapeParser.H>
@@ -130,7 +132,7 @@ fk_D3DXAnimation::fk_D3DXAnimation(void)
 
 fk_D3DXAnimation::~fk_D3DXAnimation()
 {
-	unsigned int		i;
+	_st		i;
 
 	for(i = 0; i < skinData.size(); i++) delete skinData[i];
 	for(i = 0; i < frameData.size(); i++) delete frameData[i];
@@ -264,8 +266,8 @@ bool fk_D3DXAnimation::SetAnimationName(string *argLine)
 
 	TrimString(&word);
 
-	if(word.size() == 0) return false;
-	if(animData.size() == 0) return false;
+	if(word.empty() == true) return false;
+	if(animData.empty() == true) return false;
 	cur = animData.back();
 	cur->SetName(word);
 	return true;
@@ -406,7 +408,7 @@ void fk_D3DXAnimation::MakeAnimationData(void)
 {
 	fk_TreeData				*treeData;
 	fk_D3DXPropertyList		*propList;
-	unsigned int			i;
+	_st						i;
 	fk_D3DXFrame			*frame;
 
 	if(tree == NULL) return;
@@ -473,31 +475,31 @@ fk_D3DXFrame * fk_D3DXAnimation::MakeNewFrame(fk_TreeData *argData)
 
 void fk_D3DXAnimation::MakeSkinMap(fk_D3DXShapeParser *argShape)
 {
-	int					i, j;
+	_st					i, j;
 	int					vID;
 	fk_D3DXSkinMap		skinMap;
 	fk_D3DXSkinData		*tmpSkinData;
 	double				weight;
 
-	mapData.resize(argShape->GetOptVSize());
+	mapData.resize(_st(argShape->GetOptVSize()));
 
-	for(i = 0; i < int(frameData.size()); i++) {
+	for(i = 0; i < frameData.size(); i++) {
 		tmpSkinData = frameData[i]->GetSkin();
 		if(tmpSkinData == NULL) continue;
 
-		for(j = 0; j < tmpSkinData->GetNum(); j++) {
-			vID = argShape->GetVMap(tmpSkinData->GetVID(j));
+		for(j = 0; j < static_cast<_st>(tmpSkinData->GetNum()); j++) {
+			vID = argShape->GetVMap(tmpSkinData->GetVID(static_cast<int>(j)));
 			if(vID < 0) continue;
 			if(vID >= argShape->GetOptVSize()) {
 				return;
 			}
 
-			weight = tmpSkinData->GetWeight(j);
+			weight = tmpSkinData->GetWeight(static_cast<int>(j));
 
 			if(weight > FK_EPS) {
 				skinMap.SetFrame(frameData[i]);
 				skinMap.SetWeight(weight);
-				mapData[vID].push_back(skinMap);
+				mapData[static_cast<_st>(vID)].push_back(skinMap);
 			}
 		}
 	}
@@ -513,7 +515,7 @@ void fk_D3DXAnimation::MakeDummySkinWeights(fk_TreeData *argData, int argVNum)
 	int						i;
 	fk_Matrix				offsetMatrix;
 
-	prop = (fk_D3DXPropertyList *)argData->getObject();
+	prop = static_cast<fk_D3DXPropertyList *>(argData->getObject());
 	if(prop == NULL) return;
 	frame = prop->GetFrame();
 	if(frame == NULL) return;
@@ -548,19 +550,21 @@ void fk_D3DXAnimation::SetTime(double argTime)
 
 fk_FVector fk_D3DXAnimation::GetMovePos(int argID, const fk_FVector &argV)
 {
-	fk_Vector			retV, orgV;
-	fk_D3DXFrame		*frame;
-	unsigned int		i;
-	double				weight;
+	fk_Vector		retV, orgV;
+	fk_D3DXFrame	*frame;
+	_st				i;
+	double			weight;
 
-	if(argID < 0 || argID >= int(mapData.size())) return fk_FVector(retV);
+	if(argID < 0 || argID >= static_cast<int>(mapData.size())) {
+		return fk_FVector(retV);
+	}
 
 	retV.set(0.0, 0.0, 0.0);
 	orgV = fk_Vector(argV);
 
-	for(i = 0; i < mapData[argID].size(); i++) {
-		frame = mapData[argID][i].GetFrame();
-		weight = mapData[argID][i].GetWeight();
+	for(i = 0; i < mapData[static_cast<_st>(argID)].size(); i++) {
+		frame = mapData[static_cast<_st>(argID)][i].GetFrame();
+		weight = mapData[static_cast<_st>(argID)][i].GetWeight();
 
 		retV += weight * (*(frame->GetTotalMatrix()) * orgV);
 	}
@@ -570,9 +574,11 @@ fk_FVector fk_D3DXAnimation::GetMovePos(int argID, const fk_FVector &argV)
 
 void fk_D3DXAnimation::SetBVHMotion(fk_BVHMotion *argBVH)
 {
-	unsigned int			i, j;
+	_st						i, j;
 	fk_Quaternion			q;
 	fk_D3DXFrameAnimation	*cur;
+	double					timeD;
+	int						fTime;
 
 	if(argBVH == NULL) return;
 
@@ -584,36 +590,48 @@ void fk_D3DXAnimation::SetBVHMotion(fk_BVHMotion *argBVH)
 	}
 	animData.clear();
 
-	for(i = 0; i < (unsigned int)argBVH->getNodeNum(); i++) {
-		if(argBVH->getNodeName(i) == "End Site") continue;
-		// cout << "make new animation: " << argBVH->getNodeName(i) << endl;
+	for(i = 0; i < static_cast<_st>(argBVH->getNodeNum()); i++) {
+
+		if(argBVH->getNodeName(static_cast<int>(i)) == "End Site") continue;
+
 		MakeNewAnimation();
+
 		cur = animData.back();
-		cur->SetName(argBVH->getNodeName(i));
-		cur->SetTransKeyNum(argBVH->posArray[i].size());
-		cur->SetRotKeyNum(argBVH->rotArray[i].size());
+		cur->SetName(argBVH->getNodeName(static_cast<int>(i)));
+		cur->SetTransKeyNum(static_cast<int>(argBVH->posArray[i].size()));
+		cur->SetRotKeyNum(static_cast<int>(argBVH->rotArray[i].size()));
+
 		if(argBVH->posArray[i].size() > argBVH->rotArray[i].size()) {
-			cur->SetScaleKeyNum(argBVH->posArray[i].size());
+			cur->SetScaleKeyNum(static_cast<int>(argBVH->posArray[i].size()));
 		} else {
-			cur->SetScaleKeyNum(argBVH->rotArray[i].size());
+			cur->SetScaleKeyNum(static_cast<int>(argBVH->rotArray[i].size()));
 		}
-		for(j = 0; j < (unsigned int)cur->GetTransKeyNum(); j++) {
-			cur->SetTransKey(j, double(int(argBVH->oneFrameTime*1000.0)*(j+1)));
-			cur->SetTransData(j, argBVH->posArray[i][j]);
+
+		for(j = 0; j < static_cast<_st>(cur->GetTransKeyNum()); j++) {
+			fTime = static_cast<int>(argBVH->oneFrameTime*1000.0);
+			timeD = static_cast<double>(fTime*static_cast<int>(j+1));
+															 
+			cur->SetTransKey(static_cast<int>(j), timeD);
+			cur->SetTransData(static_cast<int>(j), argBVH->posArray[i][j]);
 		}
-		for(j = 0; j < (unsigned int)cur->GetRotKeyNum(); j++) {
-			cur->SetRotKey(j, double(int(argBVH->oneFrameTime*1000.0)*(j+1)));
+		for(j = 0; j < static_cast<_st>(cur->GetRotKeyNum()); j++) {
+			fTime = static_cast<int>(argBVH->oneFrameTime*1000.0);
+			timeD = static_cast<double>(fTime*static_cast<int>(j+1));
+
+			cur->SetRotKey(static_cast<int>(j), timeD);
 			q.makeEuler(argBVH->rotArray[i][j]);
-			cur->SetRotData(j, q);
+			cur->SetRotData(static_cast<int>(j), q);
 		}
-		for(j = 0; j < (unsigned int)cur->GetScaleKeyNum(); j++) {
-			cur->SetScaleKey(j, double(int(argBVH->oneFrameTime*1000.0)*(j+1)));
-			cur->SetScaleData(j, fk_Vector(1.0, 1.0, 1.0));
+		for(j = 0; j < static_cast<_st>(cur->GetScaleKeyNum()); j++) {
+			fTime = static_cast<int>(argBVH->oneFrameTime*1000.0);
+			timeD = static_cast<double>(fTime*static_cast<int>(j+1));
+
+			cur->SetScaleKey(static_cast<int>(j), timeD);
+			cur->SetScaleData(static_cast<int>(j), fk_Vector(1.0, 1.0, 1.0));
 		}
 
 		for(j = 0; j < frameData.size(); j++) {
 			if(cur->GetName() == frameData.at(j)->GetName()) {
-				//cout << "connect: " << cur->GetName() << "->" << frameData.at(j)->GetName() << endl;
 				frameData.at(j)->SetAnimation(cur);
 				frameData.at(j)->SetUpMatrix();
 				break;
