@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -91,6 +91,7 @@ fk_DisplayLink::fk_DisplayLink(void)
 	projStatus = 0;
 
 	clearStereo();
+	stereoOverlayMode = true;
 
 	return;
 }
@@ -124,7 +125,7 @@ void fk_DisplayLink::entryModel(fk_Model *argModel)
 {
 	if(argModel == NULL) return;
 
-	if(argModel->getShape() != (fk_Shape *)NULL) {
+	if(argModel->getShape() != NULL) {
 		if(argModel->getShape()->getObjectType() == FK_LIGHT) {
 			lightList.remove(argModel);
 			lightList.push_back(argModel);
@@ -158,7 +159,7 @@ void fk_DisplayLink::entryOverlayModel(fk_Model *argModel)
 {
 	if(argModel == NULL) return;
 
-	if(argModel->getShape() != (fk_Shape *)NULL) {
+	if(argModel->getShape() != NULL) {
 		if(argModel->getShape()->getObjectType() == FK_LIGHT) {
 			return;
 		}
@@ -186,7 +187,7 @@ void fk_DisplayLink::clearOverlayModel(void)
 
 void fk_DisplayLink::entryCamera(fk_Model *argModel)
 {
-	if(argModel == (fk_Model *)NULL) {
+	if(argModel == NULL) {
 		camera = &localCamera;
 	} else {
 		camera = argModel;
@@ -225,17 +226,17 @@ void fk_DisplayLink::setProjection(fk_ProjectBase *argProj)
 
 	switch(argProj->getMode()) {
 	  case FK_PERSPECTIVE_MODE:
-		perspective = *((fk_Perspective *)argProj);
+		perspective = *(static_cast<fk_Perspective *>(argProj));
 		proj = &perspective;
 		break;
 
 	  case FK_FRUSTUM_MODE:
-		frustum = *((fk_Frustum *)argProj);
+		frustum = *(static_cast<fk_Frustum *>(argProj));
 		proj = &frustum;
 		break;
 
 	  case FK_ORTHO_MODE:
-		ortho = *((fk_Ortho *)argProj);
+		ortho = *(static_cast<fk_Ortho *>(argProj));
 		proj = &ortho;
 		break;
 
@@ -258,7 +259,8 @@ int fk_DisplayLink::GetProjChangeStatus(void) const
 	return projStatus;
 }
 
-void fk_DisplayLink::entryStereoCamera(fk_StereoChannel channel, fk_Model *argModel)
+void fk_DisplayLink::entryStereoCamera(fk_StereoChannel channel,
+									   fk_Model *argModel)
 {
 	if(channel == FK_STEREO_LEFT) {
 		stereoCamera[0] = argModel;
@@ -267,7 +269,8 @@ void fk_DisplayLink::entryStereoCamera(fk_StereoChannel channel, fk_Model *argMo
 	}
 }
 
-void fk_DisplayLink::setStereoProjection(fk_StereoChannel channel, fk_ProjectBase *argProj)
+void fk_DisplayLink::setStereoProjection(fk_StereoChannel channel,
+										 fk_ProjectBase *argProj)
 {
 	int index;
 
@@ -286,17 +289,17 @@ void fk_DisplayLink::setStereoProjection(fk_StereoChannel channel, fk_ProjectBas
 
 	switch(argProj->getMode()) {
 	  case FK_PERSPECTIVE_MODE:
-		stereoPers[index] = *((fk_Perspective *)argProj);
+		stereoPers[index] = *(static_cast<fk_Perspective *>(argProj));
 		stereoProj[index] = &stereoPers[index];
 		break;
 
 	  case FK_FRUSTUM_MODE:
-		stereoFrus[index] = *((fk_Frustum *)argProj);
+		stereoFrus[index] = *(static_cast<fk_Frustum *>(argProj));
 		stereoProj[index] = &stereoFrus[index];
 		break;
 
 	  case FK_ORTHO_MODE:
-		stereoOrtho[index] = *((fk_Ortho *)argProj);
+		stereoOrtho[index] = *(static_cast<fk_Ortho *>(argProj));
 		stereoProj[index] = &stereoOrtho[index];
 		break;
 
@@ -332,3 +335,14 @@ void fk_DisplayLink::clearStereo(void)
 	stereoProj[0] = proj;
 	stereoProj[1] = proj;
 }
+
+void fk_DisplayLink::setStereoOverlayMode(bool argFlg)
+{
+	stereoOverlayMode = argFlg;
+	return;
+}
+
+bool fk_DisplayLink::getStereoOverlayMode(void)
+{
+	return stereoOverlayMode;
+}
