@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -69,6 +69,8 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+
+#define FK_DEF_SIZETYPE
 #include <FK/Base.h>
 #include <FK/DataBase.H>
 
@@ -148,52 +150,54 @@ void fk_DataBase::CloneData(fk_DataBase *argDB)
 
 void fk_DataBase::ResizeData(fk_DataBase *argDB)
 {
-	ResizeData(argDB->vSet.size(), argDB->hSet.size(),
-			   argDB->eSet.size(), argDB->lSet.size());
+	ResizeData(static_cast<int>(argDB->vSet.size()),
+			   static_cast<int>(argDB->hSet.size()),
+			   static_cast<int>(argDB->eSet.size()),
+			   static_cast<int>(argDB->lSet.size()));
 
 	return;
 }
 
-void fk_DataBase::ResizeData(unsigned int argVNum, unsigned int argHNum,
-							 unsigned int argENum, unsigned int argLNum)
+void fk_DataBase::ResizeData(int argVNum, int argHNum,
+							 int argENum, int argLNum)
 {
-	unsigned int	i;
+	_st		i;
 
-	for(i = vSet.size(); i < argVNum; i++) {
-		vSet.push_back(new fk_Vertex(int(i+1)));
+	for(i = vSet.size(); i < static_cast<_st>(argVNum); i++) {
+		vSet.push_back(new fk_Vertex(static_cast<int>(i+1)));
 	}
 
-	for(i = argVNum; i < vSet.size(); i++) {
+	for(i = static_cast<_st>(argVNum); i < vSet.size(); i++) {
 		delete vSet.back();
 		vSet.pop_back();
 	}
-	vAdmin.Resize(argVNum);
+	vAdmin.Resize(static_cast<int>(argVNum));
 		
-	for(i = hSet.size(); i < argHNum; i++) {
-		hSet.push_back(new fk_Half(int(i+1)));
+	for(i = hSet.size(); i < static_cast<_st>(argHNum); i++) {
+		hSet.push_back(new fk_Half(static_cast<int>(i+1)));
 	}
 
-	for(i = argHNum; i < hSet.size(); i++) {
+	for(i = static_cast<_st>(argHNum); i < hSet.size(); i++) {
 		delete hSet.back();
 		hSet.pop_back();
 	}
-	hAdmin.Resize(argHNum);
+	hAdmin.Resize(static_cast<int>(argHNum));
 		
-	for(i = eSet.size(); i < argENum; i++) {
-		eSet.push_back(new fk_Edge(int(i+1)));
+	for(i = eSet.size(); i < static_cast<_st>(argENum); i++) {
+		eSet.push_back(new fk_Edge(static_cast<int>(i+1)));
 	}
 
-	for(i = argENum; i < eSet.size(); i++) {
+	for(i = static_cast<_st>(argENum); i < eSet.size(); i++) {
 		delete eSet.back();
 		eSet.pop_back();
 	}
 	eAdmin.Resize(argENum);
 		
-	for(i = lSet.size(); i < argLNum; i++) {
-		lSet.push_back(new fk_Loop(int(i+1)));
+	for(i = lSet.size(); i < static_cast<_st>(argLNum); i++) {
+		lSet.push_back(new fk_Loop(static_cast<int>(i+1)));
 	}
 
-	for(i = argLNum; i < lSet.size(); i++) {
+	for(i = static_cast<_st>(argLNum); i < lSet.size(); i++) {
 		delete lSet.back();
 		lSet.pop_back();
 	}
@@ -204,8 +208,8 @@ void fk_DataBase::ResizeData(unsigned int argVNum, unsigned int argHNum,
 
 void fk_DataBase::VSetClone(vector<fk_Vertex *> *argVSet)
 {
-	unsigned int	i;
-	fk_Vertex		*orgV, *newV;
+	_st			i;
+	fk_Vertex	*orgV, *newV;
 
 	for(i = 0; i < vSet.size(); i++) {
 		newV = vSet[i];
@@ -220,8 +224,8 @@ void fk_DataBase::VSetClone(vector<fk_Vertex *> *argVSet)
 		newV->normal = orgV->normal;
 		newV->normCalcFlag = orgV->normCalcFlag;
 		newV->normFailFlag = orgV->normFailFlag;
-		if(orgV->oneHalf == (fk_Half *)NULL) {
-			newV->oneHalf = (fk_Half *)NULL;
+		if(orgV->oneHalf == NULL) {
+			newV->oneHalf = NULL;
 		} else {
 			newV->oneHalf = GetHData(orgV->oneHalf->getID());
 		}
@@ -232,8 +236,8 @@ void fk_DataBase::VSetClone(vector<fk_Vertex *> *argVSet)
 
 void fk_DataBase::HSetClone(vector<fk_Half *> *argHSet)
 {
-	unsigned int	i;
-	fk_Half			*orgH, *newH;
+	_st			i;
+	fk_Half		*orgH, *newH;
 
 	for(i = 0; i < hSet.size(); i++) {
 		orgH = (*argHSet)[i];
@@ -247,8 +251,8 @@ void fk_DataBase::HSetClone(vector<fk_Half *> *argHSet)
 		newH->nextHalf = GetHData(orgH->nextHalf->getID());
 		newH->prevHalf = GetHData(orgH->prevHalf->getID());
 		newH->parentEdge = GetEData(orgH->parentEdge->getID());
-		if(orgH->parentLoop == (fk_Loop *)NULL) {
-			newH->parentLoop = (fk_Loop *)NULL;
+		if(orgH->parentLoop == NULL) {
+			newH->parentLoop = NULL;
 		} else {
 			newH->parentLoop = GetLData(orgH->parentLoop->getID());
 		}
@@ -259,16 +263,15 @@ void fk_DataBase::HSetClone(vector<fk_Half *> *argHSet)
 
 void fk_DataBase::ESetClone(vector<fk_Edge *> *argESet)
 {
-	unsigned int	i;
-	fk_Edge			*orgE, *newE;
+	_st			i;
+	fk_Edge		*orgE, *newE;
 
 	for(i = 0; i < eSet.size(); i++) {
 		orgE = (*argESet)[i];
 		newE = eSet[i];
 
-		if(newE->CloneElem(orgE) == false) {
-			continue;
-		}
+		if(newE->CloneElem(orgE) == false) continue;
+
 		newE->CloneMaterial(orgE);
 
 		newE->rightHalf = GetHData(orgE->rightHalf->getID());
@@ -280,16 +283,15 @@ void fk_DataBase::ESetClone(vector<fk_Edge *> *argESet)
 
 void fk_DataBase::LSetClone(vector<fk_Loop *> *argLSet)
 {
-	unsigned int	i;
-	fk_Loop			*orgL, *newL;
+	_st			i;
+	fk_Loop		*orgL, *newL;
 
 	for(i = 0; i < lSet.size(); i++) {
 		orgL = (*argLSet)[i];
 		newL = lSet[i];
 
-		if(newL->CloneElem(orgL) == false) {
-			continue;
-		}
+		if(newL->CloneElem(orgL) == false) continue;
+
 		newL->CloneMaterial(orgL);
 
 		newL->oneHalf = GetHData(orgL->oneHalf->getID());
@@ -317,16 +319,16 @@ bool fk_DataBase::VCompare(fk_DataBase *argDB)
 {
 	fk_Vertex		*v1, *v2;
 
-	v1 = GetNextV((fk_Vertex *)NULL);
-	v2 = argDB->GetNextV((fk_Vertex *)NULL);
+	v1 = GetNextV(NULL);
+	v2 = argDB->GetNextV(NULL);
 
-	while(v1 != (fk_Vertex *)NULL) {
+	while(v1 != NULL) {
 		if(v1->Compare(v2) == false) return false;
 		v1 = GetNextV(v1);
 		v2 = argDB->GetNextV(v2);
 	}
 
-	if(v2 != (fk_Vertex *)NULL) return false;
+	if(v2 != NULL) return false;
 	return true;
 }
 
@@ -334,16 +336,16 @@ bool fk_DataBase::HCompare(fk_DataBase *argDB)
 {
 	fk_Half		*h1, *h2;
 
-	h1 = GetNextH((fk_Half *)NULL);
-	h2 = argDB->GetNextH((fk_Half *)NULL);
+	h1 = GetNextH(NULL);
+	h2 = argDB->GetNextH(NULL);
 
-	while(h1 != (fk_Half *)NULL) {
+	while(h1 != NULL) {
 		if(h1->Compare(h2) == false) return false;
 		h1 = GetNextH(h1);
 		h2 = argDB->GetNextH(h2);
 	}
 
-	if(h2 != (fk_Half *)NULL) return false;
+	if(h2 != NULL) return false;
 	return true;
 }
 
@@ -351,16 +353,16 @@ bool fk_DataBase::ECompare(fk_DataBase *argDB)
 {
 	fk_Edge		*e1, *e2;
 
-	e1 = GetNextE((fk_Edge *)NULL);
-	e2 = argDB->GetNextE((fk_Edge *)NULL);
+	e1 = GetNextE(NULL);
+	e2 = argDB->GetNextE(NULL);
 
-	while(e1 != (fk_Edge *)NULL) {
+	while(e1 != NULL) {
 		if(e1->Compare(e2) == false) return false;
 		e1 = GetNextE(e1);
 		e2 = argDB->GetNextE(e2);
 	}
 
-	if(e2 != (fk_Edge *)NULL) return false;
+	if(e2 != NULL) return false;
 	return true;
 }
 
@@ -368,135 +370,135 @@ bool fk_DataBase::LCompare(fk_DataBase *argDB)
 {
 	fk_Loop		*l1, *l2;
 
-	l1 = GetNextL((fk_Loop *)NULL);
-	l2 = argDB->GetNextL((fk_Loop *)NULL);
+	l1 = GetNextL(NULL);
+	l2 = argDB->GetNextL(NULL);
 
-	while(l1 != (fk_Loop *)NULL) {
+	while(l1 != NULL) {
 		if(l1->Compare(l2) == false) return false;
 		l1 = GetNextL(l1);
 		l2 = argDB->GetNextL(l2);
 	}
 
-	if(l2 != (fk_Loop *)NULL) return false;
+	if(l2 != NULL) return false;
 	return true;
 }
 
 fk_Vertex * fk_DataBase::GetNewVertex(void)
 {
 	int newID = vAdmin.CreateID();
-	if((int)vSet.size() == newID - 1) {
+	if(static_cast<int>(vSet.size())== newID - 1) {
 		vSet.push_back(new fk_Vertex(newID));
 	} else {
-		vSet[newID-1]->Init(newID);
+		vSet[static_cast<_st>(newID-1)]->Init(newID);
 	}
 
-	return vSet[newID-1];
+	return vSet[static_cast<_st>(newID-1)];
 }
 
 fk_Vertex * fk_DataBase::GetNewVertex(int argID)
 {
 	if(vAdmin.CreateID(argID) == false) {
-		return (fk_Vertex *)NULL;
+		return NULL;
 	}
 
-	if((int)vSet.size() == argID - 1) {
+	if(static_cast<int>(vSet.size()) == argID - 1) {
 		vSet.push_back(new fk_Vertex(argID));
 	} else {
-		vSet[argID-1]->Init(argID);
+		vSet[static_cast<_st>(argID-1)]->Init(argID);
 	}
 
-	return vSet[argID-1];
+	return vSet[static_cast<_st>(argID-1)];
 }
 
 fk_Half * fk_DataBase::GetNewHalf(void)
 {
 	int newID = hAdmin.CreateID();
 
-	if((int)hSet.size() == newID - 1) {
+	if(static_cast<int>(hSet.size()) == newID - 1) {
 		hSet.push_back(new fk_Half(newID));
 	} else {
-		hSet[newID-1]->Init(newID);
+		hSet[static_cast<_st>(newID-1)]->Init(newID);
 	}
 
-	return hSet[newID-1];
+	return hSet[static_cast<_st>(newID-1)];
 }
 
 fk_Half * fk_DataBase::GetNewHalf(int argID)
 {
 	if(hAdmin.CreateID(argID) == false) {
-		return (fk_Half *)NULL;
+		return NULL;
 	}
 
-	if((int)hSet.size() == argID - 1) {
+	if(static_cast<int>(hSet.size()) == argID - 1) {
 		hSet.push_back(new fk_Half(argID));
 	} else {
-		hSet[argID-1]->Init(argID);
+		hSet[static_cast<_st>(argID-1)]->Init(argID);
 	}
 
-	return hSet[argID-1];
+	return hSet[static_cast<_st>(argID-1)];
 }
 
 fk_Edge * fk_DataBase::GetNewEdge(void)
 {
 	int newID = eAdmin.CreateID();
 
-	if((int)eSet.size() == newID - 1) {
+	if(static_cast<int>(eSet.size()) == newID - 1) {
 		eSet.push_back(new fk_Edge(newID));
 	} else {
-		eSet[newID-1]->MakeElem(newID);
+		eSet[static_cast<_st>(newID-1)]->MakeElem(newID);
 	}
 
-	return eSet[newID-1];
+	return eSet[static_cast<_st>(newID-1)];
 }
 
 fk_Edge * fk_DataBase::GetNewEdge(int argID)
 {
 	if(eAdmin.CreateID(argID) == false) {
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
-	if((int)eSet.size() == argID - 1) {
+	if(static_cast<int>(eSet.size()) == argID - 1) {
 		eSet.push_back(new fk_Edge(argID));
 	} else {
-		eSet[argID-1]->MakeElem(argID);
+		eSet[static_cast<_st>(argID-1)]->MakeElem(argID);
 	}
 
-	return eSet[argID-1];
+	return eSet[static_cast<_st>(argID-1)];
 }
 
 fk_Loop * fk_DataBase::GetNewLoop(void)
 {
 	int newID = lAdmin.CreateID();
 
-	if((int)lSet.size() == newID - 1) {
+	if(static_cast<int>(lSet.size()) == newID - 1) {
 		lSet.push_back(new fk_Loop(newID));
 	} else {
-		lSet[newID-1]->MakeElem(newID);
+		lSet[static_cast<_st>(newID-1)]->MakeElem(newID);
 	}
 
-	return lSet[newID-1];
+	return lSet[static_cast<_st>(newID-1)];
 }
 
 fk_Loop * fk_DataBase::GetNewLoop(int argID)
 {
 	if(lAdmin.CreateID(argID) == false) {
-		return (fk_Loop *)NULL;
+		return NULL;
 	}
 
-	if((int)lSet.size() == argID - 1) {
+	if(static_cast<int>(lSet.size()) == argID - 1) {
 		lSet.push_back(new fk_Loop(argID));
 	} else {
-		lSet[argID-1]->MakeElem(argID);
+		lSet[static_cast<_st>(argID-1)]->MakeElem(argID);
 	}
 
-	return lSet[argID-1];
+	return lSet[static_cast<_st>(argID-1)];
 }
 
 bool fk_DataBase::ExistVertex(fk_Vertex *argVx) const
 {
-	if(argVx == (fk_Vertex *)NULL) return false;
+	if(argVx == NULL) return false;
 	if(ExistVertex(argVx->getID()) == false) return false;
-	if(vSet[argVx->getID() - 1] != argVx) return false;
+	if(vSet[static_cast<_st>(argVx->getID() - 1)] != argVx) return false;
 	return true;
 }
 
@@ -507,9 +509,9 @@ bool fk_DataBase::ExistVertex(int argID) const
 
 bool fk_DataBase::ExistHalf(fk_Half *argHf) const
 {
-	if(argHf == (fk_Half *)NULL) return false;
+	if(argHf == NULL) return false;
 	if(ExistHalf(argHf->getID()) == false) return false;
-	if(hSet[argHf->getID() - 1] != argHf) return false;
+	if(hSet[static_cast<_st>(argHf->getID() - 1)] != argHf) return false;
 	return true;
 }
 
@@ -520,9 +522,9 @@ bool fk_DataBase::ExistHalf(int argID) const
 
 bool fk_DataBase::ExistEdge(fk_Edge *argEd) const
 {
-	if(argEd == (fk_Edge *)NULL) return false;
+	if(argEd == NULL) return false;
 	if(ExistEdge(argEd->getID()) == false) return false;
-	if(eSet[argEd->getID() - 1] != argEd) return false;
+	if(eSet[static_cast<_st>(argEd->getID() - 1)] != argEd) return false;
 	return true;
 }
 
@@ -533,9 +535,9 @@ bool fk_DataBase::ExistEdge(int argID) const
 
 bool fk_DataBase::ExistLoop(fk_Loop *argLp) const
 {
-	if(argLp == (fk_Loop *)NULL) return false;
+	if(argLp == NULL) return false;
 	if(ExistLoop(argLp->getID()) == false) return false;
-	if(lSet[argLp->getID() - 1] != argLp) return false;
+	if(lSet[static_cast<_st>(argLp->getID() - 1)] != argLp) return false;
 	return true;
 }
 
@@ -547,58 +549,58 @@ bool fk_DataBase::ExistLoop(int argID) const
 bool fk_DataBase::DeleteVertex(int argID)
 {
 	if(vAdmin.EraseID(argID) == false) return false;
-	vSet[argID-1]->DeleteElem();
+	vSet[static_cast<_st>(argID-1)]->DeleteElem();
 	return true;
 }
 
 bool fk_DataBase::DeleteHalf(int argID)
 {
 	if(hAdmin.EraseID(argID) == false) return false;
-	hSet[argID-1]->DeleteElem();
+	hSet[static_cast<_st>(argID-1)]->DeleteElem();
 	return true;
 }
 
 bool fk_DataBase::DeleteEdge(int argID)
 {
 	if(eAdmin.EraseID(argID) == false) return false;
-	eSet[argID-1]->DeleteElem();
+	eSet[static_cast<_st>(argID-1)]->DeleteElem();
 	return true;
 }
 
 bool fk_DataBase::DeleteLoop(int argID)
 {
 	if(lAdmin.EraseID(argID) == false) return false;
-	lSet[argID-1]->DeleteElem();
+	lSet[static_cast<_st>(argID-1)]->DeleteElem();
 	return true;
 }
 
 fk_Vertex * fk_DataBase::GetVData(int argVID) const
 {
-	if(vAdmin.ExistID(argVID) == false) return (fk_Vertex *)NULL;
-	return vSet[argVID - 1];
+	if(vAdmin.ExistID(argVID) == false) return NULL;
+	return vSet[static_cast<_st>(argVID - 1)];
 }
 
 fk_Half * fk_DataBase::GetHData(int argHID) const
 {
-	if(hAdmin.ExistID(argHID) == false) return (fk_Half *)NULL;
-	return hSet[argHID - 1];
+	if(hAdmin.ExistID(argHID) == false) return NULL;
+	return hSet[static_cast<_st>(argHID - 1)];
 }
 
 fk_Edge * fk_DataBase::GetEData(int argEID) const
 {
-	if(eAdmin.ExistID(argEID) == false) return (fk_Edge *)NULL;
-	return eSet[argEID - 1];
+	if(eAdmin.ExistID(argEID) == false) return NULL;
+	return eSet[static_cast<_st>(argEID - 1)];
 }
 
 fk_Loop * fk_DataBase::GetLData(int argLID) const
 {
-	if(lAdmin.ExistID(argLID) == false) return (fk_Loop *)NULL;
-	return lSet[argLID - 1];
+	if(lAdmin.ExistID(argLID) == false) return NULL;
+	return lSet[static_cast<_st>(argLID - 1)];
 }
 
 fk_Vertex * fk_DataBase::GetNextV(fk_Vertex *argV) const
 {
-	if(argV == (fk_Vertex *)NULL) {
+	if(argV == NULL) {
 		return GetVData(vAdmin.GetNext(0));
 	} else {
 		return GetVData(vAdmin.GetNext(argV->getID()));
@@ -607,7 +609,7 @@ fk_Vertex * fk_DataBase::GetNextV(fk_Vertex *argV) const
 
 fk_Half * fk_DataBase::GetNextH(fk_Half *argH) const
 {
-	if(argH == (fk_Half *)NULL) {
+	if(argH == NULL) {
 		return GetHData(hAdmin.GetNext(0));
 	} else {
 		return GetHData(hAdmin.GetNext(argH->getID()));
@@ -616,7 +618,7 @@ fk_Half * fk_DataBase::GetNextH(fk_Half *argH) const
 
 fk_Edge * fk_DataBase::GetNextE(fk_Edge *argE) const
 {
-	if(argE == (fk_Edge *)NULL) {
+	if(argE == NULL) {
 		return GetEData(eAdmin.GetNext(0));
 	} else {
 		return GetEData(eAdmin.GetNext(argE->getID()));
@@ -625,7 +627,7 @@ fk_Edge * fk_DataBase::GetNextE(fk_Edge *argE) const
 
 fk_Loop * fk_DataBase::GetNextL(fk_Loop *argL) const
 {
-	if(argL == (fk_Loop *)NULL) {
+	if(argL == NULL) {
 		return GetLData(lAdmin.GetNext(0));
 	} else {
 		return GetLData(lAdmin.GetNext(argL->getID()));
@@ -674,17 +676,15 @@ int fk_DataBase::GetLNum(void) const
 
 void fk_DataBase::VPrint(int argID) const
 {
-	register unsigned int	i;
-
 	if(argID == FK_UNDEFINED) {
-		for(i = 0; i < vSet.size(); i++) {
+		for(_st i = 0; i < vSet.size(); i++) {
 			if(vSet[i]->getID() != FK_UNDEFINED) vSet[i]->Print();
 		}
 	} else if(!vAdmin.ExistID(argID)) {
 		fk_PutError("fk_DataBase", "VPrint", 1,
 					"Vertex Admin Error.");
 	} else {
-		vSet[argID-1]->Print();
+		vSet[static_cast<_st>(argID-1)]->Print();
 	}
 
 	return;
@@ -693,17 +693,15 @@ void fk_DataBase::VPrint(int argID) const
 
 void fk_DataBase::HPrint(int argID) const
 {
-	register unsigned int	i;
-
 	if(argID == FK_UNDEFINED) {
-		for(i = 0; i < hSet.size(); i++) {
+		for(_st i = 0; i < hSet.size(); i++) {
 			if(hSet[i]->getID() != FK_UNDEFINED) hSet[i]->Print();
 		}
 	} else if(!hAdmin.ExistID(argID)) {
 		fk_PutError("fk_DataBase", "HPrint", 1,
 					"Half Edge Admin Error.");
 	} else {
-		hSet[argID-1]->Print();
+		hSet[static_cast<_st>(argID-1)]->Print();
 	}
 
 	return;
@@ -711,17 +709,15 @@ void fk_DataBase::HPrint(int argID) const
 
 void fk_DataBase::EPrint(int argID) const
 {
-	register unsigned int	i;
-
 	if(argID == FK_UNDEFINED) {
-		for(i = 0; i < eSet.size(); i++) {
+		for(_st i = 0; i < eSet.size(); i++) {
 			if(eSet[i]->getID() != FK_UNDEFINED) eSet[i]->Print();
 		}
 	} else if(!eAdmin.ExistID(argID)) {
 		fk_PutError("fk_DataBase", "EPrint", 1,
 					"Edge Admin Error.");
 	} else {
-		eSet[argID-1]->Print();
+		eSet[static_cast<_st>(argID-1)]->Print();
 	}
 
 	return;
@@ -729,17 +725,15 @@ void fk_DataBase::EPrint(int argID) const
 
 void fk_DataBase::LPrint(int argID) const
 {
-	register unsigned int	i;
-
 	if(argID == FK_UNDEFINED) {
-		for(i = 0; i < lSet.size(); i++) {
+		for(_st i = 0; i < lSet.size(); i++) {
 			if(lSet[i]->getID() != FK_UNDEFINED) lSet[i]->Print();
 		}
 	} else if(!lAdmin.ExistID(argID)) {
 		fk_PutError("fk_DataBase", "LPrint", 1,
 					"Loop Admin Error.");
 	} else {
-		lSet[argID-1]->Print();
+		lSet[static_cast<_st>(argID-1)]->Print();
 	}
 
 	return;
@@ -757,11 +751,10 @@ void	fk_DataBase::AllPrint(void) const
 
 bool	fk_DataBase::VCheck(int argID) const
 {
-	register unsigned int	i;
-	bool					retBool = true;
+	bool	retBool = true;
 
 	if(argID == FK_UNDEFINED) {
-		for(i = 0; i < vSet.size(); i++) {
+		for(_st i = 0; i < vSet.size(); i++) {
 			if(vSet[i]->getID() != FK_UNDEFINED) {
 				if(vSet[i]->Check() == false) {
 					retBool = false;
@@ -773,7 +766,7 @@ bool	fk_DataBase::VCheck(int argID) const
 					"Vertex Admin Error.");
 		retBool = false;
 	} else {
-		retBool = vSet[argID-1]->Check();
+		retBool = vSet[static_cast<_st>(argID-1)]->Check();
 	}
 
 	return retBool;
@@ -781,11 +774,10 @@ bool	fk_DataBase::VCheck(int argID) const
 
 bool	fk_DataBase::HCheck(int argID) const
 {
-	register unsigned int	i;
-	bool					retBool = true;
+	bool	retBool = true;
 
 	if(argID == FK_UNDEFINED) {
-		for(i = 0; i < hSet.size(); i++) {
+		for(_st i = 0; i < hSet.size(); i++) {
 			if(hSet[i]->getID() != FK_UNDEFINED) {
 				if(hSet[i]->Check() == false) {
 					retBool = false;
@@ -797,7 +789,7 @@ bool	fk_DataBase::HCheck(int argID) const
 					"Half Edge Admin Error.");
 		retBool = false;
 	} else {
-		retBool = hSet[argID-1]->Check();
+		retBool = hSet[static_cast<_st>(argID-1)]->Check();
 	}
 
 	return retBool;
@@ -805,11 +797,10 @@ bool	fk_DataBase::HCheck(int argID) const
 
 bool	fk_DataBase::ECheck(int argID) const
 {
-	register unsigned int	i;
-	bool					retBool = true;
+	bool	retBool = true;
 
 	if(argID == FK_UNDEFINED) {
-		for(i = 0; i < eSet.size(); i++) {
+		for(_st i = 0; i < eSet.size(); i++) {
 			if(eSet[i]->getID() != FK_UNDEFINED) {
 				if(eSet[i]->Check() == false) {
 					retBool = false;
@@ -821,7 +812,7 @@ bool	fk_DataBase::ECheck(int argID) const
 					"Edge Admin Error.");
 		retBool = false;
 	} else {
-		retBool = eSet[argID-1]->Check();
+		retBool = eSet[static_cast<_st>(argID-1)]->Check();
 	}
 
 	return retBool;
@@ -829,11 +820,10 @@ bool	fk_DataBase::ECheck(int argID) const
 
 bool fk_DataBase::LCheck(int argID) const
 {
-	register unsigned int	i;
-	bool					retBool = true;
+	bool	retBool = true;
 
 	if(argID == FK_UNDEFINED) {
-		for(i = 0; i < lSet.size(); i++) {
+		for(_st i = 0; i < lSet.size(); i++) {
 			if(lSet[i]->getID() != FK_UNDEFINED) {
 				if(lSet[i]->Check() == false) {
 					retBool = false;
@@ -845,7 +835,7 @@ bool fk_DataBase::LCheck(int argID) const
 					"Loop Admin Error");
 		retBool = false;
 	} else {
-		retBool = lSet[argID-1]->Check();
+		retBool = lSet[static_cast<_st>(argID-1)]->Check();
 	}
 
 	return retBool;
