@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -73,6 +73,7 @@
 #include "Engine_D3D.cxx"
 #else
 
+#define FK_DEF_SIZETYPE
 #include <FK/Engine.H>
 #include <FK/Scene.h>
 #include <FK/Light.h>
@@ -83,7 +84,6 @@
 #include <FK/LineDraw.H>
 #include <FK/FaceDraw.H>
 #include <FK/TextureDraw.H>
-
 #include <FK/Error.H>
 
 using namespace std;
@@ -97,7 +97,15 @@ fk_GraphicsEngine::fk_GraphicsEngine(void)
 	faceDraw = new fk_FaceDraw;
 	textureDraw = new fk_TextureDraw;
 
+	winID = 0;
 	curDLink = NULL;
+	dLinkStatus = 0;
+	dLinkID = 0;
+	wSize = 0;
+	hSize = 0;
+	arrayState = false;
+	resizeFlag = false;
+	textureMode = false;
 
 	return;
 }
@@ -153,13 +161,18 @@ void fk_GraphicsEngine::ClearTextureMemory(void)
 	return;
 }
 
+unsigned long fk_GraphicsEngine::GetUsingTextureMemory(void)
+{
+	return textureDraw->GetUsingTextureMemory();
+}
+
 void fk_GraphicsEngine::SetViewPort(void)
 {
 	glViewport(0, 0, wSize, hSize);
 	glMatrixMode(GL_PROJECTION);
 	glLoadIdentity();
 
-	if(curDLink == (fk_DisplayLink *)NULL) {
+	if(curDLink == NULL) {
 		SetDefaultProjection();
 	} else {
 		SetProjection(curDLink->getProjection());
@@ -209,7 +222,7 @@ void fk_GraphicsEngine::SetDefaultProjection(void)
 {
 	double			aspect;
 
-	aspect = GLfloat(wSize)/GLfloat(hSize);
+	aspect = static_cast<GLfloat>(wSize)/static_cast<GLfloat>(hSize);
 	gluPerspective(40.0, aspect, 1.0, 6000.0);
 }
 
@@ -227,7 +240,7 @@ void fk_GraphicsEngine::SetProjection(const fk_ProjectBase *argProj)
 	  case FK_PERSPECTIVE_MODE:
 		pers = static_cast<fk_Perspective *>(proj);
 		gluPerspective((180.0 * pers->getFovy())/FK_PI,
-					   GLfloat(wSize)/GLfloat(hSize),
+					   static_cast<GLfloat>(wSize)/static_cast<GLfloat>(hSize),
 					   pers->getNear(), pers->getFar());
 		break;
 
@@ -285,16 +298,18 @@ void fk_GraphicsEngine::OpenGLInit(void)
 	return;
 }
 
-void fk_GraphicsEngine::SetStereoViewPort(int channel)
+void fk_GraphicsEngine::SetStereoViewPort(int argChannel)
 {
+	fk_StereoChannel	channel = static_cast<fk_StereoChannel>(argChannel);
+
 	glViewport(0, 0, wSize, hSize);
 	glMatrixMode(GL_PROJECTION);
 	glLoadIdentity();
 
-	if(curDLink == (fk_DisplayLink *)NULL) {
+	if(curDLink == NULL) {
 		SetDefaultProjection();
 	} else {
-		SetProjection(curDLink->getStereoProjection((fk_StereoChannel)channel));
+		SetProjection(curDLink->getStereoProjection(channel));
 	}
 
 	glMatrixMode(GL_MODELVIEW);
@@ -304,10 +319,12 @@ void fk_GraphicsEngine::SetStereoViewPort(int channel)
 	return;
 }
 
-void fk_GraphicsEngine::RecalcStereoModelView(int channel)
+void fk_GraphicsEngine::RecalcStereoModelView(int argChannel)
 {
+	fk_StereoChannel	channel = static_cast<fk_StereoChannel>(argChannel);
+
 	if(curDLink != NULL) {
-		const fk_Model	*camera = curDLink->getStereoCamera((fk_StereoChannel)channel);
+		const fk_Model	*camera = curDLink->getStereoCamera(channel);
 		if(camera == NULL) {
 			RecalcInhModelView(curDLink->getCamera());
 		} else {
@@ -318,14 +335,8 @@ void fk_GraphicsEngine::RecalcStereoModelView(int channel)
 	return;
 }
 
-void fk_GraphicsEngine::StereoDraw(void)
+void fk_GraphicsEngine::StereoDraw()
 {
-	//bool			fogStatus = false;
-	fk_Scene		*scene;
-	fk_Color		bgColor;
-
-	scene = NULL;
-
 	// どうせ毎回ビューポートを設定するのでリサイズフラグは潰す
 	if(resizeFlag == true || generalID > 2) {
 		//SetViewPort();
@@ -342,7 +353,7 @@ void fk_GraphicsEngine::StereoDraw(void)
 	glPushMatrix();
 
 	RecalcStereoModelView(FK_STEREO_LEFT);
-	DrawObjs(false);
+	DrawStereoObjs(false);
 	glPopMatrix();
 	glFlush();
 
@@ -354,13 +365,51 @@ void fk_GraphicsEngine::StereoDraw(void)
 	glPushMatrix();
 
 	RecalcStereoModelView(FK_STEREO_RIGHT);
-	DrawObjs(false);
+	DrawStereoObjs(false);
 	glPopMatrix();
 	glFlush();
 
 	return;
 }
 
+void fk_GraphicsEngine::DrawStereoObjs(bool argPickFlg)
+{
+	list<fk_Model *>::iterator	modelP, modelPEnd;
+	list<fk_Model *>			*overlayList;
+	bool						lightFlag;
+
+	if(curDLink == NULL) return;
+	
+	lightFlag = DefineLight();
+
+	if(argPickFlg == true) modelArray.clear();
+
+	textureDraw->StartUp();
+
+	modelPEnd = curDLink->GetModelList()->end();
+	for(modelP = curDLink->GetModelList()->begin();
+		modelP != modelPEnd; ++modelP) {
+		DrawModel(*modelP, lightFlag, argPickFlg);
+	}
+
+	overlayList = curDLink->GetOverlayList();
+	if(overlayList->empty() == true) return;
+
+	if(curDLink->getStereoOverlayMode() == false) {
+		SetViewPort();
+		RecalcModelView();
+	}
+
+	glDisable(GL_DEPTH_TEST);
+	modelPEnd = overlayList->end();
+	for(modelP = overlayList->begin(); modelP != modelPEnd; ++modelP) {
+		DrawModel(*modelP, lightFlag, argPickFlg);
+	}
+	glEnable(GL_DEPTH_TEST);
+
+	return;
+}
+
 void fk_GraphicsEngine::ApplySceneParameter(bool argVPFlg)
 {
 	bool			fogStatus = false;
@@ -390,7 +439,7 @@ void fk_GraphicsEngine::ApplySceneParameter(bool argVPFlg)
 		}
 	}
 
-	if(scene != (fk_Scene *)NULL) {
+	if(scene != NULL) {
 
 		if(scene->getBlendStatus() == true) {
 			glEnable(GL_BLEND);
@@ -412,12 +461,6 @@ void fk_GraphicsEngine::ApplySceneParameter(bool argVPFlg)
 
 void fk_GraphicsEngine::Draw(bool argPickFlg)
 {
-	//bool			fogStatus = false;
-	fk_Scene		*scene;
-	fk_Color		bgColor;
-
-	scene = NULL;
-
 	// リサイズ時に加えて、マルチウィンドウ時もビューポートを再設定(by rita)
 	if(resizeFlag == true || generalID > 2) {
 		SetViewPort();
@@ -491,16 +534,16 @@ void fk_GraphicsEngine::DrawObjs(bool argPickFlg)
 
 	modelPEnd = curDLink->GetModelList()->end();
 	for(modelP = curDLink->GetModelList()->begin();
-		modelP != modelPEnd; modelP++) {
+		modelP != modelPEnd; ++modelP) {
 		DrawModel(*modelP, lightFlag, argPickFlg);
 	}
 
 	overlayList = curDLink->GetOverlayList();
-	if(overlayList->size() == 0) return;
+	if(overlayList->empty() == true) return;
 
 	glDisable(GL_DEPTH_TEST);
 	modelPEnd = overlayList->end();
-	for(modelP = overlayList->begin(); modelP != modelPEnd; modelP++) {
+	for(modelP = overlayList->begin(); modelP != modelPEnd; ++modelP) {
 		DrawModel(*modelP, lightFlag, argPickFlg);
 	}
 	glEnable(GL_DEPTH_TEST);
@@ -517,7 +560,7 @@ void fk_GraphicsEngine::DrawModel(fk_Model *argModel,
 
 	if(argPickFlg == true) {
 		if(argModel->getPickMode() == false) return;
-		glLoadName(modelArray.size());
+		glLoadName(GLuint(modelArray.size()));
 		modelArray.push_back(argModel);
 	}
 
@@ -584,7 +627,7 @@ bool fk_GraphicsEngine::DefineLight(void)
 
 		for(LightID = 0;
 			LightP != LightPEnd && LightID < MaxLNum;
-			LightP++, LightID++) {
+			++LightP, ++LightID) {
 			LightMate = (*LightP)->getInhMaterial();
 			glLightfv(LArray[LightID], GL_AMBIENT,
 					  &(LightMate->getAmbient()->col[0]));
@@ -598,26 +641,26 @@ bool fk_GraphicsEngine::DefineLight(void)
 			switch(LightShape->getLightType()) {
 			  case FK_PARALLEL_LIGHT:
 				LightPos = (*LightP)->getInhVec();
-				LPosArray[0] = float(-LightPos.x);
-				LPosArray[1] = float(-LightPos.y);
-				LPosArray[2] = float(-LightPos.z);
+				LPosArray[0] = static_cast<float>(-LightPos.x);
+				LPosArray[1] = static_cast<float>(-LightPos.y);
+				LPosArray[2] = static_cast<float>(-LightPos.z);
 				LPosArray[3] = 0.0;
 				glLightfv(LArray[LightID], GL_POSITION, LPosArray);
 				break;
 
 			  case FK_POINT_LIGHT:
 				LightPos = (*LightP)->getInhPosition();
-				LPosArray[0] = float(LightPos.x);
-				LPosArray[1] = float(LightPos.y);
-				LPosArray[2] = float(LightPos.z);
+				LPosArray[0] = static_cast<float>(LightPos.x);
+				LPosArray[1] = static_cast<float>(LightPos.y);
+				LPosArray[2] = static_cast<float>(LightPos.z);
 				LPosArray[3] = 1.0;
 				glLightfv(LArray[LightID], GL_POSITION, LPosArray);
 				glLightf(LArray[LightID], GL_LINEAR_ATTENUATION,
-						 float(LightShape->getAttenuation(0)));
+						 static_cast<float>(LightShape->getAttenuation(0)));
 				glLightf(LArray[LightID], GL_QUADRATIC_ATTENUATION,
-						 float(LightShape->getAttenuation(1)));
+						 static_cast<float>(LightShape->getAttenuation(1)));
 				glLightf(LArray[LightID], GL_CONSTANT_ATTENUATION,
-						 float(LightShape->getAttenuation(2)));
+						 static_cast<float>(LightShape->getAttenuation(2)));
 
 				glLightf(LArray[LightID], GL_SPOT_CUTOFF, 180.0);
 
@@ -626,27 +669,27 @@ bool fk_GraphicsEngine::DefineLight(void)
 			  case FK_SPOT_LIGHT:
 				LightPos = (*LightP)->getInhPosition();
 				LightDirection = (*LightP)->getInhVec();
-				LPosArray[0] = float(LightPos.x);
-				LPosArray[1] = float(LightPos.y);
-				LPosArray[2] = float(LightPos.z);
+				LPosArray[0] = static_cast<float>(LightPos.x);
+				LPosArray[1] = static_cast<float>(LightPos.y);
+				LPosArray[2] = static_cast<float>(LightPos.z);
 				LPosArray[3] = 1.0;
 				glLightfv(LArray[LightID], GL_POSITION, LPosArray);
-				LPosArray[0] = float(LightDirection.x);
-				LPosArray[1] = float(LightDirection.y);
-				LPosArray[2] = float(LightDirection.z);
+				LPosArray[0] = static_cast<float>(LightDirection.x);
+				LPosArray[1] = static_cast<float>(LightDirection.y);
+				LPosArray[2] = static_cast<float>(LightDirection.z);
 				LPosArray[3] = 0.0;
 				glLightfv(LArray[LightID], GL_SPOT_DIRECTION, LPosArray);
 
 				glLightf(LArray[LightID], GL_LINEAR_ATTENUATION,
-						 float(LightShape->getAttenuation(0)));
+						 static_cast<float>(LightShape->getAttenuation(0)));
 				glLightf(LArray[LightID], GL_QUADRATIC_ATTENUATION,
-						 float(LightShape->getAttenuation(1)));
+						 static_cast<float>(LightShape->getAttenuation(1)));
 				glLightf(LArray[LightID], GL_CONSTANT_ATTENUATION,
-						 float(LightShape->getAttenuation(2)));
+						 static_cast<float>(LightShape->getAttenuation(2)));
 				glLightf(LArray[LightID], GL_SPOT_EXPONENT,
-						 float(LightShape->getSpotExponent()));
+						 static_cast<float>(LightShape->getSpotExponent()));
 				glLightf(LArray[LightID], GL_SPOT_CUTOFF,
-						 float(LightShape->getSpotCutOff()*180.0/FK_PI));
+						 static_cast<float>(LightShape->getSpotCutOff()*180.0/FK_PI));
 
 			  default:
 				break;
@@ -699,7 +742,6 @@ void fk_GraphicsEngine::LoadModelMatrix(fk_Model *argModel)
 {
 	fk_Angle	MAngle;
 	fk_Vector	MPos;
-	double		Scale;
 
 	MAngle = argModel->getAngle();
 	MPos = argModel->getPosition();
@@ -714,7 +756,7 @@ void fk_GraphicsEngine::LoadModelMatrix(fk_Model *argModel)
 	glRotated(-180.0*MAngle.b/FK_PI, 0.0, 0.0, 1.0);
 
 	if(argModel->getScaleMode() == true) {
-		Scale = argModel->getScale();
+		double Scale = argModel->getScale();
 		glScaled(Scale * argModel->getScale(fk_X),
 				 Scale * argModel->getScale(fk_Y),
 				 Scale * argModel->getScale(fk_Z));
@@ -768,9 +810,9 @@ void fk_GraphicsEngine::InitFogStatus(fk_Scene *argScene)
 		break;
 	}
 
-	glFogf(GL_FOG_DENSITY, float(argScene->getFogDensity()));
-	glFogf(GL_FOG_START, float(argScene->getFogLinearStart()));
-	glFogf(GL_FOG_END, float(argScene->getFogLinearEnd()));
+	glFogf(GL_FOG_DENSITY, static_cast<float>(argScene->getFogDensity()));
+	glFogf(GL_FOG_START, static_cast<float>(argScene->getFogLinearStart()));
+	glFogf(GL_FOG_END, static_cast<float>(argScene->getFogLinearEnd()));
 
 	glFogfv(GL_FOG_COLOR, argScene->getFogColor().col);
 
@@ -814,12 +856,12 @@ bool fk_GraphicsEngine::GetViewLinePos(double argX, double argY,
 	ViewMatCalc(&mat);
 	mat.inverse();
 
-	tmpY = double(hSize) - argY - 1.0;
-	diffX = argX - double(viewArray[0]);
-	diffY = tmpY - double(viewArray[1]);
+	tmpY = static_cast<double>(hSize) - argY - 1.0;
+	diffX = argX - static_cast<double>(viewArray[0]);
+	diffY = tmpY - static_cast<double>(viewArray[1]);
 
-	inVec.x = diffX*2.0/double(viewArray[2]) - 1.0;
-	inVec.y = diffY*2.0/double(viewArray[3]) - 1.0;
+	inVec.x = diffX*2.0/static_cast<double>(viewArray[2]) - 1.0;
+	inVec.y = diffY*2.0/static_cast<double>(viewArray[3]) - 1.0;
 	inVec.w = 1.0;
 
 	inVec.z = -1.0;
@@ -853,10 +895,10 @@ bool fk_GraphicsEngine::GetProjectPosition(double argX, double argY,
 										   double argDist, fk_Vector *retPos)
 {
 	fk_Vector		sVec, eVec, eyeVec, cameraPos;
-	const fk_Model	*tmpCamera = curDLink->getCamera();
+	const fk_Model	*tmpCamera;
 
 	if(curDLink == NULL) return false;
-
+	tmpCamera = curDLink->getCamera();
 	if(generalID > 2) SetViewPort();
 
 	GetViewLinePos(argX, argY, &sVec, &eVec);
@@ -886,11 +928,11 @@ bool fk_GraphicsEngine::GetWindowPosition(fk_Vector argPos, fk_Vector *retPos)
 	outVec = mat * inVec;
 	if(fabs(outVec.w) < FK_EPS) return false;
 	outVec /= outVec.w;
-	retPos->set(double(viewArray[0]) +
-				double(viewArray[2])*(outVec.x + 1.0)/2.0,
-				double(viewArray[1]) +
-				double(hSize) - 1.0 -
-				double(viewArray[3])*(outVec.y + 1.0)/2.0,
+	retPos->set(static_cast<double>(viewArray[0]) +
+				static_cast<double>(viewArray[2])*(outVec.x + 1.0)/2.0,
+				static_cast<double>(viewArray[1]) +
+				static_cast<double>(hSize) - 1.0 -
+				static_cast<double>(viewArray[3])*(outVec.y + 1.0)/2.0,
 				(1.0 + outVec.z)/2.0);
 	return true;
 }
@@ -923,15 +965,16 @@ bool fk_GraphicsEngine::GetOGLTextureBindMode(void)
 
 bool fk_GraphicsEngine::SnapImage(fk_Image *argImage, fk_SnapProcMode argMode)
 {
-	int	wCount, hCount;
+	int		wCount, hCount;
+	_st		index;
 
 	if(argImage == NULL) return false;
 
 	if(argImage->getWidth() != wSize || argImage->getHeight() != hSize) {
 		argImage->newImage(wSize, hSize);
 	}
-	if((int)snapBuffer.size() != 3*wSize*hSize) {
-		snapBuffer.resize(3*wSize*hSize);
+	if(static_cast<int>(snapBuffer.size()) != 3*wSize*hSize) {
+		snapBuffer.resize(static_cast<_st>(3*wSize*hSize));
 	}
 	if(argMode == FK_SNAP_GL_FRONT) {
 		glReadBuffer(GL_FRONT);
@@ -944,10 +987,11 @@ bool fk_GraphicsEngine::SnapImage(fk_Image *argImage, fk_SnapProcMode argMode)
 
 	for(hCount = 0; hCount < hSize; hCount++) {
 		for(wCount = 0; wCount < wSize; wCount++) {
+			index = static_cast<_st>(3*(hCount*wSize + wCount));
 			argImage->setRGB(wCount, hSize - hCount - 1,
-							 snapBuffer[3*(hCount*wSize + wCount)],
-							 snapBuffer[3*(hCount*wSize + wCount)+1],
-							 snapBuffer[3*(hCount*wSize + wCount)+2]);
+							 snapBuffer[index],
+							 snapBuffer[index+1],
+							 snapBuffer[index+2]);
 		}
 	}
 
@@ -958,9 +1002,10 @@ void fk_GraphicsEngine::GetPickData(fk_PickData *argPickData,
 									int argPixSize, int argMouseX, int argMouseY)
 {
 	GLint			hits;
-	unsigned int	ii;
+	_st				ii;
 	int				elemID;
 	fk_ObjectType	elemType = FK_BASEOBJECT;
+	double			farDepth, nearDepth;
 
 	if(argPickData == NULL) return;
 
@@ -972,7 +1017,7 @@ void fk_GraphicsEngine::GetPickData(fk_PickData *argPickData,
 
 	argPickData->ClearData();
 
-	for(ii = 0; ii < (unsigned int)(hits); ii++) {
+	for(ii = 0; ii < static_cast<_st>(hits); ii++) {
 		switch(selectBuf[ii*5 + 4] % 3) {
 		  case 0:
 			elemType = FK_LOOP;
@@ -990,10 +1035,12 @@ void fk_GraphicsEngine::GetPickData(fk_PickData *argPickData,
 			break;
 		}
 
-		elemID = selectBuf[ii*5 + 4]/3;
+		elemID = static_cast<int>(selectBuf[ii*5 + 4]/3);
+		farDepth = static_cast<double>(selectBuf[ii*5 + 1])/0xffffffff;
+		nearDepth = static_cast<double>(selectBuf[ii*5 + 2])/0xffffffff;
 
 		argPickData->PushData(modelArray[selectBuf[ii*5 + 3]],
-							  elemID, elemType);
+							  elemID, elemType, farDepth, nearDepth);
 	}
 
 	SetViewPort();
@@ -1089,10 +1136,12 @@ void fk_GraphicsEngine::gluPickMatrix(GLdouble argX, GLdouble argY,
 	GLdouble	sx, sy;
 	GLdouble	tx, ty;
 
-	sx = GLdouble(viewport[2])/width;
-	sy = GLdouble(viewport[3])/height;
-	tx = (GLdouble(viewport[2]) + 2.0 * (GLdouble(viewport[0]) - argX))/width;
-	ty = (GLdouble(viewport[3]) + 2.0 * (GLdouble(viewport[1]) - argY))/height;
+	sx = static_cast<GLdouble>(viewport[2])/width;
+	sy = static_cast<GLdouble>(viewport[3])/height;
+	tx = (static_cast<GLdouble>(viewport[2]) +
+		  2.0 * (static_cast<GLdouble>(viewport[0]) - argX))/width;
+	ty = (static_cast<GLdouble>(viewport[3]) +
+		  2.0 * (static_cast<GLdouble>(viewport[1]) - argY))/height;
 
 	m[0] = sx;	m[4] = 0.0;	 m[8] = 0.0;   m[12] = tx;
 	m[1] = 0.0;	m[5] = sy;	 m[9] = 0.0;   m[13] = ty;
