@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -153,7 +153,7 @@ retry:
 				// cout << "HAL failed." << endl;
 				// 失敗したので REF で試行
 				if(FAILED(g_lpD3D->CreateDevice(D3DADAPTER_DEFAULT, D3DDEVTYPE_REF, m_hWnd, D3DCREATE_SOFTWARE_VERTEXPROCESSING, &m_d3dpp, &g_lpD3DDEV))) {
-					// cout << "REF failed. mou dame po." << endl;
+					// cout << "REF failed." << endl;
 					// 結局失敗した
 					if(argErrRep) MessageBox(m_hWnd, "Direct3D の初期化に失敗しました。", "FK_D3D", MB_OK | MB_ICONSTOP);
 					return E_FAIL;
@@ -281,7 +281,15 @@ fk_GraphicsEngine::fk_GraphicsEngine(void)
 	faceDraw = new fk_FaceDraw;
 	textureDraw = new fk_TextureDraw;
 
-	curDLink = (fk_DisplayLink *)NULL;
+	winID = 0;
+	curDLink = NULL;
+	dLinkStatus = 0;
+	dLinkID = 0;
+	wSize = 0;
+	hSize = 0;
+	arrayState = false;
+	resizeFlag = false;
+	textureMode = false;
 
 	return;
 }
@@ -367,10 +375,14 @@ void fk_GraphicsEngine::ResizeWindow(int argW, int argH)
 void fk_GraphicsEngine::ClearTextureMemory(void)
 {
 	textureDraw->clearTextureMemory();
-
 	return;
 }
 
+unsigned long fk_GraphicsEngine::GetUsingTextureMemory(void)
+{
+	return textureDraw->getUsingTextureMemory();
+}
+
 void fk_GraphicsEngine::SetViewPort(void)
 {
 	const  D3DXVECTOR3	vEye(0.0f, 0.0f, 0.0f), vAt(0.0f, 0.0f, -1.0f), vUp(0.0, 1.0, 0.0);
@@ -386,9 +398,7 @@ void fk_GraphicsEngine::SetViewPort(void)
 
 	// 右手系射影行列をセット
 	if(curDLink == (fk_DisplayLink *)NULL) {
-		D3DXMatrixPerspectiveFovRH(&workMat, (float)(40.0f*FK_PI/180.0f), (float)wSize/(float)hSize, 1.0f, 6000.0f);
-		projStack->LoadMatrix(&workMat);
-		ref_lpD3DDEV->SetTransform(D3DTS_PROJECTION, projStack->GetTop());
+		SetDefaultProjection();
 	} else {
 		SetProjection(curDLink->getProjection());
 	}
@@ -409,6 +419,53 @@ void fk_GraphicsEngine::SetViewPort(void)
 	return;
 }
 
+void fk_GraphicsEngine::SetDefaultPickProjection(void)
+{
+	double			aspect;
+
+	aspect = GLfloat(wSize)/GLfloat(hSize);
+	gluPerspective(40.0, aspect, 1.0, 6000.0);
+}
+
+
+void fk_GraphicsEngine::SetPickProjection(const fk_ProjectBase *argProj)
+{
+	fk_ProjectBase	*proj;
+	fk_Perspective	*pers;
+	fk_Frustum		*frus;
+	fk_Ortho		*orth;
+
+	proj = const_cast<fk_ProjectBase *>(argProj);
+
+	switch(argProj->getMode()) {
+	  case FK_PERSPECTIVE_MODE:
+		pers = static_cast<fk_Perspective *>(proj);
+		gluPerspective((180.0 * pers->getFovy())/FK_PI,
+					   GLfloat(wSize)/GLfloat(hSize),
+					   pers->getNear(), pers->getFar());
+		break;
+
+	  case FK_FRUSTUM_MODE:
+		frus = static_cast<fk_Frustum *>(proj);
+		glFrustum(frus->getLeft(), frus->getRight(),
+				  frus->getBottom(), frus->getTop(),
+				  frus->getNear(), frus->getFar());
+		break;
+
+	  case FK_ORTHO_MODE:
+		orth = static_cast<fk_Ortho *>(proj);
+		glOrtho(orth->getLeft(), orth->getRight(),
+				orth->getBottom(), orth->getTop(),
+				orth->getNear(), orth->getFar());
+		break;
+
+	  default:
+		break;
+	}
+
+	return;
+}
+
 void fk_GraphicsEngine::SetPickViewPort(int argPixSize, int argX, int argY)
 {
 	GLint	ViewPort[4];
@@ -429,24 +486,9 @@ void fk_GraphicsEngine::SetPickViewPort(int argPixSize, int argX, int argY)
 				  (GLdouble)argPixSize, (GLdouble)argPixSize, ViewPort);
 
 	if(curDLink == (fk_DisplayLink *)NULL) {
-		gluPerspective(40.0, (GLfloat)wSize/(GLfloat)hSize,
-					   1.0, 6000.0);
+		SetDefaultPickProjection();
 	} else {
-		const fk_ProjectBase	*argProj = curDLink->getProjection();
-		fk_Perspective	*Pers;
-		fk_Ortho		*Orth;
-
-		if(argProj->getMode() == FK_PERSPECTIVE_MODE) {
-			Pers = (fk_Perspective *)argProj;
-			gluPerspective((180.0 * Pers->getFovy())/FK_PI,
-						(GLfloat)wSize/(GLfloat)hSize,
-						Pers->getNear(), Pers->getFar());
-		} else {
-			Orth = (fk_Ortho *)argProj;
-			glOrtho(Orth->getLeft(), Orth->getRight(),
-					Orth->getBottom(), Orth->getTop(),
-					Orth->getNear(), Orth->getFar());
-		}
+		SetPickProjection(curDLink->getProjection());
 	}
 
 	glMatrixMode(GL_MODELVIEW);
@@ -456,23 +498,54 @@ void fk_GraphicsEngine::SetPickViewPort(int argPixSize, int argX, int argY)
 	return;
 }
 
+void fk_GraphicsEngine::SetDefaultProjection(void)
+{
+	static D3DXMATRIX	workMat;
+
+	D3DXMatrixPerspectiveFovRH(&workMat, (float)(40.0f*FK_PI/180.0f), (float)wSize/(float)hSize, 1.0f, 6000.0f);
+	projStack->LoadMatrix(&workMat);
+	ref_lpD3DDEV->SetTransform(D3DTS_PROJECTION, projStack->GetTop());
+
+	return;
+}
+
 void fk_GraphicsEngine::SetProjection(const fk_ProjectBase *argProj)
 {
-	fk_Perspective	*Pers;
-	fk_Ortho		*Orth;
+	fk_ProjectBase	*proj;
+	fk_Perspective	*pers;
+	fk_Frustum		*frus;
+	fk_Ortho		*orth;
 	D3DXMATRIX		workMat;
-    
-	if(argProj->getMode() == FK_PERSPECTIVE_MODE) {
-		Pers = (fk_Perspective *)argProj;
-		D3DXMatrixPerspectiveFovRH(&workMat, (float)(Pers->getFovy()),
-			(float)wSize/(float)hSize, (float)Pers->getNear(), (float)Pers->getFar());
-	} else {
-		Orth = (fk_Ortho *)argProj;
+
+	proj = const_cast<fk_ProjectBase *>(argProj);
+
+	switch(argProj->getMode()) {
+	  case FK_PERSPECTIVE_MODE:
+		pers = static_cast<fk_Perspective *>(proj);
+		D3DXMatrixPerspectiveFovRH(&workMat, (float)(pers->getFovy()),
+			(float)wSize/(float)hSize, (float)pers->getNear(), (float)pers->getFar());
+		break;
+
+	  case FK_FRUSTUM_MODE:
+		frus = static_cast<fk_Frustum *>(proj);
+		D3DXMatrixPerspectiveOffCenterRH(&workMat,
+			(float)frus->getLeft(), (float)frus->getRight(),
+			(float)frus->getBottom(), (float)frus->getTop(),
+			(float)frus->getNear(), (float)frus->getFar());
+		break;
+
+	  case FK_ORTHO_MODE:
+		orth = static_cast<fk_Ortho *>(proj);
 		D3DXMatrixOrthoOffCenterRH(&workMat,
-			(float)Orth->getLeft(), (float)Orth->getRight(),
-			(float)Orth->getBottom(), (float)Orth->getTop(),
-			(float)Orth->getNear(), (float)Orth->getFar());
+			(float)orth->getLeft(), (float)orth->getRight(),
+			(float)orth->getBottom(), (float)orth->getTop(),
+			(float)orth->getNear(), (float)orth->getFar());
+		break;
+
+	  default:
+		break;
 	}
+    
 	projStack->LoadMatrix(&workMat);
 	ref_lpD3DDEV->SetTransform(D3DTS_PROJECTION, projStack->GetTop());
 
@@ -510,35 +583,31 @@ void fk_GraphicsEngine::D3DStateInit(void)
 	return;
 }
 
-void fk_GraphicsEngine::Draw(bool argPickFlg)
+void fk_GraphicsEngine::ApplySceneParameter(bool argVPFlg)
 {
-	bool			fogStatus = false;
+	// bool			fogStatus = false;
 	fk_Scene		*scene;
 	fk_Color		bgColor(0.0f, 0.0f, 0.0f);
 
 	scene = (fk_Scene *)NULL;
 
-	// リサイズ時に加えて、マルチウィンドウ時もビューポートを再設定(by rita)
-	if(resizeFlag == true || generalID > 2) {
-		SetViewPort();
-		resizeFlag = false;
-	}
-
 	if(curDLink != (fk_DisplayLink *)NULL) {
 		if(dLinkID != curDLink->GetID() ||
 		   dLinkStatus != curDLink->GetProjChangeStatus()) {
 			dLinkID = curDLink->GetID();
 			dLinkStatus = curDLink->GetProjChangeStatus();
-			SetViewPort();
+			if(argVPFlg == true) {
+				SetViewPort();
+			}
 			if(curDLink->getObjectType() == FK_SCENE) {
 				scene = (fk_Scene *)curDLink;
 				scene->GetFogChangeStatus();
-				fogStatus = true;
+				// fogStatus = true;
 			}
 		} else {
 			if(curDLink->getObjectType() == FK_SCENE) {
 				scene = (fk_Scene *)curDLink;
-				fogStatus = scene->GetFogChangeStatus();
+				// fogStatus = scene->GetFogChangeStatus();
 			}
 		}
 	}
@@ -556,14 +625,25 @@ void fk_GraphicsEngine::Draw(bool argPickFlg)
 			InitFogStatus(scene);
 		}
 		*/
-		InitFogStatus(scene);
+		InitFogStatus(scene);	// D3D では常時設定しないとだめっぽい
 		bgColor = scene->getBGColor();
 	}
-
-	// ★ Direct3D の描画
 	// バックバッファと Z バッファをクリア
 	ref_lpD3DDEV->Clear(0, NULL, (D3DCLEAR_TARGET | D3DCLEAR_ZBUFFER), GetPackedColor(&bgColor), 1.0f, 0);
-	
+
+	return;
+}
+
+void fk_GraphicsEngine::Draw(bool argPickFlg)
+{
+	// リサイズ時に加えて、マルチウィンドウ時もビューポートを再設定(by rita)
+	if(resizeFlag == true || generalID > 2) {
+		SetViewPort();
+		resizeFlag = false;
+	}
+
+	ApplySceneParameter(true);
+
 	viewStack->Push();
 	RecalcModelView();
 
@@ -668,12 +748,12 @@ void fk_GraphicsEngine::DrawObjs(bool argPickFlg)
 
 	modelPEnd = curDLink->GetModelList()->end();
 	for(modelP = curDLink->GetModelList()->begin();
-		modelP != modelPEnd; modelP++) {
+		modelP != modelPEnd; ++modelP) {
 		DrawModel(*modelP, lightFlag, argPickFlg);
 	}
 
 	overlayList = curDLink->GetOverlayList();
-	if(overlayList->size() == 0) return;
+	if(overlayList->empty() == true) return;
 
 	if(argPickFlg == true) {
 		glDisable(GL_DEPTH_TEST);
@@ -682,7 +762,7 @@ void fk_GraphicsEngine::DrawObjs(bool argPickFlg)
 	}
 
 	modelPEnd = overlayList->end();
-	for(modelP = overlayList->begin(); modelP != modelPEnd; modelP++) {
+	for(modelP = overlayList->begin(); modelP != modelPEnd; ++modelP) {
 		DrawModel(*modelP, lightFlag, argPickFlg);
 	}
 
@@ -704,7 +784,7 @@ void fk_GraphicsEngine::DrawModel(fk_Model *argModel,
 
 	if(argPickFlg == true) {
 		if(argModel->getPickMode() == false) return;
-		glLoadName(modelArray.size());
+		glLoadName(static_cast<GLuint>(modelArray.size()));
 		modelArray.push_back(argModel);
 	}
 
@@ -774,7 +854,7 @@ bool fk_GraphicsEngine::DefineLight(void)
 
 		for(LightID = 0;
 			LightP != LightPEnd && LightID < MaxLNum;
-			LightP++, LightID++) {
+			++LightP, ++LightID) {
 
 			ZeroMemory(&lightInfo, sizeof(D3DLIGHT9));
 
@@ -1186,6 +1266,7 @@ void fk_GraphicsEngine::GetPickData(fk_PickData *argPickData,
 	unsigned int	ii;
 	int				elemID;
 	fk_ObjectType	elemType = FK_BASEOBJECT;
+	double			farDepth, nearDepth;
 
 	if(argPickData == (fk_PickData *)NULL) return;
 
@@ -1216,9 +1297,11 @@ void fk_GraphicsEngine::GetPickData(fk_PickData *argPickData,
 		}
 
 		elemID = selectBuf[ii*5 + 4]/3;
+		farDepth = (double)selectBuf[ii*5 + 1]/0xffffffff;
+		nearDepth = (double)selectBuf[ii*5 + 2]/0xffffffff;
 
 		argPickData->PushData(modelArray[selectBuf[ii*5 + 3]],
-							  elemID, elemType);
+							  elemID, elemType, farDepth, nearDepth);
 	}
 
 	SetViewPort();
