@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -73,6 +73,7 @@
 #include "FaceDraw_D3D.cxx"
 #else
 
+#define FK_DEF_SIZETYPE
 #include <FK/FaceDraw.H>
 #include <FK/OpenGL.H>
 #include <FK/IndexFace.h>
@@ -86,7 +87,6 @@ using namespace std;
 typedef list<fk_Loop *>::iterator			loopIte;
 typedef list<fk_Loop *>::reverse_iterator	loopRIte;
 
-
 fk_FaceDraw::fk_FaceDraw(void)
 {
 	SetArrayState(false);
@@ -108,7 +108,7 @@ void fk_FaceDraw::DrawShapeFace(fk_Model *argObj, bool lightFlag,
 {
 	fk_MaterialMode	shapeMateMode;
 	fk_MaterialMode	modelMateMode;
-	bool			smoothMode, nodeMode, drawMode;
+	bool			smoothMode;
 
 	shapeMateMode = argObj->getShape()->getMaterialMode();
 	modelMateMode = argObj->getMaterialMode();
@@ -137,9 +137,8 @@ void fk_FaceDraw::DrawShapeFace(fk_Model *argObj, bool lightFlag,
 		DrawShapeFaceMaterial(argObj, lightFlag);
 
 	} else {
-
-		drawMode = false;
-		nodeMode = false;
+		bool drawMode = false;
+		bool nodeMode = false;
 		if(modelMateMode == FK_CHILD_MODE) {
 			drawMode = true;
 			nodeMode = true;
@@ -196,9 +195,9 @@ void fk_FaceDraw::DrawSolidFacePick(fk_Model *argObj)
 	loopIte				ite;
 	loopRIte			rite;
 
-	solidP = (fk_Solid *)argObj->getShape();
+	solidP = static_cast<fk_Solid *>(argObj->getShape());
 	if(solidP->checkDB() == false) return;
-	if(solidP->getNextL((fk_Loop *)NULL) == (fk_Loop *)NULL) return;
+	if(solidP->getNextL(NULL) == NULL) return;
 
 	if(solidP->GetLCacheStatus() == false) {
 		solidP->MakeLCache();
@@ -211,11 +210,11 @@ void fk_FaceDraw::DrawSolidFacePick(fk_Model *argObj)
 	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
 
 	if(reverseFlag == false) {
-		for(ite = loopStack->begin(); ite != loopStack->end(); ite++) {
+		for(ite = loopStack->begin(); ite != loopStack->end(); ++ite) {
 			DrawSolidFacePickElem(*ite);
 		}
 	} else {
-		for(rite = loopStack->rbegin(); rite != loopStack->rend(); rite++) {
+		for(rite = loopStack->rbegin(); rite != loopStack->rend(); ++rite) {
 			DrawSolidFacePickElem(*rite);
 		}
 	}
@@ -230,28 +229,27 @@ void fk_FaceDraw::DrawSolidFacePickElem(fk_Loop *argL)
 	fk_Vertex			*curV;
 	fk_Half				*startH, *curH;
 	fk_Vector			*tmpPosP;
-	unsigned int		i;
 
-	glPushName(argL->getID()*3);
+	glPushName(static_cast<GLuint>(argL->getID()*3));
 
 	if(argL->isTesselated() == true) {
 		tesseVertexArray = argL->GetTesselateVertex();
 		tesseIDArray = argL->GetTesselateIndex();
 
 		glBegin(GL_TRIANGLES);
-		for(i = 0; i < tesseIDArray->size(); i++) {
-			tmpPosP = tesseVertexArray->at(tesseIDArray->at(i))->GetPositionP();
-			glVertex3dv((GLdouble *)&(tmpPosP->x));
+		for(_st i = 0; i < tesseIDArray->size(); i++) {
+			_st index = static_cast<_st>(tesseIDArray->at(i));
+			tmpPosP = tesseVertexArray->at(index)->GetPositionP();
+			glVertex3dv(static_cast<GLdouble *>(&(tmpPosP->x)));
 		}
 		glEnd();
 	} else {
 		glBegin(GL_POLYGON);
 		startH = curH = argL->getOneHalf();
-
 		do {
 			curV = curH->getVertex();
 			tmpPosP = curV->GetPositionP(); 
-			glVertex3dv((GLdouble *)&(tmpPosP->x));
+			glVertex3dv(static_cast<GLdouble *>(&(tmpPosP->x)));
 			curH = curH->getNextHalf();
 		} while(startH != curH);
 
@@ -265,12 +263,12 @@ void fk_FaceDraw::DrawSolidFacePickElem(fk_Loop *argL)
 void fk_FaceDraw::DrawIFSFacePick(fk_Model *argObj)
 {
 	fk_IndexFaceSet		*ifsP;
-	int					ii, ij;
-	int					pNum;
+	_st					ii, ij;
+	_st					pNum;
 	fk_FVector			*pos;
 	int					*ifs;
 
-	ifsP = (fk_IndexFaceSet *)argObj->getShape();
+	ifsP = static_cast<fk_IndexFaceSet *>(argObj->getShape());
 
 	switch(ifsP->type) {
 	  case FK_IF_TRIANGLES:
@@ -292,11 +290,11 @@ void fk_FaceDraw::DrawIFSFacePick(fk_Model *argObj)
 	glDisableClientState(GL_NORMAL_ARRAY);
 	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
 
-	for(ii = 0; ii < ifsP->faceSize; ii++) {
-		glPushName(ii*3);
+	for(ii = 0; ii < _st(ifsP->faceSize); ii++) {
+		glPushName(static_cast<GLuint>(ii*3));
 		glBegin(GL_POLYGON);
 		for(ij = 0; ij < pNum; ij++) {
-			glVertex3fv((GLfloat *)&pos[ifs[pNum*ii+ij]]);
+			glVertex3fv(static_cast<GLfloat *>(&(pos[ifs[pNum*ii+ij]].x)));
 		}
 		glEnd();
 		glPopName();
@@ -341,9 +339,9 @@ void fk_FaceDraw::DrawSolidFaceMaterial(fk_Model *argObj, bool lightFlag)
 	loopRIte				rite;
 
 
-	solidP = (fk_Solid *)argObj->getShape();
+	solidP = static_cast<fk_Solid *>(argObj->getShape());
 	if(solidP->checkDB() == false) return;
-	if(solidP->getNextL((fk_Loop *)NULL) == (fk_Loop *)NULL) return;
+	if(solidP->getNextL(NULL) == NULL) return;
 
 	if(solidP->GetLCacheStatus() == false) {
 		solidP->MakeLCache();
@@ -358,12 +356,12 @@ void fk_FaceDraw::DrawSolidFaceMaterial(fk_Model *argObj, bool lightFlag)
 	matV = solidP->getMaterialVector();
 
 	if(reverseFlag == false) {
-		for(ite = loopStack->begin(); ite != loopStack->end(); ite++) {
+		for(ite = loopStack->begin(); ite != loopStack->end(); ++ite) {
 			oldMateID = DrawSolidFaceMaterialElem(argObj, *ite, oldMateID,
 												  paletteSize, matV, lightFlag);
 		}
 	} else {
-		for(rite = loopStack->rbegin(); rite != loopStack->rend(); rite++) {
+		for(rite = loopStack->rbegin(); rite != loopStack->rend(); ++rite) {
 			oldMateID = DrawSolidFaceMaterialElem(argObj, *rite, oldMateID,
 												  paletteSize, matV, lightFlag);
 		}
@@ -383,7 +381,7 @@ int fk_FaceDraw::DrawSolidFaceMaterialElem(fk_Model *argObj, fk_Loop *argL,
 	fk_Vector				*tmpPosP, *tmpNormP;
 	int						retMateID, curMateID;
 	fk_Surface				*surf;
-	unsigned int			i;
+	_st						i;
 	vector<fk_Vertex *>		*tesseVertexArray;
 	vector<int>				*tesseIDArray;
 
@@ -409,15 +407,15 @@ int fk_FaceDraw::DrawSolidFaceMaterialElem(fk_Model *argObj, fk_Loop *argL,
 			CommonMateSet(argObj, argLightFlag, true);
 			retMateID = FK_UNDEFINED;
 		} else {
-			LocalMateSet(&((*argMatV)[curMateID]), argLightFlag);
+			LocalMateSet(&((*argMatV)[_st(curMateID)]), argLightFlag);
 			retMateID = curMateID;
 		}
 	}
 
-	if((surf = argL->getSurfGeometry()) != (fk_Surface *)NULL) {
+	if((surf = argL->getSurfGeometry()) != NULL) {
 		DrawSurface(surf);
 	} else if(argL->isTesselated() == true) {
-		if((tmpNormP = argL->getNormal()) == (fk_Vector *)NULL) {
+		if((tmpNormP = argL->getNormal()) == NULL) {
 			return retMateID;
 		}
 
@@ -425,23 +423,24 @@ int fk_FaceDraw::DrawSolidFaceMaterialElem(fk_Model *argObj, fk_Loop *argL,
 		tesseIDArray = argL->GetTesselateIndex();
 
 		glBegin(GL_TRIANGLES);
-		glNormal3dv((GLdouble *)&(tmpNormP->x));
+		glNormal3dv(static_cast<GLdouble *>(&(tmpNormP->x)));
 		for(i = 0; i < tesseIDArray->size(); i++) {
-			tmpPosP = tesseVertexArray->at(tesseIDArray->at(i))->GetPositionP();
-			glVertex3dv((GLdouble *)&(tmpPosP->x));
+			_st index = static_cast<_st>(tesseIDArray->at(i));
+			tmpPosP = tesseVertexArray->at(index)->GetPositionP();
+			glVertex3dv(static_cast<GLdouble *>(&(tmpPosP->x)));
 		}
 		glEnd();
 	} else {
-		if((tmpNormP = argL->getNormal()) == (fk_Vector *)NULL) {
+		if((tmpNormP = argL->getNormal()) == NULL) {
 			return retMateID;
 		}
 		startH = curH = argL->getOneHalf();
 		glBegin(GL_POLYGON);
-		glNormal3dv((GLdouble *)&(tmpNormP->x));
+		glNormal3dv(static_cast<GLdouble *>(&(tmpNormP->x)));
 		do {
 			curV = curH->getVertex();
 			tmpPosP = curV->GetPositionP(); 
-			glVertex3dv((GLdouble *)&(tmpPosP->x));
+			glVertex3dv(static_cast<GLdouble *>(&(tmpPosP->x)));
 			curH = curH->getNextHalf();
 		} while(startH != curH);
 		glEnd();
@@ -454,15 +453,15 @@ int fk_FaceDraw::DrawSolidFaceMaterialElem(fk_Model *argObj, fk_Loop *argL,
 void fk_FaceDraw::DrawIFSFaceMaterial(fk_Model *argObj, bool argLightFlag)
 {
 	fk_IndexFaceSet		*ifsP;
-	int					pNum;
+	_st					pNum;
 	fk_FVector			*pos, *pNorm;
 	int					*ifs;
-	int					ii, ij;
+	_st					ii, ij;
 	GLenum				tmpType;
 	int					oldMateID, curMateID, paletteSize;
 	vector<fk_Material>	*matV;
 
-	ifsP = (fk_IndexFaceSet *)argObj->getShape();
+	ifsP = static_cast<fk_IndexFaceSet *>(argObj->getShape());
 
 	curMateID = FK_UNDEFINED;
 	oldMateID = -2;
@@ -495,7 +494,7 @@ void fk_FaceDraw::DrawIFSFaceMaterial(fk_Model *argObj, bool argLightFlag)
 
 	if(ifsP->colorFlg == false) CommonMateSet(argObj, argLightFlag, true);
 
-	for(ii = 0; ii < ifsP->faceSize; ii++) {
+	for(ii = 0; ii < static_cast<_st>(ifsP->faceSize); ii++) {
 		if(ifsP->colorFlg == true) {
 			curMateID = ifsP->colorID[ii];
 			if(curMateID < 0 || curMateID >= paletteSize) {
@@ -506,17 +505,17 @@ void fk_FaceDraw::DrawIFSFaceMaterial(fk_Model *argObj, bool argLightFlag)
 					CommonMateSet(argObj, argLightFlag, true);
 					oldMateID = FK_UNDEFINED;
 				} else {
-					LocalMateSet(&((*matV)[curMateID]),
+					LocalMateSet(&((*matV)[_st(curMateID)]),
 								 argLightFlag);
 					oldMateID = curMateID;
 				}
 			}
 		}
 
-		glNormal3fv((GLfloat *)&pNorm[ii]);
+		glNormal3fv(static_cast<GLfloat *>(&(pNorm[ii].x)));
 
 		for(ij = 0; ij < pNum; ij++) {
-			glVertex3fv((GLfloat *)&pos[ifs[pNum*ii+ij]]);
+			glVertex3fv(static_cast<GLfloat *>(&pos[ifs[pNum*ii+ij]].x));
 		}
 	}
 	glEnd();
@@ -525,7 +524,7 @@ void fk_FaceDraw::DrawIFSFaceMaterial(fk_Model *argObj, bool argLightFlag)
 }
 
 void fk_FaceDraw::DrawShapeFaceSmooth(fk_Model *argObj,
-									bool argLightFlag, bool argNodeFlag)
+									  bool argLightFlag, bool argNodeFlag)
 {
 	switch(argObj->getShape()->getObjectType()) {
 	  case FK_INDEXFACESET:
@@ -559,9 +558,9 @@ void fk_FaceDraw::DrawSolidFaceSmooth(fk_Model *argObj,
 	loopRIte			rite;
 
 
-	solidP = (fk_Solid *)argObj->getShape();
+	solidP = static_cast<fk_Solid *>(argObj->getShape());
 	if(solidP->checkDB() == false) return;
-	if(solidP->getNextL((fk_Loop *)NULL) == (fk_Loop *)NULL) return;
+	if(solidP->getNextL(NULL) == NULL) return;
 
 	if(solidP->GetLCacheStatus() == false) {
 		solidP->MakeLCache();
@@ -574,11 +573,11 @@ void fk_FaceDraw::DrawSolidFaceSmooth(fk_Model *argObj,
 	glShadeModel(GL_SMOOTH);
 
 	if(reverseFlag == false) {
-		for(ite = loopStack->begin(); ite != loopStack->end(); ite++) {
+		for(ite = loopStack->begin(); ite != loopStack->end(); ++ite) {
 			DrawSolidFaceSmoothElem(*ite);
 		}
 	} else {
-		for(rite = loopStack->rbegin(); rite != loopStack->rend(); rite++) {
+		for(rite = loopStack->rbegin(); rite != loopStack->rend(); ++rite) {
 			DrawSolidFaceSmoothElem(*rite);
 		}
 	}
@@ -594,7 +593,7 @@ void fk_FaceDraw::DrawSolidFaceSmoothElem(fk_Loop *argL)
 	fk_Surface			*surf;
 
 
-	if((surf = argL->getSurfGeometry()) != (fk_Surface *)NULL) {
+	if((surf = argL->getSurfGeometry()) != NULL) {
 		DrawSurface(surf);
 	} else {
 		glBegin(GL_POLYGON);
@@ -604,12 +603,9 @@ void fk_FaceDraw::DrawSolidFaceSmoothElem(fk_Loop *argL)
 			curV = curH->getVertex();
 			tmpNorm = curV->GetNormalP();
 			tmpPos = curV->GetPositionP(); 
-			if(tmpNorm == (fk_Vector *)NULL ||
-			   tmpPos == (fk_Vector *)NULL) {
-				continue;
-			}
-			glNormal3dv((GLdouble *)&(tmpNorm->x));
-			glVertex3dv((GLdouble *)&(tmpPos->x));
+			if(tmpNorm == NULL || tmpPos == NULL) continue;
+			glNormal3dv(static_cast<GLdouble *>(&(tmpNorm->x)));
+			glVertex3dv(static_cast<GLdouble *>(&(tmpPos->x)));
 			curH = curH->getNextHalf();
 		} while(startH != curH);
 
@@ -627,7 +623,6 @@ void fk_FaceDraw::DrawIFSFaceSmooth(fk_Model *argObj,
 	fk_FVector			*pos, *vNorm;
 	int					*ifs;
 	GLenum				tmpType;
-	int					ii, ij, index;
 
 	ifsP = (fk_IndexFaceSet *)argObj->getShape();
 
@@ -665,11 +660,11 @@ void fk_FaceDraw::DrawIFSFaceSmooth(fk_Model *argObj,
 					   GL_UNSIGNED_INT, &ifs[0]);
 	} else {
 		glBegin(tmpType);
-		for(ii = 0; ii < ifsP->faceSize; ii++) {
-			for(ij = 0; ij < pNum; ij++) {
-				index = ifs[pNum*ii+ij];
-				glNormal3fv((GLfloat *)&vNorm[index]);
-				glVertex3fv((GLfloat *)&pos[index]);
+		for(int ii = 0; ii < ifsP->faceSize; ii++) {
+			for(int ij = 0; ij < pNum; ij++) {
+				int index = ifs[pNum*ii+ij];
+				glNormal3fv(static_cast<GLfloat *>(&vNorm[index].x));
+				glVertex3fv(static_cast<GLfloat *>(&pos[index].x));
 			}
 		}
 		glEnd();
@@ -713,9 +708,9 @@ void fk_FaceDraw::DrawSolidFaceNormal(fk_Model *argObj,
 	loopRIte			rite;
 
 
-	solidP = (fk_Solid *)argObj->getShape();
+	solidP = static_cast<fk_Solid *>(argObj->getShape());
 	if(solidP->checkDB() == false) return;
-	if(solidP->getNextL((fk_Loop *)NULL) == (fk_Loop *)NULL) return;
+	if(solidP->getNextL(NULL) == NULL) return;
 
 	if(solidP->GetLCacheStatus() == false) {
 		solidP->MakeLCache();
@@ -728,11 +723,11 @@ void fk_FaceDraw::DrawSolidFaceNormal(fk_Model *argObj,
 	glShadeModel(GL_FLAT);
 
 	if(reverseFlag == false) {
-		for(ite = loopStack->begin(); ite != loopStack->end(); ite++) {
+		for(ite = loopStack->begin(); ite != loopStack->end(); ++ite) {
 			DrawSolidFaceNormalElem(*ite);
 		}
 	} else {
-		for(rite = loopStack->rbegin(); rite != loopStack->rend(); rite++) {
+		for(rite = loopStack->rbegin(); rite != loopStack->rend(); ++rite) {
 			DrawSolidFaceNormalElem(*rite);
 		}
 	}
@@ -745,35 +740,35 @@ void fk_FaceDraw::DrawSolidFaceNormalElem(fk_Loop *argL)
 	fk_Half				*startH, *curH;
 	fk_Vertex			*curV;
 	fk_Vector			*tmpPosP, *tmpNormP;
-	unsigned int		i;
 	vector<fk_Vertex *>	*tesseVertexArray;
 	vector<int>			*tesseIDArray;
 	fk_Surface			*surf;
 
-	if((surf = argL->getSurfGeometry()) != (fk_Surface *)NULL) {
+	if((surf = argL->getSurfGeometry()) != NULL) {
 		DrawSurface(surf);
 	} else if(argL->isTesselated() == true) {
-		if((tmpNormP = argL->getNormal()) == (fk_Vector *)NULL) return;
+		if((tmpNormP = argL->getNormal()) == NULL) return;
 		tesseVertexArray = argL->GetTesselateVertex();
 		tesseIDArray = argL->GetTesselateIndex();
 		glBegin(GL_TRIANGLES);
-		glNormal3dv((GLdouble *)&(tmpNormP->x));
-		for(i = 0; i < tesseIDArray->size(); i++) {
-			tmpPosP = tesseVertexArray->at(tesseIDArray->at(i))->GetPositionP();
-			glVertex3dv((GLdouble *)&(tmpPosP->x));
+		glNormal3dv(static_cast<GLdouble *>(&(tmpNormP->x)));
+		for(_st i = 0; i < tesseIDArray->size(); i++) {
+			_st index = static_cast<_st>(tesseIDArray->at(i));
+			tmpPosP = tesseVertexArray->at(index)->GetPositionP();
+			glVertex3dv(static_cast<GLdouble *>(&(tmpPosP->x)));
 		}
 		glEnd();
 
 	} else {
-		if((tmpNormP = argL->getNormal()) == (fk_Vector *)NULL) return;
+		if((tmpNormP = argL->getNormal()) == NULL) return;
 		startH = curH = argL->getOneHalf();
 		glBegin(GL_POLYGON);
-		glNormal3dv((GLdouble *)&(tmpNormP->x));
+		glNormal3dv(static_cast<GLdouble *>(&(tmpNormP->x)));
 
 		do {
 			curV = curH->getVertex();
 			tmpPosP = curV->GetPositionP(); 
-			glVertex3dv((GLdouble *)&(tmpPosP->x));
+			glVertex3dv(static_cast<GLdouble *>(&(tmpPosP->x)));
 			curH = curH->getNextHalf();
 		} while(startH != curH);
 
@@ -792,7 +787,7 @@ void fk_FaceDraw::DrawIFSFaceNormal(fk_Model *argObj,
 	int					ii, ij;
 	GLenum				tmpType;
 
-	ifsP = (fk_IndexFaceSet *)argObj->getShape();
+	ifsP = static_cast<fk_IndexFaceSet *>(argObj->getShape());
 
 	CommonMateSet(argObj, argLightFlag, argNodeFlag);
 	glShadeModel(GL_FLAT);
@@ -819,9 +814,9 @@ void fk_FaceDraw::DrawIFSFaceNormal(fk_Model *argObj,
 
 	glBegin(tmpType);
 	for(ii = 0; ii < ifsP->faceSize; ii++) {
-		glNormal3fv((GLfloat *)&pNorm[ii]);
+		glNormal3fv(static_cast<GLfloat *>(&(pNorm[ii].x)));
 		for(ij = 0; ij < pNum; ij++) {
-			glVertex3fv((GLfloat *)&pos[ifs[pNum*ii+ij]]);
+			glVertex3fv(static_cast<GLfloat *>(&pos[ifs[pNum*ii+ij]].x));
 		}
 	}
 	glEnd();
@@ -843,7 +838,7 @@ void fk_FaceDraw::CommonMateSet(fk_Model *argObj, bool lightFlag, bool matFlag)
 
 	shapeP = argObj->getShape();
 
-	if(matFlag == true || shapeP == (fk_Shape *)NULL) {
+	if(matFlag == true || shapeP == NULL) {
 		curMat = argObj->getInhMaterial();
 	} else {
 		curMat = &(*shapeP->getMaterialVector())[0];
