@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -135,7 +135,7 @@ void fk_FaceDraw::drawShapeFace(fk_Model *argObj, bool lightFlag,
 {
 	fk_MaterialMode	shapeMateMode;
 	fk_MaterialMode	modelMateMode;
-	bool			smoothMode, nodeMode, drawMode;
+	bool			smoothMode;
 
 	shapeMateMode = argObj->getShape()->getMaterialMode();
 	modelMateMode = argObj->getMaterialMode();
@@ -159,9 +159,8 @@ void fk_FaceDraw::drawShapeFace(fk_Model *argObj, bool lightFlag,
 		DrawShapeFaceMaterial(argObj, lightFlag);
 
 	} else {
-
-		drawMode = false;
-		nodeMode = false;
+		bool drawMode = false;
+		bool nodeMode = false;
 		if(modelMateMode == FK_CHILD_MODE) {
 			drawMode = true;
 			nodeMode = true;
@@ -232,11 +231,11 @@ void fk_FaceDraw::DrawSolidFacePick(fk_Model *argObj)
 	glDisableClientState(GL_NORMAL_ARRAY);
 
 	if(reverseFlag == false) {
-		for(ite = loopStack->begin(); ite != loopStack->end(); ite++) {
+		for(ite = loopStack->begin(); ite != loopStack->end(); ++ite) {
 			DrawSolidFacePickElem(*ite);
 		}
 	} else {
-		for(rite = loopStack->rbegin(); rite != loopStack->rend(); rite++) {
+		for(rite = loopStack->rbegin(); rite != loopStack->rend(); ++rite) {
 			DrawSolidFacePickElem(*rite);
 		}
 	}
@@ -251,7 +250,6 @@ void fk_FaceDraw::DrawSolidFacePickElem(fk_Loop *argL)
 	fk_Vertex			*curV;
 	fk_Half				*startH, *curH;
 	fk_Vector			*tmpPosP;
-	unsigned int		i;
 
 	glPushName(argL->getID()*3);
 
@@ -260,7 +258,7 @@ void fk_FaceDraw::DrawSolidFacePickElem(fk_Loop *argL)
 		tesseIDArray = argL->GetTesselateIndex();
 
 		glBegin(GL_TRIANGLES);
-		for(i = 0; i < tesseIDArray->size(); i++) {
+		for(unsigned int i = 0; i < tesseIDArray->size(); i++) {
 			tmpPosP = tesseVertexArray->at(tesseIDArray->at(i))->GetPositionP();
 			glVertex3dv((GLdouble *)&(tmpPosP->x));
 		}
@@ -388,12 +386,12 @@ void fk_FaceDraw::DrawSolidFaceMaterial(fk_Model *argObj, bool lightFlag)
 	matV = solidP->getMaterialVector();
 
 	if(reverseFlag == false) {
-		for(ite = loopStack->begin(); ite != loopStack->end(); ite++) {
+		for(ite = loopStack->begin(); ite != loopStack->end(); ++ite) {
 			oldMateID = DrawSolidFaceMaterialElem(argObj, *ite, oldMateID,
 												  paletteSize, matV, lightFlag);
 		}
 	} else {
-		for(rite = loopStack->rbegin(); rite != loopStack->rend(); rite++) {
+		for(rite = loopStack->rbegin(); rite != loopStack->rend(); ++rite) {
 			oldMateID = DrawSolidFaceMaterialElem(argObj, *rite, oldMateID,
 												  paletteSize, matV, lightFlag);
 		}
@@ -461,9 +459,9 @@ int fk_FaceDraw::DrawSolidFaceMaterialElem(fk_Model *argObj, fk_Loop *argL,
 			tmpVertex.p = *(tesseVertexArray->at(tesseIDArray->at(i))->GetPositionP());
 			workVertexArray.push_back(tmpVertex);
 		}
-		if(workVertexArray.size() == 0) return retMateID;
+		if(workVertexArray.empty()) return retMateID;
 		ref_lpD3DDEV->SetFVF(D3DFVF_FACECUSTOMVERTEX);
-		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLELIST, workVertexArray.size()/3, &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
+		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLELIST, static_cast<UINT>(workVertexArray.size()/3), &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
 	} else {
 		if((tmpNormP = argL->getNormal()) == (fk_Vector *)NULL) {
 			return retMateID;
@@ -478,9 +476,9 @@ int fk_FaceDraw::DrawSolidFaceMaterialElem(fk_Model *argObj, fk_Loop *argL,
 			curH = curH->getNextHalf();
 			workVertexArray.push_back(tmpVertex);
 		} while(startH != curH);
-		if(workVertexArray.size() == 0) return retMateID;
+		if(workVertexArray.empty()) return retMateID;
 		ref_lpD3DDEV->SetFVF(D3DFVF_FACECUSTOMVERTEX);
-		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLEFAN, workVertexArray.size()-2, &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
+		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLEFAN, static_cast<UINT>(workVertexArray.size()-2), &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
 	}
 
 	return retMateID;
@@ -623,11 +621,11 @@ void fk_FaceDraw::DrawSolidFaceSmooth(fk_Model *argObj,
 	ref_lpD3DDEV->SetRenderState(D3DRS_SHADEMODE, D3DSHADE_GOURAUD);
 
 	if(reverseFlag == false) {
-		for(ite = loopStack->begin(); ite != loopStack->end(); ite++) {
+		for(ite = loopStack->begin(); ite != loopStack->end(); ++ite) {
 			DrawSolidFaceSmoothElem(*ite);
 		}
 	} else {
-		for(rite = loopStack->rbegin(); rite != loopStack->rend(); rite++) {
+		for(rite = loopStack->rbegin(); rite != loopStack->rend(); ++rite) {
 			DrawSolidFaceSmoothElem(*rite);
 		}
 	}
@@ -662,9 +660,9 @@ void fk_FaceDraw::DrawSolidFaceSmoothElem(fk_Loop *argL)
 			curH = curH->getNextHalf();
 			workVertexArray.push_back(tmpVertex);
 		} while(startH != curH);
-		if(workVertexArray.size() == 0) return;
+		if(workVertexArray.empty()) return;
 		ref_lpD3DDEV->SetFVF(D3DFVF_FACECUSTOMVERTEX);
-		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLEFAN, workVertexArray.size()-2, &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
+		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLEFAN, static_cast<UINT>(workVertexArray.size()-2), &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
 	}
 
 	return;
@@ -713,7 +711,7 @@ void fk_FaceDraw::DrawIFSFaceSmooth(fk_Model *argObj,
 				workVertexArray.push_back(tmpVertex);
 			}
 		}
-		if(workVertexArray.size() == 0) return;
+		if(workVertexArray.empty()) return;
 		ref_lpD3DDEV->SetFVF(D3DFVF_FACECUSTOMVERTEX);
 		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLELIST, ifsP->faceSize, &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
 		break;
@@ -735,7 +733,7 @@ void fk_FaceDraw::DrawIFSFaceSmooth(fk_Model *argObj,
 			tmpVertex.n = vNorm[ifs[pNum*ii+3]];
 			workVertexArray.push_back(tmpVertex);
 		}
-		if(workVertexArray.size() == 0) return;
+		if(workVertexArray.empty()) return;
 		ref_lpD3DDEV->SetFVF(D3DFVF_FACECUSTOMVERTEX);
 		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLELIST, ifsP->faceSize*2, &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
 		/*
@@ -824,11 +822,11 @@ void fk_FaceDraw::DrawSolidFaceNormal(fk_Model *argObj,
 	ref_lpD3DDEV->SetRenderState(D3DRS_SHADEMODE, D3DSHADE_FLAT);
 
 	if(reverseFlag == false) {
-		for(ite = loopStack->begin(); ite != loopStack->end(); ite++) {
+		for(ite = loopStack->begin(); ite != loopStack->end(); ++ite) {
 			DrawSolidFaceNormalElem(*ite);
 		}
 	} else {
-		for(rite = loopStack->rbegin(); rite != loopStack->rend(); rite++) {
+		for(rite = loopStack->rbegin(); rite != loopStack->rend(); ++rite) {
 			DrawSolidFaceNormalElem(*rite);
 		}
 	}
@@ -841,7 +839,6 @@ void fk_FaceDraw::DrawSolidFaceNormalElem(fk_Loop *argL)
 	fk_Half				*startH, *curH;
 	fk_Vertex			*curV;
 	fk_Vector			*tmpNormP;
-	unsigned int		i;
 	vector<fk_Vertex *>	*tesseVertexArray;
 	vector<int>			*tesseIDArray;
 	fk_Surface			*surf;
@@ -855,14 +852,14 @@ void fk_FaceDraw::DrawSolidFaceNormalElem(fk_Loop *argL)
 		tesseIDArray = argL->GetTesselateIndex();
 
 		workVertexArray.clear();
-		for(i = 0; i < tesseIDArray->size(); i++) {
+		for(unsigned int i = 0; i < tesseIDArray->size(); i++) {
 			tmpVertex.n = *tmpNormP;
 			tmpVertex.p = *(tesseVertexArray->at(tesseIDArray->at(i))->GetPositionP());
 			workVertexArray.push_back(tmpVertex);
 		}
-		if(workVertexArray.size() == 0) return;
+		if(workVertexArray.empty()) return;
 		ref_lpD3DDEV->SetFVF(D3DFVF_FACECUSTOMVERTEX);
-		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLELIST, workVertexArray.size()/3, &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
+		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLELIST, static_cast<UINT>(workVertexArray.size()/3), &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
 
 	} else {
 		if((tmpNormP = argL->getNormal()) == (fk_Vector *)NULL) return;
@@ -876,9 +873,9 @@ void fk_FaceDraw::DrawSolidFaceNormalElem(fk_Loop *argL)
 			curH = curH->getNextHalf();
 			workVertexArray.push_back(tmpVertex);
 		} while(startH != curH);
-		if(workVertexArray.size() == 0) return;
+		if(workVertexArray.empty()) return;
 		ref_lpD3DDEV->SetFVF(D3DFVF_FACECUSTOMVERTEX);
-		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLEFAN, workVertexArray.size()-2, &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
+		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLEFAN, static_cast<UINT>(workVertexArray.size()-2), &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
 
 	}
 
@@ -928,7 +925,7 @@ void fk_FaceDraw::DrawIFSFaceNormal(fk_Model *argObj,
 				workVertexArray.push_back(tmpVertex);
 			}
 		}
-		if(workVertexArray.size() == 0) return;
+		if(workVertexArray.empty()) return;
 		ref_lpD3DDEV->SetFVF(D3DFVF_FACECUSTOMVERTEX);
 		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLELIST, ifsP->faceSize, &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
 		break;
@@ -950,7 +947,7 @@ void fk_FaceDraw::DrawIFSFaceNormal(fk_Model *argObj,
 			tmpVertex.n = pNorm[ii];
 			workVertexArray.push_back(tmpVertex);
 		}
-		if(workVertexArray.size() == 0) return;
+		if(workVertexArray.empty()) return;
 		ref_lpD3DDEV->SetFVF(D3DFVF_FACECUSTOMVERTEX);
 		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLELIST, ifsP->faceSize*2, &(workVertexArray[0]), sizeof(FACECUSTOMVERTEX));
 		/*
