@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -82,6 +82,8 @@ using namespace std;
 
 fk_FileInput::fk_FileInput(void)
 {
+	DB = NULL;
+	palette = NULL;
 	sizeMode = true;
 
 	return;
@@ -113,7 +115,7 @@ fk_DataFormatMode fk_FileInput::GetMode(string argFileName)
 	string::size_type	i;
 
 
-	if((fp = fopen(argFileName.c_str(), "rb")) == (FILE *)NULL) {
+	if((fp = fopen(argFileName.c_str(), "rb")) == NULL) {
 		return FK_ERROR_FILE;
 	}
 
@@ -511,7 +513,7 @@ bool fk_FileInput::GetLineTagStatus(FILE *argFP, string *argLine,
 	char	buffer[256];
 	string	word;
 
-	if(fgets(buffer, 255, argFP) == (char *)NULL) return false;
+	if(fgets(buffer, 255, argFP) == NULL) return false;
 	*argLine = buffer;
 	word = PopWord(argLine);
 	if(word.compare(argTag) != 0) return false;
@@ -562,7 +564,7 @@ bool fk_FileInput::GetAdminHeader(fk_DataFormatMode argMode, FILE *argFP,
 
 	switch(argMode) {
 	  case FK_TEXT_FILE:
-		if(fgets(buffer, 255, argFP) == (char *)NULL) {
+		if(fgets(buffer, 255, argFP) == NULL) {
 			return false;
 		}
 
@@ -592,7 +594,7 @@ bool fk_FileInput::GetAdminEraseList(fk_DataFormatMode argMode, FILE *argFP,
 	switch(argMode) {
 	  case FK_TEXT_FILE:
 		for(i = 0; i < argSize; i++) {
-			if(fgets(buffer, 255, argFP) == (char *)NULL) {
+			if(fgets(buffer, 255, argFP) == NULL) {
 				argAdmin->Init(1);
 				return false;
 			}
@@ -605,7 +607,7 @@ bool fk_FileInput::GetAdminEraseList(fk_DataFormatMode argMode, FILE *argFP,
 		if(argSize == 0) break;
 		array = new int [argSize];
 
-		if(BRead(array, argSize, argFP) == false) {
+		if(BRead(array, size_t(argSize), argFP) == false) {
 			delete [] array;
 			argAdmin->Init(1);
 			return false;
@@ -630,22 +632,22 @@ bool fk_FileInput::SetVertexData(int argVID, int argMateID, int argMateMode,
 								 double argZ, double argSize)
 {
 	fk_Vertex		*v;
-	fk_Half			*h = (fk_Half *)NULL;
+	fk_Half			*h = NULL;
 	fk_Vector		pos(argX, argY, argZ);
 
 	v = DB->GetVData(argVID);
-	if(v == (fk_Vertex *)NULL) return false;
+	if(v == NULL) return false;
 	if(argHID != FK_UNDEFINED) {
 		h = DB->GetHData(argHID);
 	} else {
-		h = (fk_Half *)NULL;
+		h = NULL;
 	}
 
 	v->SetOneHalf(h);
 	v->SetPosition(pos);
 
 	v->setElemMaterialID(argMateID);
-	v->setElemMaterialMode(argMateMode);
+	v->setElemMaterialMode(fk_MaterialMode(argMateMode));
 
 	v->setDrawSize(argSize);
 
@@ -661,13 +663,13 @@ bool fk_FileInput::SetHalfData(int argHID, int argVID,
 
 	h = DB->GetHData(argHID);
 
-	if(h == (fk_Half *)NULL) return false;
+	if(h == NULL) return false;
 
 	if(argVID == FK_UNDEFINED) {
-		v = (fk_Vertex *)NULL;
+		v = NULL;
 	} else {
 		v = DB->GetVData(argVID);
-		if(v == (fk_Vertex *)NULL) return false;
+		if(v == NULL) return false;
 	}
 
 	nH = DB->GetHData(argNID);
@@ -692,29 +694,29 @@ bool fk_FileInput::SetEdgeData(int argEID, int argMateID, int argMateMode,
 	if(argLeftID == FK_UNDEFINED) return true;
 
 	e = DB->GetEData(argEID);
-	if(e == (fk_Edge *)NULL) return false;
+	if(e == NULL) return false;
 
 	if(argLeftID == FK_UNDEFINED) {
-		lH = (fk_Half *)NULL;
+		lH = NULL;
 	} else {
 		lH = DB->GetHData(argLeftID);
-		if(lH == (fk_Half *)NULL) return false;
+		if(lH == NULL) return false;
 	}
 
 	if(argRightID == FK_UNDEFINED) {
-		rH = (fk_Half *)NULL;
+		rH = NULL;
 	} else {
 		rH = DB->GetHData(argRightID);
-		if(rH == (fk_Half *)NULL) return false;
+		if(rH == NULL) return false;
 	}
 
 	e->SetLeftHalf(lH);
 	e->SetRightHalf(rH);
-	if(lH != (fk_Half *)NULL) lH->SetParentEdge(e);
-	if(rH != (fk_Half *)NULL) rH->SetParentEdge(e);
+	if(lH != NULL) lH->SetParentEdge(e);
+	if(rH != NULL) rH->SetParentEdge(e);
 
 	e->setElemMaterialID(argMateID);
-	e->setElemMaterialMode(argMateMode);
+	e->setElemMaterialMode(fk_MaterialMode(argMateMode));
 
 	e->setDrawWidth(argWidth);
 
@@ -729,16 +731,16 @@ bool fk_FileInput::SetLoopData(int argLID, int argMateID, int argMateMode,
 
 	l = DB->GetLData(argLID);
 	if(argHID == FK_UNDEFINED) {
-		h = (fk_Half *)NULL;
+		h = NULL;
 	} else {
 		h = DB->GetHData(argHID);
-		if(h == (fk_Half *)NULL) return false;
+		if(h == NULL) return false;
 	}
 
 	l->SetOneHalf(h);
 
 	l->setElemMaterialID(argMateID);
-	l->setElemMaterialMode(argMateMode);
+	l->setElemMaterialMode(fk_MaterialMode(argMateMode));
 
 	return true;
 }
@@ -795,8 +797,8 @@ bool fk_FileInput::GetMainMaterialData(fk_DataFormatMode argMode, FILE *argFP)
 
 bool fk_FileInput::GetSubMaterialData(fk_DataFormatMode argMode, FILE *argFP)
 {
-	unsigned int			i, palSize;
-	vector<fk_Material>		*palStack;
+	vector<fk_Material>::size_type	i, palSize;
+	vector<fk_Material>				*palStack;
 
 	palStack = palette->getMaterialVector();
 	palSize = palStack->size();
