@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -69,6 +69,8 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+
+#define FK_DEF_SIZETYPE
 #include <FK/GenMatrix.h>
 #include <FK/Error.H>
 
@@ -77,7 +79,8 @@ using namespace std;
 // 0 との比較関数 (実数用) 
 inline bool AlmostZero(double x)
 {
-	if(x < FK_MATRIX_EPS && x > -FK_MATRIX_EPS) return true;	else return false;
+	if(x < FK_MATRIX_EPS && x > -FK_MATRIX_EPS) return true;
+	return false;
 }
 
 // 実数比較 
@@ -86,37 +89,37 @@ inline bool AlmostEqual(double x, double y)
 	return(AlmostZero(x - y));
 }
 
-void CopyMatrix(int deg, vector<double> &m1, const vector<double> &m2)
+void CopyMatrix(_st deg, vector<double> &m1, const vector<double> &m2)
 {
-	register int	i;
+	register _st	i;
 	for(i = 0; i < deg*deg; i++) {
 		m1[i] = m2[i];
 	}
 	return;
 }
 
-static void AddMatrix(int deg, vector<double> &m1, const vector<double> &m2)
+static void AddMatrix(_st deg, vector<double> &m1, const vector<double> &m2)
 {
-	register int	i;
+	register _st	i;
 	for(i = 0; i < deg*deg; i++) {
 		m1[i] += m2[i];
 	}
 	return;
 }
 
-static void SubMatrix(int deg, vector<double> &m1, const vector<double> &m2)
+static void SubMatrix(_st deg, vector<double> &m1, const vector<double> &m2)
 {
-	register int	i;
+	register _st	i;
 	for(i = 0; i < deg*deg; i++) {
 		m1[i] -= m2[i];
 	}
 	return;
 }
 
-static void MultMatrix(int deg, vector<double> &m1,
+static void MultMatrix(_st deg, vector<double> &m1,
 					   const vector<double> &m2, const vector<double> &m3)
 {
-	register int	i, j, k;
+	register _st	i, j, k;
 	
 	for(i = 0; i < deg*deg; i++) m1[i] = 0.0;
 	
@@ -131,15 +134,15 @@ static void MultMatrix(int deg, vector<double> &m1,
 }
 
 // 逆行列演算 LU 分解関数 1 
-static bool LUDecomposition(int deg, vector<double> &mat,
+static bool LUDecomposition(_st deg, vector<double> &mat,
 							vector<int> &index)
 {
-	int		i, iMax, j, k;
+	_st		i, iMax, j, k;
 	double	big, dum, sum, tmp;
 
 	static vector<double>	vv;
 
-	if(int(vv.size()) < deg) vv.resize(deg);
+	if(vv.size() < deg) vv.resize(deg);
 
 	// Get Scaling Information.;
 
@@ -190,7 +193,7 @@ static bool LUDecomposition(int deg, vector<double> &mat,
 			vv[iMax] = vv[j];
 		}
 	
-		index[j] = iMax;
+		index[j] = static_cast<int>(iMax);
 
 		if(AlmostZero(mat[j*deg+j]) == true) {
 			mat[j*deg+j] = FK_MATRIX_EPS2;
@@ -206,20 +209,21 @@ static bool LUDecomposition(int deg, vector<double> &mat,
 }
 
 // 逆行列演算 LU 分解関数 2 
-static void LUBackSubsutitution(int deg,
+static void LUBackSubsutitution(_st deg,
 								vector<double> &mat,
 								vector<int> &index,
 								vector<double> &vec)
 {
-	int				i, ip, j;
-	bool			iFlg;
-	double			sum;
+	_st		i, ip, j;
+	bool	iFlg;
+	double	sum;
+	int		k;
 
 	iFlg = false;
 
 	for(i = 0; i < deg; i++) {
 		// Forward Subsutitution;
-		ip = index[i];
+		ip = static_cast<_st>(index[i]);
 		sum = vec[ip];
 		vec[ip] = vec[i];
 		if(iFlg == false) {
@@ -230,7 +234,8 @@ static void LUBackSubsutitution(int deg,
 		vec[i] = sum;
 	}
 	
-	for(i = deg-1; i >= 0; i--) {
+	for(k = static_cast<int>(deg)-1; k >= 0; k--) {
+		i = static_cast<_st>(k);
 		// Backward Subsutitution;
 		sum = vec[i];
 		for(j = i+1; j < deg; j++) sum -= mat[i*deg+j]*vec[j];
@@ -242,7 +247,7 @@ static void LUBackSubsutitution(int deg,
 void fk_GenMatrix::MultVec(fk_GenVector &retVec,
 						   const fk_GenVector &argVec) const
 {
-	register int	i, j;
+	register _st	i, j;
 
 	for(i = 0; i < deg; i++) {
 		retVec.v[i] = 0.0;
@@ -255,7 +260,7 @@ void fk_GenMatrix::MultVec(fk_GenVector &retVec,
 
 void fk_GenMatrix::MakeIdentMatrix(void)
 {
-	register int	i;
+	register _st	i;
 
 	for(i = 0; i < deg*deg; i++) m[i] = 0.0;
 
@@ -267,7 +272,7 @@ void fk_GenMatrix::MakeIdentMatrix(void)
 
 void fk_GenMatrix::MakeZeroMatrix(void)
 {
-	register int	i;
+	register _st	i;
 
 	for(i = 0; i < deg*deg; i++) {
 		m[i] = 0.0;
@@ -278,13 +283,13 @@ void fk_GenMatrix::MakeZeroMatrix(void)
 // 逆行列演算 LU 分解関数本体 
 bool fk_GenMatrix::MatrixInverse(void)
 {
-	int				i, j;
+	_st						i, j;
 	static vector<double>	vec;
 	static vector<double>	dummy;
 	static vector<double>	mat;
 	static vector<int>		index;
 
-	if(int(index.size()) < deg) {
+	if(index.size() < deg) {
 		mat.resize(deg*deg);
 		vec.resize(deg);
 		dummy.resize(deg*deg);
@@ -323,9 +328,9 @@ fk_GenMatrix::fk_GenMatrix(int argDeg)
 
 fk_GenMatrix::fk_GenMatrix(const fk_GenMatrix &argM)
 {
-	int			i;
+	_st			i;
 
-	setDeg(argM.deg);
+	setDeg(static_cast<int>(argM.deg));
 	for(i = 0; i < deg*deg; i++) {
 		m[i] = argM.m[i];
 	}
@@ -348,7 +353,7 @@ void fk_GenMatrix::setDeg(int argDeg)
 		deg = 0;
 		m.clear();
 	} else {
-		deg = argDeg;
+		deg = static_cast<_st>(argDeg);
 		m.resize(deg*deg);
 	}
 	init();
@@ -358,20 +363,26 @@ void fk_GenMatrix::setDeg(int argDeg)
 
 int fk_GenMatrix::getDeg(void) const
 {
-	return deg;
+	return static_cast<int>(deg);
 }
 
 void fk_GenMatrix::set(int argRow, int argCol, double argValue)
 {
-	if(argRow < 0 || argRow >= deg || argCol < 0 || argCol >= deg) return;
-	m[argRow*deg + argCol] = argValue;
+	_st		index = static_cast<_st>(argRow)*deg + static_cast<_st>(argCol);
+
+	if(argRow < 0 || argRow >= static_cast<int>(deg) ||
+	   argCol < 0 || argCol >= static_cast<int>(deg)) return;
+	m[index] = argValue;
 	return;
 }
 
 double fk_GenMatrix::get(int argRow, int argCol) const
 {
-	if(argRow < 0 || argRow >= deg || argCol < 0 || argCol >= deg) return 0.0;
-	return m[argRow*deg + argCol];
+	_st		index = static_cast<_st>(argRow)*deg + static_cast<_st>(argCol);
+
+	if(argRow < 0 || argRow >= static_cast<int>(deg) ||
+	   argCol < 0 || argCol >= static_cast<int>(deg)) return 0.0;
+	return m[index];
 }
 
 bool fk_GenMatrix::inverse(void)
@@ -381,7 +392,7 @@ bool fk_GenMatrix::inverse(void)
 
 void fk_GenMatrix::negate(void)
 {
-	register int	i, j;
+	register _st	i, j;
 	double			tmp;
 
 	for(i = 0; i < deg; i++) {
@@ -399,9 +410,9 @@ bool fk_GenMatrix::isSingular(void) const
 {
 	static vector<double>	mat;
 	static vector<int>		index;
-	int						i;
+	_st						i;
 
-	if(int(index.size()) < deg) {
+	if(index.size() < deg) {
 		mat.resize(deg*deg);
 		index.resize(deg);
 	}
@@ -436,7 +447,7 @@ fk_GenMatrix fk_GenMatrix::operator !(void) const
 
 bool fk_GenMatrix::operator ==(const fk_GenMatrix &argMat) const
 {
-	register int	i;
+	register _st	i;
 	
 	if(deg != argMat.deg) return false;
 	for(i = 0; i < deg*deg; i++) {
@@ -447,7 +458,7 @@ bool fk_GenMatrix::operator ==(const fk_GenMatrix &argMat) const
 
 bool fk_GenMatrix::operator !=(const fk_GenMatrix &argMat) const
 {
-	register int	i;
+	register _st 	i;
 	
 	if(deg != argMat.deg) return true;
 	for(i = 0; i < deg*deg; i++) {
@@ -458,7 +469,7 @@ bool fk_GenMatrix::operator !=(const fk_GenMatrix &argMat) const
 
 fk_GenMatrix & fk_GenMatrix::operator =(const fk_GenMatrix &argMat)
 {
-	setDeg(argMat.deg);
+	setDeg(static_cast<int>(argMat.deg));
 	CopyMatrix(deg, m, argMat.m);
 	return *this;
 }
@@ -479,7 +490,7 @@ fk_GenVector & fk_GenVector::operator *=(const fk_GenMatrix &argMat)
 	int				deg;
 	
 	deg = size();
-	if(deg != argMat.deg) return *this;
+	if(deg != static_cast<int>(argMat.deg)) return *this;
 	tmp.resize(deg);
 	argMat.MultVec(tmp, *this);
 	*this = tmp;
@@ -502,7 +513,7 @@ fk_GenMatrix & fk_GenMatrix::operator -=(const fk_GenMatrix &argMat)
 
 void fk_GenMatrix::Print(string argStr) const
 {
-	register int	i, j;
+	register _st	i, j;
 	string			line;
 
 	if(argStr.size() == 0) {
@@ -559,7 +570,7 @@ fk_GenMatrix operator *(const fk_GenMatrix &m1, const fk_GenMatrix &m2)
 	fk_GenMatrix	ret;
 
 	if(m1.deg != m2.deg) return ret;
-	ret.setDeg(m1.deg);
+	ret.setDeg(static_cast<int>(m1.deg));
 	MultMatrix(m1.deg, ret.m, m1.m, m2.m);
 	return ret;
 }
