@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -69,6 +69,8 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+
+#define FK_DEF_SIZETYPE
 #include <FK/IFSTexture.h>
 #include <FK/MQOParser.H>
 #include <FK/D3DXParser.H>
@@ -107,18 +109,10 @@ void fk_IFSTexture::init(void)
 fk_TexCoord fk_IFSTexture::getTextureCoord(int argTID, int argVID)
 {
 	fk_TexCoord	dummy(0.0, 0.0);
-	int			pNum, index;
+	int			index;
 
-	switch(ifs->getFaceType()) {
-	  case FK_IF_TRIANGLES:
-		pNum = 3;
-		break;
-
-	  case FK_IF_QUADS:
-		pNum = 4;
-		break;
-
-	  default:
+	if(ifs->getFaceType() != FK_IF_TRIANGLES &&
+	   ifs->getFaceType() != FK_IF_QUADS) {
 		return dummy;
 	}
 
@@ -129,7 +123,7 @@ fk_TexCoord fk_IFSTexture::getTextureCoord(int argTID, int argVID)
 		return dummy;
 	}
 
-	return coordArray[index];
+	return coordArray[static_cast<_st>(index)];
 }
 
 fk_IndexFaceSet * fk_IFSTexture::getIFS(void)
@@ -154,22 +148,26 @@ void fk_IFSTexture::cloneShape(fk_IFSTexture *argIT)
 void fk_IFSTexture::setTextureCoord(int argFID, int argVID,
 									fk_TexCoord &argCoord)
 {
-	int				index;
-	double			wScale, hScale;
+	int			tmp;
+	_st			index;
+	double		wScale, hScale;
 
 	const fk_Dimension *imageSize = getImageSize();
 	const fk_Dimension *bufSize = getBufferSize();
 
-	if(bufSize == (fk_Dimension *)NULL) return;
+	if(bufSize == NULL) return;
 	if(bufSize->w < 64 || bufSize->h < 64) return;
 
-	wScale = double(imageSize->w)/double(bufSize->w);
-	hScale = double(imageSize->h)/double(bufSize->h);
+	wScale = static_cast<double>(imageSize->w)/static_cast<double>(bufSize->w);
+	hScale = static_cast<double>(imageSize->h)/static_cast<double>(bufSize->h);
 
-	index = ifs->getFaceData(argFID, argVID);
-	if(index < 0) return;
+	tmp = ifs->getFaceData(argFID, argVID);
+	if(tmp < 0) return;
 
-	if(index >= int(coordArray.size())) coordArray.resize(index+1);
+	index = static_cast<_st>(tmp);
+	if(index >= coordArray.size()) {
+		coordArray.resize(index+1);
+	}
 	coordArray[index].x = argCoord.x * float(wScale);
 	coordArray[index].y = argCoord.y * float(hScale);
 	
@@ -219,12 +217,13 @@ bool fk_IFSTexture::readD3DXFile(string argFileName, string argObjName,
 {
 	fk_D3DXParser		*d3dxParser = new fk_D3DXParser();
 	bool				retVal;
+	bool				animFlg;
 
 	d3dxParser->SetIFSTexture(this);
 	retVal = d3dxParser->ReadD3DXFile(argFileName, argObjName,
-									  argMateID, true);
+									  argMateID, true, &animFlg);
 
-	setAnimationTime(-1.0);
+	if(animFlg == true) setAnimationTime(-1.0);
 	delete d3dxParser;
 	return retVal;
 }
@@ -242,19 +241,19 @@ bool fk_IFSTexture::getConnectMode(void)
 
 void fk_IFSTexture::SetConnectNormal(void)
 {
-	unsigned int			i, j;
-	fk_Vector				tmpNorm;
+	_st			i, j;
+	fk_Vector	tmpNorm;
 
 	for(i = 0; i < commonList.size(); i++) {
 		if(commonList[i].size() == 0) continue;
-		tmpNorm = ifs->getVNorm(i);
+		tmpNorm = ifs->getVNorm(static_cast<int>(i));
 		for(j = 0; j < commonList[i].size(); j++) {
 			tmpNorm += ifs->getVNorm(commonList[i][j]);
 		}
 
 		tmpNorm.normalize();
 
-		ifs->setVNorm(i, tmpNorm);
+		ifs->setVNorm(static_cast<int>(i), tmpNorm);
 		for(j = 0; j < commonList[i].size(); j++) {
 			ifs->setVNorm(commonList[i][j], tmpNorm);
 		}
@@ -265,12 +264,16 @@ void fk_IFSTexture::SetConnectNormal(void)
 bool fk_IFSTexture::moveVPosition(int argID, const fk_Vector &argV,
 								  int argOrder)
 {
-	unsigned int	i;
-	int				trueID = argID - argOrder;
+	_st		i, trueID;
+	int		tmp = argID - argOrder;
 
-	if(trueID < 0 || trueID >= int(commonList.size())) return false;
+	if(tmp < 0) return false;
+	trueID = static_cast<_st>(tmp);
+	if(trueID >= commonList.size()) return false;
 
-	if(ifs->moveVPosition(trueID, argV) == false) return false;
+	if(ifs->moveVPosition(static_cast<int>(trueID), argV) == false) {
+		return false;
+	}
 	for(i = 0; i < commonList[trueID].size(); i++) {
 		if(ifs->moveVPosition(commonList[trueID][i], argV) == false) {
 			return false;
