@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -69,14 +69,20 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+
+#define FK_DEF_SIZETYPE
 #include <FK/Image.h>
 #include <FK/Error.H>
 
 #ifdef _FREEBSD_
 #include <FL/images/png.h>
 #else
+#ifdef _MACOSX_
+#include <png.h>
+#else
 #include <libpng/png.h>
 #endif
+#endif
 
 using namespace std;
 
@@ -87,9 +93,13 @@ extern "C" {
 	#endif
 	#ifdef _FREEBSD_
 		#include <FL/images/jpeglib.h>
+	#else
+	#ifdef _MACOSX_
+		#include <jpeglib.h>
 	#else
 		#include "jpeg/jpeglib.h"
 	#endif
+	#endif
 }
 
 bool fk_Image::IsBmpFile(const string argFName) const
@@ -97,7 +107,7 @@ bool fk_Image::IsBmpFile(const string argFName) const
 	FILE		*fp;
 	fk_ImType	buf[2];
 
-	if((fp = fopen(argFName.c_str(), "rb")) == (FILE *)NULL) {
+	if((fp = fopen(argFName.c_str(), "rb")) == NULL) {
 		return false;
 	}
 
@@ -142,8 +152,8 @@ fk_Dimension fk_Image::GetBmpSize(fk_ImType *argHeader)
 {
 	fk_Dimension	retDim;
 
-	retDim.w = int(ChgUInt(argHeader, 4));
-	retDim.h = int(ChgUInt(argHeader, 8));
+	retDim.w = static_cast<int>(ChgUInt(argHeader, 4));
+	retDim.h = static_cast<int>(ChgUInt(argHeader, 8));
 
 	return retDim;
 }
@@ -161,7 +171,7 @@ fk_ImageStatus fk_Image::LoadBmpFile(const string argFName)
 	int					x, y;
 	unsigned int		paletteSize;
 
-	if((fp = fopen(argFName.c_str(), "rb")) == (FILE *)NULL) {
+	if((fp = fopen(argFName.c_str(), "rb")) == NULL) {
 		return FK_IMAGE_OPENERROR;
 	}
 
@@ -192,14 +202,15 @@ fk_ImageStatus fk_Image::LoadBmpFile(const string argFName)
 		rgbQuad.clear();
 	}
 
-	tmpSize = GetOneBufferSize(bmpType, bmpSize.w);
+	tmpSize = GetOneBufferSize(static_cast<int>(bmpType), bmpSize.w);
 	if(tmpSize < 0) return FK_IMAGE_DATAERROR;
 
-	tmpBuffer.resize(tmpSize);
+	tmpBuffer.resize(static_cast<_st>(tmpSize));
 
 	for(y = bmpSize.h - 1; y >= 0; y--) {
-		if(int(fread(&tmpBuffer[0], sizeof(fk_ImType),
-					 tmpSize, fp)) != tmpSize) {
+		if((fread(&tmpBuffer[0], sizeof(fk_ImType),
+				  static_cast<size_t>(tmpSize),
+				  fp)) != static_cast<size_t>(tmpSize)) {
 			fclose(fp);
 			rgbQuad.clear();
 			tmpBuffer.clear();
@@ -207,7 +218,8 @@ fk_ImageStatus fk_Image::LoadBmpFile(const string argFName)
 		}
 
 		for(x = 0; x < bmpSize.w; x++) {
-			SetRGBA4Bmp(x, y, &tmpBuffer[0], bmpType, rgbQuad);
+			SetRGBA4Bmp(x, y, &tmpBuffer[0],
+						static_cast<int>(bmpType), rgbQuad);
 		}
 	}
 
@@ -250,14 +262,15 @@ fk_ImageStatus fk_Image::LoadBmpData(fk_ImType *argBuffer)
 		tmpImageBuf = argBuffer + 54;
 	}
 
-	tmpSize = GetOneBufferSize(bmpType, bmpSize.w);
+	tmpSize = GetOneBufferSize(static_cast<int>(bmpType), bmpSize.w);
 	if(tmpSize < 0) return FK_IMAGE_DATAERROR;
 
 	for(y = bmpSize.h - 1, count = 0; y >= 0; y--, count++) {
 
 		for(x = 0; x < bmpSize.w; x++) {
 			SetRGBA4Bmp(x, y,
-						tmpImageBuf + count * tmpSize, bmpType, rgbQuad);
+						tmpImageBuf + count * tmpSize,
+						static_cast<int>(bmpType), rgbQuad);
 		}
 	}
 
@@ -269,30 +282,30 @@ void fk_Image::SetRGBA4Bmp(int argX, int argY,
 						   vector<fk_ImType> &argQuadBuffer)
 {
 	fk_ImType	tmp;
-	int			pb;
+	_st			pb;
 
 	switch(argType) {
 	  case 1:
 		if((argBuffer[argX/8] & (0x80 >> argX % 8)) != 0) {
 			setRGB(argX, argY,
-				   (int)argQuadBuffer[4],
-				   (int)argQuadBuffer[5],
-				   (int)argQuadBuffer[6]);
+				   static_cast<int>(argQuadBuffer[4]),
+				   static_cast<int>(argQuadBuffer[5]),
+				   static_cast<int>(argQuadBuffer[6]));
 		} else {
 			setRGB(argX, argY,
-				   (int)argQuadBuffer[0],
-				   (int)argQuadBuffer[1],
-				   (int)argQuadBuffer[2]);
+				   static_cast<int>(argQuadBuffer[0]),
+				   static_cast<int>(argQuadBuffer[1]),
+				   static_cast<int>(argQuadBuffer[2]));
 		}
 
 		break;
 
 	  case 4:
 		if((argX % 2) == 0) {
-			tmp = (fk_ImType)((int)argBuffer[argX/2] >> 4);
+			tmp = (fk_ImType)(static_cast<int>(argBuffer[argX/2]) >> 4);
 			tmp &= 0x0f;
 		} else {
-			tmp = (fk_ImType)((int)argBuffer[argX/2] & 0x0f);
+			tmp = (fk_ImType)(static_cast<int>(argBuffer[argX/2]) & 0x0f);
 		}
 
 		setRGB(argX, argY,
@@ -303,29 +316,29 @@ void fk_Image::SetRGBA4Bmp(int argX, int argY,
 		break;
 
 	  case 8:
-		pb = (int)argBuffer[argX];
+		pb = static_cast<_st>(argBuffer[argX]);
 
 		setRGB(argX, argY,
-			   (int)argQuadBuffer[2+4*pb],
-			   (int)argQuadBuffer[1+4*pb],
-			   (int)argQuadBuffer[4*pb]);
+			   static_cast<int>(argQuadBuffer[2+4*pb]),
+			   static_cast<int>(argQuadBuffer[1+4*pb]),
+			   static_cast<int>(argQuadBuffer[4*pb]));
 		break;
 
 	  case 24:
 
 		setRGB(argX, argY,
-			   (int)argBuffer[argX*3+2],
-			   (int)argBuffer[argX*3+1],
-			   (int)argBuffer[argX*3]);
+			   static_cast<int>(argBuffer[argX*3+2]),
+			   static_cast<int>(argBuffer[argX*3+1]),
+			   static_cast<int>(argBuffer[argX*3]));
 		break;
 
 	  case 32:
 
 		setRGBA(argX, argY,
-				(int)argBuffer[argX*4+2],
-				(int)argBuffer[argX*4+1],
-				(int)argBuffer[argX*4],
-				255 - (int)argBuffer[argX*4+3]);
+				static_cast<int>(argBuffer[argX*4+2]),
+				static_cast<int>(argBuffer[argX*4+1]),
+				static_cast<int>(argBuffer[argX*4]),
+				255 - static_cast<int>(argBuffer[argX*4+3]));
 		break;
 
 	  default:
@@ -342,12 +355,13 @@ fk_ImageStatus fk_Image::SaveBmpFile(string argFName, bool argTransFlg)
 	vector<fk_ImType>	bmpFileHeader;
 	vector<fk_ImType>	bmpInfoHeader;
 	vector<fk_ImType>	bmpBuffer;
-	int					bmpBufSize, x, y;
+	_st					x, bmpBufSize;
+	int					y;
 	int					bitSize;
 
 	if(imageBuf.empty() == true) return FK_IMAGE_DATAERROR;
 
-	if((fp = fopen(argFName.c_str(), "wb")) == (FILE *)NULL) {
+	if((fp = fopen(argFName.c_str(), "wb")) == NULL) {
 		return FK_IMAGE_OPENERROR;
 	}
 
@@ -359,7 +373,7 @@ fk_ImageStatus fk_Image::SaveBmpFile(string argFName, bool argTransFlg)
 	MakeBmpFileHeader(wSize, hSize, bitSize, bmpFileHeader);
 	MakeBmpInfoHeader(wSize, hSize, bitSize*8, bmpInfoHeader);
 
-	bmpBufSize = wSize * bitSize;
+	bmpBufSize = static_cast<_st>(wSize * bitSize);
 
 	while(bmpBufSize % 4 != 0) {
 		bmpBufSize++;
@@ -391,11 +405,14 @@ void fk_Image::MakeBmpFileHeader(int argW, int argH, int argBitSize,
 	int			offset = 0;
 
 	argHeader.resize(14);
-	argHeader[0] = (fk_ImType)'B';
-	argHeader[1] = (fk_ImType)'M';
+	argHeader[0] = static_cast<fk_ImType>('B');
+	argHeader[1] = static_cast<fk_ImType>('M');
 	offset += 2;
 
-	SetLong2Byte(14 + 40 + ((long)argW * (long)argH * (long)argBitSize),
+	SetLong2Byte(14 + 40 +
+				 static_cast<long>(argW) *
+				 static_cast<long>(argH) *
+				 static_cast<long>(argBitSize),
 				 &argHeader[0], offset);
 	offset += 4;
 
@@ -422,11 +439,11 @@ void fk_Image::MakeBmpInfoHeader(int argW, int argH, int argBitSize,
 	offset += 4;
 
 	// .biWidth
-	SetLong2Byte((long)argW, &argInfo[0], offset);
+	SetLong2Byte(static_cast<long>(argW), &argInfo[0], offset);
 	offset += 4;
 
 	// .biHeight
-	SetLong2Byte((long)argH, &argInfo[0], offset);
+	SetLong2Byte(static_cast<long>(argH), &argInfo[0], offset);
 	offset += 4;
 
 	// .biPlanes
@@ -472,11 +489,11 @@ void fk_Image::MakeBmpBuffer(int argY, int argW,
 	offset = (argTransFlg == true) ? 4 : 3;
 
 	for(x = 0; x < argW; x++) {
-		argBuffer[x * offset] = getB(x, argY);
-		argBuffer[x * offset + 1] = getG(x, argY);
-		argBuffer[x * offset + 2] = getR(x, argY);
+		argBuffer[x * offset] = static_cast<fk_ImType>(getB(x, argY));
+		argBuffer[x * offset + 1] = static_cast<fk_ImType>(getG(x, argY));
+		argBuffer[x * offset + 2] = static_cast<fk_ImType>(getR(x, argY));
 		if(argTransFlg == true) {
-			argBuffer[x * offset + 3] = 255 - getA(x, argY);
+			argBuffer[x * offset + 3] = static_cast<fk_ImType>(255 - getA(x, argY));
 		}
 	}
 }
@@ -511,10 +528,10 @@ bool fk_Image::writeBMP(const string argFName, const bool argTransFlg)
 
 bool fk_Image::IsPngFile(const string argFName) const
 {
-	FILE		*fp;
-	char		sig[4];
+	FILE			*fp;
+	unsigned char	sig[4];
 
-	if((fp = fopen(argFName.c_str(), "rb")) == (FILE *)NULL) {
+	if((fp = fopen(argFName.c_str(), "rb")) == NULL) {
 		return false;
 	}
 
@@ -525,7 +542,7 @@ bool fk_Image::IsPngFile(const string argFName) const
 	}
 
 	// PNGファイルであるかどうかをチェック
-	if(!png_check_sig((png_bytep)sig, 4)) {
+	if(png_sig_cmp(sig, 0, 4)) {
 		fclose(fp);
 		return false;
 	}
@@ -537,9 +554,9 @@ bool fk_Image::IsPngFile(const string argFName) const
 void _fk_Image_PngReadFunc(png_struct *argPng, png_bytep argBuf,
 						   png_size_t argSize)
 {
-	unsigned char **p = (unsigned char **)png_get_io_ptr(argPng);
+	unsigned char **p = static_cast<unsigned char **>(png_get_io_ptr(argPng));
 	memcpy(argBuf, *p, argSize);
-	*p += (int)argSize;
+	*p += static_cast<int>(argSize);
 	return;
 }
 
@@ -548,10 +565,10 @@ fk_ImageStatus fk_Image::LoadPngData(fk_ImType *argBuffer)
 {
 	png_structp		png_ptr;
 	png_infop		info_ptr;
-	unsigned int	trueX, trueY;
+	_st				trueX, trueY;
 	png_bytepp		tmpBuffer;
 
-	if(!png_check_sig((png_bytep)argBuffer, 4)) return FK_IMAGE_DATAERROR;
+	if(png_sig_cmp(argBuffer, 0, 4)) return FK_IMAGE_DATAERROR;
 
 	// PNG構造体の初期化
 	png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
@@ -563,17 +580,17 @@ fk_ImageStatus fk_Image::LoadPngData(fk_ImType *argBuffer)
 	// PNG情報構造体の初期化
 	info_ptr = png_create_info_struct(png_ptr);
 	if(info_ptr == NULL) {
-		png_destroy_read_struct(&png_ptr, (png_infopp)NULL, (png_infopp)NULL);
+		png_destroy_read_struct(&png_ptr, NULL, NULL);
 		return FK_IMAGE_DATAERROR;
 	}
 
-	if(setjmp(png_ptr->jmpbuf)) {
-		png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
+	if(setjmp(png_jmpbuf(png_ptr))) {
+		png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
 		return FK_IMAGE_DATAERROR;
 	}
 
-	png_set_read_fn(png_ptr, (png_voidp)&argBuffer,
-					(png_rw_ptr)_fk_Image_PngReadFunc);
+	png_set_read_fn(png_ptr, &argBuffer,
+					_fk_Image_PngReadFunc);
 
 	// PNG情報構造体の取得
 	png_read_info(png_ptr, info_ptr);
@@ -584,11 +601,13 @@ fk_ImageStatus fk_Image::LoadPngData(fk_ImType *argBuffer)
 	// PNG_COLOR_TYPE_PALETTE (ビット深度 1, 2, 4, 8)
 	// PNG_COLOR_TYPE_RGB (ビット深度 8, 16)
 	// PNG_COLOR_TYPE_RGB_ALPHA (ビット深度 8, 16)
-	int type     = info_ptr->color_type;					// 色タイプ
-	int depth    = info_ptr->bit_depth;						// 色深度(1,2,4,8,16)
+
+	int type    = png_get_color_type(png_ptr, info_ptr);	// 色タイプ
+	int depth	= png_get_bit_depth(png_ptr, info_ptr);	// 色深度(1,2,4,8,16)
+
 	// 16bit-depthのPNGは除外
 	if(depth == 16){
-		png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
+		png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
 		return FK_IMAGE_DATAERROR;
 	}
 
@@ -597,20 +616,23 @@ fk_ImageStatus fk_Image::LoadPngData(fk_ImType *argBuffer)
 	trueY = png_get_image_height(png_ptr, info_ptr);
 
 	// fk_Image 本体のバッファを作成
-	CreateBuffer(trueX, trueY);
+	CreateBuffer(static_cast<int>(trueX),
+				 static_cast<int>(trueY));
 
 	// テンポラリイメージデータのメモリを取得
-	if((tmpBuffer = (png_bytepp)malloc(trueY * sizeof(png_bytep))) == NULL) {
-		png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
+	if((tmpBuffer = static_cast<png_bytepp>(malloc(trueY * sizeof(png_bytep)))) == NULL) {
+		png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
 		return FK_IMAGE_READERROR;
 	}
 	for(png_uint_32 i = 0; i < trueY; i++) {
 		// 1 ラインのテンポラリメモリを取得
-		tmpBuffer[i] = (png_bytep)malloc(png_get_rowbytes(png_ptr, info_ptr));
+		tmpBuffer[i] = static_cast<png_bytep>(malloc(png_get_rowbytes(png_ptr, info_ptr)));
 		if (tmpBuffer[i] == NULL) {
-			for (png_uint_32 j = 0; j < i; j++) { free(tmpBuffer[j]); }
+			for (png_uint_32 j = 0; j < i; j++) {
+				free(tmpBuffer[j]);
+			}
 			free(tmpBuffer);
-			png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
+			png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
 			return FK_IMAGE_READERROR;
 		}
 	}
@@ -625,11 +647,11 @@ fk_ImageStatus fk_Image::LoadPngData(fk_ImType *argBuffer)
 	// フルカラー(RGB)
 	if(type == PNG_COLOR_TYPE_RGB) {
 		// 内容の移し変え
-		unsigned int offset;
+		_st		offset;
 
-		for(unsigned long j = 0; j < trueY; j++){
-			for(unsigned long i = 0; i < trueX; i++){
-				offset = GetOffset(i, j);
+		for(int j = 0; j < static_cast<int>(trueY); j++){
+			for(int i = 0; i < static_cast<int>(trueX); i++){
+				offset = static_cast<_st>(GetOffset(i, j));
 				imageBuf[offset]   = tmpBuffer[j][i*3];
 				imageBuf[offset+1] = tmpBuffer[j][i*3+1];
 				imageBuf[offset+2] = tmpBuffer[j][i*3+2];
@@ -640,20 +662,21 @@ fk_ImageStatus fk_Image::LoadPngData(fk_ImType *argBuffer)
 	// フルカラー+アルファチャンネル(RGBA)
 	else if(type == PNG_COLOR_TYPE_RGB_ALPHA) {
 		// 内容の移し変え
-		int	lineSize = png_get_rowbytes(png_ptr, info_ptr);
+		int	lineSize = static_cast<int>(png_get_rowbytes(png_ptr, info_ptr));
 
-		for(unsigned long j = 0; j < trueY; j++) {
-			memcpy(&(imageBuf[GetOffset(0, j)]), tmpBuffer[j], lineSize);
+		for(int j = 0; j < static_cast<int>(trueY); j++) {
+			memcpy(&(imageBuf[static_cast<_st>(GetOffset(0, j))]),
+				   tmpBuffer[j], static_cast<size_t>(lineSize));
 		}
 	}
 	// グレースケール(8bit)
 	else if(type == PNG_COLOR_TYPE_GRAY && depth == 8) {
 		// 内容の移し変え
-		unsigned int offset;
+		_st 	offset;
 
-		for(unsigned long j = 0; j < trueY; j++){
-			for(unsigned long i = 0; i < trueX; i++){
-				offset = GetOffset(i, j);
+		for(int j = 0; j < static_cast<int>(trueY); j++){
+			for(int i = 0; i < static_cast<int>(trueX); i++){
+				offset = static_cast<_st>(GetOffset(i, j));
 				imageBuf[offset]   = tmpBuffer[j][i];
 				imageBuf[offset+1] = tmpBuffer[j][i];
 				imageBuf[offset+2] = tmpBuffer[j][i];
@@ -665,22 +688,23 @@ fk_ImageStatus fk_Image::LoadPngData(fk_ImType *argBuffer)
 	else if(type == PNG_COLOR_TYPE_GRAY && depth == 1){
 		// 内容の移し変え
 		unsigned char	color;
-		unsigned int	offset, x, y;
+		_st				offset;
+		int				x, y;
 
-		for(unsigned long j = 0; j < trueY; j++){
-			for(unsigned long i = 0; i < trueX/8+1; i++){
+		for(int j = 0; j < static_cast<int>(trueY); j++){
+			for(int i = 0; i < static_cast<int>(trueX/8+1); i++){
 				color = tmpBuffer[j][i];
 
 				for(int k = 0; k < 8; k++){
 					x = i*8+k;
 					y = j;
-					offset = GetOffset(x, y);
+					offset = static_cast<_st>(GetOffset(x, y));
 					
-					if(x < trueX){
-						imageBuf[offset]   = 255 * ((color >> (7-k)) % 2);
-						imageBuf[offset+1] = 255 * ((color >> (7-k)) % 2);
-						imageBuf[offset+2] = 255 * ((color >> (7-k)) % 2);
-						imageBuf[offset+3] = 255;
+					if(x < static_cast<int>(trueX)){
+						imageBuf[offset]   = static_cast<fk_ImType>(255 * ((color >> (7-k)) % 2));
+						imageBuf[offset+1] = static_cast<fk_ImType>(255 * ((color >> (7-k)) % 2));
+						imageBuf[offset+2] = static_cast<fk_ImType>(255 * ((color >> (7-k)) % 2));
+						imageBuf[offset+3] = static_cast<fk_ImType>(255);
 					}
 				}
 			}
@@ -690,16 +714,16 @@ fk_ImageStatus fk_Image::LoadPngData(fk_ImType *argBuffer)
 	else if(type == PNG_COLOR_TYPE_PALETTE && depth == 8){
 		png_colorp		palette;		// パレットデータ
 		int				num_palette;	// パレット数
-		unsigned int	offset;
+		_st				offset;
 		unsigned char	num;
 		
 		// パレットの取得
 		png_get_PLTE(png_ptr, info_ptr, &palette, &num_palette);
 
 		// 内容の移し変え
-		for(unsigned long j = 0; j < trueY; j++){
-			for(unsigned long i = 0; i < trueX; i++){
-				offset = GetOffset(i, j);
+		for(int j = 0; j < static_cast<int>(trueY); j++){
+			for(int i = 0; i < static_cast<int>(trueX); i++){
+				offset = static_cast<_st>(GetOffset(i, j));
 				// パレット番号の取得
 				num = tmpBuffer[j][i];
 				imageBuf[offset]   = palette[num].red;
@@ -719,7 +743,7 @@ fk_ImageStatus fk_Image::LoadPngData(fk_ImType *argBuffer)
 	free(tmpBuffer);
 
 	// PNGメモリの解放
-	png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
+	png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
 
 	return result;
 }
@@ -727,7 +751,7 @@ fk_ImageStatus fk_Image::LoadPngData(fk_ImType *argBuffer)
 fk_ImageStatus fk_Image::LoadPngFile(const string argFName)
 {
 	FILE			*fp;
-	char			sig[4];
+	unsigned char	sig[4];
 	png_structp		png_ptr;
 	png_infop		info_ptr;
 	unsigned int	trueX, trueY;
@@ -745,7 +769,7 @@ fk_ImageStatus fk_Image::LoadPngFile(const string argFName)
 	}
 
 	// PNGファイルであるかどうかをチェック
-	if(!png_check_sig((png_bytep)sig, 4)) {
+	if(png_sig_cmp(sig, 0, 4)) {
 		fclose(fp);
 		return FK_IMAGE_DATAERROR;
 	}
@@ -760,13 +784,13 @@ fk_ImageStatus fk_Image::LoadPngFile(const string argFName)
 	// PNG情報構造体の初期化
 	info_ptr = png_create_info_struct(png_ptr);
 	if(info_ptr == NULL) {
-		png_destroy_read_struct(&png_ptr, (png_infopp)NULL, (png_infopp)NULL);
+		png_destroy_read_struct(&png_ptr, NULL, NULL);
 		fclose(fp);
 		return FK_IMAGE_DATAERROR;
 	}
 
-	if(setjmp(png_ptr->jmpbuf)) {
-		png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
+	if(setjmp(png_jmpbuf(png_ptr))) {
+		png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
 		fclose(fp);
 		return FK_IMAGE_DATAERROR;
 	}
@@ -785,11 +809,13 @@ fk_ImageStatus fk_Image::LoadPngFile(const string argFName)
 	// PNG_COLOR_TYPE_PALETTE (ビット深度 1, 2, 4, 8)
 	// PNG_COLOR_TYPE_RGB (ビット深度 8, 16)
 	// PNG_COLOR_TYPE_RGB_ALPHA (ビット深度 8, 16)
-	int type     = info_ptr->color_type;					// 色タイプ
-	int depth    = info_ptr->bit_depth;						// 色深度(1,2,4,8,16)
+
+	int type    = png_get_color_type(png_ptr, info_ptr);	// 色タイプ
+	int depth	= png_get_bit_depth(png_ptr, info_ptr);	// 色深度(1,2,4,8,16)
+
 	// 16bit-depthのPNGは除外
 	if(depth == 16){
-		png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
+		png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
 		fclose(fp);
 		return FK_IMAGE_DATAERROR;
 	}
@@ -799,21 +825,24 @@ fk_ImageStatus fk_Image::LoadPngFile(const string argFName)
 	trueY = png_get_image_height(png_ptr, info_ptr);
 
 	// fk_Image 本体のバッファを作成
-	CreateBuffer(trueX, trueY);
+	CreateBuffer(static_cast<int>(trueX),
+				 static_cast<int>(trueY));
 
 	// テンポラリイメージデータのメモリを取得
-	if((tmpBuffer = (png_bytepp)malloc(trueY * sizeof(png_bytep))) == NULL) {
-		png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
+	if((tmpBuffer = static_cast<png_bytepp>(malloc(trueY * sizeof(png_bytep)))) == NULL) {
+		png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
 		fclose(fp);
 		return FK_IMAGE_READERROR;
 	}
 	for(png_uint_32 i = 0; i < trueY; i++) {
 		// 1 ラインのテンポラリメモリを取得
-		tmpBuffer[i] = (png_bytep)malloc(png_get_rowbytes(png_ptr, info_ptr));
+		tmpBuffer[i] = static_cast<png_bytep>(malloc(png_get_rowbytes(png_ptr, info_ptr)));
 		if (tmpBuffer[i] == NULL) {
-			for (png_uint_32 j = 0; j < i; j++) { free(tmpBuffer[j]); }
+			for (png_uint_32 j = 0; j < i; j++) {
+				free(tmpBuffer[j]);
+			}
 			free(tmpBuffer);
-			png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
+			png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
 			fclose(fp);
 			return FK_IMAGE_READERROR;
 		}
@@ -832,11 +861,11 @@ fk_ImageStatus fk_Image::LoadPngFile(const string argFName)
 	// フルカラー(RGB)
 	if(type == PNG_COLOR_TYPE_RGB) {
 		// 内容の移し変え
-		unsigned int offset;
+		_st 	offset;
 
-		for(unsigned long j = 0; j < trueY; j++){
-			for(unsigned long i = 0; i < trueX; i++){
-				offset = GetOffset(i, j);
+		for(int j = 0; j < static_cast<int>(trueY); j++){
+			for(int i = 0; i < static_cast<int>(trueX); i++){
+				offset = static_cast<_st>(GetOffset(i, j));
 				imageBuf[offset]   = tmpBuffer[j][i*3];
 				imageBuf[offset+1] = tmpBuffer[j][i*3+1];
 				imageBuf[offset+2] = tmpBuffer[j][i*3+2];
@@ -847,20 +876,21 @@ fk_ImageStatus fk_Image::LoadPngFile(const string argFName)
 	// フルカラー+アルファチャンネル(RGBA)
 	else if(type == PNG_COLOR_TYPE_RGB_ALPHA) {
 		// 内容の移し変え
-		int	lineSize = png_get_rowbytes(png_ptr, info_ptr);
+		int	lineSize = static_cast<int>(png_get_rowbytes(png_ptr, info_ptr));
 
-		for(unsigned long j = 0; j < trueY; j++) {
-			memcpy(&imageBuf[GetOffset(0, j)], tmpBuffer[j], lineSize);
+		for(int j = 0; j < static_cast<int>(trueY); j++) {
+			memcpy(&imageBuf[static_cast<_st>(GetOffset(0, j))],
+				   tmpBuffer[j], static_cast<size_t>(lineSize));
 		}
 	}
 	// グレースケール(8bit)
 	else if(type == PNG_COLOR_TYPE_GRAY && depth == 8) {
 		// 内容の移し変え
-		unsigned int offset;
+		_st		offset;
 
-		for(unsigned long j = 0; j < trueY; j++){
-			for(unsigned long i = 0; i < trueX; i++){
-				offset = GetOffset(i, j);
+		for(int j = 0; j < static_cast<int>(trueY); j++){
+			for(int i = 0; i < static_cast<int>(trueX); i++){
+				offset = static_cast<_st>(GetOffset(i, j));
 				imageBuf[offset]   = tmpBuffer[j][i];
 				imageBuf[offset+1] = tmpBuffer[j][i];
 				imageBuf[offset+2] = tmpBuffer[j][i];
@@ -872,22 +902,23 @@ fk_ImageStatus fk_Image::LoadPngFile(const string argFName)
 	else if(type == PNG_COLOR_TYPE_GRAY && depth == 1){
 		// 内容の移し変え
 		unsigned char	color;
-		unsigned int	offset, x, y;
+		_st				offset;
+		int				x, y;
 
-		for(unsigned long j = 0; j < trueY; j++){
-			for(unsigned long i = 0; i < trueX/8+1; i++){
+		for(int j = 0; j < static_cast<int>(trueY); j++){
+			for(int i = 0; i < static_cast<int>(trueX/8+1); i++){
 				color = tmpBuffer[j][i];
 
 				for(int k = 0; k < 8; k++){
 					x = i*8+k;
 					y = j;
-					offset = GetOffset(x, y);
+					offset = static_cast<_st>(GetOffset(x, y));
 					
-					if(x < trueX){
-						imageBuf[offset]   = 255 * ((color >> (7-k)) % 2);
-						imageBuf[offset+1] = 255 * ((color >> (7-k)) % 2);
-						imageBuf[offset+2] = 255 * ((color >> (7-k)) % 2);
-						imageBuf[offset+3] = 255;
+					if(x < static_cast<int>(trueX)) {
+						imageBuf[offset]   = static_cast<fk_ImType>(255 * ((color >> (7-k)) % 2));
+						imageBuf[offset+1] = static_cast<fk_ImType>(255 * ((color >> (7-k)) % 2));
+						imageBuf[offset+2] = static_cast<fk_ImType>(255 * ((color >> (7-k)) % 2));
+						imageBuf[offset+3] = static_cast<fk_ImType>(255);
 					}
 				}
 			}
@@ -897,16 +928,16 @@ fk_ImageStatus fk_Image::LoadPngFile(const string argFName)
 	else if(type == PNG_COLOR_TYPE_PALETTE && depth == 8){
 		png_colorp		palette;		// パレットデータ
 		int				num_palette;	// パレット数
-		unsigned int	offset;
+		_st				offset;
 		unsigned char	num;
 		
 		// パレットの取得
 		png_get_PLTE(png_ptr, info_ptr, &palette, &num_palette);
 
 		// 内容の移し変え
-		for(unsigned long j = 0; j < trueY; j++){
-			for(unsigned long i = 0; i < trueX; i++){
-				offset = GetOffset(i, j);
+		for(int j = 0; j < static_cast<int>(trueY); j++){
+			for(int i = 0; i < static_cast<int>(trueX); i++){
+				offset = static_cast<_st>(GetOffset(i, j));
 				// パレット番号の取得
 				num = tmpBuffer[j][i];
 				imageBuf[offset]   = palette[num].red;
@@ -926,7 +957,7 @@ fk_ImageStatus fk_Image::LoadPngFile(const string argFName)
 	free(tmpBuffer);
 
 	// PNGメモリの解放
-	png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
+	png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
 
 	return result;
 }
@@ -981,11 +1012,15 @@ bool fk_Image::writePNG(const string fileName, const bool argTransFlg)
 
 	// ヘッダに情報を設定(幅、高さ、256(8bit)階調、RGB(A)、インタレースなし)
 	if(argTransFlg == true) {
-		png_set_IHDR(png_ptr, info_ptr, getWidth(), getHeight(), 8,
+		png_set_IHDR(png_ptr, info_ptr,
+					 static_cast<png_uint_32>(getWidth()),
+					 static_cast<png_uint_32>(getHeight()), 8,
 					 PNG_COLOR_TYPE_RGB_ALPHA, PNG_INTERLACE_NONE,
 					 PNG_COMPRESSION_TYPE_DEFAULT, PNG_FILTER_TYPE_BASE);
 	} else {
-		png_set_IHDR(png_ptr, info_ptr, getWidth(), getHeight(), 8,
+		png_set_IHDR(png_ptr, info_ptr,
+					 static_cast<png_uint_32>(getWidth()),
+					 static_cast<png_uint_32>(getHeight()), 8,
 					 PNG_COLOR_TYPE_RGB, PNG_INTERLACE_NONE,
 					 PNG_COMPRESSION_TYPE_DEFAULT, PNG_FILTER_TYPE_BASE);
 	}
@@ -994,17 +1029,17 @@ bool fk_Image::writePNG(const string fileName, const bool argTransFlg)
 	// 構造体にセットしてから幅と高さを取得し直す
 	trueX = png_get_image_width(png_ptr, info_ptr);
 	trueY = png_get_image_height(png_ptr, info_ptr);
-	lineSize = png_get_rowbytes(png_ptr, info_ptr);
+	lineSize = static_cast<unsigned int>(png_get_rowbytes(png_ptr, info_ptr));
 
 	// テンポラリイメージデータのメモリを取得
-	if((tmpBuffer = (png_bytepp)malloc(trueY * sizeof(png_bytep))) == NULL) {
+	if((tmpBuffer = static_cast<png_bytepp>(malloc(trueY * sizeof(png_bytep)))) == NULL) {
 		png_destroy_write_struct(&png_ptr, &info_ptr);
 		fclose(fp);
 		return false;
 	}
 	for(png_uint_32 i = 0; i < trueY; i++) {
 		// 1 ラインのテンポラリメモリを取得
-		tmpBuffer[i] = (png_bytep)malloc(lineSize);
+		tmpBuffer[i] = static_cast<png_bytep>(malloc(lineSize));
 		if(tmpBuffer[i] == NULL) {
 			for(png_uint_32 j = 0; j < i; j++) {
 				free(tmpBuffer[j]);
@@ -1018,14 +1053,16 @@ bool fk_Image::writePNG(const string fileName, const bool argTransFlg)
 
 	// 内容の移し変え
 	if(argTransFlg == true) {
-		for(unsigned int j = 0; j < trueY; j++) {
-			memcpy(tmpBuffer[j], &imageBuf[GetOffset(0, j)], lineSize);
+		for(int j = 0; j < static_cast<int>(trueY); j++) {
+			memcpy(tmpBuffer[j],
+				   &imageBuf[static_cast<_st>(GetOffset(0, j))],
+				   lineSize);
 		}
 	} else {
-		int offset;
-		for(unsigned int j = 0; j < trueY; j++) {
-			for(unsigned int i = 0; i < trueX; i++) {
-				offset = GetOffset(i, j);
+		_st		offset;
+		for(int j = 0; j < static_cast<int>(trueY); j++) {
+			for(int i = 0; i < static_cast<int>(trueX); i++) {
+				offset = static_cast<_st>(GetOffset(i, j));
 				tmpBuffer[j][i * 3 + 0] = imageBuf[offset + 0];
 				tmpBuffer[j][i * 3 + 1] = imageBuf[offset + 1];
 				tmpBuffer[j][i * 3 + 2] = imageBuf[offset + 2];
@@ -1077,18 +1114,19 @@ bool fk_Image::readJPG(const string fileName)
 	jpeg_start_decompress(&cinfo);
 
 	// 幅と高さの取得
-	int wid = cinfo.output_width;
-	int hgt = cinfo.output_height;
+	unsigned int wid = cinfo.output_width;
+	unsigned int hgt = cinfo.output_height;
 
 	// イメージを保持するメモリ領域の確保と初期化
 	JSAMPARRAY img = (JSAMPARRAY)malloc(sizeof(JSAMPROW) * hgt);
-	for(int i = 0; i < hgt; i++) {
+	for(unsigned int i = 0; i < hgt; i++) {
 		img[i] = (JSAMPROW)calloc(sizeof(JSAMPLE), 3 * wid);
 	}
 
 	// 全イメージデータを取得	
 	while(cinfo.output_scanline < cinfo.output_height) {
-		jpeg_read_scanlines(&cinfo, img + cinfo.output_scanline, cinfo.output_height - cinfo.output_scanline);
+		jpeg_read_scanlines(&cinfo, img + cinfo.output_scanline,
+							cinfo.output_height - cinfo.output_scanline);
 	}
 
 	// 展開の終了
@@ -1101,14 +1139,15 @@ bool fk_Image::readJPG(const string fileName)
 	fclose(infile);
 
 	// バッファの生成
-	CreateBuffer(wid, hgt);
+	CreateBuffer(static_cast<int>(wid),
+				 static_cast<int>(hgt));
 
 	// 内容の移し変え
-	int offset;
+	_st	 offset;
 
-	for(int j = 0; j < hgt; j++){
-		for(int i = 0; i < wid; i++){
-			offset = GetOffset(i, j);
+	for(int j = 0; j < static_cast<int>(hgt); j++){
+		for(int i = 0; i < static_cast<int>(wid); i++){
+			offset = static_cast<_st>(GetOffset(i, j));
 			imageBuf[offset + 0] = img[j][i * 3 + 0];
 			imageBuf[offset + 1] = img[j][i * 3 + 1];
 			imageBuf[offset + 2] = img[j][i * 3 + 2];
@@ -1117,7 +1156,7 @@ bool fk_Image::readJPG(const string fileName)
 	}
 
 	// イメージデータを保持するメモリ領域を開放
-	for(int i = 0; i < hgt; i++){
+	for(unsigned int i = 0; i < hgt; i++){
 		free(img[i]);
 	}
 	free(img);
@@ -1149,16 +1188,16 @@ bool fk_Image::writeJPG(const string fileName, int quality)
 		return false;
 	}
 
-	int wid = getWidth();
-	int hgt = getHeight();
-	int offset;
+	size_t		wid = static_cast<size_t>(getWidth());
+	size_t		hgt = static_cast<size_t>(getHeight());
+	_st 		offset;
 
 	// イメージを保持するメモリ領域の確保と初期化
-	img = (JSAMPARRAY)malloc(sizeof(JSAMPROW) * hgt);
-	for(int j = 0; j < hgt; j++) {
+	img = static_cast<JSAMPARRAY>(malloc(sizeof(JSAMPROW) * hgt));
+	for(int j = 0; j < static_cast<int>(hgt); j++) {
 		img[j] = (JSAMPROW)malloc(sizeof(JSAMPLE) * 3 * wid);
-		for(int i = 0; i < wid; i++) {
-			offset = GetOffset(i, j);
+		for(int i = 0; i < static_cast<int>(wid); i++) {
+			offset = static_cast<_st>(GetOffset(i, j));
 			img[j][i * 3 + 0] = imageBuf[offset + 0];
 			img[j][i * 3 + 1] = imageBuf[offset + 1];
 			img[j][i * 3 + 2] = imageBuf[offset + 2];
@@ -1182,8 +1221,8 @@ bool fk_Image::writeJPG(const string fileName, int quality)
 	jpeg_set_quality(&cinfo, quality, TRUE);
 
 	// パラメータの設定
-	cinfo.image_width      = wid;
-	cinfo.image_height     = hgt;
+	cinfo.image_width      = static_cast<JDIMENSION>(wid);
+	cinfo.image_height     = static_cast<JDIMENSION>(hgt);
 	cinfo.input_components = 3;
 	cinfo.in_color_space   = JCS_RGB;
 
@@ -1194,7 +1233,7 @@ bool fk_Image::writeJPG(const string fileName, int quality)
 	jpeg_start_compress(&cinfo, TRUE);
 
 	// 全イメージデータを出力
-	jpeg_write_scanlines(&cinfo, img, hgt);
+	jpeg_write_scanlines(&cinfo, img, static_cast<JDIMENSION>(hgt));
 
 	// 圧縮の終了
 	jpeg_finish_compress(&cinfo);
@@ -1206,7 +1245,7 @@ bool fk_Image::writeJPG(const string fileName, int quality)
 	fclose(outfile);	
 
 	// イメージデータを保持するメモリ領域を開放
-	for(int i = 0; i < hgt; i++) {
+	for(int i = 0; i < static_cast<int>(hgt); i++) {
 		free(img[i]);
 	}
 	free(img);
