@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -31,12 +31,12 @@
  *	HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
  *	STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
  *	IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- *	POSSIBILITY OF SUCH DAMAGE. 
+ *	POSSIBILITY OF SUCH DAMAGE.
  *
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -69,6 +69,9 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+
+#define FK_DEF_SIZETYPE
+#include <algorithm>
 #include <FK/IndexFace.h>
 #include <FK/Solid.h>
 #include <FK/D3DXAnimation.H>
@@ -85,8 +88,7 @@
 #include <FK/DXFOut.H>
 #include <FK/MQOOut.H>
 #include <FK/IFSetHandle.H>
-
-#include <algorithm>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -102,9 +104,21 @@ fk_IndexFaceSet::fk_IndexFaceSet(void)
 	colorFlg = false;
 	anim = NULL;
 	cloneFlg = false;
-	cloneList.clear();
 	orgIFS = NULL;
 
+	pos.clear();
+	timeOrgPos.clear();
+	vNorm.clear();
+	pNorm.clear();
+	ifs.clear();
+	edgeSet.clear();
+	loopStack.clear();
+	vNormFlg.clear();
+	pNormFlg.clear();
+	modifyList.clear();
+	colorID.clear();
+	cloneList.clear();
+
 	return;
 }
 
@@ -129,7 +143,7 @@ void fk_IndexFaceSet::DeleteCloneLink(fk_IndexFaceSet *argIFS)
 	argIFS->orgIFS = NULL;
 
 	for(ite = argIFS->cloneList.begin();
-		ite != argIFS->cloneList.end(); ite++) {
+		ite != argIFS->cloneList.end(); ++ite) {
 
 		DeleteCloneLink(*ite);
 	}
@@ -144,18 +158,18 @@ void fk_IndexFaceSet::Init(void)
 
 bool fk_IndexFaceSet::Init(int argTNum, int argPNum, int argVNum)
 {
-	vector<int>::size_type		i;
+	_st		i;
 
-	// 面数が不適切 
+	// 面数が不適切
 	if(argTNum < 1) return false;
 
-	// 角数が不適切 
+	// 角数が不適切
 	if(argPNum != 3 && argPNum != 4) return false;
 
-	// 頂点数が不適切 
+	// 頂点数が不適切
 	if(argVNum < 3) return false;
 
-	// 各データを一旦解放 
+	// 各データを一旦解放
 	pos.clear();
 	vNorm.clear();
 	pNorm.clear();
@@ -167,10 +181,10 @@ bool fk_IndexFaceSet::Init(int argTNum, int argPNum, int argVNum)
 	pNormFlg.clear();
 	colorID.clear();
 
-	pos.resize(argVNum);
-	ifs.resize(argTNum*argPNum);
+	pos.resize(static_cast<_st>(argVNum));
+	ifs.resize(static_cast<_st>(argTNum*argPNum));
 
-	// メッシュタイプの設定 
+	// メッシュタイプの設定
 	switch(argPNum) {
 	  case 3:
 		type = FK_IF_TRIANGLES;
@@ -184,8 +198,8 @@ bool fk_IndexFaceSet::Init(int argTNum, int argPNum, int argVNum)
 
 	posSize = argVNum;
 	faceSize = argTNum;
-	colorID.resize(faceSize);
-	for(i = 0; i < vector<int>::size_type(faceSize); i++) {
+	colorID.resize(static_cast<_st>(faceSize));
+	for(i = 0; i < static_cast<_st>(faceSize); i++) {
 		colorID[i] = FK_UNDEFINED;
 	}
 
@@ -198,38 +212,38 @@ bool fk_IndexFaceSet::MakeMesh(vector<fk_Vector> *vData,
 							   vector< vector<int> > *lIndex,
 							   vector<int> *mateIDSet, bool)
 {
-	int				i, j, pNum;
+	_st				i, j, pNum;
 	vector<int>		tmpP;
 
-	if(vData == (vector<fk_Vector> *)NULL ||
-	   lIndex == (vector< vector<int> > *)NULL) {
+	if(vData == NULL || lIndex == NULL) {
 		return false;
 	}
 
 	if(lIndex->size() == 0) return true;
 
-	pNum = int((*lIndex)[0].size());
+	pNum = (*lIndex)[0].size();
 
-	// 三角形か四角形でない場合はエラー 
+	// 三角形か四角形でない場合はエラー
 	if(pNum != 3 && pNum != 4) return false;
 
-	// 全ての面が同角数でなければエラー 
-	for(i = 1; i < int(lIndex->size()); i++) {
-		if(int((*lIndex)[i].size()) != pNum) {
+	// 全ての面が同角数でなければエラー
+	for(i = 1; i < lIndex->size(); i++) {
+		if((*lIndex)[i].size() != pNum) {
 			return false;
 		}
 	}
 
-	// データ領域の確保 
-	if(Init(lIndex->size(), pNum, vData->size()) == false) return false;
+	// データ領域の確保
+	if(Init(static_cast<int>(lIndex->size()), static_cast<int>(pNum),
+			static_cast<int>(vData->size())) == false) return false;
 
-	// 頂点データのコピー 
-	for(i = 0; i < int(vData->size()); i++) {
+	// 頂点データのコピー
+	for(i = 0; i < vData->size(); i++) {
 		pos[i] = (*vData)[i];
 	}
 
-	// 面データのコピー 
-	for(i = 0; i < int(lIndex->size()); i++) {
+	// 面データのコピー
+	for(i = 0; i < lIndex->size(); i++) {
 		tmpP = (*lIndex)[i];
 		for(j = 0; j < pNum; j++) {
 			ifs[i*pNum+j] = tmpP[j] - 1;
@@ -239,10 +253,10 @@ bool fk_IndexFaceSet::MakeMesh(vector<fk_Vector> *vData,
 	MakeEdgeSet();
 	ModifyVNorm();
 
-	if(mateIDSet == (vector<int> *)NULL) return true;
+	if(mateIDSet == NULL) return true;
 	if(mateIDSet->size() != lIndex->size()) return true;
 
-	for(i = 0; i < int(mateIDSet->size()); i++) {
+	for(i = 0; i < mateIDSet->size(); i++) {
 		colorID[i] = (*mateIDSet)[i];
 	}
 	colorFlg = true;
@@ -253,22 +267,22 @@ bool fk_IndexFaceSet::MakeMesh(vector<fk_Vector> *vData,
 void fk_IndexFaceSet::makeIFSet(int argTNum, int argPNum, int *argIF,
 								int argVNum, fk_Vector *argPos, int argOrder)
 {
-	int			i;
+	_st			i;
 
 	if(Init(argTNum, argPNum, argVNum) == false) return;
 
-	// 頂点データのコピー 
-	for(i = 0; i < argVNum; i++) {
+	// 頂点データのコピー
+	for(i = 0; i < static_cast<_st>(argVNum); i++) {
 		pos[i] = argPos[i];
 	}
 
-	// 面データのコピー 
-	for(i = 0; i < argPNum*argTNum; i++) {
+	// 面データのコピー
+	for(i = 0; i < static_cast<_st>(argPNum*argTNum); i++) {
 		ifs[i] = argIF[i] - argOrder;
 	}
 
 	MakeEdgeSet();
-	
+
 	return;
 }
 
@@ -278,8 +292,8 @@ void fk_IndexFaceSet::InitPNorm(void)
 
 	if(faceSize < 0) return;
 
-	pNorm.resize(faceSize);
-	pNormFlg.resize(faceSize);
+	pNorm.resize(static_cast<_st>(faceSize));
+	pNormFlg.resize(static_cast<_st>(faceSize));
 	ClearPFlg();
 
 	for(i = 0; i < faceSize; i++) {
@@ -292,29 +306,29 @@ void fk_IndexFaceSet::InitPNorm(void)
 
 void fk_IndexFaceSet::ModifyPNorm(void)
 {
-	int		i, j, vID;
+	_st		i, j, vID;
 
-	// 形状が定義されていない場合 
+	// 形状が定義されていない場合
 	if(faceSize < 0) return;
 
-	// まだ面法線配列が生成されていない場合 
-	if(pNorm.size() == 0) {
+	// まだ面法線配列が生成されていない場合
+	if(pNorm.empty() == true) {
 		InitPNorm();
 		return;
 	}
 
-	// 変形がなかった場合は終了 
+	// 変形がなかった場合は終了
 	if(modifyFlg == false) return;
 
-	// 頂点の面接続テーブルが生成されていない場合, テーブルを生成する。 
-	if(loopStack.size() == 0) {
+	// 頂点の面接続テーブルが生成されていない場合, テーブルを生成する。
+	if(loopStack.empty() == true) {
 		MakeLoopTable();
 	}
 
-	// modifyList に従って処理 
-	for(i = 0; i < int(modifyList.size()); i++) {
-		vID = modifyList[i];
-		for(j = 0; j < int(loopStack[vID].size()); j++) {
+	// modifyList に従って処理
+	for(i = 0; i < modifyList.size(); i++) {
+		vID = static_cast<_st>(modifyList[i]);
+		for(j = 0; j < loopStack[vID].size(); j++) {
 			MakePNorm(loopStack[vID][j]);
 		}
 	}
@@ -327,29 +341,30 @@ void fk_IndexFaceSet::ModifyPNorm(void)
 
 void fk_IndexFaceSet::MakePNorm(int argID)
 {
-	int			j;
+	_st		id = static_cast<_st>(argID);
+	_st		j;
 
-	if(pNormFlg[argID] == char(false)) return;
+	if(pNormFlg[id] == static_cast<char>(false)) return;
 
 	switch(type) {
 	  case FK_IF_TRIANGLES:
-		pNorm[argID] = CalcTriNorm(&ifs[argID*3]);
-		pNormFlg[argID] = char(false);
+		pNorm[id] = CalcTriNorm(&ifs[id*3]);
+		pNormFlg[id] = static_cast<char>(false);
 
-		if(vNorm.size() != 0) {
-			for(j = argID*3; j < argID*3 + 3; j++) {
-				vNormFlg[ifs[j]] = char(true);
+		if(vNorm.empty() == false) {
+			for(j = id*3; j < id*3 + 3; j++) {
+				vNormFlg[static_cast<_st>(ifs[j])] = static_cast<char>(true);
 			}
 		}
 		break;
 
 	  case FK_IF_QUADS:
-		pNorm[argID] = CalcPolyNorm(4, &ifs[argID*4]);
-		pNormFlg[argID] = char(false);
+		pNorm[id] = CalcPolyNorm(4, &ifs[id*4]);
+		pNormFlg[id] = static_cast<char>(false);
 
-		if(vNorm.size() != 0) {
-			for(j = argID*4; j < argID*4 + 4; j++) {
-				vNormFlg[ifs[j]] = char(true);
+		if(vNorm.empty() == false) {
+			for(j = id*4; j < id*4 + 4; j++) {
+				vNormFlg[static_cast<_st>(ifs[j])] = static_cast<char>(true);
 			}
 		}
 		break;
@@ -363,10 +378,10 @@ void fk_IndexFaceSet::MakePNorm(int argID)
 
 void fk_IndexFaceSet::ClearPFlg(void)
 {
-	int		i;
+	_st		i;
 
-	for(i = 0; i < faceSize; i++) {
-		pNormFlg[i] = char(true);
+	for(i = 0; i < static_cast<_st>(faceSize); i++) {
+		pNormFlg[i] = static_cast<char>(true);
 	}
 	return;
 }
@@ -375,10 +390,10 @@ void fk_IndexFaceSet::InitVNorm(void)
 {
 	vector<fk_Vector>	normArray;
 	fk_Vector			tmpVec;
-	int					vNum;
-	int					i, j;
+	_st					vNum;
+	_st					i, j;
 
-	// 形状が定義されていない場合 
+	// 形状が定義されていない場合
 	if(faceSize < 0) return;
 
 	switch(type) {
@@ -392,22 +407,22 @@ void fk_IndexFaceSet::InitVNorm(void)
 		return;
 	}
 
-	if(pNorm.size() == 0) InitPNorm();
+	if(pNorm.empty() == true) InitPNorm();
 
-	vNorm.resize(posSize);
-	vNormFlg.resize(posSize);
+	vNorm.resize(static_cast<_st>(posSize));
+	vNormFlg.resize(static_cast<_st>(posSize));
 
-	normArray.resize(posSize);
-	for(i = 0; i < posSize; i++) normArray[i].init();
+	normArray.resize(static_cast<_st>(posSize));
+	for(i = 0; i < static_cast<_st>(posSize); i++) normArray[i].init();
 
-	for(i = 0; i < faceSize; i++) {
+	for(i = 0; i < static_cast<_st>(faceSize); i++) {
 		for(j = 0; j < vNum; j++) {
 			tmpVec = pNorm[i];
-			normArray[ifs[i*vNum+j]] += tmpVec;
+			normArray[static_cast<_st>(ifs[i*vNum+j])] += tmpVec;
 		}
 	}
 
-	for(i = 0; i < posSize; i++) {
+	for(i = 0; i < static_cast<_st>(posSize); i++) {
 		normArray[i].normalize();
 		vNorm[i] = normArray[i];
 	}
@@ -419,46 +434,43 @@ void fk_IndexFaceSet::InitVNorm(void)
 void fk_IndexFaceSet::ModifyVNorm(void)
 {
 	fk_Vector		norm, tmpV;
-	int				i, j, loopID;
-	int				pNum;
+	_st				i, j, loopID;
 
-	// 形状が定義されていない場合 
+	// 形状が定義されていない場合
 	if(faceSize < 0) return;
 
-	// まだ頂点法線配列が生成されていない場合 
-	if(vNorm.size() == 0) {
+	// まだ頂点法線配列が生成されていない場合
+	if(vNorm.empty() == true) {
 		InitVNorm();
 		return;
 	}
 
-	// 変形がなかった場合は終了 
+	// 変形がなかった場合は終了
 	if(modifyFlg == false) return;
 
-	// 面法線情報を再計算 
+	// 面法線情報を再計算
 	ModifyPNorm();
 
 	switch(type) {
 	  case FK_IF_TRIANGLES:
-		pNum = 3;
 		break;
 	  case FK_IF_QUADS:
-		pNum = 4;
 		break;
 	  default:
 		return;
 	}
 
-	for(i = 0; i < posSize; i++) {
-		if(vNormFlg[i] == char(true)) {
+	for(i = 0; i < static_cast<_st>(posSize); i++) {
+		if(vNormFlg[i] == static_cast<char>(true)) {
 			norm.init();
-			for(j = 0; j < int(loopStack[i].size()); j++) {
-				loopID = loopStack[i][j];
+			for(j = 0; j < loopStack[i].size(); j++) {
+				loopID = static_cast<_st>(loopStack[i][j]);
 				tmpV = pNorm[loopID];
 				norm += tmpV;
 			}
 			norm.normalize();
 			vNorm[i] = norm;
-			vNormFlg[i] = char(false);
+			vNormFlg[i] = static_cast<char>(false);
 		}
 	}
 
@@ -467,22 +479,22 @@ void fk_IndexFaceSet::ModifyVNorm(void)
 
 void fk_IndexFaceSet::ClearVFlg(void)
 {
-	int		i;
+	_st		i;
 
-	for(i = 0; i < posSize; i++) {
-		vNormFlg[i] = char(false);
+	for(i = 0; i < static_cast<_st>(posSize); i++) {
+		vNormFlg[i] = static_cast<char>(false);
 	}
 	return;
 }
 
 fk_Vector fk_IndexFaceSet::CalcTriNorm(int *argIF)
 {
-	int			i;
+	_st			i;
 	fk_Vector	retNorm;
 	fk_Vector	triV[3];
 
 	for(i = 0; i < 3; i++) {
-		triV[i] = pos[argIF[i]];
+		triV[i] = pos[static_cast<_st>(argIF[i])];
 	}
 
 	retNorm = (triV[1] - triV[0]) ^ (triV[2] - triV[1]);
@@ -494,15 +506,15 @@ fk_Vector fk_IndexFaceSet::CalcTriNorm(int *argIF)
 fk_Vector fk_IndexFaceSet::CalcPolyNorm(int argNum, int *argIF)
 {
 	vector<fk_Vector>	posArray, normArray;
-	int					i;
+	_st					i;
 	fk_Vector			tmpVec, sumNorm;
 
 	posArray.clear();
 	normArray.clear();
 
 	if(argNum < 4) return sumNorm;
-	for(i = 0; i < argNum; i++) {
-		tmpVec = pos[argIF[i]];
+	for(i = 0; i < static_cast<_st>(argNum); i++) {
+		tmpVec = pos[static_cast<_st>(argIF[i])];
 		posArray.push_back(tmpVec);
 	}
 
@@ -510,18 +522,18 @@ fk_Vector fk_IndexFaceSet::CalcPolyNorm(int argNum, int *argIF)
 	posArray.push_back(posArray[1]);
 
 	sumNorm.init();
-	for(i = 0; i < (int)posArray.size() - 2; i++) {
+	for(i = 0; i < posArray.size() - 2; i++) {
 		normArray.push_back((posArray[i+1] - posArray[i]) ^
 							(posArray[i+2] - posArray[i+1]));
 		sumNorm += normArray[i];
 	}
 
-	for(i = 0; i < (int)normArray.size(); i++) {
+	for(i = 0; i < normArray.size(); i++) {
 		if(sumNorm * normArray[i] < 0.0) normArray[i] = -normArray[i];
 	}
 
 	sumNorm.init();
-	for(i = 0; i < (int)normArray.size(); i++) {
+	for(i = 0; i < normArray.size(); i++) {
 		sumNorm += normArray[i];
 	}
 
@@ -531,7 +543,7 @@ fk_Vector fk_IndexFaceSet::CalcPolyNorm(int argNum, int *argIF)
 
 void fk_IndexFaceSet::MakeLoopTable(void)
 {
-	int		i, j, vNum, vID;
+	_st		i, j, vNum, vID;
 
 	switch(type) {
 	  case FK_IF_TRIANGLES:
@@ -545,12 +557,12 @@ void fk_IndexFaceSet::MakeLoopTable(void)
 	}
 
 	loopStack.clear();
-	loopStack.resize(posSize);
+	loopStack.resize(static_cast<_st>(posSize));
 
-	for(i = 0; i < faceSize; i++) {
+	for(i = 0; i < static_cast<_st>(faceSize); i++) {
 		for(j = 0; j < vNum; j++) {
-			vID = ifs[i*vNum + j];
-			loopStack[vID].push_back(i);
+			vID = static_cast<_st>(ifs[i*vNum + j]);
+			loopStack[vID].push_back(static_cast<int>(i));
 		}
 	}
 
@@ -560,8 +572,8 @@ void fk_IndexFaceSet::MakeLoopTable(void)
 void fk_IndexFaceSet::MakeEdgeSet(void)
 {
 	vector< vector<int> >	edgeTable;
-	int						i, j, pSize;
-	int						tmpV1, tmpV2, v1, v2;
+	_st						i, j, pSize;
+	_st						tmpV1, tmpV2, v1, v2;
 
 	switch(type) {
 	  case FK_IF_TRIANGLES:
@@ -574,13 +586,13 @@ void fk_IndexFaceSet::MakeEdgeSet(void)
 		return;
 	}
 
-	for(i = 0; i < faceSize; i++) {
+	for(i = 0; i < static_cast<_st>(faceSize); i++) {
 		for(j = 0; j < pSize; j++) {
-			tmpV1 = ifs[i*pSize+j];
+			tmpV1 = static_cast<_st>(ifs[i*pSize+j]);
 			if(j == pSize-1) {
-				tmpV2 = ifs[i*pSize];
+				tmpV2 = static_cast<_st>(ifs[i*pSize]);
 			} else {
-				tmpV2 = ifs[i*pSize+j+1];
+				tmpV2 = static_cast<_st>(ifs[i*pSize+j+1]);
 			}
 
 			if(tmpV1 < tmpV2) {
@@ -589,18 +601,18 @@ void fk_IndexFaceSet::MakeEdgeSet(void)
 				v1 = tmpV2; v2 = tmpV1;
 			}
 
-			if(int(edgeTable.size()) <= v1) edgeTable.resize(v1+1);
+			if(edgeTable.size() <= v1) edgeTable.resize(v1+1);
 
 			if(find(edgeTable[v1].begin(),
 					edgeTable[v1].end(), v2) == edgeTable[v1].end()) {
-				edgeTable[v1].push_back(v2);
+				edgeTable[v1].push_back(static_cast<int>(v2));
 			}
 		}
-	}				
+	}
 
-	for(i = 0; i < int(edgeTable.size()); i++) {
-		for(j = 0; j < int(edgeTable[i].size()); j++) {
-			edgeSet.push_back(i);
+	for(i = 0; i < edgeTable.size(); i++) {
+		for(j = 0; j < edgeTable[i].size(); j++) {
+			edgeSet.push_back(static_cast<int>(i));
 			edgeSet.push_back(edgeTable[i][j]);
 		}
 	}
@@ -608,7 +620,7 @@ void fk_IndexFaceSet::MakeEdgeSet(void)
 	return;
 }
 
-	
+
 
 int fk_IndexFaceSet::getPosSize(void)
 {
@@ -627,16 +639,17 @@ fk_Vector fk_IndexFaceSet::getPosVec(int argID)
 	fk_Vector		retVec(0.0, 0.0, 0.0);
 
 	if(argID < 0 || argID >= posSize) return retVec;
-	retVec = pos[argID];
+	retVec = pos[static_cast<_st>(argID)];
 	return retVec;
 }
 
 vector<int> fk_IndexFaceSet::getFaceData(int argID)
 {
 	vector<int>		retIF;
-	int				pNum, i;
+	_st				pNum, i, id;
 
 	if(argID < 0 || argID >= faceSize) return retIF;
+	id = static_cast<_st>(argID);
 
 	switch(type) {
 	  case FK_IF_TRIANGLES:
@@ -649,7 +662,7 @@ vector<int> fk_IndexFaceSet::getFaceData(int argID)
 		return retIF;
 	}
 
-	for(i = argID*pNum; i < (argID+1)*pNum; i++) {
+	for(i = id*pNum; i < (id+1)*pNum; i++) {
 		retIF.push_back(ifs[i]);
 	}
 
@@ -675,7 +688,7 @@ int fk_IndexFaceSet::getFaceData(int argFID, int argVID)
 
 	if(argVID < 0 || argVID >= pNum) return -1;
 
-	return ifs[argFID * pNum + argVID];
+	return ifs[static_cast<_st>(argFID * pNum + argVID)];
 }
 
 
@@ -688,12 +701,13 @@ bool fk_IndexFaceSet::moveVPosition(int argID,
 									const fk_Vector &argPos, int argOrder)
 {
 	int		trueID = argID - argOrder;
+
 	if(trueID < 0 || trueID >= posSize) return false;
 
-	pos[trueID] = argPos;
+	pos[static_cast<_st>(trueID)] = argPos;
 
 	modifyFlg = true;
-	
+
 	if(find(modifyList.begin(),
 			modifyList.end(), trueID) == modifyList.end()) {
 		modifyList.push_back(trueID);
@@ -707,12 +721,14 @@ bool fk_IndexFaceSet::moveVPosition(int argID,
 									int argOrder)
 {
 	int		trueID = argID - argOrder;
+	_st		id;
+
 	if(trueID < 0 || trueID >= posSize) return false;
+	id = static_cast<_st>(trueID);
 
-	pos[trueID].x = float(argX);
-	pos[trueID].y = float(argY);
-	pos[trueID].z = float(argZ);
-
+	pos[id].x = float(argX);
+	pos[id].y = float(argY);
+	pos[id].z = float(argZ);
 	modifyFlg = true;
 	if(find(modifyList.begin(),
 			modifyList.end(), trueID) == modifyList.end()) {
@@ -725,11 +741,14 @@ bool fk_IndexFaceSet::moveVPosition(int argID,
 bool fk_IndexFaceSet::moveVPosition(int argID, double *argPos, int argOrder)
 {
 	int		trueID = argID - argOrder;
-	if(trueID < 0 || trueID >= posSize) return false;
+	_st		id;
 
-	pos[trueID].x = float(argPos[0]);
-	pos[trueID].y = float(argPos[1]);
-	pos[trueID].z = float(argPos[2]);
+	if(trueID < 0 || trueID >= posSize) return false;
+	id = static_cast<_st>(trueID);
+
+	pos[id].x = float(argPos[0]);
+	pos[id].y = float(argPos[1]);
+	pos[id].z = float(argPos[2]);
 
 	modifyFlg = true;
 	modifyList.push_back(trueID);
@@ -738,7 +757,7 @@ bool fk_IndexFaceSet::moveVPosition(int argID, double *argPos, int argOrder)
 			modifyList.end(), trueID) == modifyList.end()) {
 		modifyList.push_back(trueID);
 	}
-	
+
 	return true;
 }
 
@@ -746,11 +765,11 @@ fk_Vector fk_IndexFaceSet::getPNorm(int argPID, int argOrder)
 {
 	int			trueID = argPID - argOrder;
 
-	if(trueID < 0 || trueID >= int(pNorm.size())) {
+	if(trueID < 0 || trueID >= static_cast<int>(pNorm.size())) {
 		return fk_Vector(0.0, 0.0, 0.0);
 	}
 
-	return fk_Vector(pNorm[trueID]);
+	return fk_Vector(pNorm[static_cast<_st>(trueID)]);
 }
 
 bool fk_IndexFaceSet::setPNorm(int argPID,
@@ -758,8 +777,8 @@ bool fk_IndexFaceSet::setPNorm(int argPID,
 {
 	int			trueID = argPID - argOrder;
 
-	if(trueID < 0 || trueID >= int(pNorm.size())) return false;
-	pNorm[trueID] = argVec;
+	if(trueID < 0 || trueID >= static_cast<int>(pNorm.size())) return false;
+	pNorm[static_cast<_st>(trueID)] = argVec;
 	return true;
 }
 
@@ -770,7 +789,7 @@ fk_Vector fk_IndexFaceSet::getVNorm(int argVID, int argOrder)
 	if(trueID < 0 || trueID >= int(vNorm.size())) {
 		return fk_Vector(0.0, 0.0, 0.0);
 	}
-	return fk_Vector(vNorm[trueID]);
+	return fk_Vector(vNorm[static_cast<_st>(trueID)]);
 }
 
 bool fk_IndexFaceSet::setVNorm(int argVID,
@@ -778,18 +797,20 @@ bool fk_IndexFaceSet::setVNorm(int argVID,
 {
 	int			trueID = argVID - argOrder;
 
-	if(trueID < 0 || trueID >= int(vNorm.size())) return false;
-	vNorm[trueID] = argVec;
+	if(trueID < 0 || trueID >= static_cast<int>(vNorm.size())) return false;
+	vNorm[static_cast<_st>(trueID)] = argVec;
 	return true;
 }
 
 bool fk_IndexFaceSet::setElemMaterialID(int argIndex, int argColor)
 {
-	if(argIndex < 0 || argIndex >= int(colorID.size())) {
+	_st		index = static_cast<_st>(argIndex);
+
+	if(argIndex < 0 || index >= colorID.size()) {
 		return false;
 	}
 
-	colorID[argIndex] = argColor;
+	colorID[index] = argColor;
 	colorFlg = true;
 
 	return true;
@@ -797,16 +818,18 @@ bool fk_IndexFaceSet::setElemMaterialID(int argIndex, int argColor)
 
 int fk_IndexFaceSet::getElemMaterialID(int argIndex)
 {
-	if(argIndex < 0 || argIndex >= int(colorID.size())) {
+	_st		index = static_cast<_st>(argIndex);
+
+	if(argIndex < 0 || index >= colorID.size()) {
 		return -1;
 	}
 
-	return colorID[argIndex];
+	return colorID[index];
 }
 
 void fk_IndexFaceSet::flush(void)
 {
-	if(pNorm.size() == 0) {
+	if(pNorm.empty() == true) {
 		ModifyPNorm();
 	} else {
 		ModifyVNorm();
@@ -952,7 +975,7 @@ bool fk_IndexFaceSet::readD3DXFile(string argFileName, string argObjName,
 								   int argTexID, bool argSolidFlg)
 {
 	fk_D3DXParser	*d3dxParser = new fk_D3DXParser();
-	bool			retFlg;
+	bool			retFlg, animFlg;
 
 	if(anim == NULL || cloneFlg == true) {
 		anim = new fk_D3DXAnimation;
@@ -960,8 +983,8 @@ bool fk_IndexFaceSet::readD3DXFile(string argFileName, string argObjName,
 	d3dxParser->SetMeshData(this);
 	d3dxParser->SetAnimation(anim);
 	retFlg = d3dxParser->ReadD3DXFile(argFileName, argObjName,
-									  argTexID, argSolidFlg);
-	setAnimationTime(-1.0);
+									  argTexID, argSolidFlg, &animFlg);
+	if(animFlg == true) setAnimationTime(-1.0);
 	delete d3dxParser;
 	return retFlg;
 }
@@ -1024,7 +1047,7 @@ bool fk_IndexFaceSet::writeMQOFile(string argFileName)
 
 void fk_IndexFaceSet::makeBlock(double argX, double argY, double argZ)
 {
-	int			i;
+	_st			i;
 	fk_Vector	tmpVec[8];
 
 	const static double vParam[8][3] = {
@@ -1183,9 +1206,9 @@ void fk_IndexFaceSet::setBlockScale(double argX, double argY, double argZ)
 	};
 
 	if(posSize != 8 || faceSize != 6) return;
-	newPos.set(double(pos[0].x)*2.0*argX,
-			   double(pos[0].y)*2.0*argY,
-			   double(pos[0].z)*2.0*argZ);
+	newPos.set(static_cast<double>(pos[0].x)*2.0*argX,
+			   static_cast<double>(pos[0].y)*2.0*argY,
+			   static_cast<double>(pos[0].z)*2.0*argZ);
 
 	for(i = 0; i < 8; i++) {
 		moveVPosition(i, newPos.x * vParam[i][0],
@@ -1203,12 +1226,13 @@ void fk_IndexFaceSet::makeCircle(int argDiv, double argRadius)
 	int						i;
 	double					theta;
 
-	VecArray.resize(argDiv * 4 + 1);
+	VecArray.resize(static_cast<_st>(argDiv * 4 + 1));
 	VecArray[0].set(0.0, 0.0, 0.0);
 
 	for(i = 0; i < 4 * argDiv; i++) {
-		theta = (double(i) * FK_PI)/(double(argDiv*2));
-		VecArray[i+1].set(cos(theta) * argRadius, sin(theta) * argRadius, 0.0);
+		theta = (static_cast<double>(i) * FK_PI)/(double(argDiv*2));
+		VecArray[static_cast<_st>(i+1)].set(cos(theta) * argRadius,
+											sin(theta) * argRadius, 0.0);
 	}
 
 	IFArray.clear();
@@ -1231,21 +1255,21 @@ void fk_IndexFaceSet::makeCircle(int argDiv, double argRadius)
 
 void fk_IndexFaceSet::setCircleDivide(int argDiv)
 {
-	makeCircle(argDiv, double(pos[1].x));
+	makeCircle(argDiv, static_cast<double>(pos[1].x));
 
 	return;
 }
 
 void fk_IndexFaceSet::setCircleRadius(double argRadius)
 {
-	double			scale;
-	int				i;
+	double		scale;
+	_st			i;
 
-	scale = argRadius/double(pos[1].x);
+	scale = argRadius/static_cast<double>(pos[1].x);
 
-	for(i = 1; i < posSize; i++) {
-		moveVPosition(i, double(pos[i].x)*scale,
-					  double(pos[i].y)*scale, 0.0);
+	for(i = 1; i < static_cast<_st>(posSize); i++) {
+		moveVPosition(static_cast<int>(i), static_cast<double>(pos[i].x)*scale,
+					  static_cast<double>(pos[i].y)*scale, 0.0);
 	}
 
 	return;
@@ -1253,11 +1277,11 @@ void fk_IndexFaceSet::setCircleRadius(double argRadius)
 
 void fk_IndexFaceSet::setCircleScale(double argScale)
 {
-	int				i;
+	_st		i;
 
-	for(i = 1; i < posSize; i++) {
-		moveVPosition(i, double(pos[i].x)*argScale,
-					  double(pos[i].y)*argScale, 0.0);
+	for(i = 1; i < static_cast<_st>(posSize); i++) {
+		moveVPosition(static_cast<int>(i), static_cast<double>(pos[i].x)*argScale,
+					  static_cast<double>(pos[i].y)*argScale, 0.0);
 	}
 
 	return;
@@ -1268,25 +1292,27 @@ void fk_IndexFaceSet::makeSphere(int argDiv, double argRadius)
 	vector<fk_Vector>		VecArray;
 	vector<int>				IDArray;
 	vector< vector<int> >	IFArray;
-	int						i, j, index, index2;
+	_st						i, j, index, div;
+	int						ii, jj, iindex, iindex2;
 	vector<double>			xz_radius;
 	double					theta1, theta2;
 
-	VecArray.resize(argDiv*4 * (argDiv*2 - 1) + 2);
-	xz_radius.resize(argDiv*2 - 1);
+	div = static_cast<_st>(argDiv);
+	VecArray.resize(div*4 * (div*2 - 1) + 2);
+	xz_radius.resize(div*2 - 1);
 
-	for(i = 0; i < argDiv*2 - 1; i++) {
-		xz_radius[i] = argRadius*sin(double(i+1)*FK_PI/(argDiv*2.0));
+	for(i = 0; i < div*2 - 1; i++) {
+		xz_radius[i] = argRadius*sin(static_cast<double>(i+1)*FK_PI/(div*2));
 	}
 
 	VecArray.front().set(0.0, argRadius, 0.0);
 	VecArray.back().set(0.0, -argRadius, 0.0);
-	
-	for(i = 0; i < argDiv*2 - 1; i++) {
-		for(j = 0; j < argDiv*4; j++) {
-			index = i*argDiv*4 + j + 1;
-			theta1 = double(j)*FK_PI/(argDiv*2.0);
-			theta2 = double(i+1)*FK_PI/(argDiv*2.0);
+
+	for(i = 0; i < div*2 - 1; i++) {
+		for(j = 0; j < div*4; j++) {
+			index = i*div*4 + j + 1;
+			theta1 = static_cast<double>(j)*FK_PI/(div*2.0);
+			theta2 = static_cast<double>(i+1)*FK_PI/(div*2.0);
 			VecArray[index].set(xz_radius[i] * cos(theta1),
 								argRadius * cos(theta2),
 								xz_radius[i] * sin(theta1));
@@ -1295,49 +1321,49 @@ void fk_IndexFaceSet::makeSphere(int argDiv, double argRadius)
 
 	IFArray.clear();
 
-	// TOP 
-	for(i = 0; i < argDiv*4; i++) {
+	// TOP
+	for(ii = 0; ii < argDiv*4; ii++) {
 		IDArray.clear();
 		IDArray.push_back(1);
-		if(i == argDiv*4 - 1) {
+		if(ii == argDiv*4 - 1) {
 			IDArray.push_back(2);
 		} else {
-			IDArray.push_back(i+3);
+			IDArray.push_back(ii+3);
 		}
-		IDArray.push_back(i+2);
+		IDArray.push_back(ii+2);
 		IFArray.push_back(IDArray);
 	}
 
-	// BOTTOM 
-	index = (argDiv*4)*(argDiv*2 - 2) + 2;
-	for(i = 0; i < argDiv*4; i++) {
+	// BOTTOM
+	iindex = (argDiv*4)*(argDiv*2 - 2) + 2;
+	for(ii = 0; ii < argDiv*4; ii++) {
 		IDArray.clear();
-		IDArray.push_back(index + (argDiv*4));
-		IDArray.push_back(index + i);
-		if(i == argDiv*4 - 1) {
-			IDArray.push_back(index);
+		IDArray.push_back(iindex + (argDiv*4));
+		IDArray.push_back(iindex + ii);
+		if(ii == argDiv*4 - 1) {
+			IDArray.push_back(iindex);
 		} else {
-			IDArray.push_back(index + i + 1);
+			IDArray.push_back(iindex + ii + 1);
 		}
 		IFArray.push_back(IDArray);
 	}
 
-	// SIDE 
-	for(i = 0; i < argDiv*2 - 2; i++) {
-		for(j = 0; j < argDiv*4; j++) {
+	// SIDE
+	for(ii = 0; ii < argDiv*2 - 2; ii++) {
+		for(jj = 0; jj < argDiv*4; jj++) {
 			IDArray.clear();
-			index = i*argDiv*4 + j + 2;
-			index2 = (j == argDiv*4 - 1) ? i*argDiv*4 + 2 : index + 1;
+			iindex = ii*argDiv*4 + jj + 2;
+			iindex2 = (jj == argDiv*4 - 1) ? ii*argDiv*4 + 2 : iindex + 1;
 
-			IDArray.push_back(index);
-			IDArray.push_back(index2);
-			IDArray.push_back(index2 + argDiv*4);
+			IDArray.push_back(iindex);
+			IDArray.push_back(iindex2);
+			IDArray.push_back(iindex2 + argDiv*4);
 			IFArray.push_back(IDArray);
 
 			IDArray.clear();
-			IDArray.push_back(index);
-			IDArray.push_back(index2 + argDiv*4);
-			IDArray.push_back(index + argDiv*4);
+			IDArray.push_back(iindex);
+			IDArray.push_back(iindex2 + argDiv*4);
+			IDArray.push_back(iindex + argDiv*4);
 			IFArray.push_back(IDArray);
 		}
 	}
@@ -1349,20 +1375,22 @@ void fk_IndexFaceSet::makeSphere(int argDiv, double argRadius)
 
 void fk_IndexFaceSet::setSphereDivide(int argDiv)
 {
-	makeSphere(argDiv, double(pos[0].y));
+	makeSphere(argDiv, static_cast<double>(pos[0].y));
 	return;
 }
 
 void fk_IndexFaceSet::setSphereRadius(double argRadius)
 {
-	double			scale;
-	int				i;
+	double		scale;
+	_st			i;
 
-	scale = argRadius/double(pos[0].y);
+	scale = argRadius/static_cast<double>(pos[0].y);
 
-	for(i = 0; i < posSize; i++) {
-		moveVPosition(i, double(pos[i].x)*scale,
-					  double(pos[i].y)*scale, double(pos[i].z)*scale);
+	for(i = 0; i < static_cast<_st>(posSize); i++) {
+		moveVPosition(static_cast<int>(i),
+					  static_cast<double>(pos[i].x)*scale,
+					  static_cast<double>(pos[i].y)*scale,
+					  static_cast<double>(pos[i].z)*scale);
 	}
 
 	return;
@@ -1370,12 +1398,13 @@ void fk_IndexFaceSet::setSphereRadius(double argRadius)
 
 void fk_IndexFaceSet::setSphereScale(double argScale)
 {
-	int				i;
+	_st		i;
 
-	for(i = 0; i < posSize; i++) {
-		moveVPosition(i, double(pos[i].x)*argScale,
-					  double(pos[i].y)*argScale,
-					  double(pos[i].z)*argScale);
+	for(i = 0; i < static_cast<_st>(posSize); i++) {
+		moveVPosition(static_cast<int>(i),
+					  static_cast<double>(pos[i].x)*argScale,
+					  static_cast<double>(pos[i].y)*argScale,
+					  static_cast<double>(pos[i].z)*argScale);
 	}
 
 	return;
@@ -1388,26 +1417,28 @@ void fk_IndexFaceSet::makePrism(int argDiv, double argTop, double argBottom,
 	vector<fk_Vector>		VecArray;
 	vector<int>				IDArray;
 	vector< vector<int> >	IFArray;
-	int						i, v[4];
+	int						v[4], i;
+	_st						j, div;
 	double					theta;
 
-	VecArray.resize(argDiv*2+2);
+	div = static_cast<_st>(argDiv);
+	VecArray.resize(div*2+2);
 	VecArray[0].set(0.0, 0.0, 0.0);
-	VecArray[argDiv + 1].set(0.0, 0.0, -argHeight);
+	VecArray[div + 1].set(0.0, 0.0, -argHeight);
 
-	for(i = 0; i < argDiv; i++) {
-		theta = (double(i*2) * FK_PI)/double(argDiv);
-		VecArray[i+1].set(cos(theta) * argBottom,
+	for(j = 0; j < div; j++) {
+		theta = (static_cast<double>(j*2) * FK_PI)/static_cast<double>(div);
+		VecArray[j+1].set(cos(theta) * argBottom,
 						  sin(theta) * argBottom, 0.0);
-		VecArray[argDiv+i+2].set(cos(theta) * argTop, 
-								 sin(theta) * argTop, -argHeight);
+		VecArray[div+j+2].set(cos(theta) * argTop,
+							  sin(theta) * argTop, -argHeight);
 	}
 
 	IFArray.clear();
 
-	for(i = 0; i < argDiv; i++) {
-
-		// 底面 
+	for(j = 0; j < div; j++) {
+		i = static_cast<int>(j);
+		// 底面
 		IDArray.clear();
 		IDArray.push_back(1);
 		IDArray.push_back(i+2);
@@ -1418,7 +1449,7 @@ void fk_IndexFaceSet::makePrism(int argDiv, double argTop, double argBottom,
 		}
 		IFArray.push_back(IDArray);
 
-		// 上面 
+		// 上面
 		IDArray.clear();
 		IDArray.push_back(argDiv+2);
 		if(i == argDiv-1) {
@@ -1430,7 +1461,7 @@ void fk_IndexFaceSet::makePrism(int argDiv, double argTop, double argBottom,
 
 		IFArray.push_back(IDArray);
 
-		// 側面 
+		// 側面
 		v[0] = i + 2;
 		v[1] = argDiv + i + 3;
 		if(i == argDiv-1) {
@@ -1460,14 +1491,14 @@ void fk_IndexFaceSet::makePrism(int argDiv, double argTop, double argBottom,
 
 void fk_IndexFaceSet::setPrismDivide(int argDiv)
 {
-	int			div;
+	_st			div;
 	double		top, bottom, height;
 
-	if((div = posSize/2 - 1) < 3) return;
+	if((div = static_cast<_st>(posSize/2 - 1)) < 3) return;
 
-	top = double(pos[div+2].x);
-	bottom = double(pos[1].x);
-	height = -double(pos[div+1].z);
+	top = static_cast<double>(pos[div+2].x);
+	bottom = static_cast<double>(pos[1].x);
+	height = static_cast<double>(-pos[div+1].z);
 
 	makePrism(argDiv, top, bottom, height);
 	return;
@@ -1481,9 +1512,9 @@ void fk_IndexFaceSet::setPrismTopRadius(double argTop)
 	fk_Vector	vec;
 
 	div = posSize/2 - 1;
-	z = double(pos[div+2].z);
+	z = static_cast<double>(pos[static_cast<_st>(div+2)].z);
 	for(i = 0; i < div; i++) {
-		theta = (double(i*2) * FK_PI)/double(div);
+		theta = (static_cast<double>(i*2) * FK_PI)/static_cast<double>(div);
 		vec.set(cos(theta) * argTop, sin(theta) * argTop, z);
 		moveVPosition(div+i+2, vec);
 	}
@@ -1500,7 +1531,7 @@ void fk_IndexFaceSet::setPrismBottomRadius(double argBottom)
 
 	div = posSize/2 - 1;
 	for(i = 0; i < div; i++) {
-		theta = (double(i*2) * FK_PI)/double(div);
+		theta = (static_cast<double>(i*2) * FK_PI)/static_cast<double>(div);
 		vec.set(cos(theta) * argBottom, sin(theta) * argBottom, 0.0);
 		moveVPosition(i+1, vec);
 	}
@@ -1510,16 +1541,15 @@ void fk_IndexFaceSet::setPrismBottomRadius(double argBottom)
 
 void fk_IndexFaceSet::setPrismHeight(double argHeight)
 {
-	int			div;
-	int			i;
+	_st			i, div;
 	fk_Vector	vec;
 
-	div = posSize/2 - 1;
+	div = static_cast<_st>(posSize/2 - 1);
 	for(i = 0; i <= div; i++) {
-		vec.set(double(pos[div+i+1].x),
-				double(pos[div+i+1].y),
+		vec.set(static_cast<double>(pos[div+i+1].x),
+				static_cast<double>(pos[div+i+1].y),
 				-argHeight);
-		moveVPosition(div+i+1, vec);
+		moveVPosition(static_cast<int>(div+i+1), vec);
 	}
 
 	return;
@@ -1530,22 +1560,24 @@ void fk_IndexFaceSet::makeCone(int argDiv, double argRadius, double argHeight)
 	vector<fk_Vector>		VecArray;
 	vector<int>				IDArray;
 	vector< vector<int> >	IFArray;
+	_st						j, div;
 	int						i;
 	double					theta;
 
-	VecArray.resize(argDiv+2);
+	div = static_cast<_st>(argDiv);
+	VecArray.resize(div+2);
 	VecArray[0].set(0.0, 0.0, 0.0);
 	VecArray[1].set(0.0, 0.0, -argHeight);
 
-	for(i = 0; i < argDiv; i++) {
-		theta = (double(i*2) * FK_PI)/double(argDiv);
-		VecArray[i+2].set(cos(theta) * argRadius, sin(theta) * argRadius, 0.0);
+	for(j = 0; j < div; j++) {
+		theta = (static_cast<double>(j*2) * FK_PI)/static_cast<double>(div);
+		VecArray[j+2].set(cos(theta) * argRadius, sin(theta) * argRadius, 0.0);
 	}
 
 	IFArray.clear();
 
 	for(i = 0; i < argDiv; i++) {
-		// 底面 
+		// 底面
 		IDArray.clear();
 		IDArray.push_back(1);
 		IDArray.push_back(i+3);
@@ -1556,7 +1588,7 @@ void fk_IndexFaceSet::makeCone(int argDiv, double argRadius, double argHeight)
 		}
 		IFArray.push_back(IDArray);
 
-		// 側面 
+		// 側面
 		IDArray.clear();
 		IDArray.push_back(2);
 		if(i == argDiv - 1) {
@@ -1566,7 +1598,7 @@ void fk_IndexFaceSet::makeCone(int argDiv, double argRadius, double argHeight)
 		}
 		IDArray.push_back(i+3);
 		IFArray.push_back(IDArray);
-	}	
+	}
 
 	MakeMesh(&VecArray, &IFArray);
 
@@ -1577,8 +1609,8 @@ void fk_IndexFaceSet::setConeDivide(int argDiv)
 {
 	double	rad, height;
 
-	rad = double(pos[2].x);
-	height = -double(pos[1].z);
+	rad = static_cast<double>(pos[2].x);
+	height = static_cast<double>(-pos[1].z);
 
 	makeCone(argDiv, rad, height);
 }
@@ -1592,7 +1624,7 @@ void fk_IndexFaceSet::setConeRadius(double argRadius)
 
 	div = posSize - 2;
 	for(i = 0; i < div; i++) {
-		theta = (double(i*2) * FK_PI)/double(div);
+		theta = (static_cast<double>(i*2) * FK_PI)/static_cast<double>(div);
 		vec.set(cos(theta) * argRadius, sin(theta) * argRadius, 0.0);
 		moveVPosition(i+2, vec);
 	}
@@ -1614,7 +1646,7 @@ void fk_IndexFaceSet::putSolid(fk_Solid *argSolid)
 	fk_Vector	*vArray;
 	int			tmpPNum = 0;
 
-	if(argSolid == (fk_Solid *)NULL) return;
+	if(argSolid == NULL) return;
 
 	switch(type) {
 	  case FK_IF_TRIANGLES:
@@ -1630,7 +1662,7 @@ void fk_IndexFaceSet::putSolid(fk_Solid *argSolid)
 	}
 
 	vArray = new fk_Vector [posSize];
-	for(int i = 0; i < posSize; i++) vArray[i] = pos[i];
+	for(_st i = 0; i < static_cast<_st>(posSize); i++) vArray[i] = pos[i];
 
 	argSolid->makeIFSet(faceSize, tmpPNum, &ifs[0], posSize, vArray);
 	delete [] vArray;
@@ -1646,7 +1678,8 @@ fk_D3DXAnimation * fk_IndexFaceSet::GetAnimation(void)
 
 void fk_IndexFaceSet::setAnimationTime(double argTime)
 {
-	int		i;
+	_st		i;
+	int		j;
 
 	if(anim == NULL) return;
 
@@ -1656,8 +1689,9 @@ void fk_IndexFaceSet::setAnimationTime(double argTime)
 
 	anim->SetTime(argTime);
 
-	for(i = 0; i < int(pos.size()); i++) {
-		moveVPosition(i, anim->GetMovePos(i, timeOrgPos[i]));
+	for(i = 0; i < pos.size(); i++) {
+		j = static_cast<int>(i);
+		moveVPosition(j, anim->GetMovePos(j, timeOrgPos[i]));
 	}
 
 	return;
@@ -1705,3 +1739,15 @@ void fk_IndexFaceSet::cloneShape(fk_IndexFaceSet *argIFS)
 
 	return;
 }
+
+void fk_IndexFaceSet::PosPrint(string argStr)
+{
+	_st		i;
+
+	for(i = 0; i < pos.size(); i++) {
+		fk_Printf("%s[%d] = (%f, %f, %f)", argStr.c_str(), i,
+				  pos[i].x, pos[i].y, pos[i].z);
+	}
+	return;
+}
+
