@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -220,11 +220,11 @@ void fk_LineDraw::DrawSolidLinePick(fk_Model *argObj)
 	glLineWidth((GLfloat)argObj->getWidth());
 
 	if(reverseFlag == false) {
-		for(ite = edgeStack->begin(); ite != edgeStack->end(); ite++) {
+		for(ite = edgeStack->begin(); ite != edgeStack->end(); ++ite) {
 			DrawSolidLinePickElem(*ite);
 		}
 	} else {
-		for(rite = edgeStack->rbegin(); rite != edgeStack->rend(); rite++) {
+		for(rite = edgeStack->rbegin(); rite != edgeStack->rend(); ++rite) {
 			DrawSolidLinePickElem(*rite);
 		}
 	}
@@ -334,13 +334,13 @@ void fk_LineDraw::DrawSolidLineMaterial(fk_Model *argObj)
 	orgWidth = argObj->getWidth();
 
 	if(reverseFlag == false) {
-		for(ite = edgeStack->begin(); ite != edgeStack->end(); ite++) {
+		for(ite = edgeStack->begin(); ite != edgeStack->end(); ++ite) {
 			oldMateID = DrawSolidLineMaterialElem(*ite, oldMateID,
 												  paletteSize, orgWidth,
 												  matV, modelColor);
 		}
 	} else {
-		for(rite = edgeStack->rbegin(); rite != edgeStack->rend(); rite++) {
+		for(rite = edgeStack->rbegin(); rite != edgeStack->rend(); ++rite) {
 			oldMateID = DrawSolidLineMaterialElem(*rite, oldMateID,
 												  paletteSize, orgWidth,
 												  matV, modelColor);
@@ -470,11 +470,11 @@ void fk_LineDraw::DrawSolidLineNormal(fk_Model *argObj, bool argFlg)
 	orgWidth = argObj->getWidth();
 	
 	if(reverseFlag == false) {
-		for(ite = edgeStack->begin(); ite != edgeStack->end(); ite++) {
+		for(ite = edgeStack->begin(); ite != edgeStack->end(); ++ite) {
 			DrawSolidLineNormalElem(*ite, orgWidth, packedCol);
 		}
 	} else {
-		for(rite = edgeStack->rbegin(); rite != edgeStack->rend(); rite++) {
+		for(rite = edgeStack->rbegin(); rite != edgeStack->rend(); ++rite) {
 			DrawSolidLineNormalElem(*rite, orgWidth, packedCol);
 		}
 	}
@@ -536,9 +536,9 @@ void fk_LineDraw::DrawIFSLineNormal(fk_Model *argObj, bool argFlag)
 		tmpVertex.psize = lineWidth;
 		workCustomVertexArray.push_back(tmpVertex);
 	}
-	if(workCustomVertexArray.size() == 0) return;
+	if(workCustomVertexArray.empty()) return;
 	ref_lpD3DDEV->SetFVF(D3DFVF_LINECUSTOMVERTEX);
-	ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_LINELIST, workCustomVertexArray.size()/2, &(workCustomVertexArray[0]), sizeof(LINECUSTOMVERTEX));
+	ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_LINELIST, static_cast<UINT>(workCustomVertexArray.size()/2), &(workCustomVertexArray[0]), sizeof(LINECUSTOMVERTEX));
 
 	/*
 	workVertexArray.resize(2);
@@ -560,15 +560,15 @@ void fk_LineDraw::CommonLineDrawFunc(fk_Edge *argE, bool argMode, DWORD argColor
 	fk_Vector			*vPos;
 	fk_Curve			*curv;
 	vector<fk_Vector>	*vArray;
-	int					ii, div;
 	fk_Half				*lH, *rH;
 	fk_Vertex			*lV, *rV;
 	LINECUSTOMVERTEX	tmpVertex;
+	int					ii;
 
 	if((curv = argE->getCurveGeometry()) != (fk_Curve *)NULL) {
 
 		curv->makeCache();
-		div = curv->getDiv();
+		int div = curv->getDiv();
 		vArray = curv->getPosCache();
 
 		workVertexArray.clear();
@@ -586,7 +586,7 @@ void fk_LineDraw::CommonLineDrawFunc(fk_Edge *argE, bool argMode, DWORD argColor
 			workCustomVertexArray.push_back(tmpVertex);
 		}
 		ref_lpD3DDEV->SetFVF(D3DFVF_LINECUSTOMVERTEX);
-		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_LINELIST, workCustomVertexArray.size()/2, &workCustomVertexArray[0], sizeof(LINECUSTOMVERTEX));
+		ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_LINELIST, static_cast<UINT>(workCustomVertexArray.size()/2), &workCustomVertexArray[0], sizeof(LINECUSTOMVERTEX));
 
 		/*
 		m_lpD3DXLine->Begin();
@@ -636,13 +636,12 @@ void fk_LineDraw::PickLineDrawFunc(fk_Edge *argE, bool argMode)
 	fk_Vector			*vPos;
 	fk_Curve			*curv;
 	vector<fk_Vector>	*vArray;
-	int					ii, div;
 	fk_Half				*lH, *rH;
 	fk_Vertex			*lV, *rV;
 
 	if((curv = argE->getCurveGeometry()) != (fk_Curve *)NULL) {
 		curv->makeCache();
-		div = curv->getDiv();
+		int div = curv->getDiv();
 		vArray = curv->getPosCache();
 
 		if(argMode == false) {
@@ -650,7 +649,7 @@ void fk_LineDraw::PickLineDrawFunc(fk_Edge *argE, bool argMode)
 		}
 
 		glBegin(GL_LINE_STRIP);
-		for(ii = 0; ii <= div; ii++) {
+		for(int ii = 0; ii <= div; ii++) {
 			vPos = &((*vArray)[ii]);
 			glVertex3dv((GLdouble *)&(vPos->x));
 		}
