@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -69,6 +69,8 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+
+#define FK_DEF_SIZETYPE
 #include <FK/MQOParser.H>
 #include <FK/IFSTexture.h>
 #include <FK/Tree.h>
@@ -256,7 +258,7 @@ bool fk_MQOParser::MakeData(const string &argFileName,
 
 		if(line.find("{") != string::npos) {
 			data = GetProperty(data, &line);
-			propList = (_fk_MQOPropertyList *)(data->getObject());
+			propList = static_cast<_fk_MQOPropertyList *>(data->getObject());
 			if(propList->property == "Object" &&
 			   propList->data == argObjName) {
 				oMode = true;
@@ -283,7 +285,7 @@ bool fk_MQOParser::MakeData(const string &argFileName,
 			}
 
 		} else if(line.find("}") != string::npos) {
-			propList = (_fk_MQOPropertyList *)(data->getObject());
+			propList = static_cast<_fk_MQOPropertyList *>(data->getObject());
 			if(propList->property == "Object" && oMode == true) {
 				oMode = false;
 				continue;
@@ -369,10 +371,9 @@ bool fk_MQOParser::ReadLine(FILE *argFP,
 							unsigned int *argBufTag,
 							string *argOutStr)
 {
-	char				buffer[512];
-	char				*eofStatus;
-	bool				startFlg, lineFlg;
-	unsigned int		startTag, endTag;
+	char	buffer[512];
+	char	*eofStatus;
+	bool	startFlg, lineFlg;
 
 	startFlg = false;
 	lineFlg = false;
@@ -395,16 +396,16 @@ bool fk_MQOParser::ReadLine(FILE *argFP,
 			}
 
 			if(startFlg == false && lineFlg == true) {
-				startTag = *argBufTag;
 				startFlg = true;
 			}
 
 			if(startFlg == true && lineFlg == false) {
-				endTag = *argBufTag;
 				break;
 			}
 
-			if(startFlg == true) argOutStr->push_back(argBuffer[(*argBufTag)]);
+			if(startFlg == true) {
+				argOutStr->push_back(static_cast<char>(argBuffer[(*argBufTag)]));
+			}
 			(*argBufTag)++;
 		}
 	}
@@ -478,10 +479,10 @@ bool fk_MQOParser::PushFaceData(string *argLine, int argMateID)
 			for(i = 0; i < vNum; i++) {
 				word = PopWord(argLine, sep);
 				if(IsNumeric(word) == false) return false;
-				tmpCoord.x = float(Str2Double(word));
+				tmpCoord.x = static_cast<float>(Str2Double(word));
 				word = PopWord(argLine, sep);
 				if(IsNumeric(word) == false) return false;
-				tmpCoord.y = float(1.0 - Str2Double(word));
+				tmpCoord.y = static_cast<float>(1.0 - Str2Double(word));
 				texArray.push_back(tmpCoord);
 			}
 			tmpCoord = texArray[0];
@@ -628,17 +629,18 @@ void fk_MQOParser::SetQuadFace(vector< vector<int> > *argIF,
 
 bool fk_MQOParser::CheckIFData(int argVNum)
 {
-	int		fNum = 0;
-	int		i, j, id, size;
+	_st		fNum = 0;
+	_st		i, j, size;
+	int		id;
 
-	for(i = 0; i < int(fData.size()); i++) {
-		size = int(fData[i].size());
+	for(i = 0; i < fData.size(); i++) {
+		size = fData[i].size();
 		if(size < 3 || size > 4) {
 			return false;
 		}
 		fNum += (size - 2);
 
-		for(j = 0; j < int(fData[i].size()); j++) {
+		for(j = 0; j < fData[i].size(); j++) {
 			id = fData[i][j];
 			if(id <= 0 || id > argVNum) {
 				return false;
@@ -651,7 +653,7 @@ bool fk_MQOParser::CheckIFData(int argVNum)
 	if(contFlg == true) MakeUniqueVertex4Texture();
 
 	if(meshTexture != NULL) {
-		meshTexture->setTriNum(fNum);
+		meshTexture->setTriNum(static_cast<int>(fNum));
 	}
 
 	return true;
@@ -659,26 +661,26 @@ bool fk_MQOParser::CheckIFData(int argVNum)
 
 void fk_MQOParser::OptimizeData(void)
 {
-	unsigned int		i, j;
-	vector<char>		tmpArray;
-	vector<int>			mapArray;
-	int					index, count;
+	_st				i, j;
+	vector<char>	tmpArray;
+	vector<int>		mapArray;
+	int				index, count;
 
 	tmpArray.resize(vData.size());
-	for(i = 0; i < tmpArray.size(); i++) tmpArray[i] = char(false);
+	for(i = 0; i < tmpArray.size(); i++) tmpArray[i] = static_cast<char>(false);
 
 	for(i = 0; i < fData.size(); i++) {
 		for(j = 0; j < fData[i].size(); j++) {
 			index = fData[i][j]-1;
-			if(index < 0 || index >= int(tmpArray.size())) return;
-			tmpArray[index] = char(true);
+			if(index < 0 || index >= static_cast<int>(tmpArray.size())) return;
+			tmpArray[static_cast<_st>(index)] = static_cast<char>(true);
 		}
 	}
 
 	count = 1;
 	mapArray.resize(tmpArray.size());
 	for(i = 0; i < tmpArray.size(); i++) {
-		if(tmpArray[i] == char(true)) {
+		if(tmpArray[i] == static_cast<char>(true)) {
 			mapArray[i] = count;
 			optVData.push_back(vData[i]);
 			count++;
@@ -690,7 +692,7 @@ void fk_MQOParser::OptimizeData(void)
 	for(i = 0; i < fData.size(); i++) {
 		for(j = 0; j < fData[i].size(); j++) {
 			index = fData[i][j]-1;
-			fData[i][j] = mapArray[index];
+			fData[i][j] = mapArray[static_cast<_st>(index)];
 		}
 	}
 
@@ -700,22 +702,21 @@ void fk_MQOParser::OptimizeData(void)
 void fk_MQOParser::MakeUniqueVertex4Texture(void)
 {
 	vector< vector<_fk_MQO_IDSet> >		listSet;
-	int									index;
 	fk_TexCoord							coord;
-	unsigned int						i, j, k;
+	_st									i, j, k, index;
 	_fk_MQO_IDSet						idset;
 	int									newID;
 	vector< vector<int> >				*commonList;
 
 	listSet.resize(optVData.size());
-	newID = optVData.size();
+	newID = static_cast<int>(optVData.size());
 
 	for(i = 0; i < fData.size(); i++) {
 		if(fData[i].size() != tData[i].size()) continue;
 
 		for(j = 0; j < fData[i].size(); j++) {
-			index = fData[i][j] - 1;
-			idset.id = index;
+			index = static_cast<_st>(fData[i][j] - 1);
+			idset.id = static_cast<int>(index);
 
 			coord = tData[i][j];
 			idset.coord = coord;
@@ -755,29 +756,31 @@ void fk_MQOParser::MakeUniqueVertex4Texture(void)
 
 void fk_MQOParser::SetMeshTexCoord(void)
 {
-	int			i, j;
+	_st			i, j;
 	fk_Vector	triPos[3];
 	fk_TexCoord	triCoord[3];
 
 	if(meshTexture == NULL) return;
-	for(i = 0; i < int(fData.size()); i++) {
+	for(i = 0; i < fData.size(); i++) {
 		for(j = 0; j < 3; j++) {
-			triPos[j] = optVData[fData[i][j]-1];
+			triPos[j] = optVData[static_cast<_st>(fData[i][j]-1)];
 			triCoord[j] = tData[i][j];
 		}
-		meshTexture->setTriPos(i, triPos);
-		meshTexture->setTriTextureCoord(i, triCoord);
+		meshTexture->setTriPos(static_cast<int>(i), triPos);
+		meshTexture->setTriTextureCoord(static_cast<int>(i), triCoord);
 	}
 	return;
 }
 
 void fk_MQOParser::SetIFSTexCoord(void)
 {
-	int			i, j;
+	_st			i, j;
 
-	for(i = 0; i < int(tData.size()); i++) {
-		for(j = 0; j < int(tData[i].size()); j++) {
-			ifsTexture->setTextureCoord(i, j, tData[i][j]);
+	for(i = 0; i < tData.size(); i++) {
+		for(j = 0; j < tData[i].size(); j++) {
+			ifsTexture->setTextureCoord(static_cast<int>(i),
+										static_cast<int>(j),
+										tData[i][j]);
 		}
 	}
 	return;
