@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -332,3 +332,35 @@ void fk_Math::calcClosestPtPtToSeg(const fk_Vector &c, const fk_Vector &a, const
 
 	return;
 }
+
+bool fk_Math::calcCrossLineAndTri(const fk_Vector &argP,
+								  const fk_Vector &argQ,
+								  const fk_Vector &argA,
+								  const fk_Vector &argB,
+								  const fk_Vector &argC,
+								  fk_Vector *argR)
+{
+	fk_Vector		L, M, S, D, R;
+	fk_Matrix		mat;
+
+	L = argB - argA;
+	M = argC - argA;
+	S = argP - argQ;
+	D = argP - argA;
+
+	mat.setCol(0, L);
+	mat.setCol(1, M);
+	mat.setCol(2, S);
+	if(mat.inverse() == false) return false;
+	
+	R = mat * D;
+
+	if(argR != NULL) argR->set(R.x, R.y, R.z);
+
+	if(R.x <= -FK_EPS || R.y <= -FK_EPS || R.x + R.y >= 1.0 + FK_EPS ||
+	   R.z <= -FK_EPS || R.z >= 1.0 + FK_EPS) {
+		return false;
+	}
+
+	return true;
+}
