@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -384,6 +384,83 @@ void fk_OrthoMatrix::set(int argR, int argC, double argValue)
 	return;
 }
 
+void fk_OrthoMatrix::setRow(int argR, const fk_Vector &argV)
+{
+	if(argR < 0 || argR > 3) {
+		fk_PutError("fk_OrthoMatrix", "setRow", 1, "ID Error");
+		return;
+	}
+
+	m[argR][0] = argV.x;
+	m[argR][1] = argV.y;
+	m[argR][2] = argV.z;
+	return;
+}
+
+void fk_OrthoMatrix::setRow(int argR, const fk_HVector &argV)
+{
+	if(argR < 0 || argR > 3) {
+		fk_PutError("fk_OrthoMatrix", "setRow", 2, "ID Error");
+		return;
+	}
+
+	m[argR][0] = argV.x;
+	m[argR][1] = argV.y;
+	m[argR][2] = argV.z;
+	m[argR][3] = argV.w;
+	return;
+}
+
+void fk_OrthoMatrix::setCol(int argC, const fk_Vector &argV)
+{
+	if(argC < 0 || argC > 3) {
+		fk_PutError("fk_OrthoMatrix", "setCol", 1, "ID Error");
+		return;
+	}
+
+	m[0][argC] = argV.x;
+	m[1][argC] = argV.y;
+	m[2][argC] = argV.z;
+	return;
+}
+
+void fk_OrthoMatrix::setCol(int argC, const fk_HVector &argV)
+{
+	if(argC < 0 || argC > 3) {
+		fk_PutError("fk_OrthoMatrix", "setCol", 2, "ID Error");
+		return;
+	}
+
+	m[0][argC] = argV.x;
+	m[1][argC] = argV.y;
+	m[2][argC] = argV.z;
+	m[3][argC] = argV.w;
+	return;
+}
+
+fk_HVector fk_OrthoMatrix::getRow(int argR)
+{
+	fk_HVector	retV;
+
+	if(argR < 0 || argR > 3) {
+		fk_PutError("fk_OrthMatrix", "getRow", 1, "ID Error");
+		return retV;
+	}
+	retV.set(m[argR][0], m[argR][1], m[argR][2], m[argR][3]);
+	return retV;
+}
+
+fk_HVector fk_OrthoMatrix::getCol(int argC)
+{
+	fk_HVector	retV;
+
+	if(argC < 0 || argC > 3) {
+		fk_PutError("fk_OrthMatrix", "getCol", 1, "ID Error");
+		return retV;
+	}
+	retV.set(m[0][argC], m[1][argC], m[2][argC], m[3][argC]);
+	return retV;
+}
 
 bool fk_OrthoMatrix::inverse(void)
 {
