@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -69,6 +69,8 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+
+#define FK_DEF_SIZETYPE
 #include <FK/Modify.h>
 #include <FK/IFSetHandle.H>
 #include <FK/Vertex.h>
@@ -95,16 +97,16 @@ fk_Loop * fk_Modify::removeVertexInLoop(fk_Vertex *argVx)
 	vector<fk_Edge *>	connectE;
 	vector<fk_Loop *>	connectL;
 	vector<fk_Vertex *>	neighborV;
-	unsigned int		i;
+	_st					i;
 	fk_Half				*remainH;
 	fk_Loop				*retL;
 
-	if(checkDB() == false) return (fk_Loop *)NULL;
-	if(existVertex(argVx) == false) return (fk_Loop *)NULL;
+	if(checkDB() == false) return NULL;
+	if(existVertex(argVx) == false) return NULL;
 
 	neighborV = getAllNeighborVOnV(argVx);
 	for(i = 0; i < neighborV.size(); i++) {
-		if(getENumOnV(neighborV[i]) < 3) return (fk_Loop *)NULL;
+		if(getENumOnV(neighborV[i]) < 3) return NULL;
 	}
 
 	connectE = getAllEOnV(argVx);
@@ -113,15 +115,15 @@ fk_Loop * fk_Modify::removeVertexInLoop(fk_Vertex *argVx)
 
 	for(i = 0; i < connectL.size(); i++) {
 		if(deleteLoop(connectL[i]) == false) {
-			return (fk_Loop *)NULL;
+			return NULL;
 		}
 	}
 
 	for(i = 0; i < connectE.size(); i++) {
-		if(deleteEdge(connectE[i]) == false) return (fk_Loop *)NULL;
+		if(deleteEdge(connectE[i]) == false) return NULL;
 	}
 
-	if(deleteVertex(argVx) == false) return (fk_Loop *)NULL;
+	if(deleteVertex(argVx) == false) return NULL;
 
 	retL = makeLoop(remainH);
 	return retL;
@@ -151,13 +153,13 @@ bool fk_Modify::contractEdge(fk_Edge *argEd, fk_Vector argPos, bool rightFlg)
 	fk_Vertex				*remainV, *deleteV;
 	fk_Vertex				*NeighborV[2];
 	fk_Half					*newArgFirstH, *curH;
-	fk_Half					*newArgH1 = (fk_Half *)NULL;
-	fk_Half					*newArgH2 = (fk_Half *)NULL;
+	fk_Half					*newArgH1 = NULL;
+	fk_Half					*newArgH2 = NULL;
 	fk_Loop					*remainL;
-	fk_Edge					*newE = (fk_Edge *)NULL;
+	fk_Edge					*newE = NULL;
 	vector<fk_Vertex *>		OldConnectV;
 	vector<fk_Half *>		NewConnectH;
-	register unsigned int	i;
+	register _st			i;
 
 
 	// データベースが存在しない 
@@ -167,8 +169,8 @@ bool fk_Modify::contractEdge(fk_Edge *argEd, fk_Vector argPos, bool rightFlg)
 	if(existEdge(argEd) == false) return false;
 
 	// 稜線が定義稜線でない 
-	if(argEd->getRightHalf()->getParentLoop() == (fk_Loop *)NULL ||
-	   argEd->getLeftHalf()->getParentLoop() == (fk_Loop *)NULL) {
+	if(argEd->getRightHalf()->getParentLoop() == NULL ||
+	   argEd->getLeftHalf()->getParentLoop() == NULL) {
 		return false;
 	}
 
@@ -238,7 +240,7 @@ bool fk_Modify::contractEdge(fk_Edge *argEd, fk_Vector argPos, bool rightFlg)
 				getRightHOnE(newE) : getLeftHOnE(newE);
 		}
 		newE = separateLoop(newArgH1, newArgH2);
-		if(newE == (fk_Edge *)NULL) return false;
+		if(newE == NULL) return false;
 	}
 
 	// remainV を移動 
@@ -253,7 +255,7 @@ bool fk_Modify::checkContract(fk_Edge *argEd)
 	fk_Half		*rH, *lH;
 	fk_Vertex	*rV, *lV;
 
-	if(argEd == (fk_Edge *)NULL) return false;
+	if(argEd == NULL) return false;
 	rH = argEd->getRightHalf();
 	lH = argEd->getLeftHalf();
 
@@ -263,11 +265,11 @@ bool fk_Modify::checkContract(fk_Edge *argEd)
 	rV = rH->getVertex();
 	lV = lH->getVertex();
 
-	if(rL != (fk_Loop *)NULL) {
+	if(rL != NULL) {
 		if(CheckLoop4Cont(rH) == false) return false;
 	}
 
-	if(lL != (fk_Loop *)NULL) {
+	if(lL != NULL) {
 		if(CheckLoop4Cont(lH) == false) return false;
 	}
 
@@ -284,7 +286,7 @@ bool fk_Modify::CheckLoop4Cont(fk_Half *argHf)
 	fk_Half	*nMateH, *pMateH;
 
 	// argHf が NULL の場合 
-	if(argHf == (fk_Half *)NULL) return false;
+	if(argHf == NULL) return false;
 
 	nextH = argHf->getNextHalf();
 	prevH = argHf->getPrevHalf();
@@ -309,14 +311,14 @@ bool fk_Modify::CheckLoop4Cont(fk_Half *argHf)
 fk_Loop * fk_Modify::makePolygon(vector<fk_Vector> *argVec,
 							bool argOpenFlg, bool argClearFlg)
 {
-	unsigned int			i;
+	_st						i;
 	fk_Vertex				*curV;
 	vector<fk_Vertex *>		VertexArray;
 	fk_Edge					*prevE;
 	fk_Half					*nextH, *prevH, *lH, *rH, *nextH2, *prevH2;
-	fk_Loop					*retL = (fk_Loop *)NULL;
+	fk_Loop					*retL = NULL;
 
-	if(argVec == (vector<fk_Vector> *)NULL) return retL;
+	if(argVec == NULL) return retL;
 	if(argVec->size() < 3) return retL;
 	VertexArray.clear();
 
@@ -331,7 +333,7 @@ fk_Loop * fk_Modify::makePolygon(vector<fk_Vector> *argVec,
 		VertexArray.push_back(curV);
 	}
 
-	if((prevE = makeEdge(VertexArray[1], VertexArray[0])) == (fk_Edge *)NULL) {
+	if((prevE = makeEdge(VertexArray[1], VertexArray[0])) == NULL) {
 		fk_PutError("fk_Modify", "makePolygon", 1, "Make Edge Error.");
 		AllClear_();
 		return retL;
@@ -349,7 +351,7 @@ fk_Loop * fk_Modify::makePolygon(vector<fk_Vector> *argVec,
 		}
 
 		if((prevE = makeEdge(VertexArray[i-1], VertexArray[i],
-							 prevH, nextH)) == (fk_Edge *)NULL) {
+							 prevH, nextH)) == NULL) {
 			fk_PutError("fk_Modify", "makePolygon", 2, "Make Edge Error.");
 			AllClear_();
 			return retL;
@@ -364,12 +366,12 @@ fk_Loop * fk_Modify::makePolygon(vector<fk_Vector> *argVec,
 		prevH2 = getMateHOnH(nextH2);
 
 		if(makeEdge(VertexArray.back(), VertexArray[0],
-					prevH, nextH, prevH2, nextH2) == (fk_Edge *)NULL) {
+					prevH, nextH, prevH2, nextH2) == NULL) {
 			fk_PutError("fk_Modify", "makePolygon", 3, "Make Edge Error.");
 			AllClear_();
 			return retL;
 		}
-		if((retL = makeLoop(prevH)) == (fk_Loop *)NULL) {
+		if((retL = makeLoop(prevH)) == NULL) {
 			fk_PutError("fk_Modify", "makePolygon", 4, "Make Loop Error.");
 			AllClear_();
 			return retL;
@@ -383,10 +385,11 @@ fk_Loop * fk_Modify::makePolygon(int argNum, fk_Vector *argVec,
 							bool argOpenFlg, bool argClearFlg)
 {
 	vector<fk_Vector>	VecArray;
-	int			i;
+	_st					i, num;
+	num = static_cast<_st>(argNum);
 
-	VecArray.resize(argNum);
-	for(i = 0; i < argNum; i++) VecArray[i] = argVec[i];
+	VecArray.resize(num);
+	for(i = 0; i < num; i++) VecArray[i] = argVec[i];
 
 	return makePolygon(&VecArray, argOpenFlg, argClearFlg);
 }
@@ -406,7 +409,7 @@ void fk_Modify::pushPolygonVertex(fk_Vector argVec, bool argOpenFlg)
 		break;
 
 	  case 1:
-		startV = getNextV((fk_Vertex *)NULL);
+		startV = getNextV(NULL);
 		curV = makeVertex(argVec);
 		makeEdge(curV, startV);
 		break;
@@ -423,8 +426,8 @@ void fk_Modify::pushPolygonVertex(fk_Vector argVec, bool argOpenFlg)
 			makeEdge(startV, curV, prevH, nextH);
 		} else {
 
-			curV = getNextV((fk_Vertex *)NULL);
-			while(curV != (fk_Vertex *)NULL) {
+			curV = getNextV(NULL);
+			while(curV != NULL) {
 				VecArray.push_back(curV->getPosition());
 				curV = getNextV(curV);
 			}
@@ -449,19 +452,21 @@ fk_Loop * fk_Modify::pushPolygon(int argNum,
 								 fk_Vector *argVec, bool argOpenFlg)
 {
 	vector<fk_Vector>	VecArray;
-	int			i;
+	_st					i, num;
 
-	VecArray.resize(argNum);
-	for(i = 0; i < argNum; i++) VecArray[i] = argVec[i];
+	num = static_cast<_st>(argNum);
+
+	VecArray.resize(num);
+	for(i = 0; i < num; i++) VecArray[i] = argVec[i];
 
 	return makePolygon(&VecArray, argOpenFlg, false);
 }
 
 void fk_Modify::makePoint(vector<fk_Vector> *argVec)
 {
-	unsigned int	i;
+	_st		i;
 
-	if(argVec == (vector<fk_Vector> *)NULL) return;
+	if(argVec == NULL) return;
 	if(checkDB() == false) return;
 	AllClear_();
 
@@ -474,7 +479,7 @@ void fk_Modify::makePoint(vector<fk_Vector> *argVec)
 
 void fk_Modify::makePoint(int argNum, fk_Vector *argVec)
 {
-	int		i;
+	int			i;
 
 	if(checkDB() == false) return;
 	AllClear_();
@@ -493,10 +498,10 @@ fk_Vertex * fk_Modify::pushPointVertex(fk_Vector argVec)
 
 void fk_Modify::makeLines(vector<fk_Vector> *argVec)
 {
-	unsigned int	i;
-	fk_Vertex		*v1, *v2;
+	_st			i;
+	fk_Vertex	*v1, *v2;
 
-	if(argVec == (vector<fk_Vector> *)NULL) return;
+	if(argVec == NULL) return;
 	if(checkDB() == false) return;
 	AllClear_();
 
@@ -514,7 +519,7 @@ void fk_Modify::makeLines(int argNum, fk_Vector *argVec)
 	int			i;
 	fk_Vertex		*v1, *v2;
 
-	if(argVec == (fk_Vector *)NULL) return;
+	if(argVec == NULL) return;
 	if(checkDB() == false) return;
 	AllClear_();
 
@@ -531,7 +536,7 @@ fk_Edge * fk_Modify::pushLines(fk_Vector argVec1, fk_Vector argVec2)
 {
 	fk_Vertex		*v1, *v2;
 	
-	if(checkDB() == false) return (fk_Edge *)NULL;
+	if(checkDB() == false) return NULL;
 	v1 = makeVertex(argVec1);
 	v2 = makeVertex(argVec2);
 	return makeEdge(v1, v2);
@@ -543,8 +548,8 @@ bool fk_Modify::changeLine(int argID, fk_Vector argPos1, fk_Vector argPos2)
 
 	if(checkDB() == false) return false;
 
-	if((v1 = getVData(2*argID + 1)) == (fk_Vertex *)NULL ||
-	   (v2 = getVData(2*argID + 2)) == (fk_Vertex *)NULL) {
+	if((v1 = getVData(2*argID + 1)) == NULL ||
+	   (v2 = getVData(2*argID + 2)) == NULL) {
 		return false;
 	}
 
@@ -559,7 +564,7 @@ bool fk_Modify::setLinePos(int argEID, int argVID, fk_Vector argPos)
 
 	if(checkDB() == false) return false;
 
-	if((tmpV = getVData(2*argEID + argVID + 1)) == (fk_Vertex *)NULL) {
+	if((tmpV = getVData(2*argEID + argVID + 1)) == NULL) {
 		return false;
 	}
 
@@ -635,13 +640,13 @@ void fk_Modify::setBlockSize(double argX, double argY, double argZ)
 	if(checkDB() == false) return;
 	if(getVNum() != 8 || getLNum() != 6) return;
 
-	curV = getNextV((fk_Vertex *)NULL);
+	curV = getNextV(NULL);
 	basePos = curV->getPosition();
 	scaleX = argX/(basePos.x * 2.0);
 	scaleY = argY/(basePos.y * 2.0);
 	scaleZ = argZ/(basePos.z * 2.0);
 
-	while(curV != (fk_Vertex *)NULL) {
+	while(curV != NULL) {
 		curPos = curV->getPosition();
 		newPos.set(curPos.x*scaleX, curPos.y*scaleY, curPos.z*scaleZ);
 		moveVertex(curV, newPos);
@@ -661,7 +666,7 @@ void fk_Modify::setBlockSize(double argSize, fk_Axis argAxis)
 
 	if(getVNum() != 8 || getLNum() != 6) return;
 	
-	curV = getNextV((fk_Vertex *)NULL);
+	curV = getNextV(NULL);
 	basePos = curV->getPosition();
 	scaleX = scaleY = scaleZ = 1.0;
 
@@ -679,7 +684,7 @@ void fk_Modify::setBlockSize(double argSize, fk_Axis argAxis)
 		break;
 	}
 
-	while(curV != (fk_Vertex *)NULL) {
+	while(curV != NULL) {
 		curPos = curV->getPosition();
 		newPos.set(curPos.x*scaleX, curPos.y*scaleY, curPos.z*scaleZ);
 		moveVertex(curV, newPos);
@@ -704,7 +709,7 @@ void fk_Modify::setBlockScale(double argScale, fk_Axis argAxis)
 
 	if(getVNum() != 8 || getLNum() != 6) return;
 	
-	curV = getNextV((fk_Vertex *)NULL);
+	curV = getNextV(NULL);
 
 	scaleX = scaleY = scaleZ = 1.0;
 
@@ -722,7 +727,7 @@ void fk_Modify::setBlockScale(double argScale, fk_Axis argAxis)
 		break;
 	}
 
-	while(curV != (fk_Vertex *)NULL) {
+	while(curV != NULL) {
 		curPos = curV->getPosition();
 		newPos.set(curPos.x*scaleX, curPos.y*scaleY, curPos.z*scaleZ);
 		moveVertex(curV, newPos);
@@ -741,9 +746,9 @@ void fk_Modify::setBlockScale(double argX, double argY, double argZ)
 
 	if(getVNum() != 8 || getLNum() != 6) return;
 
-	curV = getNextV((fk_Vertex *)NULL);
+	curV = getNextV(NULL);
 
-	while(curV != (fk_Vertex *)NULL) {
+	while(curV != NULL) {
 		curPos = curV->getPosition();
 		newPos.set(curPos.x*argX, curPos.y*argY, curPos.z*argZ);
 		moveVertex(curV, newPos);
@@ -759,31 +764,33 @@ void fk_Modify::makeCircle(int argDiv, double argRadius)
 	vector<fk_Vector>		VecArray;
 	vector<int>				IDArray;
 	vector< vector<int> >	IFArray;
-	register int			i;
+	register _st			i, div;
 	double					theta;
+	int						j;
 
 	if(checkDB() == false) return;
 	AllClear_();
 
 	IFSet.SetDataBase(GetDB());
 
-	VecArray.resize(argDiv * 4 + 1);
+	div = static_cast<_st>(argDiv);
+	VecArray.resize(div * 4 + 1);
 	VecArray[0].set(0.0, 0.0, 0.0);
 
-	for(i = 0; i < 4 * argDiv; i++) {
-		theta = (double(i) * FK_PI)/(double(argDiv*2));
+	for(i = 0; i < 4 * div; i++) {
+		theta = (static_cast<double>(i) * FK_PI)/(static_cast<double>(div*2));
 		VecArray[i+1].set(cos(theta) * argRadius, sin(theta) * argRadius, 0.0);
 	}
 
 	IFArray.clear();
-	for(i = 0; i < argDiv*4; i++) {
+	for(j = 0; j < argDiv*4; i++) {
 		IDArray.clear();
 		IDArray.push_back(1);
-		IDArray.push_back(i + 2);
-		if(i == argDiv * 4 - 1) {
+		IDArray.push_back(j+2);
+		if(i == div * 4 - 1) {
 			IDArray.push_back(2);
 		} else {
-			IDArray.push_back(i + 3);
+			IDArray.push_back(j+3);
 		}
 		IFArray.push_back(IDArray);
 	}
@@ -801,7 +808,7 @@ void fk_Modify::setCircleDivide(int argDiv)
 	if(checkDB() == false) return;
 	if(getLNum() == argDiv * 4) return;
 
-	if((curV = getNextV(getNextV((fk_Vertex *)NULL))) == (fk_Vertex *)NULL) {
+	if((curV = getNextV(getNextV(NULL))) == NULL) {
 		return;
 	}
 
@@ -818,14 +825,14 @@ void fk_Modify::setCircleRadius(double argRadius)
 
 	if(checkDB() == false) return;
 
-	curV = getNextV((fk_Vertex *)NULL);
+	curV = getNextV(NULL);
 	curV = getNextV(curV);
-	if(curV == (fk_Vertex *)NULL) return;
+	if(curV == NULL) return;
 
 	basePos = curV->getPosition();
 	scale = argRadius/basePos.x;
 
-	while(curV != (fk_Vertex *)NULL) {
+	while(curV != NULL) {
 		basePos = curV->getPosition();
 		curPos.set(basePos.x * scale, basePos.y * scale, 0.0);
 		moveVertex(curV, curPos);
@@ -842,11 +849,11 @@ void fk_Modify::setCircleScale(double argScale)
 
 	if(checkDB() == false) return;
 
-	if((curV = getNextV(getNextV((fk_Vertex *)NULL))) == (fk_Vertex *)NULL) {
+	if((curV = getNextV(getNextV(NULL))) == NULL) {
 		return;
 	}
 
-	while(curV != (fk_Vertex *)NULL) {
+	while(curV != NULL) {
 		basePos = curV->getPosition();
 		curPos.set(basePos.x * argScale, basePos.y * argScale, 0.0);
 		moveVertex(curV, curPos);
@@ -863,6 +870,7 @@ void fk_Modify::makeSphere(int argDiv, double argRadius)
 	vector<int>				IDArray;
 	vector< vector<int> >	IFArray;
 	int						i, j, index, index2;
+	_st						ii, jj;
 	vector<double>			xz_radius;
 	double					theta1, theta2;
 
@@ -871,11 +879,12 @@ void fk_Modify::makeSphere(int argDiv, double argRadius)
 	AllClear_();
 	IFSet.SetDataBase(GetDB());
 
-	VecArray.resize(argDiv*4 * (argDiv*2 - 1) + 2);
-	xz_radius.resize(argDiv*2 - 1);
+	VecArray.resize(static_cast<_st>(argDiv*4 * (argDiv*2 - 1) + 2));
+	xz_radius.resize(static_cast<_st>(argDiv*2 - 1));
 
 	for(i = 0; i < argDiv*2 - 1; i++) {
-		xz_radius[i] = argRadius*sin(double(i+1)*FK_PI/(argDiv*2.0));
+		ii = static_cast<_st>(i);
+		xz_radius[ii] = argRadius*sin(static_cast<double>(i+1)*FK_PI/(argDiv*2.0));
 	}
 
 	VecArray.front().set(0.0, argRadius, 0.0);
@@ -884,11 +893,14 @@ void fk_Modify::makeSphere(int argDiv, double argRadius)
 	for(i = 0; i < argDiv*2 - 1; i++) {
 		for(j = 0; j < argDiv*4; j++) {
 			index = i*argDiv*4 + j + 1;
-			theta1 = double(j)*FK_PI/(argDiv*2.0);
-			theta2 = double(i+1)*FK_PI/(argDiv*2.0);
-			VecArray[index].set(xz_radius[i] * cos(theta1),
-								argRadius * cos(theta2),
-								xz_radius[i] * sin(theta1));
+			ii = static_cast<_st>(i);
+			jj = static_cast<_st>(index);
+
+			theta1 = static_cast<double>(j)*FK_PI/(argDiv*2.0);
+			theta2 = static_cast<double>(i+1)*FK_PI/(argDiv*2.0);
+			VecArray[jj].set(xz_radius[ii] * cos(theta1),
+							 argRadius * cos(theta2),
+							 xz_radius[ii] * sin(theta1));
 		}
 	}
 
@@ -948,7 +960,7 @@ void fk_Modify::setSphereDivide(int argDiv)
 
 	if(checkDB() == false) return;
 
-	if((curV = getNextV((fk_Vertex *)NULL)) == (fk_Vertex *)NULL) {
+	if((curV = getNextV(NULL)) == NULL) {
 		return;
 	}
 	makeSphere(argDiv, curV->getPosition().y);
@@ -963,13 +975,13 @@ void fk_Modify::setSphereRadius(double argRadius)
 
 	if(checkDB() == false) return;
 
-	curV = getNextV((fk_Vertex *)NULL);
-	if(curV == (fk_Vertex *)NULL) return;
+	curV = getNextV(NULL);
+	if(curV == NULL) return;
 
 	basePos = curV->getPosition();
 	scale = argRadius/basePos.y;
 
-	while(curV != (fk_Vertex *)NULL) {
+	while(curV != NULL) {
 		basePos = curV->getPosition();
 		curPos.set(basePos.x * scale, basePos.y * scale, basePos.z * scale);
 		moveVertex(curV, curPos);
@@ -986,10 +998,10 @@ void fk_Modify::setSphereScale(double argScale)
 
 	if(checkDB() == false) return;
 
-	curV = getNextV((fk_Vertex *)NULL);
-	if(curV == (fk_Vertex *)NULL) return;
+	curV = getNextV(NULL);
+	if(curV == NULL) return;
 
-	while(curV != (fk_Vertex *)NULL) {
+	while(curV != NULL) {
 		basePos = curV->getPosition();
 		curPos.set(basePos.x * argScale,
 				   basePos.y * argScale, basePos.z * argScale);
@@ -1015,16 +1027,16 @@ void fk_Modify::makePrism(int argDiv, double argTop, double argBottom,
 
 	IFSet.SetDataBase(GetDB());
 
-	VecArray.resize(argDiv*2+2);
+	VecArray.resize(static_cast<_st>(argDiv*2+2));
 	VecArray[0].set(0.0, 0.0, 0.0);
-	VecArray[argDiv + 1].set(0.0, 0.0, -argHeight);
+	VecArray[static_cast<_st>(argDiv + 1)].set(0.0, 0.0, -argHeight);
 
 	for(i = 0; i < argDiv; i++) {
-		theta = (double(i*2) * FK_PI)/double(argDiv);
-		VecArray[i+1].set(cos(theta) * argBottom,
+		theta = (static_cast<double>(i*2) * FK_PI)/static_cast<double>(argDiv);
+		VecArray[static_cast<_st>(i+1)].set(cos(theta) * argBottom,
 						  sin(theta) * argBottom, 0.0);
-		VecArray[argDiv+i+2].set(cos(theta) * argTop, 
-								 sin(theta) * argTop, -argHeight);
+		VecArray[static_cast<_st>(argDiv+i+2)].set(cos(theta) * argTop, 
+												   sin(theta) * argTop, -argHeight);
 	}
 
 	IFArray.clear();
@@ -1112,7 +1124,7 @@ void fk_Modify::setPrismTopRadius(double argTop)
 	z = getVData(div+3)->getPosition().z;
 	for(i = 0; i < div; i++) {
 		v = getVData(div+i+3);
-		theta = (double(i*2) * FK_PI)/double(div);
+		theta = (static_cast<double>(i*2) * FK_PI)/static_cast<double>(div);
 		pos.set(cos(theta) * argTop, sin(theta) * argTop, z);
 		moveVertex(v, pos);
 	}
@@ -1131,7 +1143,7 @@ void fk_Modify::setPrismBottomRadius(double argBottom)
 	div = getVNum()/2 - 1;
 	for(i = 0; i < div; i++) {
 		v = getVData(i+2);
-		theta = (double(i*2) * FK_PI)/double(div);
+		theta = (static_cast<double>(i*2) * FK_PI)/static_cast<double>(div);
 		pos.set(cos(theta) * argBottom, sin(theta) * argBottom, 0.0);
 		moveVertex(v, pos);
 	}
@@ -1170,13 +1182,13 @@ void fk_Modify::makeCone(int argDiv, double argRadius, double argHeight)
 
 	IFSet.SetDataBase(GetDB());
 	
-	VecArray.resize(argDiv+2);
+	VecArray.resize(static_cast<_st>(argDiv+2));
 	VecArray[0].set(0.0, 0.0, 0.0);
 	VecArray[1].set(0.0, 0.0, -argHeight);
 
 	for(i = 0; i < argDiv; i++) {
-		theta = (double(i*2) * FK_PI)/double(argDiv);
-		VecArray[i+2].set(cos(theta) * argRadius, sin(theta) * argRadius, 0.0);
+		theta = (static_cast<double>(i*2) * FK_PI)/static_cast<double>(argDiv);
+		VecArray[static_cast<_st>(i+2)].set(cos(theta) * argRadius, sin(theta) * argRadius, 0.0);
 	}
 
 	IFArray.clear();
@@ -1213,11 +1225,10 @@ void fk_Modify::makeCone(int argDiv, double argRadius, double argHeight)
 
 void fk_Modify::setConeDivide(int argDiv)
 {
-	int		div;
 	double	rad, height;
 
 	if(checkDB() == false) return;
-	if((div = getVNum()-2) < 3) return;
+	if(getVNum() < 5) return;
 
 	rad = getVData(3)->getPosition().x;
 	height = -(getVData(2)->getPosition().z);
@@ -1236,7 +1247,7 @@ void fk_Modify::setConeRadius(double argRadius)
 	div = getVNum()-2;
 	for(i = 0; i < div; i++) {
 		v = getVData(i+3);
-		theta = (double(i*2) * FK_PI)/double(div);
+		theta = (static_cast<double>(i*2) * FK_PI)/static_cast<double>(div);
 		pos.set(cos(theta) * argRadius, sin(theta) * argRadius, 0.0);
 		moveVertex(v, pos);
 	}
