@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -70,6 +70,7 @@
  *
  ****************************************************************************/
 #define __FK_OPERATION_CODE__
+#define FK_DEF_SIZETYPE
 #include <FK/Operation.h>
 #include <FK/Vertex.h>
 #include <FK/Half.h>
@@ -97,12 +98,12 @@ fk_Operation::~fk_Operation()
 
 void fk_Operation::UndefVNorm(fk_Vertex *argV)
 {
-	register unsigned int	i, j;
+	register _st			i, j;
 	vector<fk_Loop *>		LoopArray;
 	vector<fk_Vertex *>		VertexArray;
 
 
-	if(argV == (fk_Vertex *)NULL) return;
+	if(argV == NULL) return;
 	LoopArray = getAllLOnV(argV);
 
 	for(i = 0; i < LoopArray.size(); i++) {
@@ -125,16 +126,16 @@ fk_Loop * fk_Operation::SetLoop(fk_Half *argH, bool nullFlg,
 	unsigned int		i;
 
 
-	if(checkDB() == false) return (fk_Loop *)NULL;
+	if(checkDB() == false) return NULL;
 
-	if(nullFlg == true && argH->getParentLoop() != (fk_Loop *)NULL) {
+	if(nullFlg == true && argH->getParentLoop() != NULL) {
 		fk_PutError("fk_Operation", "SetLoop", 1,
 					"Loop Definition Error.");
-		return (fk_Loop *)NULL;
+		return NULL;
 	}
 
 	loopH = argH->getNextHalf();
-	if(nullFlg == false && argL != (fk_Loop *)NULL) {
+	if(nullFlg == false && argL != NULL) {
 		newL = argL;
 	} else {
 		newL = (argLID == FK_UNDEFINED) ?
@@ -145,14 +146,14 @@ fk_Loop * fk_Operation::SetLoop(fk_Half *argH, bool nullFlg,
 	while(loopH != argH) {
 		mateH = getMateHOnH(loopH);
 		if(nullFlg == true &&
-		   loopH->getParentLoop() != (fk_Loop *)NULL) {
+		   loopH->getParentLoop() != NULL) {
 			for(i = 0; i < halfStack.size(); i++) {
 				halfStack[i]->SetParentLoop(loopStack[i]);
 			}
 			DeleteLoopObj(newL);
 			fk_PutError("fk_Operation", "SetLoop", 2,
 						"Loop Definition Error.");
-			return (fk_Loop *)NULL;
+			return NULL;
 		}
 
 		if(mateH->getParentLoop() == newL) {
@@ -162,7 +163,7 @@ fk_Loop * fk_Operation::SetLoop(fk_Half *argH, bool nullFlg,
 			if(nullFlg == true) {
 				DeleteLoopObj(newL);
 			}
-			return (fk_Loop *)NULL;
+			return NULL;
 		}
 
 		loopStack.push_back(loopH->getParentLoop());
@@ -178,7 +179,7 @@ fk_Loop * fk_Operation::SetLoop(fk_Half *argH, bool nullFlg,
 			}
 			fk_PutError("fk_Operation", "SetLoop", 3,
 						"Half Edge Connection Error.");
-			return (fk_Loop *)NULL;
+			return NULL;
 		}
 		loopH = nextH;
 	}
@@ -200,7 +201,7 @@ fk_Vertex * fk_Operation::MakeVertex(const fk_Vector argPos, int argID)
 {
 	fk_Vertex *newV;
 
-	if(checkDB() == false) return (fk_Vertex *)NULL;
+	if(checkDB() == false) return NULL;
 
 	if(argID == FK_UNDEFINED) {
 		newV = GetNewVertexObj();
@@ -208,7 +209,7 @@ fk_Vertex * fk_Operation::MakeVertex(const fk_Vector argPos, int argID)
 		newV = GetNewVertexObj(argID);
 	}
 
-	if(newV == (fk_Vertex *)NULL) return (fk_Vertex *)NULL;
+	if(newV == NULL) return NULL;
 
 	newV->SetPosition(argPos);
 
@@ -233,8 +234,8 @@ bool fk_Operation::DeleteVertex(fk_Vertex *argV)
 	fk_Vector	pos;
 
 	if(checkDB() == false) return false;
-	if(argV == (fk_Vertex *)NULL) return false;
-	if(argV->getOneHalf() != (fk_Half *)NULL) {
+	if(argV == NULL) return false;
+	if(argV->getOneHalf() != NULL) {
 		fk_PutError("fk_Operation", "DeleteVertex", 1,
 					"Vertex Connection Error.");
 		return false;
@@ -269,7 +270,7 @@ bool fk_Operation::MoveVertex(fk_Vertex *argV, fk_Vector argVec)
 	vector<fk_Loop *>::iterator		lIterator;
 	fk_Vector						orgPos;
 
-	if(argV == (fk_Vertex *)NULL) return false;
+	if(argV == NULL) return false;
 
 	if(historyMode == true) {
 		orgPos = argV->getPosition();
@@ -279,7 +280,7 @@ bool fk_Operation::MoveVertex(fk_Vertex *argV, fk_Vector argVec)
 	LoopSet = getAllLOnV(argV);
 
 	for(lIterator = LoopSet.begin();
-		lIterator != LoopSet.end(); lIterator++) {
+		lIterator != LoopSet.end(); ++lIterator) {
 		(*lIterator)->ModifyLoop();
 	}
 	UndefVNorm(argV);
@@ -301,18 +302,18 @@ fk_Edge * fk_Operation::makeEdge(fk_Vertex *argV1, fk_Vertex *argV2,
 {
 	fk_Edge			*newE;
 
-	newE = (fk_Edge *)NULL;
-	if(checkDB() == false) return (fk_Edge *)NULL;
+	newE = NULL;
+	if(checkDB() == false) return NULL;
 
-	if(argV1 == (fk_Vertex *)NULL || argV2 == (fk_Vertex *)NULL) {
-		return (fk_Edge *)NULL;
+	if(argV1 == NULL || argV2 == NULL) {
+		return NULL;
 	}
 
-	if(argH1_1 == (fk_Half *)NULL && argH1_2 == (fk_Half *)NULL &&
-	   argH2_1 == (fk_Half *)NULL && argH2_2 == (fk_Half *)NULL) {
+	if(argH1_1 == NULL && argH1_2 == NULL &&
+	   argH2_1 == NULL && argH2_2 == NULL) {
 		newE = MakeEdge1(argV1, argV2);
 
-	} else if(argH2_1 == (fk_Half *)NULL && argH2_2 == (fk_Half *)NULL) {
+	} else if(argH2_1 == NULL && argH2_2 == NULL) {
 		newE = MakeEdge2(argV1, argV2, argH1_1, argH1_2, true, false);
 	} else {
 		newE = MakeEdge3(argV1, argV2, argH1_1, argH1_2, argH2_1, argH2_2,
@@ -329,11 +330,10 @@ fk_Edge * fk_Operation::MakeEdge1(fk_Vertex *argV1, fk_Vertex *argV2,
 	fk_Half			*newH1, *newH2;
 
 	// 両方が独立頂点かどうかのチェック 
-	if(argV1->getOneHalf() != (fk_Half *)NULL ||
-	   argV2->getOneHalf() != (fk_Half *)NULL) {
+	if(argV1->getOneHalf() != NULL || argV2->getOneHalf() != NULL) {
 		fk_PutError("fk_Operation", "MakeEdge1", 1,
 					"Vertex Topology Error.");
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
 	// 新要素の生成 
@@ -383,18 +383,18 @@ fk_Edge * fk_Operation::MakeEdge2(fk_Vertex *argV1, fk_Vertex *argV2,
 	fk_Half			*newH1, *newH2;
 
 	// v1 が接続頂点、v2 が独立頂点になっているかどうかのチェック 
-	if(argV1->getOneHalf() == (fk_Half *)NULL ||
-	   argV2->getOneHalf() != (fk_Half *)NULL) {
+	if(argV1->getOneHalf() == NULL ||
+	   argV2->getOneHalf() != NULL) {
 		fk_PutError("fk_Operation", "MakeEdge2", 1,
 					"Vertex Topology Error.");
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
 	// 半稜線の NULL ポインタチェック 
-	if(argH1 == (fk_Half *)NULL || argH2 == (fk_Half *)NULL) {
+	if(argH1 == NULL || argH2 == NULL) {
 		fk_PutError("fk_Operation", "MakeEdge2", 2,
 					"Half Edge Null Pointer Error.");
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
 	// v1, h1, h2 の接続関係のチェック 
@@ -402,15 +402,15 @@ fk_Edge * fk_Operation::MakeEdge2(fk_Vertex *argV1, fk_Vertex *argV2,
 	   argH2->getVertex() != argV1) {
 		fk_PutError("fk_Operation", "MakeEdge2", 3,
 					"Half Edge Topology Error.");
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
 	// h1, h2 が未定義半稜線かどうかのチェック 
-	if(argH1->getParentLoop() != (fk_Loop *)NULL ||
-	   argH2->getParentLoop() != (fk_Loop *)NULL) {
+	if(argH1->getParentLoop() != NULL ||
+	   argH2->getParentLoop() != NULL) {
 		fk_PutError("fk_Operation", "MakeEdge2", 4,
 					"Half Edge Has Loop Error.");
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
 	// 新要素の生成 
@@ -477,19 +477,19 @@ fk_Edge * fk_Operation::MakeEdge3(fk_Vertex *argV1, fk_Vertex *argV2,
 	fk_Half		*newH1, *newH2;
 
 	// v1, v2 が接続頂点かどうかのチェック 
-	if(argV1->getOneHalf() == (fk_Half *)NULL ||
-	   argV2->getOneHalf() == (fk_Half *)NULL) {
+	if(argV1->getOneHalf() == NULL ||
+	   argV2->getOneHalf() == NULL) {
 		fk_PutError("fk_Operation", "MakeEdge3", 1,
 					"Vertex Topology Error.");
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
 	// 半稜線の NULL ポインタチェック 
-	if(argH1_1 == (fk_Half *)NULL || argH1_2 == (fk_Half *)NULL ||
-	   argH2_1 == (fk_Half *)NULL || argH2_2 == (fk_Half *)NULL) {
+	if(argH1_1 == NULL || argH1_2 == NULL ||
+	   argH2_1 == NULL || argH2_2 == NULL) {
 		fk_PutError("fk_Operation", "MakeEdge3", 2,
 					"Half Edge Null Pointer Error.");
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
 	// v1,v2 まわりの位相チェック 
@@ -501,17 +501,17 @@ fk_Edge * fk_Operation::MakeEdge3(fk_Vertex *argV1, fk_Vertex *argV2,
 	   argH2_2->getVertex() != argV2) {
 		fk_PutError("fk_Operation", "MakeEdge3", 3,
 					"Half Edge Topology Error.");
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
 	// 全半稜線が未定義半稜線かどうかのチェック 
-	if(argH1_1->getParentLoop() != (fk_Loop *)NULL ||
-	   argH1_2->getParentLoop() != (fk_Loop *)NULL ||
-	   argH2_1->getParentLoop() != (fk_Loop *)NULL ||
-	   argH2_2->getParentLoop() != (fk_Loop *)NULL) {
+	if(argH1_1->getParentLoop() != NULL ||
+	   argH1_2->getParentLoop() != NULL ||
+	   argH2_1->getParentLoop() != NULL ||
+	   argH2_2->getParentLoop() != NULL) {
 		fk_PutError("fk_Operation", "MakeEdge3", 4,
 					"Half Edge Has Loop Error.");
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
 	// 新要素の生成 
@@ -600,15 +600,15 @@ bool fk_Operation::DeleteEdge1(fk_Edge *argE)
 {
 	fk_Vertex		*lV, *rV;
 	fk_Half			*lH, *rH;
-	int				eID, lHID, rHID, lVID, rVID;
+	int				eID, lHID, rHID;
 
 	lH = argE->getLeftHalf();
 	rH = argE->getRightHalf();
 	lV = lH->getVertex();
 	rV = rH->getVertex();
 
-	lV->SetOneHalf((fk_Half *)NULL);
-	rV->SetOneHalf((fk_Half *)NULL);
+	lV->SetOneHalf(NULL);
+	rV->SetOneHalf(NULL);
 
 	eID = argE->getID();
 	lHID = lH->getID();
@@ -622,8 +622,8 @@ bool fk_Operation::DeleteEdge1(fk_Edge *argE)
 	}
 
 	if(historyMode == true) {
-		lVID = lV->getID();
-		rVID = rV->getID();
+		int lVID = lV->getID();
+		int rVID = rV->getID();
 
 		history.Open(DELE1);
 		history.PushInt(lVID);
@@ -642,7 +642,7 @@ bool fk_Operation::DeleteEdge2(fk_Half *argH)
 	fk_Edge			*delE;
 	fk_Half			*mateH, *prevH, *nextH;
 	fk_Vertex		*conV, *aloneV;
-	int				eID, argHID, mateHID, prevHID, nextHID, conVID, aloneVID;
+	int				eID, argHID, mateHID;
 	bool			lrFlag, v1ParentFlag;
 
 	delE = argH->getParentEdge();
@@ -658,7 +658,7 @@ bool fk_Operation::DeleteEdge2(fk_Half *argH)
 		lrFlag = false;
 	}
 
-	aloneV->SetOneHalf((fk_Half *)NULL);
+	aloneV->SetOneHalf(NULL);
 	prevH->SetNextHalf(nextH);
 	nextH->SetPrevHalf(prevH);
 	if(conV->getOneHalf() == argH) {
@@ -681,10 +681,8 @@ bool fk_Operation::DeleteEdge2(fk_Half *argH)
 	}
 
 	if(historyMode == true) {
-		prevHID = prevH->getID();
-		nextHID = nextH->getID();
-		conVID = conV->getID();
-		aloneVID = aloneV->getID();
+		int prevHID = prevH->getID();
+		int aloneVID = aloneV->getID();
 
 		history.Open(DELE2);
 		history.PushInt(aloneVID);
@@ -704,7 +702,7 @@ bool fk_Operation::DeleteEdge3(fk_Edge *argE)
 {
 	fk_Vertex	*lV, *rV;
 	fk_Half		*lH, *rH, *lPrevH, *lNextH, *rPrevH, *rNextH;
-	int			eID, lVID, rVID, lHID, rHID, lPHID, lNHID, rPHID, rNHID;
+	int			eID, lHID, rHID, lPHID, rPHID;
 	bool		lVParentFlag, rVParentFlag;
 
 	lH = argE->getLeftHalf();
@@ -717,14 +715,10 @@ bool fk_Operation::DeleteEdge3(fk_Edge *argE)
 	rNextH = lH->getNextHalf();
 
 	eID = argE->getID();
-	lVID = lV->getID();
-	rVID = rV->getID();
 	lHID = lH->getID();
 	rHID = rH->getID();
 	lPHID = lPrevH->getID();
-	lNHID = lNextH->getID();
 	rPHID = rPrevH->getID();
-	rNHID = rNextH->getID();
 
 	// lV まわり設定 
 	lPrevH->SetNextHalf(lNextH);
@@ -779,9 +773,8 @@ fk_Loop * fk_Operation::MakeLoop(fk_Half *argH, int argLID)
 	fk_Loop		*newL;
 	fk_Half		*loopH;
 
-	if((newL = SetLoop(argH, true, (fk_Loop *)NULL, argLID))
-                                        == (fk_Loop *)NULL) {
-		return (fk_Loop *)NULL;
+	if((newL = SetLoop(argH, true, NULL, argLID)) == NULL) {
+		return NULL;
 	}
 
 	loopH = argH;
@@ -810,7 +803,7 @@ bool fk_Operation::DeleteLoop(fk_Loop *argL)
 	fk_Half	*loopH, *oneH;
 	int		loopID;
 
-	if(checkDB() == false) return (fk_Loop *)NULL;
+	if(checkDB() == false) return false;
 
 	oneH = argL->getOneHalf();
 	loopH = oneH->getNextHalf();
@@ -822,7 +815,7 @@ bool fk_Operation::DeleteLoop(fk_Loop *argL)
 			return false;
 		}
 
-		loopH->SetParentLoop((fk_Loop *)NULL);
+		loopH->SetParentLoop(NULL);
 		loopH->getVertex()->UndefNormal();
 		loopH = loopH->getNextHalf();
 	}
@@ -832,7 +825,7 @@ bool fk_Operation::DeleteLoop(fk_Loop *argL)
 					"Parent Loop Error.");
 		return false;
 	} else {
-		oneH->SetParentLoop((fk_Loop *)NULL);
+		oneH->SetParentLoop(NULL);
 	}
 
 	loopID = argL->getID();
@@ -854,7 +847,7 @@ bool fk_Operation::DeleteLoop(fk_Loop *argL)
 
 fk_Edge * fk_Operation::separateLoop(fk_Half *argPrevH, fk_Half *argNextH)
 {
-	return SeparateLoop(argPrevH, argNextH, (fk_Half *)NULL, (fk_Half *)NULL,
+	return SeparateLoop(argPrevH, argNextH, NULL, NULL,
 						false, false);
 }
 
@@ -869,25 +862,28 @@ fk_Edge * fk_Operation::SeparateLoop(fk_Half *argPrevH, fk_Half *argNextH,
 	fk_Edge		*newE;
 	fk_Half		*oldNextH, *oldPrevH;
 	fk_Vertex	*lV, *rV;
+	/*
 	int			pHID, nHID, newLID, newEID, newLHID, newRHID;
 	int			lLOneHID, rLOneHID, uniRLOneHID;
+	*/
+	int			uniRLOneHID;
 
-	if(checkDB() == false) return (fk_Edge *)NULL;
+	if(checkDB() == false) return NULL;
 
 	curL = argPrevH->getParentLoop();
 
 	// argPrevH と argNextH が異なるループに属す場合のエラー処理 
-	if(curL == (fk_Loop *)NULL || curL != argNextH->getParentLoop()) {
+	if(curL == NULL || curL != argNextH->getParentLoop()) {
 		fk_PutError("fk_Operation", "separateLoop", 1,
 					"Illegal Loop Error.");
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
 	// argPrevH の次の半稜線が argNextH だった場合のエラー処理 
 	if(argPrevH->getNextHalf() == argNextH) {
 		fk_PutError("fk_Operation", "separateLoop", 2,
 					"Illegal Connection Error.");
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
 	oldNextH = argPrevH->getNextHalf();
@@ -936,7 +932,7 @@ fk_Edge * fk_Operation::SeparateLoop(fk_Half *argPrevH, fk_Half *argNextH,
 
 	// 旧ループが保持する半稜線情報を再設定 
 	uniRLOneHID = curL->getOneHalf()->getID();
-	if(rLOneH == (fk_Half *)NULL) {
+	if(rLOneH == NULL) {
 		curL->SetOneHalf(newRH);
 	} else {
 		curL->SetOneHalf(rLOneH);
@@ -945,14 +941,13 @@ fk_Edge * fk_Operation::SeparateLoop(fk_Half *argPrevH, fk_Half *argNextH,
 	curL->ModifyLoop();
 
 	// 新ループ側の半稜線へ、ループ情報を設定 
-	if((newL = SetLoop(newLH, false, (fk_Loop *)NULL, argLID))
-	   == (fk_Loop *)NULL) {
+	if((newL = SetLoop(newLH, false, NULL, argLID)) == NULL) {
 		fk_PutError("fk_Operation", "separateLoop", 3,
 					"Set Loop Error.");
-		return (fk_Edge *)NULL;
+		return NULL;
 	}
 
-	if(lLOneH != (fk_Half *)NULL) {
+	if(lLOneH != NULL) {
 		newL->SetOneHalf(lLOneH);
 	}
 
@@ -960,23 +955,14 @@ fk_Edge * fk_Operation::SeparateLoop(fk_Half *argPrevH, fk_Half *argNextH,
 	UndefVNorm(rV);
 
 	if(historyMode == true) {
-		pHID = argPrevH->getID();
-		nHID = argNextH->getID();
-		newLID = newL->getID();
-		newEID = newE->getID();
-		newLHID = newLH->getID();
-		newRHID = newRH->getID();
-
-		if(lLOneH != (fk_Half *)NULL) {
-			lLOneHID = lLOneH->getID();
-		} else {
-			lLOneHID = FK_UNDEFINED;
-		}
-		if(rLOneH != (fk_Half *)NULL) {
-			rLOneHID = rLOneH->getID();
-		} else {
-			rLOneHID = FK_UNDEFINED;
-		}
+		int pHID = argPrevH->getID();
+		int nHID = argNextH->getID();
+		int newLID = newL->getID();
+		int newEID = newE->getID();
+		int newLHID = newLH->getID();
+		int newRHID = newRH->getID();
+		int lLOneHID = (lLOneH != NULL) ? lLOneH->getID() : FK_UNDEFINED;
+		int rLOneHID = (rLOneH != NULL) ? rLOneH->getID() : FK_UNDEFINED;
 
 		history.Open(SEPL);
 		history.PushInt(pHID);
@@ -999,7 +985,7 @@ fk_Edge * fk_Operation::SeparateLoop(fk_Half *argPrevH, fk_Half *argNextH,
 
 bool fk_Operation::uniteLoop(fk_Edge *argE)
 {
-	return UniteLoop(argE, (fk_Half *)NULL);
+	return UniteLoop(argE, NULL);
 }
 
 bool fk_Operation::UniteLoop(fk_Edge *argE, fk_Half *argNewRL1H)
@@ -1019,7 +1005,7 @@ bool fk_Operation::UniteLoop(fk_Edge *argE, fk_Half *argNewRL1H)
 	lL = lH->getParentLoop();
 	rL = rH->getParentLoop();
 
-	if(lL == (fk_Loop *)NULL || rL == (fk_Loop *)NULL) {
+	if(lL == NULL || rL == NULL) {
 		fk_PutError("fk_Operation", "uniteLoop", 1,
 					"No BothDefEdge Error.");
 		return false;
@@ -1082,7 +1068,7 @@ bool fk_Operation::UniteLoop(fk_Edge *argE, fk_Half *argNewRL1H)
 		SetLoop(rL->getOneHalf(), false, rL);
 	}
 
-	if(argNewRL1H != (fk_Half *)NULL) {
+	if(argNewRL1H != NULL) {
 		rL->SetOneHalf(argNewRL1H);
 		uniRLOneHID = argNewRL1H->getID();
 	} else {
@@ -1120,7 +1106,7 @@ bool fk_Operation::UniteLoop(fk_Edge *argE, fk_Half *argNewRL1H)
 
 fk_Vertex * fk_Operation::separateEdge(fk_Edge *argE)
 {
-	return SeparateEdge(argE, false, false, false, false, (fk_Vector *)NULL);
+	return SeparateEdge(argE, false, false, false, false, NULL);
 }
 
 fk_Vertex * fk_Operation::SeparateEdge(fk_Edge *argE, bool argOrgEFlag,
@@ -1137,7 +1123,7 @@ fk_Vertex * fk_Operation::SeparateEdge(fk_Edge *argE, bool argOrgEFlag,
 	fk_Vertex	*v1, *v2, *newV;		// argE の両端点と新頂点 
 	fk_Loop		*l1, *l2;				// argE の属するループ 
 
-	if(checkDB() == false) return (fk_Vertex *)NULL;
+	if(checkDB() == false) return NULL;
 
 	// 各データの取得 
 	if(argOrgEFlag == true) {
@@ -1198,7 +1184,7 @@ fk_Vertex * fk_Operation::SeparateEdge(fk_Edge *argE, bool argOrgEFlag,
 	orgH1->SetVertex(newV);
 
 	// 新頂点情報の設定 
-	if(argPos != (fk_Vector *)NULL) {
+	if(argPos != NULL) {
 		newV->SetPosition(*argPos);
 	} else {
 		newV->SetPosition((v1->getPosition() + v2->getPosition())/2.0);
@@ -1210,16 +1196,16 @@ fk_Vertex * fk_Operation::SeparateEdge(fk_Edge *argE, bool argOrgEFlag,
 	v1->UndefNormal();
 	v2->UndefNormal();
 
-	if(argL1PFlag == true && l1 != (fk_Loop *)NULL) {
+	if(argL1PFlag == true && l1 != NULL) {
 		l1->SetOneHalf(newH1);
 	}
 
-	if(argL2PFlag == true && l2 != (fk_Loop *)NULL) {
+	if(argL2PFlag == true && l2 != NULL) {
 		l2->SetOneHalf(newH2);
 	}
 
-	if(l1 != (fk_Loop *)NULL) l1->ModifyLoop();
-	if(l2 != (fk_Loop *)NULL) l2->ModifyLoop();
+	if(l1 != NULL) l1->ModifyLoop();
+	if(l2 != NULL) l2->ModifyLoop();
 
 	if(historyMode == true) {
 		history.Open(SEPE);
@@ -1358,11 +1344,11 @@ void fk_Operation::NegateBody(void)
 	vector<fk_Half *>	rNext, rPrev, lNext, lPrev;
 	fk_Edge				*curE;
 	fk_Loop				*curL;
-	int					i;
+	_st					i;
 
 	if(checkDB() == false) return;
-	for(curE = getNextE((fk_Edge *)NULL);
-		curE != (fk_Edge *)NULL;
+	for(curE = getNextE(NULL);
+		curE != NULL;
 		curE = getNextE(curE)) {
 		rNext.push_back(getMateHOnH(curE->getLeftHalf()->getPrevHalf()));
 		rPrev.push_back(getMateHOnH(curE->getLeftHalf()->getNextHalf()));
@@ -1371,8 +1357,8 @@ void fk_Operation::NegateBody(void)
 	}
 
 	i = 0;
-	for(curE = getNextE((fk_Edge *)NULL);
-		curE != (fk_Edge *)NULL;
+	for(curE = getNextE(NULL);
+		curE != NULL;
 		curE = getNextE(curE)) {
 		curE->getRightHalf()->SetNextHalf(rNext[i]);
 		curE->getRightHalf()->SetPrevHalf(rPrev[i]);
@@ -1381,8 +1367,8 @@ void fk_Operation::NegateBody(void)
 		i++;
 	}
 
-	for(curL = getNextL((fk_Loop *)NULL);
-		curL != (fk_Loop *)NULL;
+	for(curL = getNextL(NULL);
+		curL != NULL;
 		curL = getNextL(curL)) {
 		curL->SetOneHalf(getMateHOnH(curL->getOneHalf()));
 	}
@@ -1545,9 +1531,9 @@ void fk_Operation::UndoCom(fk_Command *argCom)
 		tmpH1 = getHData(history.GetInt(intI));
 		tmpH2 = getHData(history.GetInt(intI+1));
 		tmpH3 = (history.GetInt(intI+6) != FK_UNDEFINED) ?
-			getHData(history.GetInt(intI+6)) : (fk_Half *)NULL;
+			getHData(history.GetInt(intI+6)) : NULL;
 		tmpH4 = (history.GetInt(intI+7) != FK_UNDEFINED) ?
-			getHData(history.GetInt(intI+7)) : (fk_Half *)NULL;
+			getHData(history.GetInt(intI+7)) : NULL;
 
 		SeparateLoop(tmpH1, tmpH2, tmpH3, tmpH4,
 					 history.GetBool(boolI),
@@ -1672,9 +1658,9 @@ void fk_Operation::RedoCom(fk_Command *argCom)
 		tmpH1 = getHData(history.GetInt(intI));
 		tmpH2 = getHData(history.GetInt(intI+1));
 		tmpH3 = (history.GetInt(intI+6) != FK_UNDEFINED) ?
-			getHData(history.GetInt(intI+6)) : (fk_Half *)NULL;
+			getHData(history.GetInt(intI+6)) : NULL;
 		tmpH4 = (history.GetInt(intI+7) != FK_UNDEFINED) ?
-			getHData(history.GetInt(intI+7)) : (fk_Half *)NULL;
+			getHData(history.GetInt(intI+7)) : NULL;
 
 		SeparateLoop(tmpH1, tmpH2, tmpH3, tmpH4,
 					 history.GetBool(boolI),
