@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -69,6 +69,8 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+
+#define FK_DEF_SIZETYPE
 #include <FK/Palette.h>
 #include <FK/Error.H>
 
@@ -96,14 +98,6 @@ void fk_Palette::clearMaterial(void)
 	return;
 }
 
-/*
-void fk_Palette::setObjMaterial(fk_Material *argMaterial)
-{
-	thisMaterial = *argMaterial;
-	thisColorID = FK_UNDEFINED;
-}
-*/
-
 void fk_Palette::setObjMaterialID(int argID)
 {
 	thisColorID = argID;
@@ -120,16 +114,17 @@ void fk_Palette::setPalette(fk_Material *argMaterial,
 							int argMatID)
 {
 	fk_Material		Dummy;
+	_st				matID = static_cast<_st>(argMatID);
 
 	if(argMatID < 0) return;
-	if(argMatID < (int)paletteStack.size()) { // 既存パレットの上書き 
-		paletteStack[argMatID] = *argMaterial;
+	if(matID < paletteStack.size()) { // 既存パレットの上書き 
+		paletteStack[matID] = *argMaterial;
 
-	} else if(argMatID == (int)paletteStack.size()) { // 単純な追加 
+	} else if(matID == paletteStack.size()) { // 単純な追加 
 		paletteStack.push_back(*argMaterial);
 
 	} else { // パレットのサイズよりも大きな ID が指定された場合 
-		for(int i = paletteStack.size(); i < argMatID; i++) {
+		for(_st i = paletteStack.size(); i < matID; i++) {
 			paletteStack.push_back(Dummy);
 		}
 		paletteStack.push_back(*argMaterial);
@@ -138,13 +133,6 @@ void fk_Palette::setPalette(fk_Material *argMaterial,
 	return;
 }
 
-/*
-fk_Material * fk_Palette::getObjMaterial(void)
-{
-	return &thisMaterial;
-}
-*/
-
 int fk_Palette::getObjMaterialID(void)
 {
 	return thisColorID;
@@ -152,13 +140,13 @@ int fk_Palette::getObjMaterialID(void)
 
 int fk_Palette::getPaletteSize(void)
 {
-	return paletteStack.size();
+	return static_cast<int>(paletteStack.size());
 }
 
 fk_Material * fk_Palette::getMaterial(int argID)
 {
-	if(argID < 0 || argID >= int(paletteStack.size())) return &dummyMat;
-	return &paletteStack[argID];
+	if(argID < 0 || argID >= static_cast<int>(paletteStack.size())) return &dummyMat;
+	return &paletteStack[static_cast<_st>(argID)];
 }
 
 vector<fk_Material> * fk_Palette::getMaterialVector(void)
@@ -168,17 +156,17 @@ vector<fk_Material> * fk_Palette::getMaterialVector(void)
 
 void fk_Palette::Resize(int argSize)
 {
-	paletteStack.resize(argSize);
+	paletteStack.resize(static_cast<_st>(argSize));
 	return;
 }
 
 void fk_Palette::Print(int argTabSize, string argTag)
 {
 	string		tab;
-	int			i;
+	_st			i;
 
 	tab.erase();
-	for(i = 0; i < argTabSize; i++) tab += '\t';
+	for(i = 0; i < static_cast<_st>(argTabSize); i++) tab += '\t';
 
 	if(argTag.size() == 0) {
 		fk_PutError(tab + "MatAdmin {");
@@ -187,8 +175,7 @@ void fk_Palette::Print(int argTabSize, string argTag)
 	}
 
 	fk_PutError(tab + fk_StrPrintf("\tthisColorID = %d;", thisColorID));
-	//thisMaterial.Print(argTabSize + 1, "THISMAT");
-	for(i = 0; i < (int)paletteStack.size(); i++) {
+	for(i = 0; i < paletteStack.size(); i++) {
 		paletteStack[i].Print(argTabSize + 1, fk_StrPrintf("PAL%d", i));
 	}
 	fk_PutError(tab + "\tColID = {");
