@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -197,11 +197,11 @@ void fk_PointDraw::DrawSolidPointPick(fk_Model *argObj)
 	glDisableClientState(GL_VERTEX_ARRAY);
 
 	if(reverseFlag == false) {
-		for(ite = vertexStack->begin(); ite != vertexStack->end(); ite++) {
+		for(ite = vertexStack->begin(); ite != vertexStack->end(); ++ite) {
 			DrawSolidPointPickElem(*ite);
 		}
 	} else {
-		for(rite = vertexStack->rbegin(); rite != vertexStack->rend(); rite++) {
+		for(rite = vertexStack->rbegin(); rite != vertexStack->rend(); ++rite) {
 			DrawSolidPointPickElem(*rite);
 		}
 	}
@@ -334,14 +334,14 @@ void fk_PointDraw::DrawSolidPointMaterial(fk_Model *argObj)
 	matV = solidP->getMaterialVector();
 
 	if(reverseFlag == false) {
-		for(ite = vertexStack->begin(); ite != vertexStack->end(); ite++) {
+		for(ite = vertexStack->begin(); ite != vertexStack->end(); ++ite) {
 			oldMateID = DrawSolidPointMaterialElem(*ite, oldMateID,
 												   paletteSize, orgSize,
 												   matV, modelColor);
 		}
 	} else {
 		for(rite = vertexStack->rbegin();
-			rite != vertexStack->rend(); rite++) {
+			rite != vertexStack->rend(); ++rite) {
 			oldMateID = DrawSolidPointMaterialElem(*rite, oldMateID,
 												   paletteSize, orgSize,
 												   matV, modelColor);
@@ -359,7 +359,7 @@ int fk_PointDraw::DrawSolidPointMaterialElem(fk_Vertex *argV,
 											 fk_Color *argModelColor)
 {
 	int			curMateID, retMateID;
-	double		trueSize;
+	// double		trueSize;
 	fk_Color	*curColor;
 
 	POINTCUSTOMVERTEX	tmpVertex;
@@ -391,8 +391,8 @@ int fk_PointDraw::DrawSolidPointMaterialElem(fk_Vertex *argV,
 		}
 	}
 
-	trueSize = argV->getDrawSize();
 	/*
+	trueSize = argV->getDrawSize();
 	if(trueSize < 0.0) {
 		glPointSize((GLfloat)argOrgSize);
 	} else {
@@ -462,9 +462,9 @@ void fk_PointDraw::DrawParticlePointMaterial(fk_Model *argObj)
 		}
 		id = point->vec.next(id);
 	}
-	if(workVertexArray.size() == 0) return;
+	if(workVertexArray.empty()) return;
 	ref_lpD3DDEV->SetFVF(D3DFVF_POINTCUSTOMVERTEX);
-	ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_POINTLIST, workVertexArray.size(), &(workVertexArray[0]), sizeof(POINTCUSTOMVERTEX));
+	ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_POINTLIST, static_cast<UINT>(workVertexArray.size()), &(workVertexArray[0]), sizeof(POINTCUSTOMVERTEX));
 
 	return;
 }
@@ -534,11 +534,11 @@ void fk_PointDraw::DrawSolidPointNormal(fk_Model *argObj, bool argFlg)
 	orgSize = argObj->getSize();
 
 	if(reverseFlag == false) {
-		for(ite = vertexStack->begin(); ite != vertexStack->end(); ite++) {
+		for(ite = vertexStack->begin(); ite != vertexStack->end(); ++ite) {
 			DrawSolidPointNormalElem(*ite, orgSize, packedCol);
 		}
 	} else {
-		for(rite = vertexStack->rbegin(); rite != vertexStack->rend(); rite++) {
+		for(rite = vertexStack->rbegin(); rite != vertexStack->rend(); ++rite) {
 			DrawSolidPointNormalElem(*rite, orgSize, packedCol);
 		}
 	}
@@ -548,11 +548,11 @@ void fk_PointDraw::DrawSolidPointNormal(fk_Model *argObj, bool argFlg)
 
 void fk_PointDraw::DrawSolidPointNormalElem(fk_Vertex *argV, double argOrgSize, DWORD argPackedColor)
 {
-	double trueSize;
+	// double trueSize;
 	POINTCUSTOMVERTEX	tmpVertex;
 
-	trueSize = argV->getDrawSize();
 	/*
+	trueSize = argV->getDrawSize();
 	if(trueSize < 0.0) {
 		glPointSize((GLfloat)argOrgSize);
 	} else {
@@ -596,7 +596,7 @@ void fk_PointDraw::DrawIFSPointNormal(fk_Model *argObj, bool argFlag)
 		tmpVertex.color = packedCol;
 		workVertexArray.push_back(tmpVertex);
 	}
-	if(workVertexArray.size() == 0) return;
+	if(workVertexArray.empty()) return;
 	ref_lpD3DDEV->SetFVF(D3DFVF_POINTCUSTOMVERTEX);
 	ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_POINTLIST, ifsetP->posSize, &(workVertexArray[0]), sizeof(POINTCUSTOMVERTEX));
 
@@ -638,9 +638,9 @@ void fk_PointDraw::DrawParticlePointNormal(fk_Model *argObj, bool argFlag)
 		}
 		id = point->vec.next(id);
 	}
-	if(workVertexArray.size() == 0) return;
+	if(workVertexArray.empty()) return;
 	ref_lpD3DDEV->SetFVF(D3DFVF_POINTCUSTOMVERTEX);
-	ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_POINTLIST, workVertexArray.size(), &(workVertexArray[0]), sizeof(POINTCUSTOMVERTEX));
+	ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_POINTLIST, static_cast<UINT>(workVertexArray.size()), &(workVertexArray[0]), sizeof(POINTCUSTOMVERTEX));
 
 	return;
 }
