@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -251,11 +251,12 @@ bool fk_Solid::readD3DXFile(string argFileName, string argObjName,
 {
 	fk_D3DXParser	*d3dxParser = new fk_D3DXParser();
 	bool			retFlg;
+	bool			animFlg;
 
 	d3dxParser->SetMeshData(this);
 	AllCacheClear();
 	retFlg = d3dxParser->ReadD3DXFile(argFileName, argObjName,
-									  argTexID, argSolidFlg);
+									  argTexID, argSolidFlg, &animFlg);
 	delete d3dxParser;
 	return retFlg;
 }
