@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -31,12 +31,12 @@
  *	HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
  *	STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
  *	IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- *	POSSIBILITY OF SUCH DAMAGE. 
+ *	POSSIBILITY OF SUCH DAMAGE.
  *
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -69,13 +69,14 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+
+#define FK_DEF_SIZETYPE
+#include <map>
+#include <algorithm>
 #include <FK/TextImage.h>
 #include <FK/Error.H>
 #include <ft2build.h>
 
-#include <map>
-#include <algorithm>
-
 using namespace std;
 
 #include FT_FREETYPE_H
@@ -294,7 +295,7 @@ void fk_FTGlyph::Init(void)
 
 	return;
 }
-	
+
 fk_FontServer::fk_FontServer(void)
 {
 	FT_Init_FreeType(&library);
@@ -305,13 +306,13 @@ fk_FontServer::~fk_FontServer()
 {
 	map<string, FT_Face>::iterator	p;
 
-	for(p = faceArray.begin(); p != faceArray.end(); p++) {
+	for(p = faceArray.begin(); p != faceArray.end(); ++p) {
 		FT_Done_Face(p->second);
 	}
 	FT_Done_FreeType(library);
 	return;
 }
-	
+
 FT_Face fk_FontServer::GetFace(string argName)
 {
 	map<string, FT_Face>::iterator	p;
@@ -359,7 +360,7 @@ void fk_GlyphServer::Clear(void)
 	map<fk_GlyphStatus, fk_GlyphCache *>::iterator		p;
 	fk_GlyphCache										*tmpCache;
 
-	for(p = glyphArray.begin(); p != glyphArray.end(); p++) {
+	for(p = glyphArray.begin(); p != glyphArray.end(); ++p) {
 		tmpCache = p->second;
 		delete tmpCache->buffer;
 		delete tmpCache;
@@ -591,10 +592,10 @@ bool fk_TextImage::initFont(const string fontName)
 
 void fk_TextImage::FreeGlyph(vector<fk_FTGlyph *> *argGlyphArray)
 {
-	int				i;
+	_st				i;
 	fk_FTGlyph		*glyph;
 
-	for(i = 0; i < int(argGlyphArray->size()); i++) {
+	for(i = 0; i < argGlyphArray->size(); i++) {
 		glyph = (*argGlyphArray)[i];
 		glyph->Init();
 		delete glyph;
@@ -606,23 +607,24 @@ void fk_TextImage::FreeGlyph(vector<fk_FTGlyph *> *argGlyphArray)
 
 bool fk_TextImage::send(void)
 {
-	int		i, endPos;
+	_st		i, endPos, sp;
 
-	if(sendPos == int(charArray.size())) return false;
+	sp = static_cast<_st>(sendPos);
+	if(sp == charArray.size()) return false;
 
 	switch(sendingMode) {
 	  case FK_SENDING_ALL:
-		endPos = int(charArray.size());
+		endPos = charArray.size();
 		break;
 
 	  case FK_SENDING_CHAR:
-		endPos = sendPos + 1;
+		endPos = sp + 1;
 		break;
 
 	  case FK_SENDING_LINE:
 
-		for(i = sendPos + 1; i < int(charArray.size()); i++) {
-			if(lineMap[sendPos] != lineMap[i]) break;
+		for(i = sp + 1; i < charArray.size(); i++) {
+			if(lineMap[sp] != lineMap[i]) break;
 		}
 		endPos = i;
 		break;
@@ -631,10 +633,10 @@ bool fk_TextImage::send(void)
 		return false;
 	}
 
-	for(i = sendPos; i < endPos; i++) {
-		CopyCharImage(i);
+	for(i = sp; i < endPos; i++) {
+		CopyCharImage(static_cast<int>(i));
 	}
-	sendPos = endPos;
+	sendPos = static_cast<int>(endPos);
 
 	return true;
 }
@@ -643,7 +645,7 @@ bool fk_TextImage::finish(void)
 {
 	int		i, endPos;
 
-	endPos = int(charArray.size());
+	endPos = static_cast<int>(charArray.size());
 	if(sendPos == endPos) return false;
 
 	for(i = sendPos; i < endPos; i++) {
@@ -660,7 +662,7 @@ bool fk_TextImage::clear(void)
 	if(sendPos == 0) return false;
 	InitTextImage();
 	sendPos = 0;
-	if(charImages.size() == 0) loadUniStr(NULL);
+	if(charImages.empty() == true) loadUniStr(NULL);
 	return true;
 }
 
@@ -679,7 +681,7 @@ bool fk_TextImage::loadUniStr(fk_UniStr *argStr)
 {
 	fk_FTGlyph				*glyph;
 	vector<fk_FTGlyph *>	glyphArray;
-	unsigned int			i;
+	int						i;
 	int						upper, lineNum;
 	fk_UniStr				tmpStr, line;
 	int						fbScale[1024], sbScale[1024];
@@ -693,20 +695,22 @@ bool fk_TextImage::loadUniStr(fk_UniStr *argStr)
 	tmpStr.copyStr(&strData);
 
 	FreeGlyph(&glyphArray);
-	FT_Set_Char_Size(face->face, ptsize << 6, ptsize << 6, dpi, dpi);
+	FT_Set_Char_Size(face->face, ptsize << 6, ptsize << 6,
+					 static_cast<FT_UInt>(dpi),
+					 static_cast<FT_UInt>(dpi));
 
 	lineArray.clear();
 	lineMap.clear();
 	charArray.clear();
 	ClearCharImages();
-	
+
 	MakeColorScale(fgColor, bgColor, fbScale);
 	if(shadowMode == true) MakeColorScale(shadowColor, bgColor, sbScale);
 
 	for(lineNum = 0; tmpStr.getLine(&line); lineNum++) {
-		for(i = 0; int(i) < line.getLength(); i++) {
+		for(i = 0; i < line.getLength(); i++) {
 			glyph = new fk_FTGlyph;
-			glyph->status.Set(face->face, line.getCode(i),
+			glyph->status.Set(face->face, static_cast<FT_UInt>(line.getCode(i)),
 							  ptsize, dpi, boldStrength);
 			glyphArray.push_back(glyph);
 			lineMap.push_back(lineNum);
@@ -721,9 +725,9 @@ bool fk_TextImage::loadUniStr(fk_UniStr *argStr)
 	ReCalcCharOffset();
 	InitTextImage();
 	if(sendingMode == FK_SENDING_ALL) {
-		for(i = 0; i < charArray.size(); i++) CopyCharImage(i);
+		for(i = 0; i < static_cast<int>(charArray.size()); i++) CopyCharImage(i);
 		ClearCharImages();
-		sendPos = int(charArray.size());
+		sendPos = static_cast<int>(charArray.size());
 	} else {
 		sendPos = 0;
 	}
@@ -734,7 +738,7 @@ bool fk_TextImage::loadUniStr(fk_UniStr *argStr)
 
 void fk_TextImage::ClearCharImages(void)
 {
-	for(unsigned int i = 0; i < charImages.size(); i++) {
+	for(_st i = 0; i < charImages.size(); i++) {
 		delete charImages[i];
 	}
 
@@ -752,9 +756,9 @@ void fk_TextImage::MakeColorScale(const fk_Color &argC1,
 	for(i = 0; i < 256; i++) {
 		for(j = 0; j < 4; j++) {
 			index = i*4 + j;
-			val1 = argC1.col[j] * float(i)/255.0f;
-			val2 = argC2.col[j] * (1.0f - (float(i)/255.0f));
-			argScale[index] = int(256.0f*(val1 + val2));
+			val1 = argC1.col[j] * static_cast<float>(i)/255.0f;
+			val2 = argC2.col[j] * (1.0f - (static_cast<float>(i)/255.0f));
+			argScale[index] = static_cast<int>(256.0f*(val1 + val2));
 			if(argScale[index] >= 256) argScale[index] = 255;
 			if(argScale[index] < 0) argScale[index] = 0;
 		}
@@ -766,7 +770,7 @@ int fk_TextImage::LayoutGlyphs(vector<fk_FTGlyph *> *argGlyphArray)
 {
 	FT_Pos			image_w, image_h, oneImage_w, oneImage_h, upper, under;
 	FT_UInt			load_flags;
-	int				i, j;
+	_st				i, j;
 	FT_BBox			*pBBox;
 	FT_Glyph		glyph;
 	fk_FTGlyph		*fkGlyph;
@@ -784,7 +788,7 @@ int fk_TextImage::LayoutGlyphs(vector<fk_FTGlyph *> *argGlyphArray)
 	upper = 0;
 	under = 0;
 
-	for(i = 0; i < int(argGlyphArray->size()); i++) {
+	for(i = 0; i < argGlyphArray->size(); i++) {
 		fkGlyph = (*argGlyphArray)[i];
 
 		if(glyphServer.IsArive(fkGlyph->status) == false) {
@@ -824,9 +828,9 @@ int fk_TextImage::LayoutGlyphs(vector<fk_FTGlyph *> *argGlyphArray)
 			oneImage_h = pBBox->yMax - pBBox->yMin;
 
 			buffer = glyphServer.GetBuffer(fkGlyph->status);
-			buffer->resize(oneImage_w * oneImage_h);
+			buffer->resize(static_cast<_st>(oneImage_w * oneImage_h));
 
-			for(j = 0; j < oneImage_w * oneImage_h; j++) {
+			for(j = 0; j < static_cast<_st>(oneImage_w * oneImage_h); j++) {
 				(*buffer)[j] = slot->bitmap.buffer[j];
 			}
 			FT_Done_Glyph(glyph);
@@ -858,10 +862,10 @@ int fk_TextImage::LayoutGlyphs(vector<fk_FTGlyph *> *argGlyphArray)
 	image_h = upper - under;
 	if(shadowMode == true && image_h != 0) image_h += abs(shadowOffset.h);
 
-	lineRect.set(0, 0, image_w - charSkip, image_h);
+	lineRect.set(0, 0, static_cast<int>(image_w - charSkip), static_cast<int>(image_h));
 	lineArray.push_back(lineRect);
 
-	return upper;
+	return static_cast<int>(upper);
 }
 
 void fk_TextImage::DumpRasterMap(int argUpper,
@@ -869,25 +873,25 @@ void fk_TextImage::DumpRasterMap(int argUpper,
 								 int *argSBScale,
 								 vector<fk_FTGlyph *> *argGlyphArray)
 {
-	int				i, j, k;
+	_st				i, j, k;
 	fk_GlyphBuffer	*localImageBuf;
 	FT_BBox			*pBBox;
-	unsigned int	pixel, setVal;
+	_st				pixel, setVal;
 	fk_FTGlyph		*glyph;
 	fk_Rect			charRect;
 	fk_Image		*charImage;
 	fk_Dimension	orgImageSize;
 	fk_Dimension	posOffset;
 
-	for(i = 0; i < int(argGlyphArray->size()); i++) {
+	for(i = 0; i < argGlyphArray->size(); i++) {
 		glyph = (*argGlyphArray)[i];
 		pBBox = &(glyph->bbox);
 		localImageBuf = glyphServer.GetBuffer(glyph->status);
 
-		charRect.x = glyph->xOffset;
-		charRect.y = argUpper - pBBox->yMax;
-		orgImageSize.w = pBBox->xMax - pBBox->xMin;
-		orgImageSize.h = pBBox->yMax - pBBox->yMin;
+		charRect.x = static_cast<int>(glyph->xOffset);
+		charRect.y = static_cast<int>(argUpper - pBBox->yMax);
+		orgImageSize.w = static_cast<int>(pBBox->xMax - pBBox->xMin);
+		orgImageSize.h = static_cast<int>(pBBox->yMax - pBBox->yMin);
 
 		if(shadowMode == true) {
 			charRect.w = orgImageSize.w + abs(shadowOffset.w);
@@ -905,17 +909,17 @@ void fk_TextImage::DumpRasterMap(int argUpper,
 			posOffset.w = (shadowOffset.w < 0) ? 0 : shadowOffset.w;
 			posOffset.h = (shadowOffset.h < 0) ? 0 : shadowOffset.h;
 
-			for(j = 0; j < orgImageSize.h; j++) {
-				for(k = 0; k < orgImageSize.w; k++) {
-					pixel = localImageBuf->at(j * orgImageSize.w + k);
+			for(j = 0; j < static_cast<_st>(orgImageSize.h); j++) {
+				for(k = 0; k < static_cast<_st>(orgImageSize.w); k++) {
+					pixel = localImageBuf->at(j * static_cast<_st>(orgImageSize.w) + k);
 					if(smoothFlg == true) {
 						setVal = (pixel > 255) ? 255 : pixel;
 					} else {
 						setVal = (pixel > 128) ? 255 : 0;
 					}
 					if(setVal != 0) {
-						charImage->setRGBA(k + posOffset.w,
-										   j + posOffset.h,
+						charImage->setRGBA(static_cast<int>(k) + posOffset.w,
+										   static_cast<int>(j) + posOffset.h,
 										   argSBScale[setVal*4],
 										   argSBScale[setVal*4 + 1],
 										   argSBScale[setVal*4 + 2],
@@ -930,16 +934,17 @@ void fk_TextImage::DumpRasterMap(int argUpper,
 			posOffset.set(0, 0);
 		}
 
-		for(j = 0; j < orgImageSize.h; j++) {
-			for(k = 0; k < orgImageSize.w; k++) {
-				pixel = localImageBuf->at(j * orgImageSize.w + k);
+		for(j = 0; j < static_cast<_st>(orgImageSize.h); j++) {
+			for(k = 0; k < static_cast<_st>(orgImageSize.w); k++) {
+				pixel = localImageBuf->at(j * static_cast<_st>(orgImageSize.w) + k);
 				if(smoothFlg == true) {
 					setVal = (pixel > 255) ? 255 : pixel;
 				} else {
 					setVal = (pixel > 128) ? 255 : 0;
 				}
 				if(setVal != 0) {
-					charImage->setRGBA(k + posOffset.w, j + posOffset.h,
+					charImage->setRGBA(static_cast<int>(k) + posOffset.w,
+									   static_cast<int>(j) + posOffset.h,
 									   argFBScale[setVal*4],
 									   argFBScale[setVal*4 + 1],
 									   argFBScale[setVal*4 + 2],
@@ -1052,9 +1057,9 @@ fk_Color fk_TextImage::getShadowColor(void) const
 
 void fk_TextImage::CalcTextOffset(void)
 {
-	unsigned int	lineID;
-	int				yOffset, xOffset;
-	int				curW, curH, trueWidth;
+	_st		lineID;
+	int		yOffset, xOffset;
+	int		curW, curH, trueWidth;
 
 	yOffset = upOffset;
 
@@ -1111,17 +1116,18 @@ void fk_TextImage::CalcTextOffset(void)
 
 void fk_TextImage::ReCalcCharOffset(void)
 {
-	int		i;
+	_st		i, index;
 
-	if(charArray.size() == 0) return;
+	if(charArray.empty() == true) return;
 
-	for(i = 0; i < int(charArray.size()); i++) {
-		charArray[i].x += lineArray[lineMap[i]].x;
-		charArray[i].y += lineArray[lineMap[i]].y;
+	for(i = 0; i < charArray.size(); i++) {
+		index = static_cast<_st>(lineMap[i]);
+		charArray[i].x += lineArray[index].x;
+		charArray[i].y += lineArray[index].y;
 	}
 	return;
 }
-	
+
 
 void fk_TextImage::InitTextImage(void)
 {
@@ -1129,7 +1135,7 @@ void fk_TextImage::InitTextImage(void)
 	int				bgCol[4];
 
 	for(i = 0; i < 4; i++) {
-		bgCol[i] = int(bgColor.col[i] * 256);
+		bgCol[i] = static_cast<int>(bgColor.col[i] * 256);
 		if(bgCol[i] >= 256) bgCol[i] = 255;
 		if(bgCol[i] < 0) bgCol[i] = 0;
 	}
@@ -1141,7 +1147,9 @@ void fk_TextImage::InitTextImage(void)
 
 void fk_TextImage::CopyCharImage(int argID)
 {
-	copyImage(charImages[argID], charArray[argID].x, charArray[argID].y);
+	_st		id = static_cast<_st>(argID);
+
+	copyImage(charImages[id], charArray[id].x, charArray[id].y);
 
 	return;
 }
@@ -1161,53 +1169,61 @@ bool fk_TextImage::loadStrFile(const string argFileName, fk_StringCode argCode)
 
 int fk_TextImage::getLineNum(void) const
 {
-	return int(lineArray.size());
+	return static_cast<int>(lineArray.size());
 }
 
 int fk_TextImage::getLineCharNum(int argLineID) const
 {
-	int			i, count;
+	_st			i, count;
 
 	if(argLineID < 0 || argLineID >= int(lineArray.size())) return 0;
 
-	for(count = 0, i = 0; i < int(lineMap.size()); i++) {
+	for(count = 0, i = 0; i < lineMap.size(); i++) {
 		if(argLineID == lineMap[i]) count++;
 		if(argLineID < lineMap[i]) break;
 	}
-	return count;
+	return static_cast<int>(count);
 }
 
 int fk_TextImage::getAllCharNum(void) const
 {
-	return int(charArray.size());
+	return static_cast<int>(charArray.size());
 }
 
 int fk_TextImage::getLineWidth(int argID) const
 {
-	if(argID < 0 || argID >= int(lineArray.size())) return -1;
+	_st		id = static_cast<_st>(argID);
 
-	return lineArray[argID].w;
+	if(argID < 0 || id >= lineArray.size()) return -1;
+
+	return lineArray[id].w;
 }
 
 int fk_TextImage::getLineHeight(int argID) const
 {
-	if(argID < 0 || argID >= int(lineArray.size())) return -1;
+	_st		id = static_cast<_st>(argID);
 
-	return lineArray[argID].h;
+	if(argID < 0 || id >= lineArray.size()) return -1;
+
+	return lineArray[id].h;
 }
 
 int fk_TextImage::getLineStartXPos(int argID) const
 {
-	if(argID < 0 || argID >= int(lineArray.size())) return -1;
+	_st		id = static_cast<_st>(argID);
 
-	return lineArray[argID].x;
+	if(argID < 0 || id >= lineArray.size()) return -1;
+
+	return lineArray[id].x;
 }
 
 int fk_TextImage::getLineStartYPos(int argID) const
 {
-	if(argID < 0 || argID >= int(lineArray.size())) return -1;
+	_st		id = static_cast<_st>(argID);
 
-	return lineArray[argID].y;
+	if(argID < 0 || id >= lineArray.size()) return -1;
+
+	return lineArray[id].y;
 }
 
 void fk_TextImage::setShadowMode(bool argMode)
