@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -102,8 +102,8 @@ bool fk_TexCoord::operator ==(const fk_TexCoord &c) const
 
 void fk_TexCoord::set(double argX, double argY)
 {
-	x = float(argX);
-	y = float(argY);
+	x = static_cast<float>(argX);
+	y = static_cast<float>(argY);
 	return;
 }
 
@@ -111,7 +111,7 @@ fk_Texture::fk_Texture(fk_Image *argImage)
 	: fk_Shape(FK_TEXTURE)
 {
 	SetPaletteData(&localPal);
-	image = (fk_Image *)NULL;
+	image = NULL;
 	BaseInit();
 	setImage(argImage);
 
@@ -127,7 +127,7 @@ fk_Texture::~fk_Texture()
 
 void fk_Texture::BaseInit(void)
 {
-	setImage((fk_Image *)NULL);
+	setImage(NULL);
 	clearMaterial();
 	AttrInit();
 	setTextureMode(FK_TEX_MODULATE);
@@ -180,10 +180,10 @@ bool fk_Texture::readJPG(string argFileName)
 
 const fk_ImType * fk_Texture::getImageBuf(void)
 {
-	if(image != (fk_Image *)NULL) {
+	if(image != NULL) {
 		return image->getBufPointer();
 	}
-	return (fk_ImType *)NULL;
+	return NULL;
 }
 
 void fk_Texture::setImage(fk_Image *argImage)
@@ -203,25 +203,25 @@ fk_Image * fk_Texture::getImage(void)
 
 const fk_Dimension * fk_Texture::getImageSize(void)
 {
-	if(image != (fk_Image *)NULL) {
+	if(image != NULL) {
 		return image->getImageSize();
 	}
 
-	return (fk_Dimension *)NULL;
+	return NULL;
 }
 
 const fk_Dimension * fk_Texture::getBufferSize(void)
 {
-	if(image != (fk_Image *)NULL) {
+	if(image != NULL) {
 		return image->getBufferSize();
 	}
 
-	return (fk_Dimension *)NULL;
+	return NULL;
 }
 
 bool fk_Texture::GetInitFlag(void)
 {
-	if(image != (fk_Image *)NULL) {
+	if(image != NULL) {
 		return image->GetInitFlag();
 	}
 
@@ -230,7 +230,7 @@ bool fk_Texture::GetInitFlag(void)
 
 void fk_Texture::SetInitFlag(bool argFlg)
 {
-	if(image != (fk_Image *)NULL) {
+	if(image != NULL) {
 		image->SetInitFlag(argFlg);
 	}
 
@@ -239,7 +239,7 @@ void fk_Texture::SetInitFlag(bool argFlg)
 
 fk_TexID fk_Texture::GetTexID(void)
 {
-	if(image != (fk_Image *)NULL) {
+	if(image != NULL) {
 		return image->GetTexID();
 	}
 
@@ -248,13 +248,23 @@ fk_TexID fk_Texture::GetTexID(void)
 
 void fk_Texture::SetTexID(fk_TexID argID)
 {
-	if(image != (fk_Image *)NULL) {
+	if(image != NULL) {
 		image->SetTexID(argID);
 	}
 
 	return;
 }
 
+void fk_Texture::ClearTexState(fk_Image *argImage)
+{
+	if(argImage == NULL) return;
+
+	argImage->SetInitFlag(false);
+	argImage->SetTexID(0);
+
+	return;
+}
+
 void fk_Texture::setTextureMode(fk_TexMode argMode)
 {
 	texMode = argMode;
