@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -73,6 +73,7 @@
 #include "TextureDraw_D3D.cxx"
 #else
 
+#define FK_DEF_SIZETYPE
 #include <FK/TextureDraw.H>
 #include <FK/IFSTexture.h>
 #include <FK/Model.h>
@@ -83,7 +84,9 @@
 
 using namespace std;
 
-vector<GLuint>	fk_TextureDraw::texNameArray;
+vector<GLuint>		fk_TextureDraw::texNameArray;
+unsigned long		fk_TextureDraw::texLoadedSize = 0;
+vector<fk_Image *>	fk_TextureDraw::texImageArray;
 
 fk_TextureDraw::fk_TextureDraw(void)
 {
@@ -106,8 +109,6 @@ void fk_TextureDraw::SetArrayState(bool argState)
 
 void fk_TextureDraw::StartUp(void)
 {
-	string		str;
-
 	oldTexID = 0;
 	return;
 }
@@ -119,31 +120,33 @@ void fk_TextureDraw::DrawTextureObj(fk_Model *argObj, bool argLightFlag, bool ar
 	GLboolean	texStatus;
 	fk_TexID	texID;
 
-	texObj = (fk_Texture *)argObj->getShape();
+	if((argObj->getDrawMode() & FK_TEXTUREMODE) == FK_NONEMODE) return;
 
-	if(texObj->getBufferSize() == (fk_Dimension *)NULL) return;
+	texObj = static_cast<fk_Texture *>(argObj->getShape());
+
+	if(texObj->getBufferSize() == NULL) return;
 
 	// ピックモードが ON の場合
 	if(argPickFlag == true) {
 		// テクスチャの種類の選択 
 		switch(texObj->getObjectType()) {
-		case FK_RECTTEXTURE:
-			DrawRectTexturePick((fk_RectTexture *)texObj);
+		  case FK_RECTTEXTURE:
+			DrawRectTexturePick(static_cast<fk_RectTexture *>(texObj));
 			break;
 
-		case FK_TRITEXTURE:
-			DrawTriTexturePick((fk_TriTexture *)texObj);
+		  case FK_TRITEXTURE:
+			DrawTriTexturePick(static_cast<fk_TriTexture *>(texObj));
 			break;
 
-		case FK_MESHTEXTURE:
-			DrawMeshTexturePick((fk_MeshTexture *)texObj);
+		  case FK_MESHTEXTURE:
+			DrawMeshTexturePick(static_cast<fk_MeshTexture *>(texObj));
 			break;
 
-		case FK_IFSTEXTURE:
-			DrawIFSTexturePick((fk_IFSTexture *)texObj);
+		  case FK_IFSTEXTURE:
+			DrawIFSTexturePick(static_cast<fk_IFSTexture *>(texObj));
 			break;
 
-		default:
+		  default:
 			break;
 		}
 		return;
@@ -190,19 +193,19 @@ void fk_TextureDraw::DrawTextureObj(fk_Model *argObj, bool argLightFlag, bool ar
 	// テクスチャの種類の選択 
 	switch(texObj->getObjectType()) {
 	  case FK_RECTTEXTURE:
-		DrawRectTextureObj((fk_RectTexture *)texObj);
+		DrawRectTextureObj(static_cast<fk_RectTexture *>(texObj));
 		break;
 
 	  case FK_TRITEXTURE:
-		DrawTriTextureObj((fk_TriTexture *)texObj);
+		DrawTriTextureObj(static_cast<fk_TriTexture *>(texObj));
 		break;
 
 	  case FK_MESHTEXTURE:
-		DrawMeshTextureObj((fk_MeshTexture *)texObj);
+		DrawMeshTextureObj(static_cast<fk_MeshTexture *>(texObj));
 		break;
 
 	  case FK_IFSTEXTURE:
-		DrawIFSTextureObj((fk_IFSTexture *)texObj);
+		DrawIFSTextureObj(static_cast<fk_IFSTexture *>(texObj));
 
 	  default:
 		break;
@@ -223,21 +226,20 @@ void fk_TextureDraw::DrawTextureObj(fk_Model *argObj, bool argLightFlag, bool ar
 void fk_TextureDraw::DrawRectTextureObj(fk_RectTexture *argTexObj)
 {
 	fk_TexCoord	texSize, startParam, endParam;
-	double		wScale, hScale;
 	double		tmpX, tmpY;
 
 	const fk_Dimension *imageSize = argTexObj->getImageSize();
 	const fk_Dimension *bufSize = argTexObj->getBufferSize();
 
-	if(bufSize == (fk_Dimension *)NULL) return;
+	if(bufSize == NULL) return;
 	if(bufSize->w < 64 || bufSize->h < 64) return;
 
 	if(argTexObj->getRepeatMode() == true) {
 		startParam.set(0.0, 0.0);
 		endParam = argTexObj->getRepeatParam();
 	} else {
-		wScale = double(imageSize->w)/double(bufSize->w);
-		hScale = double(imageSize->h)/double(bufSize->h);
+		double wScale = static_cast<double>(imageSize->w)/static_cast<double>(bufSize->w);
+		double hScale = static_cast<double>(imageSize->h)/static_cast<double>(bufSize->h);
 		startParam.set(wScale * argTexObj->texCoord[0].x,
 					   hScale * argTexObj->texCoord[0].y);
 		endParam.set(wScale * argTexObj->texCoord[1].x,
@@ -273,17 +275,17 @@ void fk_TextureDraw::DrawTriTextureObj(fk_TriTexture *argTexObj)
 	fk_Vector		*pos;
 	fk_TexCoord		*coord;
 	double			wScale, hScale;
-	register int	counter;
+	_st				counter;
 	fk_Vector		norm;
 
 	const fk_Dimension *imageSize = argTexObj->getImageSize();
 	const fk_Dimension *bufSize = argTexObj->getBufferSize();
 
-	if(bufSize == (fk_Dimension *)NULL) return;
+	if(bufSize == NULL) return;
 	if(bufSize->w < 64 || bufSize->h < 64) return;
 
-	wScale = double(imageSize->w)/double(bufSize->w);
-	hScale = double(imageSize->h)/double(bufSize->h);
+	wScale = static_cast<double>(imageSize->w)/static_cast<double>(bufSize->w);
+	hScale = static_cast<double>(imageSize->h)/static_cast<double>(bufSize->h);
 
 	pos = argTexObj->getPos();
 	coord = argTexObj->getCoord();
@@ -317,7 +319,7 @@ void fk_TextureDraw::DrawMeshTextureObj(fk_MeshTexture *argTexObj)
 	vector<fk_TexCoord>	*coordArray;
 	double				wScale, hScale;
 	int					triNum;
-	register int		ii, ij;
+	_st					ii, ij;
 	fk_Vector			norm;
 
 	const fk_Dimension *imageSize = argTexObj->getImageSize();
@@ -327,17 +329,17 @@ void fk_TextureDraw::DrawMeshTextureObj(fk_MeshTexture *argTexObj)
 	triNum = argTexObj->getTriNum();
 	if(triNum <= 0) return;
 
-	if(bufSize == (fk_Dimension *)NULL) return;
+	if(bufSize == NULL) return;
 	if(bufSize->w < 64 || bufSize->h < 64) return;
 
-	wScale = double(imageSize->w)/double(bufSize->w);
-	hScale = double(imageSize->h)/double(bufSize->h);
+	wScale = static_cast<double>(imageSize->w)/static_cast<double>(bufSize->w);
+	hScale = static_cast<double>(imageSize->h)/static_cast<double>(bufSize->h);
 
 	posArray = &(argTexObj->getPos()->at(0));
 	coordArray = argTexObj->getCoord();
 
 	glBegin(GL_TRIANGLES);
-	for(ii = 0; ii < triNum; ii++) {
+	for(ii = 0; ii < static_cast<_st>(triNum); ii++) {
 		norm = (posArray[ii*3 + 1] - posArray[ii*3]) ^
 				(posArray[ii*3 + 2] - posArray[ii*3]);
 		if(norm.normalize() == false) {
@@ -346,11 +348,11 @@ void fk_TextureDraw::DrawMeshTextureObj(fk_MeshTexture *argTexObj)
 			continue;
 		}
 						
-		glNormal3dv((GLdouble *)&(norm.x));
+		glNormal3dv(static_cast<GLdouble *>(&(norm.x)));
 		for(ij = 0; ij < 3; ij++) {
-			glTexCoord2f((*coordArray)[ii*3+ij].x * float(wScale),
-						 (*coordArray)[ii*3+ij].y * float(hScale));
-			glVertex3dv((GLdouble *)&(posArray[ii*3+ij].x));
+			glTexCoord2f((*coordArray)[ii*3+ij].x * static_cast<float>(wScale),
+						 (*coordArray)[ii*3+ij].y * static_cast<float>(hScale));
+			glVertex3dv(static_cast<GLdouble *>(&(posArray[ii*3+ij].x)));
 		}
 	}
 
@@ -361,21 +363,15 @@ void fk_TextureDraw::DrawMeshTextureObj(fk_MeshTexture *argTexObj)
 void fk_TextureDraw::DrawIFSTextureObj(fk_IFSTexture *argTexObj)
 {
 	fk_IndexFaceSet	*ifsP;
-	int				pNum;
+	_st				pNum;
 	fk_TexCoord		*texCoord;
 	GLenum			tmpType;
-	int				ii, ij, index;
-	double			wScale, hScale;
 
-	const fk_Dimension *imageSize = argTexObj->getImageSize();
 	const fk_Dimension *bufSize = argTexObj->getBufferSize();
 
-	if(bufSize == (fk_Dimension *)NULL) return;
+	if(bufSize == NULL) return;
 	if(bufSize->w < 64 || bufSize->h < 64) return;
 
-	wScale = double(imageSize->w)/double(bufSize->w);
-	hScale = double(imageSize->h)/double(bufSize->h);
-
 	ifsP = argTexObj->getIFS();
 
 	if(ifsP->modifyFlg == true) {
@@ -410,13 +406,13 @@ void fk_TextureDraw::DrawIFSTextureObj(fk_IFSTexture *argTexObj)
 		glNormalPointer(GL_FLOAT, 0, &ifsP->vNorm[0]);
 		glTexCoordPointer(2, GL_FLOAT, 0, &texCoord[0]);
 		
-		glDrawElements(tmpType, ifsP->faceSize * pNum,
+		glDrawElements(tmpType, ifsP->faceSize * static_cast<GLsizei>(pNum),
 					   GL_UNSIGNED_INT, &ifsP->ifs[0]);
 	} else {
 		glBegin(tmpType);
-		for(ii = 0; ii < ifsP->faceSize; ii++) {
-			for(ij = 0; ij < pNum; ij++) {
-				index = ifsP->ifs[pNum*ii+ij];
+		for(_st ii = 0; ii < static_cast<_st>(ifsP->faceSize); ii++) {
+			for(_st ij = 0; ij < pNum; ij++) {
+				_st index = static_cast<_st>(ifsP->ifs[pNum*ii+ij]);
 				glNormal3fv((GLfloat *)&(ifsP->vNorm[index]));
 				glTexCoord2fv((GLfloat *)&texCoord[index]);
 				glVertex3fv((GLfloat *)&(ifsP->pos[index]));
@@ -457,6 +453,9 @@ void fk_TextureDraw::GenTextureObj(fk_Texture *argTexObj)
 	argTexObj->SetTexID(tmpTexName);
 	argTexObj->SetInitFlag(false);
 	texNameArray.push_back(tmpTexName);
+	texImageArray.push_back(argTexObj->getImage());
+
+	texLoadedSize += static_cast<_st>(bufSize->w*bufSize->h*4);
 
 	return;
 }
@@ -489,44 +488,24 @@ void fk_TextureDraw::ReplaceTextureObj(fk_Texture *argTexObj)
 			glTexSubImage2D(GL_TEXTURE_2D, 0, 0, 0, bufSize->w, bufSize->h,
 							GL_RGBA, GL_UNSIGNED_BYTE, imageBuf);
 		} else {	// 指定されていたら部分更新
-			subBuffer.resize(tmpRect.w*tmpRect.h*4);
+			subBuffer.resize(static_cast<_st>(tmpRect.w*tmpRect.h*4));
 			for(int i = 0; i < tmpRect.h; i++) {
-				memcpy(&(subBuffer[(tmpRect.h-i-1)*tmpRect.w*4]),
-						imageBuf+((imageSize->h - (tmpRect.y+i) - 1)*bufSize->w + tmpRect.x)*4,
-						tmpRect.w*4);
+				memcpy(&(subBuffer[static_cast<_st>((tmpRect.h-i-1)*tmpRect.w*4)]),
+					   imageBuf+((imageSize->h - (tmpRect.y+i) - 1)*bufSize->w + tmpRect.x)*4,
+					   static_cast<size_t>(tmpRect.w*4));
 			}
 			if(!subBuffer.empty()) {
-				glTexSubImage2D(GL_TEXTURE_2D, 0, tmpRect.x, imageSize->h - tmpRect.h - tmpRect.y, tmpRect.w, tmpRect.h,
+				glTexSubImage2D(GL_TEXTURE_2D, 0, tmpRect.x,
+								imageSize->h - tmpRect.h - tmpRect.y,
+								tmpRect.w, tmpRect.h,
 								GL_RGBA, GL_UNSIGNED_BYTE, &(subBuffer[0]));
 			}
 		}
 	} else {
-		texNameArray.erase(find(texNameArray.begin(),
-								texNameArray.end(),
-								tmpTexName));
-
-		glDeleteTextures(1, &tmpTexName);
-		glGenTextures(1, &tmpTexName);
-		glBindTexture(GL_TEXTURE_2D, tmpTexName);
-		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
-		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
-
-		switch(argTexObj->getTexRendMode()) {
-		case FK_TEX_REND_NORMAL:
-			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
-			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
-			break;
-
-		case FK_TEX_REND_SMOOTH:
-			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-			break;
-		}
-		
 		glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, bufSize->w, bufSize->h,
 					 0, GL_RGBA, GL_UNSIGNED_BYTE, imageBuf);
-		argTexObj->SetTexID(tmpTexName);
-		texNameArray.push_back(tmpTexName);
+		texLoadedSize -= static_cast<_st>(texW*texH*4);
+		texLoadedSize += static_cast<_st>(bufSize->w*bufSize->h*4);
 	}
 	// フラグ解除
 	argTexObj->SetInitFlag(false);
@@ -537,15 +516,43 @@ void fk_TextureDraw::ReplaceTextureObj(fk_Texture *argTexObj)
 void fk_TextureDraw::ClearTextureMemory(void)
 {
 	if(texNameArray.empty() == false) {
-		glDeleteTextures(GLsizei(texNameArray.size()), &texNameArray[0]);
+		glDeleteTextures(static_cast<GLsizei>(texNameArray.size()), &texNameArray[0]);
+		for(_st i = 0; i < texImageArray.size(); i++) {
+			if(texImageArray[i] == NULL) continue;
+			fk_Texture::ClearTexState(texImageArray[i]);
+		}
 		texNameArray.clear();
+		texImageArray.clear();
+		texLoadedSize = 0;
+	}
+	return;
+}
+
+unsigned long fk_TextureDraw::GetUsingTextureMemory(void)
+{
+	return texLoadedSize;
+}
+
+void fk_TextureDraw::ReleaseTexture(fk_Image *argImage)
+{
+	if(argImage->GetTexID() == 0) return;
+	for(_st i = 0; i < texNameArray.size(); i++) {
+		if(argImage->GetTexID() == texNameArray[i]) {
+			const fk_Dimension *bufSize = argImage->getBufferSize();
+			glDeleteTextures(1, &texNameArray[i]);
+			fk_Texture::ClearTexState(argImage);
+			texNameArray[i] = 0;
+			texImageArray[i] = NULL;
+			texLoadedSize -= static_cast<_st>(bufSize->w*bufSize->h*4);
+			break;
+		}
 	}
 	return;
 }
 
 void fk_TextureDraw::InitTextureEnv(fk_Texture *argTexObj)
 {
-	GLenum		texMode = GL_MODULATE;
+	GLint		texMode = GL_MODULATE;
 	fk_TexID	curID;
 
 	switch(argTexObj->getTextureMode()) {
@@ -598,7 +605,7 @@ void fk_TextureDraw::DrawRectTexturePick(fk_RectTexture *argTexObj)
 
 	const fk_Dimension *bufSize = argTexObj->getBufferSize();
 
-	if(bufSize == (fk_Dimension *)NULL) return;
+	if(bufSize == NULL) return;
 	if(bufSize->w < 64 || bufSize->h < 64) return;
 
 	texSize = argTexObj->getTextureSize();
@@ -626,7 +633,7 @@ void fk_TextureDraw::DrawTriTexturePick(fk_TriTexture *argTexObj)
 
 	const fk_Dimension *bufSize = argTexObj->getBufferSize();
 
-	if(bufSize == (fk_Dimension *)NULL) return;
+	if(bufSize == NULL) return;
 	if(bufSize->w < 64 || bufSize->h < 64) return;
 
 	pos = argTexObj->getPos();
@@ -650,7 +657,7 @@ void fk_TextureDraw::DrawMeshTexturePick(fk_MeshTexture *argTexObj)
 {
 	fk_Vector		*posArray;
 	int				triNum;
-	register int	ii, ij;
+	register _st	ii, ij;
 
 	const fk_Dimension *bufSize = argTexObj->getBufferSize();
 
@@ -658,17 +665,17 @@ void fk_TextureDraw::DrawMeshTexturePick(fk_MeshTexture *argTexObj)
 	triNum = argTexObj->getTriNum();
 	if(triNum <= 0) return;
 
-	if(bufSize == (fk_Dimension *)NULL) return;
+	if(bufSize == NULL) return;
 	if(bufSize->w < 64 || bufSize->h < 64) return;
 
 	posArray = &(argTexObj->getPos()->at(0));
 
-	for(ii = 0; ii < triNum; ii++) {
-		glPushName(ii*3);
+	for(ii = 0; ii < static_cast<_st>(triNum); ii++) {
+		glPushName(static_cast<GLuint>(ii*3));
 		glBegin(GL_TRIANGLES);
 
 		for(ij = 0; ij < 3; ij++) {
-			glVertex3dv((GLdouble *)&(posArray[ii*3+ij].x));
+			glVertex3dv(static_cast<GLdouble *>(&(posArray[ii*3+ij].x)));
 		}
 
 		glEnd();
@@ -705,10 +712,10 @@ void fk_TextureDraw::DrawIFSTexturePick(fk_IFSTexture *argObj)
 	ifs = &ifsP->ifs[0];
 
 	for(ii = 0; ii < ifsP->faceSize; ii++) {
-		glPushName(ii*3);
+		glPushName(static_cast<GLuint>(ii*3));
 		glBegin(GL_POLYGON);
 		for(ij = 0; ij < pNum; ij++) {
-			glVertex3fv((GLfloat *)&pos[ifs[pNum*ii+ij]]);
+			glVertex3fv(static_cast<GLfloat *>(&pos[ifs[pNum*ii+ij]].x));
 		}
 		glEnd();
 		glPopName();
