@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -96,6 +96,8 @@ static vector<TEXTURECUSTOMVERTEX>	workVertexArray;
 vector<LPDIRECT3DTEXTURE9>	fk_TextureDraw::texObjArray(1);
 vector<fk_Dimension>		fk_TextureDraw::texSizeArray(1);
 vector<fk_TexID>			fk_TextureDraw::texNameArray;
+unsigned long				fk_TextureDraw::texLoadedSize = 0;
+vector<fk_Image *>			fk_TextureDraw::texImageArray;
 
 // ライトなし時のダミーライト
 static D3DLIGHT9	dummyLight;
@@ -152,6 +154,8 @@ void fk_TextureDraw::drawTextureObj(fk_Model *argObj, bool argLightFlag, bool ar
 	int				mateID = -2;
 	fk_TexID		texID;
 
+	if((argObj->getDrawMode() & FK_TEXTUREMODE) == FK_NONEMODE) return;
+
 	texObj = (fk_Texture *)argObj->getShape();
 
 	if(texObj->getBufferSize() == (fk_Dimension *)NULL) return;
@@ -262,7 +266,6 @@ void fk_TextureDraw::drawTextureObj(fk_Model *argObj, bool argLightFlag, bool ar
 void fk_TextureDraw::DrawRectTextureObj(fk_RectTexture *argTexObj)
 {
 	fk_TexCoord		texSize, startParam, endParam;
-	double			wScale, hScale;
 	float			tmpX, tmpY;
 
 	const fk_Dimension *imageSize = argTexObj->getImageSize();
@@ -275,8 +278,8 @@ void fk_TextureDraw::DrawRectTextureObj(fk_RectTexture *argTexObj)
 		startParam.set(0.0, 0.0);
 		endParam = argTexObj->getRepeatParam();
 	} else {
-		wScale = double(imageSize->w)/double(bufSize->w);
-		hScale = double(imageSize->h)/double(bufSize->h);
+		double wScale = double(imageSize->w)/double(bufSize->w);
+		double hScale = double(imageSize->h)/double(bufSize->h);
 		startParam.set(wScale * argTexObj->texCoord[0].x,
 					   hScale * argTexObj->texCoord[0].y);
 		endParam.set(wScale * argTexObj->texCoord[1].x,
@@ -398,7 +401,7 @@ void fk_TextureDraw::DrawMeshTextureObj(fk_MeshTexture *argTexObj)
 	}
 	// メッシュ枚数チェック済み
 	ref_lpD3DDEV->SetFVF(D3DFVF_TEXTURECUSTOMVERTEX);
-	ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLELIST, workVertexArray.size()/3, &(workVertexArray[0]), sizeof(TEXTURECUSTOMVERTEX));
+	ref_lpD3DDEV->DrawPrimitiveUP(D3DPT_TRIANGLELIST, static_cast<UINT>(workVertexArray.size()/3), &(workVertexArray[0]), sizeof(TEXTURECUSTOMVERTEX));
 
 	return;
 }
@@ -411,11 +414,10 @@ void fk_TextureDraw::DrawIFSTextureObj(fk_IFSTexture *argTexObj)
 	int					pNum;
 	fk_TexCoord			*texCoord;
 	int					ii, ij, index;
-	double				wScale, hScale;
 
 	TEXTURECUSTOMVERTEX	tmpVertex;
 
-	const fk_Dimension *imageSize = argTexObj->getImageSize();
+	// const fk_Dimension *imageSize = argTexObj->getImageSize();
 	const fk_Dimension *bufSize = argTexObj->getBufferSize();
 
 	if(bufSize == (fk_Dimension *)NULL) return;
@@ -424,9 +426,6 @@ void fk_TextureDraw::DrawIFSTextureObj(fk_IFSTexture *argTexObj)
 	ifsP = argTexObj->getIFS();
 	if(ifsP->faceSize <= 0) return;
 
-	wScale = double(imageSize->w)/double(bufSize->w);
-	hScale = double(imageSize->h)/double(bufSize->h);
-
 	if(ifsP->modifyFlg == true) {
 		ifsP->ModifyVNorm();
 	}
@@ -538,7 +537,7 @@ void fk_TextureDraw::GenTextureObj(fk_Texture *argTexObj)
 	const fk_ImType *imageBuf = argTexObj->getImageBuf();
 
 	D3DXCreateTexture(ref_lpD3DDEV, bufSize->w, bufSize->h, 0, 0, D3DFMT_A8R8G8B8, D3DPOOL_MANAGED, &tmpTexObj);
-	tmpTexName = texObjArray.size();
+	tmpTexName = static_cast<fk_TexID>(texObjArray.size());
 
 	tmpTexObj->LockRect(0, &rect, NULL, 0);
 	pDst = (unsigned char*)(rect.pBits);
@@ -554,9 +553,13 @@ void fk_TextureDraw::GenTextureObj(fk_Texture *argTexObj)
 	argTexObj->SetInitFlag(false);
 
 	texObjArray.push_back(tmpTexObj);
-	texNameArray.push_back(tmpTexName);
 	texSizeArray.push_back(*bufSize);
 
+	texNameArray.push_back(tmpTexName);
+	texImageArray.push_back(argTexObj->getImage());
+
+	texLoadedSize += bufSize->w*bufSize->h*4;
+
 	return;
 }
 
@@ -576,6 +579,8 @@ void fk_TextureDraw::ReplaceTextureObj(fk_Texture *argTexObj)
 	if(texSizeArray[tmpTexName].w != bufSize->w || texSizeArray[tmpTexName].h != bufSize->h) {
 		RELEASE(texObjArray[tmpTexName]);
 		D3DXCreateTexture(ref_lpD3DDEV, bufSize->w, bufSize->h, 0, 0, D3DFMT_A8R8G8B8, D3DPOOL_MANAGED, &texObjArray[tmpTexName]);
+		texLoadedSize -= texSizeArray[tmpTexName].w*texSizeArray[tmpTexName].h*4;
+		texLoadedSize += bufSize->w*bufSize->h*4;
 	}
 
 	texObjArray[tmpTexName]->LockRect(0, &rect, NULL, 0);
@@ -600,12 +605,40 @@ void fk_TextureDraw::clearTextureMemory(void)
 	if(texNameArray.empty() == false) {
 		for(unsigned int i = 0; i < texNameArray.size(); i++) {
 			RELEASE(texObjArray[texNameArray[i]]);
+			if(texImageArray[i] == (fk_Image *)NULL) continue;
+			fk_Texture::ClearTexState(texImageArray[i]);
 		}
-		texNameArray.clear();
 		texObjArray.resize(1);
 		texObjArray[0] = NULL;
 		texSizeArray.resize(1);
 		texSizeArray[0].set(0, 0);
+
+		texNameArray.clear();
+		texImageArray.clear();
+		texLoadedSize = 0;
+	}
+	return;
+}
+
+unsigned long fk_TextureDraw::getUsingTextureMemory(void)
+{
+	return texLoadedSize;
+}
+
+void fk_TextureDraw::ReleaseTexture(fk_Image *argImage)
+{
+	if(argImage->GetTexID() == 0) return;
+	for(unsigned int i = 0; i < texNameArray.size(); i++) {
+		if(argImage->GetTexID() == texNameArray[i]) {
+			const fk_Dimension *bufSize = argImage->getBufferSize();
+			RELEASE(texObjArray[texNameArray[i]]);
+			texSizeArray[texNameArray[i]].set(0, 0);
+			fk_Texture::ClearTexState(argImage);
+			texNameArray[i] = 0;
+			texImageArray[i] = (fk_Image *)NULL;
+			texLoadedSize -= bufSize->w*bufSize->h*4;
+			break;
+		}
 	}
 	return;
 }
@@ -613,8 +646,8 @@ void fk_TextureDraw::clearTextureMemory(void)
 void fk_TextureDraw::InitTextureEnv(fk_Texture *argTexObj)
 {
 	fk_TexID	curID = argTexObj->GetTexID();
-
-	if(bindMode == false || curID != oldTexID) {
+	// 強制的に毎回通るように
+	// if(bindMode == false || curID != oldTexID) {
 
 		ref_lpD3DDEV->SetTexture(0, texObjArray[curID]);
 
@@ -635,6 +668,14 @@ void fk_TextureDraw::InitTextureEnv(fk_Texture *argTexObj)
 			ref_lpD3DDEV->SetTextureStageState(0, D3DTSS_ALPHAARG2, D3DTA_TEXTURE);
 			break;
 
+		case FK_TEX_DECAL:
+			ref_lpD3DDEV->SetTextureStageState(0, D3DTSS_COLORARG1, D3DTA_TEXTURE);
+			ref_lpD3DDEV->SetTextureStageState(0, D3DTSS_COLOROP, D3DTOP_BLENDTEXTUREALPHA);
+			ref_lpD3DDEV->SetTextureStageState(0, D3DTSS_COLORARG2, D3DTA_DIFFUSE);
+			ref_lpD3DDEV->SetTextureStageState(0, D3DTSS_ALPHAOP, D3DTOP_SELECTARG2);
+			ref_lpD3DDEV->SetTextureStageState(0, D3DTSS_ALPHAARG2, D3DTA_DIFFUSE);
+			break;
+
 		default:
 			break;
 		}
@@ -654,7 +695,7 @@ void fk_TextureDraw::InitTextureEnv(fk_Texture *argTexObj)
 			break;
 
 		}
-	}
+	//}
 
 	oldTexID = curID;
 
