@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -120,13 +120,13 @@ fk_TreeData * fk_TreeData::getChild(fk_TreeData *argPrev)
 	list_ite		ite;
 
 	if(argPrev == NULL) {
-		if(children.size() == 0) return NULL;
+		if(children.empty() == true) return NULL;
 		return children.front();
 	}
 
 	ite = find(children.begin(), children.end(), argPrev);
 	if(ite == children.end()) return NULL;
-	ite++;
+	++ite;
 	if(ite == children.end()) return NULL;
 	return (*ite);
 }
@@ -143,9 +143,9 @@ fk_TreeData * fk_TreeData::getNext(void)
 	if(parent == NULL) return NULL;
 
 	for(ite = parent->children.begin();
-		ite != parent->children.end(); ite++) {
+		ite != parent->children.end(); ++ite) {
 		if((*ite) == this) {
-			ite++;
+			++ite;
 			if(ite == parent->children.end()) return NULL;
 			return (*ite);
 		}
@@ -162,7 +162,7 @@ fk_TreeData * fk_TreeData::getPrev(void)
 	ite = find(parent->children.begin(), parent->children.end(), this);
 	if(ite == parent->children.end() ||
 	   ite == parent->children.begin()) return NULL;
-	ite--;
+	--ite;
 	return (*ite);
 }
 
@@ -174,7 +174,7 @@ int fk_TreeData::getOrder(void)
 	if(parent == NULL) return 0;
 
 	for(ite = parent->children.begin();
-		ite != parent->children.end(); ite++) {
+		ite != parent->children.end(); ++ite) {
 		if((*ite) == this) return order;
 		order++;
 	}
@@ -215,7 +215,7 @@ void fk_TreeData::Print(void)
 	str += fk_StrPrintf("(%s, %d)", name.c_str(), maxDepth);
 	fk_PutError(str);
 
-	for(ite = children.begin(); ite != children.end(); ite++) {
+	for(ite = children.begin(); ite != children.end(); ++ite) {
 		(*ite)->Print();
 	}
 	return;
@@ -227,7 +227,7 @@ void fk_TreeData::_calcMaxDepth(void)
 	int				tmpDepth;
 
 	maxDepth = depth;
-	for(ite = children.begin(); ite != children.end(); ite++) {
+	for(ite = children.begin(); ite != children.end(); ++ite) {
 		tmpDepth = (*ite)->getMaxDepth();
 		if(tmpDepth > maxDepth) maxDepth = tmpDepth;
 	}
@@ -292,7 +292,7 @@ void fk_Tree::_clear(void)
 {
 	list_ite		ite;
 
-	for(ite = _treeData.begin(); ite != _treeData.end(); ite++) {
+	for(ite = _treeData.begin(); ite != _treeData.end(); ++ite) {
 		delete *ite;
 	}
 	_treeData.clear();
@@ -396,7 +396,7 @@ fk_TreeData * fk_Tree::_simpleClone(fk_TreeData *argParentData,
 	newData = makeNewData(this, argFromData->name, argParentData);
 	for(ite = argFromData->children.begin();
 		ite != argFromData->children.end();
-		ite++) {
+		++ite) {
 		newData->_addChild(_simpleClone(newData, (*ite)));
 	}
 	newData->object = argFromData->object;
@@ -427,7 +427,7 @@ int fk_Tree::_setDepth(fk_TreeData *argData, int argDepth)
 	argData->maxDepth = argDepth;
 
 	for(ite = argData->children.begin();
-		ite != argData->children.end(); ite++) {
+		ite != argData->children.end(); ++ite) {
 		tmpMax = _setDepth(*ite, argDepth+1);
 		if(tmpMax > argData->maxDepth) argData->maxDepth = tmpMax;
 	}
@@ -458,7 +458,7 @@ void fk_Tree::toFront(int argNum, fk_TreeData *argData)
 {
 	list_ite	ite;
 	fk_TList	*list;
-	int			i, order;
+	int			order;
 
 	if(argNum == 0) return;
 	if(isArive(argData) == false) return;
@@ -467,7 +467,7 @@ void fk_Tree::toFront(int argNum, fk_TreeData *argData)
 	list = &(argData->parent->children);
 
 	order = 0;
-	for(ite = list->begin(); ite != list->end(); ite++) {
+	for(ite = list->begin(); ite != list->end(); ++ite) {
 		if((*ite) == argData) break;
 		order++;
 	}
@@ -479,7 +479,7 @@ void fk_Tree::toFront(int argNum, fk_TreeData *argData)
 		list->push_front(argData);
 	} else {
 		ite = list->begin();
-		for(i = 0; i < order - argNum; i++) ite++;
+		for(int i = 0; i < order - argNum; i++) ++ite;
 		list->insert(ite, argData);
 	}
 	return;
@@ -489,7 +489,7 @@ void fk_Tree::toBack(int argNum, fk_TreeData *argData)
 {
 	list_ite	ite;
 	fk_TList	*list;
-	int			i, order;
+	int			order;
 
 	if(argNum == 0) return;
 	if(isArive(argData) == false) return;
@@ -498,7 +498,7 @@ void fk_Tree::toBack(int argNum, fk_TreeData *argData)
 	list = &(argData->parent->children);
 
 	order = 0;
-	for(ite = list->begin(); ite != list->end(); ite++) {
+	for(ite = list->begin(); ite != list->end(); ++ite) {
 		if((*ite) == argData) break;
 		order++;
 	}
@@ -510,7 +510,7 @@ void fk_Tree::toBack(int argNum, fk_TreeData *argData)
 		list->push_back(argData);
 	} else {
 		ite = list->begin();
-		for(i = 0; i < order+argNum; i++) ite++;
+		for(int i = 0; i < order+argNum; i++) ++ite;
 		list->insert(ite, argData);
 	}
 	return;
@@ -521,7 +521,7 @@ fk_TreeData * fk_Tree::findData(const string argName)
 	list_ite		ite;
 	fk_TreeData		*cur;
 
-	for(ite = _treeData.begin(); ite != _treeData.end(); ite++) {
+	for(ite = _treeData.begin(); ite != _treeData.end(); ++ite) {
 		cur = *ite;
 		if(cur->name == argName) return cur;
 	}
@@ -537,7 +537,7 @@ fk_TreeData * fk_Tree::foreachData(fk_TreeData *argData)
 	}
 	ite = find(_treeData.begin(), _treeData.end(), argData);
 	if(ite == _treeData.end()) return NULL;
-	ite++;
+	++ite;
 	if(ite == _treeData.end()) return NULL;
 	return (*ite);
 }
