@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -69,9 +69,12 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+
+#define FK_DEF_SIZETYPE
 #include <FK/ShapeViewer.h>
 #include <FK/Vertex.h>
 #include <FK/Error.H>
+#include <FK/System.h>
 
 #include <FL/Fl_Menu_Bar.H>
 #include <FL/Fl_Value_Slider.H>
@@ -80,7 +83,7 @@
 #include <FL/Fl_Check_Button.H>
 #include <FL/Fl_Color_Chooser.H>
 #include <FL/fl_ask.H>
-#include <FL/Fl_File_Chooser.H>
+#include <FL/Fl_Native_File_Chooser.H>
 
 using namespace std;
 
@@ -142,13 +145,13 @@ Fl_Menu_Item menuTable[] = {
 
 static void LocalMenuToggle(Fl_Widget *argW, void *)
 {
-	Fl_Menu_			*mw = (Fl_Menu_ *)argW;
+	Fl_Menu_			*mw = static_cast<Fl_Menu_ *>(argW);
 	const Fl_Menu_Item	*mItem = mw->mvalue();
 	string				labelString;
 
 	if(mItem == NULL) return;
 	labelString = mItem->label();
-	if(labelString == "WRL&Open") {
+	if(labelString == "&WRLOpen") {
 		globalMenuStatus = FK_SV_GUI_WRLOPEN;
 	} else if(labelString == "S&TLOpen") {
 		globalMenuStatus = FK_SV_GUI_STLOPEN;
@@ -193,10 +196,12 @@ static void LocalMenuToggle(Fl_Widget *argW, void *)
 	return;
 }
 
-void fk_ShapeViewer::GetMaterial(int id, fk_ShapeGUIMenuItem index,
+void fk_ShapeViewer::GetMaterial(int argID, fk_ShapeGUIMenuItem index,
 								 double *r, double *g, double *b)
 {
-	if(id < 0 || id >= int(polyMaterial.size())) return;
+	_st		id = static_cast<_st>(argID);
+
+	if(argID < 0 || id >= polyMaterial.size()) return;
 
 	// Index によってマテリアルの各種属性を (R, G, B) に代入
 
@@ -237,10 +242,12 @@ void fk_ShapeViewer::GetMaterial(int id, fk_ShapeGUIMenuItem index,
 	return;
 }
 
-void fk_ShapeViewer::SetMaterial(int id, fk_ShapeGUIMenuItem index,
+void fk_ShapeViewer::SetMaterial(int argID, fk_ShapeGUIMenuItem index,
 								 double r, double g, double b)
 {
-	if(id < 0 || id >= int(polyMaterial.size())) return;
+	_st		id = static_cast<_st>(argID);
+
+	if(argID < 0 || id >= polyMaterial.size()) return;
 
 	// Index によって (R, G, B) を各種マテリアルに設定 
 
@@ -327,8 +334,7 @@ void fk_ShapeViewer::InitWindow(void)
 
 	delete mainWindow;
 
-	mainWindow = new Fl_Window(allWinSize.w, allWinSize.h,
-							   "FK Shape Viewer");
+	mainWindow = new Fl_Window(allWinSize.w, allWinSize.h, "FK Shape Viewer");
 	viewWin = new fk_Window(10, 40, fkWinSize.w, fkWinSize.h);
 	InitGUI();
 	mainWindow->end();
@@ -496,6 +502,7 @@ void fk_ShapeViewer::AxisInit(void)
 	axisLine.setMaterialMode(FK_PARENT_MODE);
 	axisModel.setMaterialMode(FK_PARENT_MODE);
 	scene.entryModel(&axisModel);
+	axisFlag = true;
 	return;
 }
 
@@ -567,7 +574,7 @@ void fk_ShapeViewer::SetSceneFlg(fk_ShapeGUIMenuItem argStatus)
 void fk_ShapeViewer::ModelInit(int argIndex, fk_Shape *argShape)
 {
 	fk_Model	*localModel;
-	int			trueID;
+	_st			trueID;
 	fk_Material	mat;
 	fk_Color	eCol, vCol;
 	fk_Material	*matP;
@@ -598,7 +605,7 @@ void fk_ShapeViewer::ModelInit(int argIndex, fk_Shape *argShape)
 		vertexColor.push_back(vColP);
 
 	} else {
-		trueID = IDMap[argIndex];
+		trueID = static_cast<_st>(IDMap[argIndex]);
 		localModel = modelArray[trueID];
 	}
 
@@ -667,25 +674,32 @@ void fk_ShapeViewer::RotateLight(double argAngle)
 	return;
 }
 
-string fk_ShapeViewer::CommonFileChooser(string argFil, int argMode,
+string fk_ShapeViewer::CommonFileChooser(string argFil,
+										 int argType,
 										 string argTitle)
 {
-	Fl_File_Chooser		*fc;
-	const char			*fCharP;
-	string				fileName = "";
+	Fl_Native_File_Chooser	*fc;
+	string					fileName = "";
+	string					pathName;
 
-	fc = new Fl_File_Chooser(".", argFil.c_str(), argMode, argTitle.c_str());
-	fc->show();
-	while(fc->visible()) {
-		Fl::wait();
-	}
+	pathName = fk_System::get_cwd();
+	fc = new Fl_Native_File_Chooser();
+	fc->type(argType);
+	fc->title(argTitle.c_str());
+	fc->filter(argFil.c_str());
+	if(pathName.empty() == false) fc->directory(pathName.c_str());
 
-	fCharP = fc->value(1);
-	if(fCharP == NULL) {
+	switch(fc->show()) {
+	  case -1:
+		fl_alert("%s", fc->errmsg());
+		break;
+	  case 1:
 		return fileName;
+	  default:
+		break;
 	}
 
-	fileName = fCharP;
+	fileName = fc->filename();
 	delete fc;
 	return fileName;
 }
@@ -693,6 +707,7 @@ string fk_ShapeViewer::CommonFileChooser(string argFil, int argMode,
 bool fk_ShapeViewer::MenuSelect(void)
 {
 	int				i;
+	_st				j;
 	string			fileName;
 	double			colR, colG, colB, shininess;
 	fk_Shape		*shape;
@@ -712,7 +727,8 @@ bool fk_ShapeViewer::MenuSelect(void)
 		return false;
 
 	  case FK_SV_GUI_WRLOPEN:
-		fileName = CommonFileChooser("*.wrl", Fl_File_Chooser::SINGLE,
+		fileName = CommonFileChooser("*.wrl",
+									 Fl_Native_File_Chooser::BROWSE_FILE,
 									 "VRML2.0 File Select");
 		if(fileName.length() == 0) break;
 		if(localSolid.readVRMLFile(fileName, true, false) == false) {
@@ -729,7 +745,8 @@ bool fk_ShapeViewer::MenuSelect(void)
 		break;
 
 	  case FK_SV_GUI_STLOPEN:
-		fileName = CommonFileChooser("*.stl", Fl_File_Chooser::SINGLE,
+		fileName = CommonFileChooser("*.stl",
+									 Fl_Native_File_Chooser::BROWSE_FILE,
 									 "STL File Select");
 		if(fileName.length() == 0) break;
 
@@ -744,7 +761,8 @@ bool fk_ShapeViewer::MenuSelect(void)
 		break;
 
 	  case FK_SV_GUI_DXFOPEN:
-		fileName = CommonFileChooser("*.dxf", Fl_File_Chooser::SINGLE,
+		fileName = CommonFileChooser("*.dxf",
+									 Fl_Native_File_Chooser::BROWSE_FILE,
 									 "DXF File Select");
 		if(fileName.length() == 0) break;
 
@@ -760,7 +778,8 @@ bool fk_ShapeViewer::MenuSelect(void)
 
 	  case FK_SV_GUI_WRLSAVE:
 
-		fileName = CommonFileChooser("*", Fl_File_Chooser::CREATE,
+		fileName = CommonFileChooser("*",
+									 Fl_Native_File_Chooser::BROWSE_SAVE_FILE,
 									 "Save File Select");
 
 		if(fileName.length() == 0) break;
@@ -782,7 +801,7 @@ bool fk_ShapeViewer::MenuSelect(void)
 		  case FK_POLYLINE:
 		  case FK_CLOSEDLINE:
 		  case FK_POINT:
-			solid = (fk_Solid *)shape;
+			solid = static_cast<fk_Solid *>(shape);
 			if(solid->writeVRMLFile(fileName, polyMaterial[0]) == false) {
 				fl_alert("%s: Can't Write.", fileName.c_str());
 			}
@@ -794,7 +813,7 @@ bool fk_ShapeViewer::MenuSelect(void)
 		  case FK_SPHERE:
 		  case FK_PRISM:
 		  case FK_CONE:
-			ifs = (fk_IndexFaceSet *)shape;
+			ifs = static_cast<fk_IndexFaceSet *>(shape);
 			if(ifs->writeVRMLFile(fileName, polyMaterial[0]) == false) {
 				fl_alert("%s: Can't Write.", fileName.c_str());
 			}
@@ -807,7 +826,8 @@ bool fk_ShapeViewer::MenuSelect(void)
 		break;
 
 	  case FK_SV_GUI_STLSAVE:
-		fileName = CommonFileChooser("*", Fl_File_Chooser::CREATE,
+		fileName = CommonFileChooser("*",
+									 Fl_Native_File_Chooser::BROWSE_SAVE_FILE,
 									 "Save File Select");
 
 		if(fileName.length() == 0) break;
@@ -826,13 +846,14 @@ bool fk_ShapeViewer::MenuSelect(void)
 		if(solid->writeSTLFile(fileName) == false) {
 			fl_alert("%s: Can't Write.", fileName.c_str());
 		}
-
-		// ModelInit(0, &localSolid);
 		*/
+		// ModelInit(0, &localSolid);
+
 		break;
 
 	  case FK_SV_GUI_IMAGESNAP:
-		fileName = CommonFileChooser("*", Fl_File_Chooser::CREATE,
+		fileName = CommonFileChooser("*",
+									 Fl_Native_File_Chooser::BROWSE_SAVE_FILE,
 									 "Save Image File Select");
 
 		if(fileName.length() == 0) break;
@@ -868,8 +889,10 @@ bool fk_ShapeViewer::MenuSelect(void)
 	  case FK_SV_GUI_AXISDRAW:
 		if(globalMenuValue == true) {
 			scene.entryModel(&axisModel);
+			axisFlag = true;
 		} else {
 			scene.removeModel(&axisModel);
+			axisFlag = false;
 		}
 		break;
 
@@ -896,9 +919,9 @@ bool fk_ShapeViewer::MenuSelect(void)
 					   fk_StrPrintf("%lf", shininess).c_str());
 		if(str == NULL) break;
 		shininess = atof(str);
-		if(shininess >= 1.0 || shininess <= 128.0) {
-			for(i = 0; i < getModelNum(); i++) {
-				polyMaterial[i]->setShininess(shininess);
+		if(shininess >= 1.0 && shininess <= 128.0) {
+			for(j = 0; j < static_cast<_st>(getModelNum()); j++) {
+				polyMaterial[j]->setShininess(shininess);
 			}
 		}
 		SetAllMaterial();
@@ -939,7 +962,7 @@ void fk_ShapeViewer::MovePosition(double argX, double argY, double argZ)
 {
 	fk_Matrix		mat;
 	fk_Vector		orgVec(argX, argY, argZ), vec;
-	unsigned int	i;
+	_st				i;
 
 	mat = parentModel.getInvMatrix();
 	vec = mat * orgVec;
@@ -954,18 +977,18 @@ void fk_ShapeViewer::MovePosition(double argX, double argY, double argZ)
 
 void fk_ShapeViewer::DragShape(void)
 {
-	double	oldX, oldY;
+	double		tmpX, tmpY;
 
 	if(viewWin == NULL) return;
 	if(viewWin->getMouseStatus(FK_MOUSE1) == true) {
 		moveFlag = true;
-		oldX = mouseX;
-		oldY = mouseY;
+		double oldX = mouseX;
+		double oldY = mouseY;
 		viewWin->getMousePosition(&mouseX, &mouseY);
 		if(oldMoveFlag == true) {
-			MovePosition(double(mouseX - oldX)*720.0/double(fkWinSize.h),
-						 double(oldY - mouseY)*720.0/double(fkWinSize.h),
-						 0.0);
+			tmpX = static_cast<double>(mouseX - oldX)*720.0/static_cast<double>(fkWinSize.h);
+			tmpY = static_cast<double>(oldY - mouseY)*720.0/static_cast<double>(fkWinSize.h);
+			MovePosition(tmpX, tmpY, 0.0);
 		}
 	} else {
 		moveFlag = false;
@@ -1097,11 +1120,11 @@ void fk_ShapeViewer::setDrawMode(fk_DrawMode argMode)
 
 void fk_ShapeViewer::setDrawMode(int argID, fk_DrawMode argMode)
 {
-	int			trueID;
+	_st			trueID;
 	fk_Model	*model;
 
 	if(IDMap.find(argID) == IDMap.end()) return;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 	model = modelArray[trueID];
 	model->setDrawMode(argMode);
 	return;
@@ -1109,12 +1132,12 @@ void fk_ShapeViewer::setDrawMode(int argID, fk_DrawMode argMode)
 
 void fk_ShapeViewer::SetDrawMode(void)
 {
-	unsigned int	i;
+	_st				i;
 	Fl_Menu_Item	*mP, *mE, *mV;
 
-	mP = (Fl_Menu_Item *)(gui->menuBar->menu() + 11);
-	mE = (Fl_Menu_Item *)(gui->menuBar->menu() + 12);
-	mV = (Fl_Menu_Item *)(gui->menuBar->menu() + 13);
+	mP = const_cast<Fl_Menu_Item *>(gui->menuBar->menu() + 9);
+	mE = const_cast<Fl_Menu_Item *>(gui->menuBar->menu() + 10);
+	mV = const_cast<Fl_Menu_Item *>(gui->menuBar->menu() + 11);
 
 	mP->flags = mE->flags = mV->flags = FL_MENU_TOGGLE;
 
@@ -1137,6 +1160,17 @@ void fk_ShapeViewer::SetDrawMode(void)
 	return;
 }
 
+void fk_ShapeViewer::setBlendStatus(bool argMode)
+{
+	scene.setBlendStatus(argMode);
+	return;
+}
+
+bool fk_ShapeViewer::getBlendStatus(void)
+{
+	return scene.getBlendStatus();
+}
+
 void fk_ShapeViewer::setFrameMode(fk_FrameMode argMode)
 {
 	if(viewWin == NULL) return;
@@ -1173,8 +1207,8 @@ void fk_ShapeViewer::setHead(double argVal)
 	int		div;
 	double	trueVal;
 
-	div = int(argVal / (2.0*FK_PI));
-	trueVal = argVal - double(div)*(2.0*FK_PI);
+	div = static_cast<int>(argVal / (2.0*FK_PI));
+	trueVal = argVal - static_cast<double>(div)*(2.0*FK_PI);
 	if(trueVal >= FK_PI) {
 		trueVal -= 2.0*FK_PI;
 	} else if(trueVal <= -FK_PI) {
@@ -1191,8 +1225,8 @@ void fk_ShapeViewer::setPitch(double argVal)
 	int		div;
 	double	trueVal;
 
-	div = int(argVal / (2.0*FK_PI));
-	trueVal = argVal - double(div)*(2.0*FK_PI);
+	div = static_cast<int>(argVal / (2.0*FK_PI));
+	trueVal = argVal - static_cast<double>(div)*(2.0*FK_PI);
 	if(trueVal >= FK_PI) {
 		trueVal -= 2.0*FK_PI;
 	} else if(trueVal <= -FK_PI) {
@@ -1209,8 +1243,8 @@ void fk_ShapeViewer::setBank(double argVal)
 	int		div;
 	double	trueVal;
 
-	div = int(argVal / (2.0*FK_PI));
-	trueVal = argVal - double(div)*(2.0*FK_PI);
+	div = static_cast<int>(argVal / (2.0*FK_PI));
+	trueVal = argVal - static_cast<double>(div)*(2.0*FK_PI);
 	if(trueVal >= FK_PI) {
 		trueVal -= 2.0*FK_PI;
 	} else if(trueVal <= -FK_PI) {
@@ -1235,13 +1269,30 @@ void fk_ShapeViewer::setAxisScale(double argVal)
 	gui->axisRoller->value(log10(argVal));
 }
 
+void fk_ShapeViewer::setAxisMode(bool argMode)
+{
+	Fl_Menu_Item		*mA;
+
+	mA = const_cast<Fl_Menu_Item *>(gui->menuBar->menu() + 12);
+	mA->flags = FL_MENU_TOGGLE;
+	if(argMode == true) {
+		axisFlag = true;
+		scene.entryModel(&axisModel);
+		mA->flags |= FL_MENU_VALUE;
+	} else {
+		axisFlag = false;
+		scene.removeModel(&axisModel);
+	}
+	return;
+}
+
 void fk_ShapeViewer::setPosition(int argID, fk_Vector argPos)
 {
-	int			trueID;
+	_st			trueID;
 	fk_Model	*model;
 
 	if(IDMap.find(argID) == IDMap.end()) return;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 	model = modelArray[trueID];
 	model->glMoveTo(argPos);
 	return;
@@ -1258,10 +1309,10 @@ void fk_ShapeViewer::setPosition(int argID,
 
 void fk_ShapeViewer::setMaterial(int argID, fk_Material argMat)
 {
-	int		trueID;
+	_st		trueID;
 
 	if(IDMap.find(argID) == IDMap.end()) return;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 
 	*polyMaterial[trueID] = argMat;
 	SetAllMaterial();
@@ -1270,10 +1321,10 @@ void fk_ShapeViewer::setMaterial(int argID, fk_Material argMat)
 
 void fk_ShapeViewer::setEdgeColor(int argID, fk_Color argCol)
 {
-	int		trueID;
+	_st		trueID;
 
 	if(IDMap.find(argID) == IDMap.end()) return;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 
 	*edgeColor[trueID] = argCol;
 	SetAllMaterial();
@@ -1283,10 +1334,10 @@ void fk_ShapeViewer::setEdgeColor(int argID, fk_Color argCol)
 
 void fk_ShapeViewer::setVertexColor(int argID, fk_Color argCol)
 {
-	int		trueID;
+	_st		trueID;
 
 	if(IDMap.find(argID) == IDMap.end()) return;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 
 	*vertexColor[trueID] = argCol;
 	SetAllMaterial();
@@ -1295,11 +1346,11 @@ void fk_ShapeViewer::setVertexColor(int argID, fk_Color argCol)
 
 void fk_ShapeViewer::setAngle(int argID, fk_Angle argAngle)
 {
-	int			trueID;
+	_st			trueID;
 	fk_Model	*model;
 
 	if(IDMap.find(argID) == IDMap.end()) return;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 	model = modelArray[trueID];
 	model->glAngle(argAngle);
 	return;
@@ -1316,11 +1367,11 @@ void fk_ShapeViewer::setAngle(int argID,
 
 void fk_ShapeViewer::setVec(int argID, fk_Vector argVec)
 {
-	int			trueID;
+	_st			trueID;
 	fk_Model	*model;
 
 	if(IDMap.find(argID) == IDMap.end()) return;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 	model = modelArray[trueID];
 	model->glVec(argVec);
 	return;
@@ -1336,11 +1387,11 @@ void fk_ShapeViewer::setVec(int argID, double argX, double argY, double argZ)
 
 void fk_ShapeViewer::setUpvec(int argID, fk_Vector argVec)
 {
-	int			trueID;
+	_st			trueID;
 	fk_Model	*model;
 
 	if(IDMap.find(argID) == IDMap.end()) return;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 	model = modelArray[trueID];
 	model->glUpvec(argVec);
 	return;
@@ -1356,11 +1407,11 @@ void fk_ShapeViewer::setUpvec(int argID, double argX, double argY, double argZ)
 
 void fk_ShapeViewer::setLineWidth(int argID, double argW)
 {
-	int			trueID;
+	_st			trueID;
 	fk_Model	*model;
 
 	if(IDMap.find(argID) == IDMap.end()) return;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 	model = modelArray[trueID];
 	model->setWidth(argW);
 	return;
@@ -1368,11 +1419,11 @@ void fk_ShapeViewer::setLineWidth(int argID, double argW)
 
 void fk_ShapeViewer::setPointSize(int argID, double argS)
 {
-	int			trueID;
+	_st			trueID;
 	fk_Model	*model;
 
 	if(IDMap.find(argID) == IDMap.end()) return;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 	model = modelArray[trueID];
 	model->setSize(argS);
 	return;
@@ -1380,7 +1431,7 @@ void fk_ShapeViewer::setPointSize(int argID, double argS)
 
 int fk_ShapeViewer::getModelNum(void)
 {
-	return int(modelArray.size());
+	return static_cast<int>(modelArray.size());
 }
 
 fk_Shape * fk_ShapeViewer::getShape(int argID)
@@ -1389,12 +1440,12 @@ fk_Shape * fk_ShapeViewer::getShape(int argID)
 		return(NULL);
 	}
 
-	return modelArray[IDMap[argID]]->getShape();
+	return modelArray[static_cast<_st>(IDMap[argID])]->getShape();
 }
 
 fk_DrawMode fk_ShapeViewer::getDrawMode(void)
 {
-	if(modelArray.size() == 0) {
+	if(modelArray.empty() == true) {
 		return FK_NONEMODE;
 	}
 
@@ -1403,11 +1454,11 @@ fk_DrawMode fk_ShapeViewer::getDrawMode(void)
 
 fk_DrawMode fk_ShapeViewer::getDrawMode(int argID)
 {
-	int			trueID;
+	_st			trueID;
 	fk_Model	*model;
 
 	if(IDMap.find(argID) == IDMap.end()) return FK_NONEMODE;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 	model = modelArray[trueID];
 	return model->getDrawMode();
 }
@@ -1455,11 +1506,16 @@ double fk_ShapeViewer::getAxisScale(void)
 	return pow(10.0, gui->axisRoller->value());
 }
 
+bool fk_ShapeViewer::getAxisMode(void)
+{
+	return axisFlag;
+}
+
 fk_Vector fk_ShapeViewer::getCenter(void)
 {
 	fk_Vector	dummy(0.0, 0.0, 0.0);
 
-	if(modelArray.size() == 0) {
+	if(modelArray.empty() == true) {
 		return dummy;
 	}
 
@@ -1468,22 +1524,22 @@ fk_Vector fk_ShapeViewer::getCenter(void)
 
 double fk_ShapeViewer::getLineWidth(int argID)
 {
-	int			trueID;
+	_st			trueID;
 	fk_Model	*model;
 
 	if(IDMap.find(argID) == IDMap.end()) return -1.0;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 	model = modelArray[trueID];
 	return model->getWidth();
 }
 
 double fk_ShapeViewer::getPointSize(int argID)
 {
-	int			trueID;
+	_st			trueID;
 	fk_Model	*model;
 
 	if(IDMap.find(argID) == IDMap.end()) return -1.0;
-	trueID = IDMap[argID];
+	trueID = static_cast<_st>(IDMap[argID]);
 	model = modelArray[trueID];
 	return model->getWidth();
 }
