@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -36,7 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -77,14 +77,17 @@
 #include <FL/Fl.H>
 #include <FK/Error.H>
 
+#ifdef _FREEBSD_
+#include <sys/resource.h>
+#endif
+
 int fk_Window::drawWindow(bool argDrawMode)
 {
-	unsigned long			time;
 	const unsigned long		ONE_FRAME_TIME = 25;
 	Fl_Window				*pWin;
 
-	pWin = (Fl_Window *)this->parent();
-	if(pWin == (Fl_Window *)NULL) return 0;
+	pWin = static_cast<Fl_Window *>(this->parent());
+	if(pWin == NULL) return 0;
 	// rita_ext: ESC キー抑制
 	/*
 	if(Fl::event_inside(pWin) != 0) {
@@ -94,10 +97,12 @@ int fk_Window::drawWindow(bool argDrawMode)
 
 	if(argDrawMode == true) {
 		if(frameMode != FK_DEFAULT_FRAME) {
+			unsigned long time;
+
 			frameTime = getNow();
 
 			if((frameMode & FK_SKIP_FRAME) != FK_DEFAULT_FRAME) {
-				time = prevTime + frameInterval * (unsigned long)skipCount;
+				time = prevTime + frameInterval * static_cast<unsigned long>(skipCount);
 				if(time < frameTime) {
 					skipCount++;
 					return 1;
@@ -109,7 +114,7 @@ int fk_Window::drawWindow(bool argDrawMode)
 			if((frameMode & FK_WAIT_FRAME) != FK_DEFAULT_FRAME) {
 				time = prevTime + frameInterval;
 				while(time > frameTime + ONE_FRAME_TIME) {
-					Fl::wait(double(time - frameTime - ONE_FRAME_TIME)/1000.0);
+					Fl::wait(static_cast<double>(time - frameTime - ONE_FRAME_TIME)/1000.0);
 					frameTime = getNow();
 				}
 			}
@@ -144,7 +149,7 @@ void fk_Window::resizeWindow(int argX, int argY, int argW, int argH)
 
 bool fk_Window::getKeyStatus(char argKey, bool argInsideFlag)
 {
-	if(argInsideFlag == true && Fl::event_inside(this) == 0) {
+	if(argInsideFlag == true && IsInsideWindow() == false) {
 		return false;
 	}
 
@@ -156,7 +161,7 @@ bool fk_Window::getKeyStatus(char argKey, bool argInsideFlag)
 
 bool fk_Window::getSpecialKeyStatus(fk_SpecialKey argKey, bool argInsideFlag)
 {
-	if(argInsideFlag == true && Fl::event_inside(this) == 0) {
+	if(argInsideFlag == true && IsInsideWindow() == false) {
 		return false;
 	}
 
@@ -266,8 +271,10 @@ bool fk_Window::getSpecialKeyStatus(fk_SpecialKey argKey, bool argInsideFlag)
 
 char fk_Window::getLastKey(void)
 {
-	if(Fl::event_inside(this) != 0) {
-		lastKey = Fl::event_key();
+	Fl_Group	*mainWin = GetInhParentWindow();
+
+	if(Fl::focus() == mainWin) {
+		lastKey = char(Fl::event_key());
 	}
 
 	return lastKey;
@@ -276,28 +283,42 @@ char fk_Window::getLastKey(void)
 void fk_Window::getMousePosition(int *argX, int *argY, bool argInsideFlag)
 {
 	if(argInsideFlag == true && IsInsideWindow() == false) {
-
 		*argX = *argY = -1;
 		return;
 	}
 
 	*argX = Fl::event_x() - GLWinXPosition;
 	*argY = Fl::event_y() - GLWinYPosition;
+
 	return;
 }
 
+Fl_Group * fk_Window::GetInhParentWindow(void)
+{
+	Fl_Group	*mainWin = this;
+
+	while(mainWin->parent() != NULL) {
+		mainWin = mainWin->parent();
+	}
+
+	return mainWin;
+}
+
 bool fk_Window::IsInsideWindow(void)
 {
 	Fl_Group		*mainWin;
 	int				posX, posY;
 
-	mainWin = this;
-	while(mainWin->parent() != (Fl_Group *)NULL) {
-		mainWin = mainWin->parent();
-	}
+	mainWin = GetInhParentWindow();
 
+#ifdef WIN32
+	Fl::get_mouse(posX, posY);
+	posX -= mainWin->x();
+	posY -= mainWin->y();
+#else
 	posX = Fl::event_x_root() - mainWin->x();
 	posY = Fl::event_y_root() - mainWin->y();
+#endif
 
 	if(posX < GLWinXPosition || posX >= GLWinXPosition + GLWinWSize ||
 	   posY < GLWinYPosition || posY >= GLWinYPosition + GLWinHSize) {
@@ -312,16 +333,19 @@ unsigned long fk_Window::getNow(void)
 
 #if defined(WIN32)
 
-	return (unsigned long)timeGetTime();
+	return static_cast<unsigned long>(timeGetTime());
 
 #else
 
-	struct timeval		tm;
+	struct rusage		tmp_t;
+	struct timeval		tv;
 	unsigned long		retVal;
 
-	gettimeofday(&tm, NULL);
-	retVal = (tm.tv_sec % 16777216) * 1000;
-	retVal += tm.tv_usec/1000;
+	//gettimeofday(&tm, NULL);
+	getrusage(RUSAGE_SELF, &tmp_t);
+	tv = tmp_t.ru_utime;
+	retVal = static_cast<unsigned long>((tv.tv_sec % 16777216) * 1000);
+	retVal += static_cast<unsigned long>(tv.tv_usec/1000);
 	return retVal;
 
 #endif
@@ -399,13 +423,13 @@ fk_FrameMode fk_Window::getFrameMode(void)
 void fk_Window::setFrameInterval(int argInterval)
 {
 	if(argInterval < 0) return;
-	frameInterval = (unsigned long)argInterval;
+	frameInterval = static_cast<unsigned long>(argInterval);
 	return;
 }
 
 int fk_Window::getFrameInterval(void)
 {
-	return (int)frameInterval;
+	return static_cast<int>(frameInterval);
 }
 
 int fk_Window::getSkipFrame(void)
