@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -31,12 +31,12 @@
  *	HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
  *	STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
  *	IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- *	POSSIBILITY OF SUCH DAMAGE. 
+ *	POSSIBILITY OF SUCH DAMAGE.
  *
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -73,13 +73,13 @@
 #include "Window_fltk_D3D.cxx"
 #else
 
+#include <iostream>
 #include <FK/Window.h>
 #include <FK/Image.h>
 #include <FL/Fl.H>
 #include <FK/Error.H>
 #include <FL/Fl_Multi_Browser.H>
 #include <FL/x.H>
-#include <iostream>
 
 using namespace std;
 
@@ -102,6 +102,8 @@ fk_Window::fk_Window(int argX, int argY, int argW, int argH, string argStr)
 	setFrameMode(FK_DEFAULT_FRAME);
 	winNum++;
 
+	stereoMode = false;
+
 	return;
 }
 
@@ -126,6 +128,11 @@ void fk_Window::clearTextureMemory(void)
 	return;
 }
 
+unsigned long fk_Window::getUsingTextureMemory(void)
+{
+	return engine.GetUsingTextureMemory();
+}
+
 void fk_Window::SetPickViewPort(int &argX, int &argY)
 {
 	int		mouseX, mouseY;
@@ -213,11 +220,25 @@ void fk_Window::setOGLStereoMode(bool argFlg)
 {
 	clearTextureMemory();
 	if(argFlg == true) {
+		GLboolean	val = GL_FALSE;
+		Fl_Window	*pWin = dynamic_cast<Fl_Window *>(GetInhParentWindow());
+		if(pWin == NULL) return;
+
+		pWin->show();
 		mode(mode() | FL_STEREO);
+		Fl::check();
+
+		glGetBooleanv(GL_STEREO, &val);
+		if(val == GL_TRUE) {
+			stereoMode = true;
+		} else {
+			setOGLStereoMode(false);
+		}
 	} else {
 		mode(mode() & (~FL_STEREO));
+		Fl::check();
+		stereoMode = false;
 	}
-	stereoMode = argFlg;
 	return;
 }
 
@@ -273,7 +294,7 @@ bool fk_Window::SnapImageGDI(fk_Image *argImage)
 	RECT			rect;
 	unsigned char	*buf = NULL;
 
-	if(argImage == (fk_Image *)NULL) return false;
+	if(argImage == NULL) return false;
 
 	ZeroMemory(&bi, sizeof(bi));
 
@@ -287,7 +308,8 @@ bool fk_Window::SnapImageGDI(fk_Image *argImage)
 
 	HDC hdcScreen = GetDC(NULL);
 	HDC _hdcShot = CreateCompatibleDC(hdcScreen);
-	HBITMAP _bmpShot = CreateDIBSection(NULL, &bi, DIB_RGB_COLORS, (void**)&buf, NULL, 0);
+	HBITMAP _bmpShot = CreateDIBSection(NULL, &bi, DIB_RGB_COLORS,
+										reinterpret_cast<void **>(&buf), NULL, 0);
 	HBITMAP _bmpOld = (HBITMAP)SelectObject(_hdcShot, _bmpShot);
 	BitBlt(_hdcShot, 0, 0, iWidth, iHeight, hdcScreen, rect.left, rect.top, SRCCOPY);
 	ReleaseDC(NULL, hdcScreen);
@@ -296,7 +318,7 @@ bool fk_Window::SnapImageGDI(fk_Image *argImage)
 
 	for(int j = 0; j < iHeight; j++) {
 		for(int k = 0; k < iWidth; k++) {
-			argImage->setRGBA(k, j,  buf[((iHeight-j-1)*iWidth + k)*4+2],
+			argImage->setRGBA(k, j, buf[((iHeight-j-1)*iWidth + k)*4+2],
 									buf[((iHeight-j-1)*iWidth + k)*4+1],
 									buf[((iHeight-j-1)*iWidth + k)*4],
 									buf[((iHeight-j-1)*iWidth + k)*4+3]);
