@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -31,12 +31,12 @@
  *	HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
  *	STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
  *	IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- *	POSSIBILITY OF SUCH DAMAGE. 
+ *	POSSIBILITY OF SUCH DAMAGE.
  *
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
+ *	Copyright (c) 1999-2011, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -69,13 +69,13 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+#include <iostream>
 #include <FK/D3D/Window.h>
 #include <FK/Image.h>
 #include <FL/Fl.h>
 #include <FK/Error.h>
 #include <FL/Fl_Multi_Browser.h>
 #include <FL/x.h>
-#include <iostream>
 
 using namespace std;
 
@@ -147,6 +147,11 @@ void fk_Window::clearTextureMemory(void)
 	return;
 }
 
+unsigned long fk_Window::getUsingTextureMemory(void)
+{
+	return engine.GetUsingTextureMemory();
+}
+
 void fk_Window::SetPickViewPort(bool argFlag, int argPixSize,
 								int &argX, int &argY)
 {
@@ -192,7 +197,7 @@ void fk_Window::draw(void)
 		preInit();
 		engine.D3DStateInit();
 		postInit();
-	}	
+	}
 
 	preDraw();
 	engine.Draw(false);
@@ -302,7 +307,8 @@ bool fk_Window::SnapImageGDI(fk_Image *argImage)
 
 	HDC hdcScreen = GetDC(NULL);
 	HDC _hdcShot = CreateCompatibleDC(hdcScreen);
-	HBITMAP _bmpShot = CreateDIBSection(NULL, &bi, DIB_RGB_COLORS, (void**)&buf, NULL, 0);
+	HBITMAP _bmpShot = CreateDIBSection(NULL, &bi, DIB_RGB_COLORS,
+										reinterpret_cast<void **>(&buf), NULL, 0);
 	HBITMAP _bmpOld = (HBITMAP)SelectObject(_hdcShot, _bmpShot);
 	BitBlt(_hdcShot, 0, 0, iWidth, iHeight, hdcScreen, rect.left, rect.top, SRCCOPY);
 	ReleaseDC(NULL, hdcScreen);
